/** 
 *******************************************************************************
 * @file    bsp.c
 * @brief   Board Support Package. \n
 *          TMPM4KN Evaluation Board.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include <stdio.h>
#include "bsp.h"

#if defined(__BSP_H)
/**
 *  @addtogroup BSP
 *  @{
 */

/** 
 *  @defgroup TMPM4KN_EVAL TMPM4KN Evaluation Board
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_macro TMPM4KN Evaluation Board Private Macro
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_define TMPM4KN Evaluation Board Private Define
 *  @{
 */

/** 
 *  @defgroup ELOSCConfiguration ELOSC Configuration
 *  @brief    ELOSC Configuration.
 *  @{
 */
#define ELOSC_CFG_WARM_UP_TIME  ((uint32_t)(5000))      /*!< Warm up time(us). */
#define ELOSC_CFG_CLOCK         ((uint32_t)(32768))     /*!< Clock(hz).        */

/** 
 *  @}
 */ /* End of group ELOSCConfiguration */

/** 
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_define */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_define TMPM4KN Evaluation Board Private Define
 *  @{
 */

#define BSP_NULL        ((void *)0) /*!< Null Pointer */

/** 
 *  @defgroup  CGWUPLCR  CGWUPLCR Register
 *  @brief     LOSC warming up Register.
 *  @details   Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31:27 | -          |
 *  | 26:12 | WUPTL      |
 *  | 11:8  | WUPTL      |
 *  | 7:2   | -          |
 *  | 1     | WULEF      |
 *  | 0     | WULON      |
 *  @{
 */
/* WUPTL  */
#define CGWUPLCR_WUPTL_HIGH_MASK        ((uint32_t)0x07FFF000)    /*!< WUPTL   :High Bit Mask.  */
/* WULEF  */
#define CGWUPLCR_WULEF_MASK             ((uint32_t)0x00000002)    /*!< WULEF   :Mask.           */
#define CGWUPLCR_WULEF_R_DONE           ((uint32_t)0x00000000)    /*!< WULEF   :[R]  :Done      */
#define CGWUPLCR_WULEF_R_RUNNING        ((uint32_t)0x00000002)    /*!< WULEF   :[R]  :Running   */
/* WULON  */
#define CGWUPLCR_WULON_MASK             ((uint32_t)0x00000001)    /*!< WULON   :Mask.           */
#define CGWUPLCR_WULON_W_ENABLE         ((uint32_t)0x00000001)    /*!< WULON   :[W]  :Enable     */
/** 
 *  @}
 */ /* End of group CGWUPLCR */

/** 
 *  @defgroup  RLMLOSCCR  RLMLOSCCR Register
 *  @brief     LOSC Control Register.
 *  @details   Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 7:2   | -          |
 *  | 1     | -          |
 *  | 0     | XTEN       |
 *  @{
 */
/* XTEN */
#define RLMLOSCCR_XTEN_RW_DISABLE       ((uint8_t)0x00)    /*!< XTEN :[R/W]  :Disable  */
#define RLMLOSCCR_XTEN_RW_ENABLE        ((uint8_t)0x01)    /*!< XTEN :[R/W]  :Enable   */
/** 
 *  @}
 */ /* End of group RLMLOSCCR */

/** 
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_define TMPM4KN Evaluation Board Private Define
 *  @{
 */
/*! @enum dnfint_t
    @brief Select External INT
 */
typedef enum
{
    DNFINT_INT00 = 0,            /*!< INT00 */
    DNFINT_INT01A,               /*!< INT01a */
    DNFINT_INT01B,               /*!< INT01b */
    DNFINT_INT02A,               /*!< INT02a */
    DNFINT_INT02B,               /*!< INT02b */
    DNFINT_INT03A,               /*!< INT03a */
    DNFINT_INT03B,               /*!< INT03b */
    DNFINT_INT04A,               /*!< INT04a */
    DNFINT_INT04B,               /*!< INT04b */
    DNFINT_INT05A11B,            /*!< INT05a/INT11b */
    DNFINT_INT05B,               /*!< INT05b */
    DNFINT_INT06A,               /*!< INT06a */
    DNFINT_INT06B,               /*!< INT06b */
    DNFINT_INT07A,               /*!< INT07a */
    DNFINT_INT07B,               /*!< INT07b */
    DNFINT_INT08A,               /*!< INT08a */
    DNFINT_INT08B,               /*!< INT08b */
    DNFINT_INT09,                /*!< INT09 */
    DNFINT_INT10,                /*!< INT10 */
    DNFINT_INT11A,               /*!< INT11a */
    DNFINT_INT12,                /*!< INT12 */
    DNFINT_INT13,                /*!< INT13 */
    DNFINT_INT14A,               /*!< INT14a */
    DNFINT_INT14B,               /*!< INT14b */
    DNFINT_INT15,                /*!< INT15 */
    DNFINT_INT16A,               /*!< INT16a */
    DNFINT_INT16B,               /*!< INT16b */
    DNFINT_INT17A,               /*!< INT17a */
    DNFINT_INT17B,               /*!< INT17b */
    DNFINT_INT18A,               /*!< INT18a */
    DNFINT_INT18B,               /*!< INT18b */
    DNFINT_INT21,                /*!< INT21 */
}dnfint_t;

/** 
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_define */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_typedef TMPM4KN Evaluation Board Private Typedef
 *  @{
 */

/*----------------------------------*/
/** 
 * @brief   Timer Information Table.
 * @details 
 * | [][0] | [][1] | [][2] |
 * | :---  | :---  | :---  |
 * | CH    | Type  | IRQ   |
*/
/*----------------------------------*/
typedef struct
{
    uint32_t  ch;       /*!< channel  */
    uint32_t  type;     /*!< type     */
    IRQn_Type irq;      /*!< irq Type */
} bsp_timer_info_t;

/*----------------------------------*/
/** 
 * @brief   Output Pulse Information Table.
 * @details 
 * | [][0] | [][1] | [][2] |
 * | :---  | :---  | :---  |
 * | CH    | Type  | IRQ   |
*/
/*----------------------------------*/
typedef struct
{
    uint32_t  ch;       /*!< channel  */
    uint32_t  type;     /*!< type     */
    IRQn_Type irq;      /*!< irq Type */
} bsp_output_pulse_info_t;


/**
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_variables TMPM4KN Evaluation Board Private Variables
 *  @{
 */
static gpio_t port;     /*!< Port driver instance. */
static BSPExInt exi;
static cg_t cg;

/*----------------------------------*/
/** 
 * @brief   USB UART TX Information Table.
 * @details 
 * | [][0] | [][1] | [][2] | [][3]  | [][4]         | 
 * | :---  | :---  | :---  | :---   | :---          |
 * | Group | Num   | CH    | DMA CH | Baudrate(bps) |
*/
/*----------------------------------*/
static const uint32_t usbUartTxTbl[BSP_USB_UART_MAX][5] =
{
    {GPIO_PORT_C, GPIO_PORT_0, (uint32_t)(0), (uint32_t)(5), (uint32_t)(115200)},
    {GPIO_PORT_C, GPIO_PORT_4, (uint32_t)(1), (uint32_t)(7), (uint32_t)(115200)},
    {GPIO_PORT_F, GPIO_PORT_0, (uint32_t)(2), (uint32_t)(9), (uint32_t)(115200)},
    {GPIO_PORT_F, GPIO_PORT_3, (uint32_t)(3), (uint32_t)(11), (uint32_t)(115200)}
};

/*----------------------------------*/
/** 
 * @brief   USB UART RX Information Table.
 * @details 
 * | [][0] | [][1] | [][2] | [][3]  | [][4]         | 
 * | :---  | :---  | :---  | :---   | :---          |
 * | Group | Num   | CH    | DMA CH | Baudrate(bps) |
*/
/*----------------------------------*/
static const uint32_t usbUartRxTbl[BSP_USB_UART_MAX][5] =
{
    {GPIO_PORT_C, GPIO_PORT_1, (uint32_t)(0), (uint32_t)(4), (uint32_t)(115200)},
    {GPIO_PORT_C, GPIO_PORT_5, (uint32_t)(1), (uint32_t)(6), (uint32_t)(115200)},
    {GPIO_PORT_F, GPIO_PORT_1, (uint32_t)(2), (uint32_t)(8), (uint32_t)(115200)},
    {GPIO_PORT_F, GPIO_PORT_4, (uint32_t)(3), (uint32_t)(10), (uint32_t)(115200)}
};

/*----------------------------------*/
/** 
 * @brief   TSPI TX Information Table.
 * @details   Detail.
 * | [][0] | [][1] | [][2] | [][3]  | 
 * | :---  | :---  | :---  | :---   |
 * | Group | Num   | CH    | DMA CH |
*/
/*----------------------------------*/
static const uint32_t tspiTxTbl[BSP_TSPI_MAX][4] =
{
    {GPIO_PORT_A, GPIO_PORT_3, (uint32_t)(0), (uint32_t)(1)},
    {GPIO_PORT_G, GPIO_PORT_5, (uint32_t)(1), (uint32_t)(3)}
};

/*----------------------------------*/
/** 
 * @brief   TSPI CLK Information Table.
 * @details   Detail.
 * | [][0] | [][1] | [][2] |
 * | :---  | :---  | :---  |
 * | Group | Num   | CH    |
*/
/*----------------------------------*/
static const uint32_t tspiCLKTbl[BSP_TSPI_MAX][3] =
{
    {GPIO_PORT_A, GPIO_PORT_4, (uint32_t)(0)},
    {GPIO_PORT_G, GPIO_PORT_6, (uint32_t)(1)}
};

/*----------------------------------*/
/** 
 * @brief   TSPI RX Information Table.
 * @details   Detail.
 * | [][0] | [][1] | [][2] | [][3]  | 
 * | :---  | :---  | :---  | :---   |
 * | Group | Num   | CH    | DMA CH |
*/
/*----------------------------------*/
static const uint32_t tspiRxTbl[BSP_TSPI_MAX][4] =
{
    {GPIO_PORT_A, GPIO_PORT_2, (uint32_t)(0), (uint32_t)(0)},
    {GPIO_PORT_G, GPIO_PORT_4, (uint32_t)(1), (uint32_t)(2)}
};
/*-----------------------------------------*/
/* Name        | Pin    | Port |  CN       */
/*-----------------------------------------*/
/* PORT_LED[1] | 30     | PB0  |  5: 28    */
/* PORT_LED[2] | 31     | PB2  |  5: 30    */
/* PORT_LED[3] | 32     | PB4  |  5: 32    */
/* PORT_LED[4] | 33     | PV0  |  5: 34    */
/*-----------------------------------------*/
/*----------------------------------*/
/** 
 * @brief   Port LED Information Table.
 * @details 
 * | [][0] | [][1] |
 * | :---  | :---  |
 * | Group | Num   |
*/
/*----------------------------------*/
static const uint32_t ledTbl[BSP_LED_MAX][2] =
{
    {GPIO_PORT_B, GPIO_PORT_0},
    {GPIO_PORT_B, GPIO_PORT_2},
    {GPIO_PORT_B, GPIO_PORT_4},
    {GPIO_PORT_V, GPIO_PORT_0}
};

/*-----------------------------------------*/
/* Name        | Pin    | Port |  CN       */
/*-----------------------------------------*/
/* PORT_PSW[1] | 65     | PD1  |  10: 65   */
/* PORT_PSW[2] | 64     | PD0  |  10: 64   */
/* PORT_PSW[3] | 05     | PU4  |  09: 05   */
/* PORT_PSW[4] | 06     | PU5  |  09: 06   */
/*-----------------------------------------*/
/*----------------------------------*/
/** 
 * @brief   Push SW Information Table.
 * @details 
 * | [][0] | [][1] |
 * | :---  | :---  |
 * | Group | Num   |
*/
/*----------------------------------*/
static const uint32_t pswTbl[BSP_PSW_MAX][2] =
{
    {GPIO_PORT_D, GPIO_PORT_1},
    {GPIO_PORT_D, GPIO_PORT_0},
    {GPIO_PORT_U, GPIO_PORT_4},
    {GPIO_PORT_U, GPIO_PORT_5}
};

/*-----------------------------------------*/
/* Name        | Pin    | Port |  CN       */
/*-----------------------------------------*/
/* PORT_SSW[3] | 73     | PG3  |  10: 73   */
/* PORT_SSW[2] | 74     | PG4  |  10: 74   */
/* PORT_SSW[1] | 75     | PG5  |  10: 75   */
/* PORT_SSW[0] | 76     | PG6  |  10: 76   */
/*-----------------------------------------*/
/*----------------------------------*/
/** 
 * @brief   Slide SW Information Table.
 * @details 
 * | [][0] | [][1] |
 * | :---  | :---  |
 * | Group | Num   |
*/
/*----------------------------------*/
static const uint32_t sswTbl[BSP_PSW_MAX][2] =
{
    {GPIO_PORT_G, GPIO_PORT_3},
    {GPIO_PORT_G, GPIO_PORT_4},
    {GPIO_PORT_G, GPIO_PORT_5},
    {GPIO_PORT_G, GPIO_PORT_6}
};

/*----------------------------------*/
/** 
 * @brief   Timer Information Table.
*/
/*----------------------------------*/
static const bsp_timer_info_t timerTbl[BSP_TIMER_MAX] =
{
    {(uint32_t)0, (uint32_t)T32A_TIMERA, INTT32A00AC_IRQn},
    {(uint32_t)3, (uint32_t)T32A_TIMERB, INTT32A03B_IRQn}
};

/*----------------------------------*/
/** 
 * @brief   Output Pulse Information Table.
*/
/*----------------------------------*/
static const bsp_output_pulse_info_t pulseOutTbl[BSP_OUT_PULSE_SAMPLE_MAX] =
{
    {(uint32_t)3, (uint32_t)T32A_TIMERA, INTT32A03AC_IRQn},
    {(uint32_t)3, (uint32_t)T32A_TIMERB, INTT32A03B_IRQn}
};


/*-----------------------------------------*/
/* Name        | Pin    | Port |  CN       */
/*-----------------------------------------*/
/* PORT_AIN[0] | 45     | PJ0  |  09: 45   */
/*-----------------------------------------*/
/*----------------------------------*/
/** 
 * @brief   ADC Information Table.
 * @details 
 * | [][0] | [][1] | [][2]    | [][3]  | [][4]  |
 * | :---  | :---  | :---     | :---   | :---   |
 * | Group | Num   | ADIN CH  | ADC CH | DMA CH |
*/
/*----------------------------------*/
static const uint32_t adcTbl[BSP_ADC_MAX][5] =
{
    {GPIO_PORT_J, GPIO_PORT_0, (uint32_t)(0), (uint32_t)(0), (uint32_t)(14) }
};

/*----------------------------------*/
/** 
 * @brief   DNF Information Table.
 * @details   Detail.
 * | [][0] | 
 * | :---  | 
 * | Num | 
*/
/*-----------------------------------------*/
static const dnfint_t dnfTbl[BSP_DNF_MAX][1] =
{
#if defined(TMPM4KHA)
    {DNFINT_INT13},
#else
    {DNFINT_INT21},
#endif
};

/**
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_variables */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TMPM4KN_EVAL_Private_fuctions TMPM4KN Evaluation Board Private Fuctions
 *  @{
 */
static void bsp_error(void);
static void port_initialize(void);
static void port_finalize(void);

/*--------------------------------------------------*/
/** 
  * @brief  Error Hook
  * @param  -
  * @return -
  * @retval -
  * @note   for debug
  */
/*--------------------------------------------------*/
static void bsp_error(void)
{
#ifdef BSP_DEBUG
    while(1)
    {
        __NOP();
    }
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  Port Initialize.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void port_initialize(void)
{
    /*===============================================================================*/
    /*  [Port A]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PADATA | PACR | PAFRn | PAOD | PAPUP | PADN | PAIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PA0  | TSPI0CSIN | I   | 0      | 0    | PAFR1 | 0    | 0     | 0    | 1     */
    /*  PA1  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PA2  | TSPI0RXD  | I   | 0      | 0    | PAFR1 | 0    | 0     | 0    | 1     */
    /*  PA3  | TSPI0TXD  | O   | 0      | 1    | PAFR1 | 0    | 0     | 0    | 0     */
    /*  PA4  | TSPI0SCK  | O   | 0      | 1    | PAFR1 | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pa_instance = TSB_PA;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_A) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PA0 -*/
#if defined(TMPM4KNA) || defined(TMPM4KMA) || defined(TMPM4MNA) || defined(TMPM4MMA)
    if (gpio_func(&port, GPIO_PORT_A, GPIO_PORT_0, (uint32_t)GPIO_PA0_TSPI0CSIN, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
         bsp_error();
    }
#endif
    /*- PA1 -*/
    /* Use reset value.  */
    /*- PA2 -*/
    if (gpio_func(&port, GPIO_PORT_A, GPIO_PORT_2, (uint32_t)GPIO_PA2_TSPI0RXD, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PA3 -*/
    if (gpio_func(&port, GPIO_PORT_A, GPIO_PORT_3, (uint32_t)GPIO_PA3_TSPI0TXD, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#ifdef TSPI_SLAVE
    /*- PA4 -*/
    if (gpio_func(&port, GPIO_PORT_A, GPIO_PORT_4, (uint32_t)GPIO_PA4_TSPI0SCK, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#else
    /*- PA4 -*/
    if (gpio_func(&port, GPIO_PORT_A, GPIO_PORT_4, (uint32_t)GPIO_PA4_TSPI0SCK, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif

    /*===============================================================================*/
    /*  [Port B]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PBDATA | PBCR | PBFRn | PBOD | PBPUP | PBDN | PBIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PB0  |PORT_LED[1]| O   | 0      | 1    | 0     | 0    | 0     | 0    | 0     */
    /*  PB1  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PB2  |PORT_LED[2]| O   | 0      | 1    | 0     | 0    | 0     | 0    | 0     */
    /*  PB3  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PB4  |PORT_LED[3]| O   | 0      | 1    | 0     | 0    | 0     | 0    | 0     */
    /*  PB5  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PB6  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PB7  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pb_instance = TSB_PB;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_B) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PB0 -*/
    if (gpio_func(&port, GPIO_PORT_B, GPIO_PORT_0, (uint32_t)GPIO_PB0_OUTPUT, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PB1 -*/
    /* Use reset value.  */
    /*- PB2 -*/
    if (gpio_func(&port, GPIO_PORT_B, GPIO_PORT_2, (uint32_t)GPIO_PB2_OUTPUT, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PB3 -*/
    /* Use reset value.  */
    /*- PB4 -*/
    if (gpio_func(&port, GPIO_PORT_B, GPIO_PORT_4, (uint32_t)GPIO_PB4_OUTPUT, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PB5 -*/
    /* Use reset value.  */
    /*- PB6 -*/
    /* Use reset value.  */
    /*- PB7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port C]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PCDATA | PCCR | PCFRn | PCOD | PCPUP | PCDN | PCIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PC0  | UT0TXDA   | O   | 0      | 1    | PCFR1 | 0    | 0     | 0    | 0     */
    /*  PC1  | UT0RXD    | I   | 0      | 0    | PCFR1 | 0    | 0     | 0    | 1     */
    /*  PC2  | TSPI0CS0  | O   | 0      | 1    | PCFR3 | 0    | 0     | 0    | 0     */
    /*  PC3  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PC4  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PC5  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PC6  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pc_instance = TSB_PC;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_C) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PC0 -*/
    gpio_write_bit(&port, GPIO_PORT_C, GPIO_PORT_0, GPIO_Mode_DATA, GPIO_PIN_SET);
    if (gpio_func(&port, GPIO_PORT_C, GPIO_PORT_0, (uint32_t)GPIO_PC0_UT0TXDA, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PC1 -*/
    if (gpio_func(&port, GPIO_PORT_C, GPIO_PORT_1, (uint32_t)GPIO_PC1_UT0RXD, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#if !defined(TMPM4KHA)
    /*- PC2 -*/
    if (gpio_func(&port, GPIO_PORT_C, GPIO_PORT_2, (uint32_t)GPIO_PC2_TSPI0CS0, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PC3 -*/
    /* Use reset value.  */
    /*- PC4 -*/
    /* Use reset value.  */
    /*- PC5 -*/
    /* Use reset value.  */
    /*- PC6 -*/
    /* Use reset value.  */
    /*- PC7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port D]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PDDATA | PDCR | PDFRn | PDOD | PDPUP | PDDN | PDIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PD0  |PORT_PSW[2]| -   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PD1  |PORT_PSW[1]| -   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PD2  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PD3  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PD4  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PD5  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
#if defined(TMPM4KNA) || defined(TMPM4MNA)
    port.p_pd_instance = TSB_PD;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_D) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PD0 -*/
    if (gpio_func(&port, GPIO_PORT_D, GPIO_PORT_0, (uint32_t)GPIO_PD0_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PD1 -*/
    if (gpio_func(&port, GPIO_PORT_D, GPIO_PORT_1, (uint32_t)GPIO_PD1_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PD2 -*/
    /* Use reset value.  */
    /*- PD3 -*/
    /* Use reset value.  */
    /*- PD4 -*/
    /* Use reset value.  */
    /*- PD5 -*/
    /* Use reset value.  */
#endif

    /*===============================================================================*/
    /*  [Port E]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PEDATA | PECR | PEFRn | PEOD | PEPUP | PEDN | PEIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PE0  | CANATX    | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PE1  | CANARX    | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PE2  | T32A03OUTA| O   | 0      | 1    | PEFR4 | 0    | 0     | 0    | 0     */
    /*  PE3  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PE4  | T32A03INB0| -   | 0      | 0    | PEFR4 | 0    | 0     | 0    | 1     */
    /*  PE5  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PE6  | T32A03OUTB| O   | 0      | 1    | PEFR4 | 0    | 0     | 0    | 0     */
    /*  PE7  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pe_instance = TSB_PE;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_E) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PE0 -*/
#if defined(TMPM4MNA) || defined(TMPM4MMA) || defined(TMPM4MLA)
    if (gpio_func(&port, GPIO_PORT_E, GPIO_PORT_0, (uint32_t)GPIO_PE0_CANATX, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PE1 -*/
#if defined(TMPM4MNA) || defined(TMPM4MMA) || defined(TMPM4MLA)
    if (gpio_func(&port, GPIO_PORT_E, GPIO_PORT_1, (uint32_t)GPIO_PE1_CANARX, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PE2 -*/
    if (gpio_func(&port, GPIO_PORT_E, GPIO_PORT_2, (uint32_t)GPIO_PE2_T32A03OUTA, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PE3 -*/
    /* Use reset value.  */
    /*- PE4 -*/
#if !defined(TMPM4KHA)
    if (gpio_func(&port, GPIO_PORT_E, GPIO_PORT_4, (uint32_t)GPIO_PE4_T32A03INB0, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PE5 -*/
    /* Use reset value.  */
    /*- PE6 -*/
#if !defined(TMPM4KHA)
    if (gpio_func(&port, GPIO_PORT_E, GPIO_PORT_6, (uint32_t)GPIO_PE6_T32A03OUTB, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PE7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port F]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PFDATA | PFCR | PFFRn | PFOD | PFPUP | PFDN | PFIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PF0  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PF1  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PF2  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PF3  | T32A01INA0| I   | 0      | 0    | PFFR4 | 0    | 0     | 0    | 1     */
    /*  PF4  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PF5  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PF6  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PF7  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pf_instance = TSB_PF;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_F) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PF0 -*/
    /* Use reset value.  */
    /*- PF1 -*/
    /* Use reset value.  */
    /*- PF2 -*/
    /* Use reset value.  */
    /*- PF3 -*/
#if defined(TMPM4KNA) || defined(TMPM4KMA) || defined(TMPM4MNA) || defined(TMPM4MMA)
    if (gpio_func(&port, GPIO_PORT_F, GPIO_PORT_3, (uint32_t)GPIO_PF3_T32A01INA0, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PF4 -*/
    /* Use reset value.  */
    /*- PF5 -*/
    /* Use reset value.  */
    /*- PF6 -*/
    /* Use reset value.  */
    /*- PF7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port G]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PGDATA | PGCR | PGFRn | PGOD | PGPUP | PGDN | PGIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PG0  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PG1  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PG2  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PG3  |PORT_SSW[1]| I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PG4  |PORT_SSW[2]| I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PG5  |PORT_SSW[3]| I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PG6  |PORT_SSW[4]| I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PG7  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pg_instance = TSB_PG;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_G) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PG0 -*/
    /* Use reset value.  */
    /*- PG1 -*/
    /* Use reset value.  */
    /*- PG2 -*/
    /* Use reset value.  */
#if !defined(TMPM4KHA)
    /*- PG3 -*/
    if (gpio_func(&port, GPIO_PORT_G, GPIO_PORT_3, (uint32_t)GPIO_PG3_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PG4 -*/
    if (gpio_func(&port, GPIO_PORT_G, GPIO_PORT_4, (uint32_t)GPIO_PG4_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PG5 -*/
    if (gpio_func(&port, GPIO_PORT_G, GPIO_PORT_5, (uint32_t)GPIO_PG5_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PG6 -*/
    if (gpio_func(&port, GPIO_PORT_G, GPIO_PORT_6, (uint32_t)GPIO_PG6_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
    /*- PG7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port H]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PHDATA | PHCR | PHFRn | PHOD | PHPUP | PHDN | PHIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PH0  | X1        | I   | 0      | N/A  | N/A   | N/A  | N/A   | 0    | 0     */
    /*  PH1  | X2        | O   | 0      | N/A  | N/A   | N/A  | N/A   | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_ph_instance = TSB_PH;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_H) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PH0 -*/
    if (gpio_func(&port, GPIO_PORT_H, GPIO_PORT_0, (uint32_t)GPIO_PH0_X1, GPIO_PIN_NOTINOUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PH1 -*/
    if (gpio_func(&port, GPIO_PORT_H, GPIO_PORT_1, (uint32_t)GPIO_PH1_X2, GPIO_PIN_NOTINOUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }

    /*===============================================================================*/
    /*  [Port J]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PJDATA | PJCR | PJFRn | PJOD | PJPUP | PJDN | PJIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PJ0  | AINC00    | I   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PJ1  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PJ2  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PJ3  | -         | -   | 0      | 1    | N/A   | 0    | 0     | 0    | 0     */
    /*  PJ4  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PJ5  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
#if !defined(TMPM4KHA)
    port.p_pj_instance = TSB_PJ;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_J) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PJ0 -*/
    if (gpio_func(&port, GPIO_PORT_J, GPIO_PORT_0, (uint32_t)GPIO_PJ0_AINC00, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PJ1 -*/
    /* Use reset value.  */
    /*- PJ2 -*/
    /* Use reset value.  */
    /*- PJ3 -*/
    /* Use reset value.  */
    /*- PJ4 -*/
    /* Use reset value.  */
    /*- PJ5 -*/
    /* Use reset value.  */
#endif
    /*===============================================================================*/
    /*  [Port K]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PKDATA | PKCR | PKFRn | PKOD | PKPUP | PKDN | PKIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PK0  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PK1  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PK2  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PK3  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PK4  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pk_instance = TSB_PK;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_K) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PK0 -*/
    /* Use reset value.  */
    /*- PK1 -*/
    /* Use reset value.  */
    /*- PK2 -*/
    /* Use reset value.  */
    /*- PK3 -*/
    /* Use reset value.  */
    /*- PK4 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port L]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PLDATA | PLCR | PLFRn | PLOD | PLPUP | PLDN | PLIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PL0  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL1  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL2  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL3  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL4  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL5  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL6  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PL7  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pl_instance = TSB_PL;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_L) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PL0 -*/
    /* Use reset value.  */
    /*- PL1 -*/
    /* Use reset value.  */
    /*- PL2 -*/
    /* Use reset value.  */
    /*- PL3 -*/
    /* Use reset value.  */
    /*- PL4 -*/
    /* Use reset value.  */
    /*- PL5 -*/
    /* Use reset value.  */
    /*- PL6 -*/
    /* Use reset value.  */
    /*- PL7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port M]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PMDATA | PMCR | PMFRn | PMOD | PMPUP | PMDN | PMIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PM0  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PM1  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*  PM2  | -         | -   | 0      | 0    | N/A   | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
#if defined(TMPM4KNA) || defined(TMPM4MNA)
    port.p_pm_instance = TSB_PM;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_M) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PM0 -*/
    /* Use reset value.  */
    /*- PM1 -*/
    /* Use reset value.  */
    /*- PM2 -*/
    /* Use reset value.  */
    /*- PM3 -*/
    /* Use reset value.  */
    /*- PM4 -*/
    /* Use reset value.  */
    /*- PM5 -*/
    /* Use reset value.  */
    /*- PM6 -*/
    /* Use reset value.  */
    /*- PM7 -*/
    /* Use reset value.  */
#endif
    /*===============================================================================*/
    /*  [Port N]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PNDATA | PNCR | PNFRn | PNOD | PNPUP | PNDN | PNIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PN0  | ENC0A     | I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PN1  | ENC0B     | I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PN2  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
#if defined(TMPM4KNA) || defined(TMPM4KMA) || defined(TMPM4MNA) || defined(TMPM4MMA)
    port.p_pn_instance = TSB_PN;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_N) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PN0 -*/
    if (gpio_func(&port, GPIO_PORT_N, GPIO_PORT_0, (uint32_t)GPIO_PN0_ENC0A, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PN1 -*/
    if (gpio_func(&port, GPIO_PORT_N, GPIO_PORT_1, (uint32_t)GPIO_PN1_ENC0B, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PN2 -*/
    /* Use reset value.  */
#endif
    /*===============================================================================*/
    /*  [Port U]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PUDATA | PUCR | PUFRn | PUOD | PUPUP | PUDN | PUIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PU0  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PU1  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PU2  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PU3  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PU4  |PORT_PSW[3]| I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PU5  |PORT_PSW[4]| I   | 0      | 0    | 0     | 0    | 0     | 0    | 1     */
    /*  PU6  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*  PU7  | -         | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
    port.p_pu_instance = TSB_PU;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_U) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PU0 -*/
    /* Use reset value.  */
    /*- PU1 -*/
    /* Use reset value.  */
    /*- PU2 -*/
    /* Use reset value.  */
    /*- PU3 -*/
    /* Use reset value.  */
    /*- PU4 -*/
    if (gpio_func(&port, GPIO_PORT_U, GPIO_PORT_4, (uint32_t)GPIO_PU4_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PU5 -*/
    if (gpio_func(&port, GPIO_PORT_U, GPIO_PORT_5, (uint32_t)GPIO_PU5_INPUT, GPIO_PIN_INPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*- PU6 -*/
    /* Use reset value.  */
    /*- PU7 -*/
    /* Use reset value.  */

    /*===============================================================================*/
    /*  [Port V]                                                                     */
    /*-------------------------------------------------------------------------------*/
    /*  Port | Function  | I/O | PLDATA | PLCR | PLFRn | PLOD | PLPUP | PLDN | PLIE  */
    /*-------------------------------------------------------------------------------*/
    /*  PV0  |PORT_LED[4]| O   | 0      | 1    | 0     | 0    | 0     | 0    | 0     */
    /*  PV1  |-          | -   | 0      | 0    | 0     | 0    | 0     | 0    | 0     */
    /*===============================================================================*/
    /*--- Construct  ---*/
    /* Register Allocation */
#if defined(TMPM4KNA) || defined(TMPM4MNA)
    port.p_pv_instance = TSB_PV;
    /*--- Initialize ---*/
    if (gpio_init(GPIO_PORT_V) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Setting    ---*/
    /*- PV0 -*/
    if (gpio_func(&port, GPIO_PORT_V, GPIO_PORT_0, (uint32_t)GPIO_PV0_OUTPUT, GPIO_PIN_OUTPUT) != TXZ_SUCCESS)
    {
        bsp_error();
    }
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  Port Finalize.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void port_finalize(void)
{
    /*======================*/
    /*  [Port A]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_A) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pa_instance = BSP_NULL;
    /*======================*/
    /*  [Port B]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_B) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pb_instance = BSP_NULL;
    /*======================*/
    /*  [Port C]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_C) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pc_instance = BSP_NULL;
    /*======================*/
    /*  [Port D]            */
    /*======================*/
    /*--- Finalize ---*/
#if defined(TMPM4KNA) || defined(TMPM4MNA)
    if (gpio_deinit(GPIO_PORT_D) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pd_instance = BSP_NULL;
#endif
    /*======================*/
    /*  [Port E]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_E) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pe_instance = BSP_NULL;
    /*======================*/
    /*  [Port F]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_F) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pf_instance = BSP_NULL;
    /*======================*/
    /*  [Port G]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_G) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pg_instance = BSP_NULL;
    /*======================*/
    /*  [Port H]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_H) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_ph_instance = BSP_NULL;
    /*======================*/
    /*  [Port J]            */
    /*======================*/
    /*--- Finalize ---*/
#if !defined(TMPM4KHA)
    if (gpio_deinit(GPIO_PORT_J) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pj_instance = BSP_NULL;
#endif
    /*======================*/
    /*  [Port K]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_K) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pk_instance = BSP_NULL;
    /*======================*/
    /*  [Port L]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_L) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pl_instance = BSP_NULL;
    /*======================*/
    /*  [Port M]            */
    /*======================*/
    /*--- Finalize ---*/
#if defined(TMPM4KNA) || defined(TMPM4MNA)
    if (gpio_deinit(GPIO_PORT_M) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pm_instance = BSP_NULL;
#endif
    /*======================*/
    /*  [Port N]            */
    /*======================*/
    /*--- Finalize ---*/
#if defined(TMPM4KNA) || defined(TMPM4KMA) || defined(TMPM4MNA) || defined(TMPM4MMA)
    if (gpio_deinit(GPIO_PORT_N) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pn_instance = BSP_NULL;
#endif
    /*======================*/
    /*  [Port U]            */
    /*======================*/
    /*--- Finalize ---*/
    if (gpio_deinit(GPIO_PORT_U) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pu_instance = BSP_NULL;
    /*======================*/
    /*  [Port V]            */
    /*======================*/
    /*--- Finalize ---*/
#if defined(TMPM4KNA) || defined(TMPM4MNA)
    if (gpio_deinit(GPIO_PORT_V) != TXZ_SUCCESS)
    {
        bsp_error();
    }
    /*--- Destruct ---*/
    /* Register Release */
    port.p_pv_instance = BSP_NULL;
#endif
}

/**
 *  @}
 */ /* End of group TMPM4KN_EVAL_Private_fuctions */


/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TMPM4KN_EVAL_Exported_functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Initialize.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void bsp_initialize(void)
{
    cg.p_instance = TSB_CG;
    /*--- Fsys Enable      ---*/
    cg_set_all_fsysmena(&cg, TXZ_ENABLE);
    cg_set_all_fsysmenb(&cg, TXZ_ENABLE);
    cg_set_all_fsysena(&cg, TXZ_ENABLE);
    /*--- DNF Clock Enable ---*/
    cg_set_all_fcen(&cg, TXZ_ENABLE);
    /*--- ADC Clock Enable ---*/
    /*--- EMT Trace Clock Enable ---*/
    cg_set_all_spclken(&cg, TXZ_ENABLE);
    /*--- Port             ---*/
    port_initialize();
}

/*--------------------------------------------------*/
/** 
  * @brief  Finalize.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void bsp_finalize(void)
{
    cg.p_instance = TSB_CG;
    /*--- Fsys Enable      ---*/
    cg_set_all_fsysmena(&cg, TXZ_DISABLE);
    cg_set_all_fsysmenb(&cg, TXZ_DISABLE);
    cg_set_all_fsysena(&cg, TXZ_DISABLE);
    /*--- Port              ---*/
    port_finalize();
    /*--- DNF Clock Enable ---*/
    cg_set_all_fcen(&cg, TXZ_DISABLE);
    /*--- ADC Clock Enable ---*/
    /*--- EMT Trace Clock Enable ---*/
    cg_set_all_spclken(&cg, TXZ_DISABLE);
}

/*--------------------------------------------------*/
/** 
  * @brief  Port Driver Instance Addess Get Function.
  * @param  -
  * @return Port Driver Instance Addess.
  * @retval != Null :Valid Value.
  * @note   -
  */
/*--------------------------------------------------*/
gpio_t *bsp_get_gpio_instance_address(void)
{
    return (&port);
}

/*--------------------------------------------------*/
/** 
  * @brief  Port LED GPIO Get Function.
  * @param  led     :Port LED.
  * @param  p_group :GPIO Group Destination Address. \n
  *                 :Value is @ref gpio_gr_t.
  * @param  p_num   :GPIO Number Destination Address.\n
  *                 :Value is @ref gpio_num_t.
  * @return -
  * @retval -
  * @note   You can read the Port LED GPIO Group and GPIO Num.
  */
/*--------------------------------------------------*/
void bsp_get_gpio_led(BSPLed led, uint32_t *p_group, uint32_t *p_num)
{
    *p_group = ledTbl[(uint32_t)led][0];
    *p_num   = ledTbl[(uint32_t)led][1];
}

/*--------------------------------------------------*/
/** 
  * @brief  Port LED GPIO Group Get Function.
  * @param  led     :Port LED.
  * @return Port LED GPIO Group. \n
  *         Value is @ref gpio_gr_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
gpio_gr_t bsp_get_gpio_group_led(BSPLed led)
{
    return (gpio_gr_t)(ledTbl[(uint32_t)led][0]);
}

/*--------------------------------------------------*/
/** 
  * @brief  Port LED GPIO Number Get Function.
  * @param  led     :Port LED.
  * @return Port LED GPIO Number. \n
  *         Value is @ref gpio_num_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
gpio_num_t bsp_get_gpio_num_led(BSPLed led)
{
    return (gpio_num_t)(ledTbl[(uint32_t)led][1]);
}

/*--------------------------------------------------*/
/** 
  * @brief  Push SW GPIO Get Function.
  * @param  psw     :Push SW.
  * @param  p_group :GPIO Group Destination Address. \n
  *                 :Value is @ref gpio_gr_t.
  * @param  p_num   :GPIO Number Destination Address. \n
  *                 :Value is @ref gpio_num_t.
  * @return -
  * @retval -
  * @note   You can read the Push SW GPIO Group and GPIO Num.
  */
/*--------------------------------------------------*/
void bsp_get_gpio_psw(BSPPsw psw, uint32_t *p_group, uint32_t *p_num)
{
    *p_group = pswTbl[(uint32_t)psw][0];
    *p_num   = pswTbl[(uint32_t)psw][1];
}

/*--------------------------------------------------*/
/** 
  * @brief  Push SW GPIO Group Get Function.
  * @param  psw :Push SW.
  * @return Push SW GPIO Group. \n
  *         Value is @ref gpio_gr_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
gpio_gr_t bsp_get_gpio_group_psw(BSPPsw psw)
{
    return (gpio_gr_t)(pswTbl[(uint32_t)psw][0]);
}

/*--------------------------------------------------*/
/** 
  * @brief  Push SW GPIO Number Get Function.
  * @param  psw :Push SW.
  * @return Push SW GPIO Number. \n
  *         Value is @ref gpio_num_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
gpio_num_t bsp_get_gpio_num_psw(BSPPsw psw)
{
    return (gpio_num_t)(pswTbl[(uint32_t)psw][1]);
}

/*--------------------------------------------------*/
/** 
  * @brief  Slide SW GPIO Get Function.
  * @param  ssw     :Slide SW.
  * @param  p_group :GPIO Group Destination Address. \n
  *                 :Value is @ref gpio_gr_t.
  * @param  p_num   :GPIO Number Destination Address. \n
  *                 :Value is @ref gpio_num_t.
  * @return -
  * @retval -
  * @note   You can read the Slide SW GPIO Group and GPIO Num.
  */
/*--------------------------------------------------*/
void bsp_get_gpio_ssw(BSPSsw ssw, uint32_t *p_group, uint32_t *p_num)
{
    *p_group = sswTbl[(uint32_t)ssw][0];
    *p_num   = sswTbl[(uint32_t)ssw][1];
}

/*--------------------------------------------------*/
/** 
  * @brief  Slide SW GPIO Group Get Function.
  * @param  psw :Slide SW.
  * @return Slide SW GPIO Group. \n
  *         Value is @ref gpio_gr_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
gpio_gr_t bsp_get_gpio_group_ssw(BSPSsw ssw)
{
    return (gpio_gr_t)(sswTbl[(uint32_t)ssw][0]);
}

/*--------------------------------------------------*/
/** 
  * @brief  Slide SW GPIO Number Get Function.
  * @param  psw :Slide SW.
  * @return Slide SW GPIO Number. \n
  *         Value is @ref gpio_num_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
gpio_num_t bsp_get_gpio_num_ssw(BSPSsw ssw)
{
    return (gpio_num_t)(sswTbl[(uint32_t)ssw][1]);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Channel Get Function.
  * @param  uart :USB UART.
  * @return UART Channel.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
uint32_t bsp_get_usb_uart_tx_ch(BSPUsbUart uart)
{
    return (usbUartTxTbl[(uint32_t)uart][2]);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Channel Get Function.
  * @param  uart :USB UART
  * @return UART Channel.
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
uint32_t bsp_get_usb_uart_rx_ch(BSPUsbUart uart)
{
    return (usbUartRxTbl[(uint32_t)uart][2]);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Interrupt Number Get Function.
  * @param  uart :USB UART.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_usb_uart_tx_nvic(BSPUsbUart uart)
{
    IRQn_Type type;
    switch(uart){
        case BSP_USB_UART_0:
            type = INTSC0TX_IRQn;
            break;
        case BSP_USB_UART_1:
            type = INTSC1TX_IRQn;
            break;
        case BSP_USB_UART_2:
            type = INTSC2TX_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA)
        case BSP_USB_UART_3:
            type = INTSC3TX_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Interrupt Number Get Function.
  * @param  uart :USB UART.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_usb_uart_rx_nvic(BSPUsbUart uart)
{
    IRQn_Type type;
    switch(uart){
        case BSP_USB_UART_0:
            type = INTSC0RX_IRQn;
            break;
        case BSP_USB_UART_1:
            type = INTSC1RX_IRQn;
            break;
        case BSP_USB_UART_2:
            type = INTSC2RX_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA)
        case BSP_USB_UART_3:
            type = INTSC3RX_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Interrupt Number Get Function.
  * @param  uart :USB UART.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Error
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_usb_uart_err_nvic(BSPUsbUart uart)
{
    IRQn_Type type;
    switch(uart){
        case BSP_USB_UART_0:
            type = INTSC0ERR_IRQn;
            break;
        case BSP_USB_UART_1:
            type = INTSC1ERR_IRQn;
            break;
        case BSP_USB_UART_2:
            type = INTSC2ERR_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA)
        case BSP_USB_UART_3:
            type = INTSC3ERR_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART DMA Channel Get Function.
  * @param  uart :USB UART.
  * @return DMA Channel.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
uint32_t bsp_get_usb_uart_tx_dma_ch(BSPUsbUart uart)
{
    return (usbUartTxTbl[(uint32_t)uart][3]);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART DMA Channel Get Function.
  * @param  uart :USB UART.
  * @return DMA Channel.
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
uint32_t bsp_get_usb_uart_rx_dma_ch(BSPUsbUart uart)
{
    return (usbUartRxTbl[(uint32_t)uart][3]);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Baudrate Get Function.
  * @param  uart :USB UART.
  * @return Baudrate(bps).
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
uint32_t bsp_get_usb_uart_tx_baudrate(BSPUsbUart uart)
{
    return (usbUartTxTbl[(uint32_t)uart][4]);
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART Baudrate Get Function.
  * @param  uart :USB UART.
  * @return Baudrate(bps).
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
uint32_t bsp_get_usb_uart_rx_baudrate(BSPUsbUart uart)
{
    return (usbUartRxTbl[(uint32_t)uart][4]);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Channel Get Function.
  * @param  tspi :TSPI.
  * @return TSPI Channel.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
uint32_t bsp_get_tspi_tx_ch(BSPTspi tspi)
{
    return (tspiTxTbl[(uint32_t)tspi][2]);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Channel Get Function.
  * @param  tspi :TSPI.
  * @return TSPI Channel.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
uint32_t bsp_get_tspi_clk_ch(BSPTspi tspi)
{
    return (tspiCLKTbl[(uint32_t)tspi][2]);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Channel Get Function.
  * @param  tspi :TSPI
  * @return TSPI Channel.
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
uint32_t bsp_get_tspi_rx_ch(BSPTspi tspi)
{
    return (tspiRxTbl[(uint32_t)tspi][2]);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Interrupt Number Get Function.
  * @param  tspi :TSPI.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_tspi_tx_nvic(BSPTspi tspi)
{
    IRQn_Type type;
    switch(tspi){
        case BSP_TSPI_0:
            type = INTSC0TX_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA) || defined(TMPM4MLA)
        case BSP_TSPI_1:
            type = INTSC1TX_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Interrupt Number Get Function.
  * @param  tspi :TSPI.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_tspi_rx_nvic(BSPTspi tspi)
{
    IRQn_Type type;
    switch(tspi){
        case BSP_TSPI_0:
            type = INTSC0RX_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA) || defined(TMPM4MLA)
        case BSP_TSPI_1:
            type = INTSC1RX_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Interrupt Number Get Function.
  * @param  tspi :TSPI.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Error
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_tspi_tx_err_nvic(BSPTspi tspi)
{
    IRQn_Type type;
    switch(tspi){
        case BSP_TSPI_0:
            type = INTSC0ERR_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA) || defined(TMPM4MLA)
        case BSP_TSPI_1:
            type = INTSC1ERR_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI Interrupt Number Get Function.
  * @param  tspi :TSPI.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   for Error
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_tspi_rx_err_nvic(BSPTspi tspi)
{
    IRQn_Type type;
    switch(tspi){
        case BSP_TSPI_0:
            type = INTSC0ERR_IRQn;
            break;
#if defined(TMPM4MNA) || defined(TMPM4MMA) || defined(TMPM4MLA)
        case BSP_TSPI_1:
            type = INTSC1ERR_IRQn;
            break;
#endif
        default:
            break;
    }
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI DMA Channel Get Function.
  * @param  tspi :TSPI.
  * @return DMA Channel.
  * @retval -
  * @note   for Transmission
  */
/*--------------------------------------------------*/
uint32_t bsp_get_tspi_tx_dma_ch(BSPTspi tspi)
{
    return (tspiTxTbl[(uint32_t)tspi][3]);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI DMA Channel Get Function.
  * @param  tspi :TSPI.
  * @return DMA Channel.
  * @retval -
  * @note   for Receiving
  */
/*--------------------------------------------------*/
uint32_t bsp_get_tspi_rx_dma_ch(BSPTspi tspi)
{
    return (tspiRxTbl[(uint32_t)tspi][3]);
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer Get Function.
  * @param  timer :Timer.
  * @param  p_ch  :Timer Channel Destination Address.
  * @param  p_type:Timer Type Destination Address. \n
  *               :Value is @ref t32_type_t.
  * @return -
  * @retval -
  * @note   You can read the 1ms Timer Channel and Type.
  */
/*--------------------------------------------------*/
void bsp_get_timer(BSPTimer timer, uint32_t *p_ch, uint32_t *p_type)
{
    *p_ch   = timerTbl[(uint32_t)timer].ch;
    *p_type = timerTbl[(uint32_t)timer].type;
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer Channel Get Function.
  * @param  timer :Timer.
  * @return Timer Channel.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_timer_ch(BSPTimer timer)
{
    return (timerTbl[(uint32_t)timer].ch);
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer Type Get Function.
  * @param  timer :Timer.
  * @return Timer Type. \n
  *         Value is @ref t32_type_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_timer_type(BSPTimer timer)
{
    return (timerTbl[(uint32_t)timer].type);
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer Interrupt Number Get Function.
  * @param  timer :Timer.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_timer_nvic(BSPTimer timer)
{
    return (timerTbl[(uint32_t)timer].irq);
}

/*--------------------------------------------------*/
/** 
  * @brief  Output Pulse Channel Get Function.
  * @param  pulse :Output Pulse.
  * @return Output Pulse Channel.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_output_pulse_ch(BSPOutputPulse pulse)
{
    return (pulseOutTbl[(uint32_t)pulse].ch);
}

/*--------------------------------------------------*/
/** 
  * @brief  Output Pulse Type Get Function.
  * @param  pulse :Output Pulse.
  * @return Output Pulse Type. \n
  *         Value is @ref t32_type_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_output_pulse_type(BSPOutputPulse pulse)
{
    return (pulseOutTbl[(uint32_t)pulse].type);
}

/*--------------------------------------------------*/
/** 
  * @brief  Output Pulse Interrupt Number Get Function.
  * @param  pulse :Output Pulse.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_output_pulse_nvic(BSPOutputPulse pulse)
{
    return (pulseOutTbl[(uint32_t)pulse].irq);
}

/*--------------------------------------------------*/
/** 
  * @brief  ADC ADIN Get Function
  * @param  adc :adc.
  * @return ADC ADIN.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_adc_adin(BSPAdc adc)
{
    return (adcTbl[(uint32_t)adc][2]);
}

/*--------------------------------------------------*/
/** 
  * @brief  ADC ADC Channel Get Function
  * @param  adc :adc.
  * @return ADC Channel.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_adc_ch(BSPAdc adc)
{
    return (adcTbl[(uint32_t)adc][3]);
}
/*--------------------------------------------------*/
/** 
  * @brief  Adc ADC DMA Channel Get Function
  * @param  adc :Adc.
  * @return  ADC DMA Channel.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_adc_dma_ch(BSPAdc adc)
{
    return (adcTbl[(uint32_t)adc][4]);
}

/*--------------------------------------------------*/
/** 
  * @brief  IRQ External Interrupt Enable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void bsp_irq_exint_enable(void)
{
    except_t except;
    except.p_instance2 = TSB_IB;

#if defined(TMPM4KHA)
    except_set_mode(&except, INT_REGISTER_B, MODE_RISING_EDGE, 55, INT_IMC);
    except_set_inten(&except, INT_REGISTER_B, 55, INT_IMC, TXZ_ENABLE);
#else
    except_set_mode(&except, INT_REGISTER_B, MODE_RISING_EDGE, 69, INT_IMC);
    except_set_inten(&except, INT_REGISTER_B, 69, INT_IMC, TXZ_ENABLE);
#endif
}
/*--------------------------------------------------*/
/** 
  * @brief  IRQ External Interrupt Enable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void bsp_irq_exint_disable(void)
{
    except_t except;
    except.p_instance2 = TSB_IB;

#if defined(TMPM4KHA)
    except_set_inten(&except, INT_REGISTER_B, 55, INT_IMC, TXZ_DISABLE);
    except_clear_intn(&except, INT_REGISTER_B, 55, INT_IMC);
    except_clear_intp(&except, INT_REGISTER_B, 55, INT_IMC);
    while(except_get_intn(&except, INT_REGISTER_B, 55, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    while(except_get_intp(&except, INT_REGISTER_B, 55, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
#else
    except_set_inten(&except, INT_REGISTER_B, 69, INT_IMC, TXZ_DISABLE);
    except_clear_intn(&except, INT_REGISTER_B, 69, INT_IMC);
    except_clear_intp(&except, INT_REGISTER_B, 69, INT_IMC);
    while(except_get_intn(&except, INT_REGISTER_B, 69, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    while(except_get_intp(&except, INT_REGISTER_B, 69, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
#endif
}
/*--------------------------------------------------*/
/** 
  * @brief  External Interrupt Number Get Function.
  * @param  dnf :DNF.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_exint_nvic(void)
{
#if defined(TMPM4KHA)
    return (INT13_IRQn);
#else
    return (INT21_IRQn);
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  IRQ External Interrupt (DNF) Enable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void bsp_irq_dnf_enable(void)
{
    except_t except;
    except.p_instance2 = TSB_IB;

#if defined(TMPM4KHA)
    except_set_mode(&except, INT_REGISTER_B, MODE_RISING_EDGE, 55, INT_IMC);
    except_set_inten(&except, INT_REGISTER_B, 55, INT_IMC, TXZ_ENABLE);
#else
    except_set_mode(&except, INT_REGISTER_B, MODE_RISING_EDGE, 69, INT_IMC);
    except_set_inten(&except, INT_REGISTER_B, 69, INT_IMC, TXZ_ENABLE);
#endif
}
/*--------------------------------------------------*/
/** 
  * @brief  IRQ External Interrupt (DNF) Disable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void bsp_irq_dnf_disable(void)
{
    /*-----------------------------*/
    except_t except;
    except.p_instance2 = TSB_IB;

#if defined(TMPM4KHA)
    except_set_inten(&except, INT_REGISTER_B, 55, INT_IMC, TXZ_DISABLE);
    except_clear_intn(&except, INT_REGISTER_B, 55, INT_IMC);
    except_clear_intp(&except, INT_REGISTER_B, 55, INT_IMC);
    while(except_get_intn(&except, INT_REGISTER_B, 55, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    while(except_get_intp(&except, INT_REGISTER_B, 55, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
#else
    except_set_inten(&except, INT_REGISTER_B, 69, INT_IMC, TXZ_DISABLE);
    except_clear_intn(&except, INT_REGISTER_B, 69, INT_IMC);
    except_clear_intp(&except, INT_REGISTER_B, 69, INT_IMC);
    while(except_get_intn(&except, INT_REGISTER_B, 69, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    while(except_get_intp(&except, INT_REGISTER_B, 69, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
#endif
}
/*--------------------------------------------------*/
/** 
  * @brief  DNF Register Get Function.
  * @param  dnf :DNF.
  * @return DNF Register.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
TSB_DNF_TypeDef * bsp_get_dnf_reg(BSPDnf dnf)
{
    uint32_t int_num = (uint32_t)dnfTbl[(uint32_t)dnf][0];
    if (int_num < 16)
    {
        return (TSB_DNFA);
    }else if(int_num < 31)
    {
        return (TSB_DNFB);
    }else
    {    
#if !defined(TMPM4KHA)
    return (TSB_DNFC);
#else
    return (TSB_DNFB);
#endif
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  DNF InterruptNumber Get Function.
  * @param  dnf :DNF.
  * @return InterruptNumber Noise Filter Enable Value. \n
  *         Value is @ref t32_type_t.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t bsp_get_dnf_int_num(BSPDnf dnf)
{
    uint32_t num = 0x00000001;
    uint32_t int_num = (uint32_t)dnfTbl[(uint32_t)dnf][0];
    if (int_num < 16)
    {
        num = (num << int_num);
    }else if(int_num < 31)
    {
        int_num = int_num -16;
        num = (num << int_num);
    }else
    {
        int_num = int_num -27;
        num = (num << int_num);
    }
    return (num);
}

/*--------------------------------------------------*/
/** 
  * @brief  DNF Interrupt Number Get Function.
  * @param  dnf :DNF.
  * @return Interrupt Number. \n
  *         Value is @ref IRQn_Type.
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
IRQn_Type bsp_get_dnf_nvic(BSPDnf dnf)
{
    IRQn_Type type;
#if defined(TMPM4KHA)
    /* INT21 is not available. */
    switch(dnf){
        /*--- dnf 0 ---*/
        case BSP_DNF_0:
            type = INT13_IRQn;
            break;
        default:
            break;
    }
#else
    switch(dnf){
        /*--- dnf 0 ---*/
        case BSP_DNF_0:
            type = INT21_IRQn;
            break;
        default:
            break;
    }
#endif
    return (type);
}

/*--------------------------------------------------*/
/** 
  * @brief  Systick IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_systick(void)
{
    
}
/*--------------------------------------------------*/
/** 
  * @brief  Push SW State Change.
  * @param  psw :Push SW.
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_psw(BSPPsw psw)
{
    
}
/*--------------------------------------------------*/
/** 
  * @brief  USB UART reception IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_usb_uart_rx(BSPUsbUart uart)
{
    
}
/*--------------------------------------------------*/
/** 
  * @brief  USB UART transmit IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_usb_uart_tx(BSPUsbUart uart)
{
    
}
/*--------------------------------------------------*/
/** 
  * @brief  USB UART error IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_usb_uart_err(BSPUsbUart uart)
{
    
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer.
  * @param  timer :Timer.
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_timer(BSPTimer timer)
{
    
}

/*--------------------------------------------------*/
/** 
  * @brief  PPG.
  * @param  ppg :PPG.
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_ppg(BSPOutputPulse ppg)
{
    
}

/*--------------------------------------------------*/
/** 
  * @brief  Parity.
  * @param  -
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_parity(void)
{
    
}

/*--------------------------------------------------*/
/** 
  * @brief  ADC SGL IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   Please overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_adc_sgl(void)
{
    
}

/*--------------------------------------------------*/
/** 
  * @brief  ADC CNT IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_adc_cnt(void)
{
    
}
/*--------------------------------------------------*/
/** 
  * @brief  External Interrupt  IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_exint(BSPExInt exi)
{
    
}
/*--------------------------------------------------*/
/** 
  * @brief  TSPI reception IRQ
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_tspi_rx(BSPTspi tspi)
{
  
}
/*--------------------------------------------------*/
/** 
  * @brief  TSPI transmission IRQ
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_tspi_tx(BSPTspi tspi)
{
  
}
/*--------------------------------------------------*/
/** 
  * @brief  TSPI error IRQ
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_tspi_err(BSPTspi tspi)
{
  
}
/*--------------------------------------------------*/
/** 
  * @brief  HDMA Done IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_dmac_done(uint32_t ch)
{
  
}

/*--------------------------------------------------*/
/** 
  * @brief  HDMA error IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_dmac_err(void)
{
  
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer Counterr IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_counter(BSPCounter cnt)
{
  
}

/*--------------------------------------------------*/
/** 
  * @brief  I2C IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_i2c(void)
{
  
}

/*--------------------------------------------------*/
/** 
  * @brief  I2C TBE IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_i2c_tbe(void)
{
  
}

/*--------------------------------------------------*/
/** 
  * @brief  I2C RBF IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   lease overwrite in user application if you need this function.
  */
/*--------------------------------------------------*/
__weak void irq_i2c_rbf(void)
{
  
}


/*--------------------------------------------------*/
/** 
  * @brief  SysTick Handler
  * @param  -
  * @return -
  * @retval -
  */
/*--------------------------------------------------*/
void SysTick_Handler(void)
{
    irq_systick();
}

/*--------------------------------------------------*/
/** 
  * @brief  INT00 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   0: Interrupt Pin0
  */
/*--------------------------------------------------*/
void INT00_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT01a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   1: Interrupt Pin1
  */
/*--------------------------------------------------*/
void INT01_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT02a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   2: Interrupt Pin2
  */
/*--------------------------------------------------*/
void INT02_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT03a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   3: Interrupt Pin3
  */
/*--------------------------------------------------*/
void INT03_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT04a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   4: Interrupt Pin4
  */
/*--------------------------------------------------*/
void INT04_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT05a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   5: Interrupt Pin5
  */
/*--------------------------------------------------*/
void INT05_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT06a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   6: Interrupt Pin6
  */
/*--------------------------------------------------*/
void INT06_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT07a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   7: Interrupt Pin7
  */
/*--------------------------------------------------*/
void INT07_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT08a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   8: Interrupt Pin8
  */
/*--------------------------------------------------*/
void INT08_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT09 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   9: Interrupt Pin9
  */
/*--------------------------------------------------*/
void INT09_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT10 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   10: Interrupt Pin10
  */
/*--------------------------------------------------*/
void INT10_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT11a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   11: Interrupt Pin11
  */
/*--------------------------------------------------*/
void INT11_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT12 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   12: Interrupt Pin12
  */
/*--------------------------------------------------*/
void INT12_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT13 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   13: Interrupt Pin13
  */
/*--------------------------------------------------*/
void INT13_IRQHandler(void)
{
#if !defined(TMPM4KHA)
    /* INT13 is not available.  */
    if(exi==BSP_EXINT_1){ exi =BSP_EXINT_0; }
    else { exi =BSP_EXINT_1; }
#else
    except_t except;
    except.p_instance2 = TSB_IB;

    except_clear_intn(&except, INT_REGISTER_B, 55, INT_IMC);
    except_clear_intp(&except, INT_REGISTER_B, 55, INT_IMC);
    while(except_get_intn(&except, INT_REGISTER_B, 55, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    while(except_get_intp(&except, INT_REGISTER_B, 55, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    if(exi==BSP_EXINT_1){ exi =BSP_EXINT_0; }
    else { exi =BSP_EXINT_1; }
    /*--- Handler Call     ---*/
    irq_exint(exi);
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INT14a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   14: Interrupt Pin14
  */
/*--------------------------------------------------*/
void INT14_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT15 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   15: Interrupt Pin15
  */
/*--------------------------------------------------*/
void INT15_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT16a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   16: Interrupt Pin16
  */
/*--------------------------------------------------*/
void INT16_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT17a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   18: Interrupt Pin 17
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT18a/b IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   19: Interrupt Pin 18
  */
/*--------------------------------------------------*/
void INT18_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INT21 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   20: Interrupt Pin 21
  */
/*--------------------------------------------------*/
void INT21_IRQHandler(void)
{
#if defined(TMPM4KHA)
    /* INT21 is not available. */
    if(exi==BSP_EXINT_1){ exi =BSP_EXINT_0; }
    else { exi =BSP_EXINT_1; }
#else
    except_t except;
    except.p_instance2 = TSB_IB;

    except_clear_intn(&except, INT_REGISTER_B, 69, INT_IMC);
    except_clear_intp(&except, INT_REGISTER_B, 69, INT_IMC);
    while(except_get_intn(&except, INT_REGISTER_B, 69, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    while(except_get_intp(&except, INT_REGISTER_B, 69, INT_IMC) == INTERRUPT_DETECT)
    {
        ;
    }
    if(exi==BSP_EXINT_1){ exi =BSP_EXINT_0; }
    else { exi =BSP_EXINT_1; }
    /*--- Handler Call     ---*/
    irq_exint(exi);
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INTEMG0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   23: PMD0 EMG interrupt
  */
/*--------------------------------------------------*/
void INTEMG0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTOVV0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   24: PMD0 OVV interrupt
  */
/*--------------------------------------------------*/
void INTOVV0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTPMD0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   25: PMD0 interrupt
  */
/*--------------------------------------------------*/
void INTPMD0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTENC00 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   26: Encoder 0 interrupt 0
  */
/*--------------------------------------------------*/
void INTENC00_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTENC01 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   27: Encoder 0 interrupt 1
  */
/*--------------------------------------------------*/
void INTENC01_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADAPDA IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   28: ADC conversion triggered by PMD is finished A
  */
/*--------------------------------------------------*/
void INTADAPDA_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADAPDB IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   29: ADC conversion triggered by PMD is finished B
  */
/*--------------------------------------------------*/
void INTADAPDB_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADCCP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   30: ADC conversion monitoring function interrupt A
  */
/*--------------------------------------------------*/
void INTADCCP0_IRQHandler(void)
{
#ifdef ADC_MONITOR_USE
    irq_adc_cp0();
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADCCP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   31: ADC conversion monitoring function interrupt B
  */
/*--------------------------------------------------*/
void INTADCCP1_IRQHandler(void)
{
#ifdef ADC_MONITOR_USE
    irq_adc_cp1();
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADATRG IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   32: ADC conversion triggered by General purpose is finished
  */
/*--------------------------------------------------*/
void INTADATRG_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADASGL IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   33: ADC conversion triggered by Single program is finished
  */
/*--------------------------------------------------*/
void INTADASGL_IRQHandler(void)
{
    irq_adc_sgl();
}

/*--------------------------------------------------*/
/** 
  * @brief  INTADACNT IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   34: ADC conversion triggered by Continuity program is finished
  */
/*--------------------------------------------------*/
void INTADACNT_IRQHandler(void)
{
   irq_adc_cnt();
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C0 I2C0ST IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   51: I2C0 transmission and reception interrupt / EI2C ch0 status interrupt 
  */
/*--------------------------------------------------*/
void INTI2C0NST_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C0AL I2C0TBE IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   52: I2C0 arbitration lost interrupt / EI2C ch0 transmit buffer empty interrupt
  */
/*--------------------------------------------------*/
void INTI2C0ATX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C0BF I2C0RBE IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   53: I2C0 bus free interrupt / EI2C ch0 receive buffer empty interrupt
  */
/*--------------------------------------------------*/
void INTI2C0BRX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C0NA IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   54: I2C0 no ack interrupt
  */
/*--------------------------------------------------*/
void INTI2C0NA_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1 I2C1ST IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   55: I2C1 transmission and reception interrupt / EI2C ch1 status interrupt
  */
/*--------------------------------------------------*/
void INTI2C1NST_IRQHandler(void)
{
    irq_i2c();
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1AL I2C1TBE IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   56: I2C1 arbitration lost interrupt / EI2C ch1 transmit buffer empty interrupt
  */
/*--------------------------------------------------*/
void INTI2C1ATX_IRQHandler(void)
{
    /* no process */
    irq_i2c_tbe();
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1BF I2C1RBE IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   57: I2C1 bus free interrupt / EI2C ch1 receive buffer empty interrupt
  */
/*--------------------------------------------------*/
void INTI2C1BRX_IRQHandler(void)
{
    /* no process */
    irq_i2c_rbf();
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1NA IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   58: I2C1 no ack interrupt
  */
/*--------------------------------------------------*/
void INTI2C1NA_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC0RX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   67: UART reception (channel 0)
  */
/*--------------------------------------------------*/
void INTSC0RX_IRQHandler(void)
{
#ifdef TSPI_USE
    irq_tspi_rx(BSP_TSPI_0);
#else
    irq_usb_uart_rx(BSP_USB_UART_0);
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC0TX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   68: UART transmit (channel 0)
  */
/*--------------------------------------------------*/
void INTSC0TX_IRQHandler(void)
{
#ifdef TSPI_USE
    irq_tspi_tx(BSP_TSPI_0);
#else
    irq_usb_uart_tx(BSP_USB_UART_0);
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC0ERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   69: UART error (channel 0)
  */
/*--------------------------------------------------*/
void INTSC0ERR_IRQHandler(void)
{
#ifdef TSPI_USE
    irq_tspi_err(BSP_TSPI_0);
#else
    irq_usb_uart_err(BSP_USB_UART_0);
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC1RX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   70: UART reception (channel 1)
  */
/*--------------------------------------------------*/
void INTSC1RX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC1TX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   71: UART transmit (channel 1)
  */
/*--------------------------------------------------*/
void INTSC1TX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC1ERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   72: UART error (channel 1)
  */
/*--------------------------------------------------*/
void INTSC1ERR_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC2RX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   73: UART reception (channel 2)
  */
/*--------------------------------------------------*/
void INTSC2RX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC2TX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   74: UART transmit (channel 2)
  */
/*--------------------------------------------------*/
void INTSC2TX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC2ERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   75: UART error (channel 2)
  */
/*--------------------------------------------------*/
void INTSC2ERR_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC3RX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   76: UART reception (channel 3)
  */
/*--------------------------------------------------*/
void INTSC3RX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC3TX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   77: UART transmit (channel 3)
  */
/*--------------------------------------------------*/
void INTSC3TX_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTSC3ERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   78: UART error (channel 3)
  */
/*--------------------------------------------------*/
void INTSC3ERR_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT320A0AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   85: 32bit T32A00A compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00AC_IRQHandler(void)
{
    irq_timer(BSP_TIMER_1MS);
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00ACCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   86: 32bit T32A00A input capture 0
  */
/*--------------------------------------------------*/
void INTT32A00ACCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00ACCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   87: 32bit T32A00A input capture 1
  */
/*--------------------------------------------------*/
void INTT32A00ACCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00B IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   88: 32bit T32A00B compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00B_IRQHandler(void)
{
    irq_timer(BSP_TIMER_1MS);
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00BCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   89: 32bit T32A00B input capture 0
  */
/*--------------------------------------------------*/
void INTT32A00BCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00BCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   90: 32bit T32A00B input capture 1
  */
/*--------------------------------------------------*/
void INTT32A00BCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A01AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   94: 32bit T32A01A compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A01AC_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A01ACCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   95: 32bit T32A01A input capture 0
  */
/*--------------------------------------------------*/
void INTT32A01ACCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A01ACCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   96: 32bit T32A01A input capture 1
  */
/*--------------------------------------------------*/
void INTT32A01ACCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A01B IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   97: 32bit T32A01B compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A01B_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A01BCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   98: 32bit T32A01B input capture 0
  */
/*--------------------------------------------------*/
void INTT32A01BCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A01BCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   99: 32bit T32A01B input capture 1
  */
/*--------------------------------------------------*/
void INTT32A01BCAP1_IRQHandler(void)
{
    /* no process */
}


/*--------------------------------------------------*/
/** 
  * @brief  INTT32A02AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  103: 32bit T32A02A compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A02AC_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A02ACCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  104: 32bit T32A02A input capture 0
  */
/*--------------------------------------------------*/
void INTT32A02ACCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A02ACCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  105: 32bit T32A02A input capture 1
  */
/*--------------------------------------------------*/
void INTT32A02ACCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A02B IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  106: 32bit T32A02B compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A02B_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A02BCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  107: 32bit T32A02B input capture 0
  */
/*--------------------------------------------------*/
void INTT32A02BCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A02BCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  108: 32bit T32A02B input capture 1
  */
/*--------------------------------------------------*/
void INTT32A02BCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  112: 32bit T32A03A compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A03AC_IRQHandler(void)
{
    irq_ppg(BSP_OUT_PULSE_SAMPLE_A);
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03ACCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  113: 32bit T32A03A input capture 0
  */
/*--------------------------------------------------*/
void INTT32A03ACCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03ACCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  114: 32bit T32A03A input capture 1
  */
/*--------------------------------------------------*/
void INTT32A03ACCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03B IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  115: 32bit T32A03B compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A03B_IRQHandler(void)
{
    irq_ppg(BSP_OUT_PULSE_SAMPLE_B);
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03BCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  116: 32bit T32A03B input capture 0
  */
/*--------------------------------------------------*/
void INTT32A03BCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03BCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   117: 32bit T32A03B input capture 1
  */
/*--------------------------------------------------*/
void INTT32A03BCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A04AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  121: 32bit T32A04A compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A04AC_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A04ACCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  122: 32bit T32A04A input capture 0
  */
/*--------------------------------------------------*/
void INTT32A04ACCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A04ACCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  123: 32bit T32A04A input capture 1
  */
/*--------------------------------------------------*/
void INTT32A04ACCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A04B IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  124: 32bit T32A04B compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A04B_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A04BCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  125: 32bit T32A04B input capture 0
  */
/*--------------------------------------------------*/
void INTT32A04BCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A04BCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note  126: 32bit T32A04B input capture 1
  */
/*--------------------------------------------------*/
void INTT32A04BCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A05AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   130: 32bit T32A05A compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A05AC_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A05ACCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   131: 32bit T32A05A input capture 0
  */
/*--------------------------------------------------*/
void INTT32A05ACCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A05ACCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   132: 32bit T32A05A input capture 1
  */
/*--------------------------------------------------*/
void INTT32A05ACCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A05B IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   133: 32bit T32A05B compare match detection 0 / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A05B_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A05BCAP0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   134: 32bit T32A05B input capture 0
  */
/*--------------------------------------------------*/
void INTT32A05BCAP0_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A05BCAP1 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   135: 32bit T32A05B input capture 1
  */
/*--------------------------------------------------*/
void INTT32A05BCAP1_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTPARI0 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   157: RAM parity interrupt
  */
/*--------------------------------------------------*/
void INTPARI0_IRQHandler(void)
{
    irq_parity();
}


/*--------------------------------------------------*/
/** 
  * @brief  INTDMAATCINTDMACTC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   158: DMAA end of transfer
  */
/*--------------------------------------------------*/
void INTDMAATC_IRQHandler(void)
{
    uint32_t i;
    except_state flag;
    except_t except;
    except.p_instance2 = TSB_IB;
    except.p_instance3 = TSB_IMN;

    for (i=0; i<DMA_CH_NUM; i++)
    {
        /* Read the interrupt flag(IMNFLG3).  */
        flag = imn_get_flag(&except, 96 + i);

        /* Check the DMA channel.  */
        if (flag)
        {
            /* Clear the interrupt flag. */
            /* DMAC ch A(ch0 -ch31) [IBIMC000] - [IBIMC031] */
            except_clear_intp(&except, INT_REGISTER_B, i, INT_IMC);
            while(except_get_intp(&except, INT_REGISTER_B, i, INT_IMC) == INTERRUPT_DETECT)
            {
                ;
            }

            /* Call Handler. */
            irq_dmac_done(i);
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INTDMAAERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   159: DMAA transfer error
  */
/*--------------------------------------------------*/
void INTDMAAERR_IRQHandler(void)
{
    irq_dmac_err();
}

/*--------------------------------------------------*/
/** 
  * @brief  INTFLCRDY IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   164: Code FLASH Ready interrupt
  */
/*--------------------------------------------------*/
void INTFLCRDY_IRQHandler(void)
{
    /* no process */
}

/*--------------------------------------------------*/
/** 
  * @brief  INTFLDRDY IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   165: Data FLASH Ready interrupt
  */
/*--------------------------------------------------*/
void INTFLDRDY_IRQHandler(void)
{
    /* no process */
}

/**
 *  @}
 */ /* End of group TMPM4KN_EVAL_Exported_functions */

/**
 *  @}
 */ /* End of group TMPM4KN_EVAL */

/**
 *  @} 
 */ /* End of group Example */

#endif /* defined(__BSP_H)  */
#ifdef __cplusplus
}
#endif /* __cplusplus */
