/** 
 *******************************************************************************
 * @file    main.c
 * @brief   CRC Sample Application.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include <stdio.h>
#include "bsp.h"
#include "bsp_uart_io.h"
#include "bsp_led.h"
#include "crc.h"

/**
 *  @addtogroup Example
 *  @{
 */


/** 
 *  @}
 */ /* End of group CRC_Private_define */
 
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_config CRC Config
 *  @{
 */

#define CRC16
/*#define CRC32*/

#define CRC_MEMORY
/*#define CRC_RAM*/

#define MEMORY_SIZE     ((uint32_t)9)      /*!< Size                    */
#define MAIN_NULL       ((void *)0)     /*!< NULL. */
#define USER_ID_UART    ((uint32_t)1)   /*!< User ID :USB UART (Any value) */

/** 
 *  @}
 */ /* End of group CRC_config */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CRC_Private_typedef CRC Private Typedef
 *  @{
 */
/*----------------------------------*/
/** 
 * @brief Instance Information.
*/
/*----------------------------------*/
typedef struct
{
    uart_io_t    *p_uart;           /*!< Application :USB UART. */
    led_t        led[(uint32_t)BSP_LED_MAX]; /*!< Application :LED                */
} instance_t;

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CRC_Private_variables CRC Private Variables
 *  @{
 */
/*----------------------------------*/
/** 
 * @brief Variables.
*/
/*----------------------------------*/
static instance_t instance;     /*!< Instance.                */
static crc_crctyp_t crc_t;
/**
 *  @}
 */ /* End of group CRC_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_Private_variables CRC Private Variables
 *  @{
 */
#ifdef CRC_MEMORY
const uint8_t comp_data[MEMORY_SIZE] = "123456789";
#else
#ifdef CRC_RAM
uint8_t comp_data[MEMORY_SIZE] = "123456789";
#endif
#endif
uint32_t crc_clc_value;
/**
 *  @}
 */ /* End of group CRC_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CRC_Private_fuctions CRC Private Fuctions
 *  @{
 */
static void variable_initialize(void);
static TXZ_Result application_initialize(void);
static void CRC_calculation(uint32_t top_memory , uint32_t size_memory);
/*--------------------------------------------------*/
/** 
  * @brief  Variable Initialize
  * @param  -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void variable_initialize(void)
{
    uint32_t i;

    /* Instance. */
    instance.p_uart             = MAIN_NULL;
    for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
    {
        instance.led[i].init.p_gpio = MAIN_NULL;
    }
}


/*--------------------------------------------------*/
/** 
  * @brief  Application Initialize
  * @param  -
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result application_initialize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* LED                  */
    /*----------------------*/
    {
        uint32_t i;
        led_t *p_led = MAIN_NULL;

        for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
        {
            p_led = &instance.led[i];

            p_led->init.id                  = (uint32_t)p_led;
            p_led->init.p_gpio              = bsp_get_gpio_instance_address();
            p_led->init.port.group          = bsp_get_gpio_group_led((BSPLed)(i));
            p_led->init.port.num            = bsp_get_gpio_num_led((BSPLed)(i));
            p_led->init.blink.func          = TXZ_DISABLE;
            p_led->init.blink.interval.on   = 0;
            p_led->init.blink.interval.off  = 0;
            p_led->init.state           = LED_STATE_OFF;
            led_initialize(p_led);
        }
    }
    /*----------------------*/
    /* Usb Uart             */
    /*----------------------*/
    /* Tx & Rx use same UART channel. */
    {
        uart_io_initial_setting_t param;

        param.id         = USER_ID_UART;
        switch (bsp_get_usb_uart_tx_ch(BSP_USB_UART_0))
        {
        case 0:
            param.p_reg  = TSB_UART0;
            break;
        case 1:
            param.p_reg  = TSB_UART1;
            break;
        case 2:
            param.p_reg  = TSB_UART2;
            break;
        default:
            param.p_reg  = MAIN_NULL;
            break;
        }
        param.boudrate   = bsp_get_usb_uart_tx_baudrate(BSP_USB_UART_0);
        param.irq.tx     = bsp_get_usb_uart_tx_nvic(BSP_USB_UART_0);
        param.irq.rx     = bsp_get_usb_uart_rx_nvic(BSP_USB_UART_0);
        param.irq.err    = bsp_get_usb_uart_err_nvic(BSP_USB_UART_0);
        if (param.p_reg != MAIN_NULL)
        {
            result  = uart_io_initialize(&param);
        }
        else
        {
            result = TXZ_ERROR;
        }
    }
    
    return (result);
}


/**
 *  @}
 */ /* End of group CRC_Private_fuctions */


/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CRC_Exported_functions CRC Exported Functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    uint32_t    crcclc_init = 0;
    uint32_t    work = 0;

    /*----------------------*/
    /* BSP initialize       */
    /*----------------------*/
    bsp_initialize();
    /*----------------------*/
    /* Initialize           */
    /*----------------------*/
    /*--- variable    ---*/
    variable_initialize();

    /*--- application ---*/
    if (application_initialize() != TXZ_SUCCESS)
    {
    }

#ifdef CRC16
    crc_t.cfmt = REG_CRC_CFMT_CRC16;
    crc_t.dbit = REG_CRC_DBIT_32bit;
    crcclc_init = REG_CRCCLC_DEFAULT_VAL_16;
#else
#ifdef CRC32
    crc_t.cfmt = REG_CRC_CFMT_CRC32;
    crc_t.dbit = REG_CRC_DBIT_32bit;
    crcclc_init = REG_CRCCLC_DEFAULT_VAL_32;
#endif
#endif

    REG_CRCTYP_set(TSB_CRC, crc_t);
    REG_CRCCLC_set(TSB_CRC, crcclc_init);
    
    CRC_calculation((uint32_t )comp_data, MEMORY_SIZE);
    crc_clc_value = REG_CRCCLC_get(TSB_CRC);
    crc_clc_value = REG_CRCCLC_get(TSB_CRC);

    work = (uint32_t)crc_clc_value;

    crc_t.cfmt = (REG_CRCTYP_get(TSB_CRC) & 0x0000000C);
#ifdef CRC16
    crc_t.dbit = REG_CRC_DBIT_16bit;
#else
#ifdef CRC32
    crc_t.dbit = REG_CRC_DBIT_32bit;
#endif
#endif
    REG_CRCTYP_set(TSB_CRC, crc_t);
    REG_CRCDIN_set(TSB_CRC, work);
    
    crc_clc_value = REG_CRCCLC_get(TSB_CRC);
    crc_clc_value = REG_CRCCLC_get(TSB_CRC);
    if(crc_clc_value == 0x00000000)
    {
        led_turn_on(&instance.led[0]);
        led_turn_off(&instance.led[1]);
    }
    else
    {
        led_turn_off(&instance.led[0]);
        led_turn_on(&instance.led[1]);
    }

    printf("START = 0x%08X\n" , (uint32_t )comp_data);
    printf("END   = 0x%08X\n" , (uint32_t )comp_data + MEMORY_SIZE -1);
    printf("CRC   = 0x%08X\n\n" , work);
    
    while(1){}
}


/*--------------------------------------------------*/
/**
  * @brief     CRC_calculation
  * @param     top_memory , size_meomory
  * @note      -
  */
/*--------------------------------------------------*/
void CRC_calculation(uint32_t top_memory , uint32_t size_memory)
{
    uint32_t i;
    uint8_t *ptr;
    uint32_t length;
    uint32_t work;
    
    ptr = (uint8_t *)top_memory;
    length = size_memory;
    work = 0x00;
    for( i=0; i < length; ++i )
    {
        work = ((work << 8U) | ((uint32_t)*ptr));
        ptr++;
        if( (i % 4) == 3 )
        {
            REG_CRCDIN_set(TSB_CRC, work);
            work = 0x00;
        }
    }
    if( (length % 4 ) == 0 )
    {
        /* no process */
    }
    else if( (length % 4 ) == 1 )
    {
        crc_t.cfmt = (REG_CRCTYP_get(TSB_CRC) & 0x0000000C);
        crc_t.dbit = REG_CRC_DBIT_8bit;
        REG_CRCTYP_set(TSB_CRC, crc_t);
        REG_CRCDIN_set(TSB_CRC, work);
    }
    else if( (length % 4 ) == 2 )
    {
        crc_t.cfmt = (REG_CRCTYP_get(TSB_CRC) & 0x0000000C);
        crc_t.dbit = REG_CRC_DBIT_16bit;
        REG_CRCTYP_set(TSB_CRC, crc_t);
        REG_CRCDIN_set(TSB_CRC, work);
    }
    else if( (length % 4 ) == 3 )
    {
        uint32_t work2 = work >> 8U;
        crc_t.cfmt = (REG_CRCTYP_get(TSB_CRC) & 0x0000000C);
        crc_t.dbit = REG_CRC_DBIT_16bit;
        REG_CRCTYP_set(TSB_CRC, crc_t);
        REG_CRCDIN_set(TSB_CRC, work2);
        work2 = work & 0xFFU;
        crc_t.cfmt = (REG_CRCTYP_get(TSB_CRC) & 0x0000000C);
        crc_t.dbit = REG_CRC_DBIT_8bit;
        REG_CRCTYP_set(TSB_CRC, crc_t);
        REG_CRCDIN_set(TSB_CRC, work2);
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART reception IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_usb_uart_rx(BSPUsbUart uart)
{
    switch (uart)
    {
    /*--- usb uart 0 ---*/
    case BSP_USB_UART_0:
        uart_io_rx_irq_handler();
        break;
    /*--- default    ---*/
    default:
        /* no processing */
        break;
    }

}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART transmit IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_usb_uart_tx(BSPUsbUart uart)
{
    switch (uart)
    {
    /*--- usb uart 0 ---*/
    case BSP_USB_UART_0:
        uart_io_tx_irq_handler();
        break;
    /*--- default    ---*/
    default:
        /* no processing */
        break;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART error IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_usb_uart_err(BSPUsbUart uart)
{
    switch (uart)
    {
    /*--- usb uart 0 ---*/
    case BSP_USB_UART_0:
        uart_io_err_irq_handler();
        break;
    /*--- default    ---*/
    default:
        /* no processing */
        break;
    }
}


#ifdef __DEBUG__
/*--------------------------------------------------*/
/** 
  * @brief  Failure Assert.
  * @note   for debug
  */
/*--------------------------------------------------*/
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
/**
 *  @}
 */ /* End of group CRC_Exported_functions */

/**
 *  @}
 */ /* End of group CRC */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
