/** 
 *******************************************************************************
 * @file    main.c
 * @brief   TSPI SLAVE TRANS Sample Application.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif
/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "bsp.h"
#include "bsp_sw.h"
#include "bsp_led.h"
#include "bsp_timer.h"
#include "crc.h"
#include "dmac_com.h"
#include "tspi.h"
#include "tspi_dma.h"
#include "sys_timer.h"
/**
 *  @addtogroup Example
 *  @{
 */

/** 
 *  @defgroup TSPI_SlaveTrans TSPI_SlaveTrans Sample Appli
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_macro TSPI_SlaveTrans Private Macro
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_macro */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_define TSPI_SlaveTrans Private Define
 *  @{
 */
#define MCU_NAME        "TMPM4KNFYA"

#define CHK_CODE_CRC16  16
#define CHK_CODE_CRC32  32
#define CHK_CODE        CHK_CODE_CRC16

#if CHK_CODE == CHK_CODE_CRC16
    #define DATA_LENGTH     (12)                    /*!< Length of base data.      */
#else
    #define DATA_LENGTH     (14)                    /*!< Length of base data.      */
#endif


#define FIFO_MODE        0
#define DMA_MODE         1
#define TX_MODE          FIFO_MODE


#define TX_FILL_LEVEL    3

/** 
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_define */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_define TSPI_SlaveTrans Private Define
 *  @{
 */

#define MAIN_NULL       ((void *)0)          /*!< Null Pointer.  */
/** 
 *  @defgroup SWPollingConfiguration SW Polling Time Configuration
 *  @brief    SW Polling Time(ms).
 *  @{
 */
#define CFG_SW_POLLING_TIME     ((uint32_t)(100))
/** 
 *  @}
 */ /* End of group SWPollingConfiguration */

#define USER_ID_TSPI_TX       ((uint32_t)0)              /*!< User ID :TSPI (Any value) */

#define TSPIxCR1_FC_MASK      ((uint32_t)0x000000FF)     /*!<                                                            */

/*----------------------*/
/*  DMA Setting         */
/*----------------------*/
/* Work Area = ((The total number of the used channel) * (4 * DWORD) * 2)  */
#define CFG_DMA_WORK_SIZE     ((uint32_t)(DMA_CH_NUM * 4 * sizeof(uint32_t) * 2))     /*!< DMA work area. */

#define CFG_DMA_ch_dstinc_1byte               0x00000000 ; /*!< dstinc 1 byte */
#define CFG_DMA_ch_dstinc_2byte               0x00000001 ; /*!< dstinc 2 byte */
#define CFG_DMA_ch_dstinc_4byte               0x00000010 ; /*!< dstinc 4 byte */
#define CFG_DMA_ch_dstinc_none                0x00000011 ; /*!< dstinc none */
#define CFG_DMA_ch_dstsize_1byte              0x00000000 ; /*!< dstsize 1 byte */
#define CFG_DMA_ch_dstsize_2byte              0x00000001 ; /*!< dstsize 2 byte */
#define CFG_DMA_ch_dstsize_4byte              0x00000010 ; /*!< dstsize 4 byte */
#define CFG_DMA_ch_srcinc_1byte               0x00000000 ; /*!< srcinc 1 byte */
#define CFG_DMA_ch_srcinc_2byte               0x00000001 ; /*!< srcinc 2 byte */
#define CFG_DMA_ch_srcinc_4byte               0x00000010 ; /*!< srcinc 4 byte */
#define CFG_DMA_ch_srcinc_none                0x00000011 ; /*!< srcinc none */
#define CFG_DMA_ch_srcsize_1byte              0x00000000 ; /*!< srcsize 1 byte */
#define CFG_DMA_ch_srcsize_2byte              0x00000001 ; /*!< srcsize 2 byte */
#define CFG_DMA_ch_srcsize_4byte              0x00000010 ; /*!< srcsize 4 byte */
#define CFG_DMA_ch_rpow_001                   0x00000000 ; /*!< R power 1 */
#define CFG_DMA_ch_rpow_002                   0x00000001 ; /*!< R power 2 */
#define CFG_DMA_ch_rpow_004                   0x00000010 ; /*!< R power 4 */
#define CFG_DMA_ch_rpow_008                   0x00000011 ; /*!< R power 8 */
#define CFG_DMA_ch_rpow_016                   0x00000100 ; /*!< R power 16 */
#define CFG_DMA_ch_rpow_032                   0x00000101 ; /*!< R power 32 */
#define CFG_DMA_ch_rpow_064                   0x00000110 ; /*!< R power 64 */
#define CFG_DMA_ch_rpow_128                   0x00000111 ; /*!< R power 128 */
#define CFG_DMA_ch_rpow_256                   0x00001000 ; /*!< R power 256 */
#define CFG_DMA_ch_rpow_512                   0x00001001 ; /*!< R power 512 */
#define CFG_DMA_ch_rpow_none                  0x00001111 ; /*!< R power none */
#define CFG_DMA_ch_next_usesingle             0x00000000 ; /*!< next use single */
#define CFG_DMA_ch_next_useburst              0x00000001 ; /*!< next use burst  */

/** 
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_define TSPI_SlaveTrans Private Define
 *  @{
 */

/*----------------------------------*/
/** 
 * @brief Instance Information.
*/
/*----------------------------------*/
typedef struct
{
    t32a_t      t32a;                       /*!< Driver      :T32A               */
    timer_t     timer;                      /*!< Application :Timer (1ms timer). */

    led_t       led[(uint32_t)BSP_LED_MAX]; /*!< Application :LED                */
    sw_t        sw[(uint32_t)BSP_PSW_MAX];  /*!< Application :PSW                */
#if TX_MODE  == FIFO_MODE
    tspi_t      tspi_tx_obj;                /*!< Application :TSPI. */
#else
    tspi_dma_t    tspi_dma;
    dma_t         dma;                      /*!< Driver      :DMA.               */
#endif
} instance_t;

/*----------------------------------*/
/** 
 * @enum   Processing
 * @brief  Processing mode.
*/
/*----------------------------------*/
typedef enum
{
#if TX_MODE  == FIFO_MODE
    PROC_FIFO_IDLE,         /*!< Idle.                              */
    PROC_FIFO_START,        /*!< Start.                             */
    PROC_FIFO_TRANS,        /*!< Trans.                             */
    PROC_FIFO_RECV,         /*!< Receive.                           */
    PROC_FIFO_FINISHED,     /*!< Finished.                          */
    PROC_FIFO_CMP,          /*!< Compare.                           */
    PROC_FIFO_ERROR,        /*!< Error.                             */
#else
    PROC_DMAC_IDLE,         /*!< Idle.                              */
    PROC_DMAC_START,
    PROC_DMAC_TRANS,        /*!< Trans.                             */
    PROC_DMAC_RECV,         /*!< Receive.                           */
    PROC_DMAC_FINISHED,     /*!< Finished.                          */
    PROC_DMAC_CMP,          /*!< Compare.                           */
    PROC_DMAC_ERROR,        /*!< Error.                             */
#endif
    PROC_ERROR,
} Processing;

/*----------------------------------*/
/** 
 * @enum   SendState
 * @brief  Send state.
*/
/*----------------------------------*/
typedef enum {
#if TX_MODE == FIFO_MODE
    SEND_IDLE = 0U,              /*!< Idle                   */
    SEND_RUN,                    /*!< Transmiting.           */
    SEND_SUCCESS,                /*!< Transmission complete. */
    SEND_FAILURE                 /*!< Transmission error.    */
#else
    TSPI_DMA_SEND_IDLE = 0U,     /*!< Idle                   */
    TSPI_DMA_SEND_RUN,           /*!< Transmiting.           */
    TSPI_DMA_SEND_SUCCESS,       /*!< Transmission complete. */
    TSPI_DMA_SEND_FAILURE        /*!< Transmission error.    */
#endif
} SendState;

/*----------------------------------*/
/** 
 * @struct send_t
 * @brief  Send information.
*/
/*----------------------------------*/
typedef struct
{
    volatile SendState  state;                          /*!< Status.                     */
    uint32_t            wp;                             /*!< Write pointer.              */
    uint32_t            rp;                             /*!< Read pointer(Now, no use).  */
    uint8_t             tx_buf[DATA_LENGTH];            /*!< Send data.                  */

} send_t;

/** 
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_define */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_typedef TSPI_SlaveTrans Private Typedef
 *  @{
 */
/** 
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_variables TSPI_SlaveTrans Private Variables
 *  @{
 */

/*----------------------------------*/
/** 
 * @brief Variables.
*/
/*----------------------------------*/
static instance_t instance;     /*!< Instance.                */
static volatile Processing proc;                         /*!< Processing mode.         */
static uint8_t ledflag;     /*!< led flag. */
volatile send_t       send;                               /*!< Send information.     */
#if TX_MODE  == DMA_MODE
#if defined ( __CC_ARM   )      /* RealView Compiler */
    static __align(0x400) uint8_t primary[CFG_DMA_WORK_SIZE]; /*!< DMA work area. */
#elif defined ( __ICCARM__ )    /*IAR Compiler */
    #pragma location="dma_work"
    #pragma data_alignment=1024
    static uint8_t primary[CFG_DMA_WORK_SIZE]; /*!< DMA work area. */
#elif defined ( __SES_ARM )     /* Segger Compiler */
    static uint8_t __attribute__((__aligned__(0x400)))primary[CFG_DMA_WORK_SIZE];
#endif
#else
static tspi_transmit_t t_info;
#endif
/**
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Private_functions TSPI_SlaveTrans Private Functions
 *  @{
 */
static void variable_initialize(void);
static TXZ_Result driver_initialize(void);
static TXZ_Result driver_finalize(void);
static TXZ_Result application_initialize(void);
static TXZ_Result application_finalize(void);
static void timer_interval_handler(uint32_t id);
static void sw_state_change_handler(uint32_t id, gpio_pinstate_t state);
static TXZ_Result tspi_initialize(void);
static void set_crc_tx_data(void);
static void transmit_handler(uint32_t id, TXZ_Result result);

/*--------------------------------------------------*/
/** 
  * @brief  Variable Initialize
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */ 
/*--------------------------------------------------*/
static void variable_initialize(void)
{
    instance.t32a.p_instance    = MAIN_NULL;
    instance.timer.init.p_t32a  = MAIN_NULL;
    {
        uint32_t i;

        for (i=0; i<(uint32_t)BSP_PSW_MAX; i++)
        {
            instance.sw[i].init.p_gpio  = MAIN_NULL;
        }
        for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
        {
            instance.led[i].init.p_gpio = MAIN_NULL;
        }
    }
#if TX_MODE  == FIFO_MODE
    /* Instance. */
    instance.tspi_tx_obj.p_instance    = MAIN_NULL;
    /* Processing mode. */
    proc = PROC_FIFO_IDLE;
    send.state      = SEND_IDLE;
#else
    uint32_t i;

    /* DMA work area. */
    for (i=0; i<CFG_DMA_WORK_SIZE; i++)
    {
        primary[i] = 0;
    }
    /* Processing mode. */
    proc = PROC_DMAC_IDLE;
    instance.tspi_dma.super.p_instance     = MAIN_NULL;
    instance.dma.p_instance     = MAIN_NULL;
#endif
    /* ledflag. */
    ledflag = 0;
}


/*--------------------------------------------------*/
/** 
  * @brief  Driver Initialize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result driver_initialize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* GPIO                 */
    /*----------------------*/
    /* Driver initialize has done within BSP. */
    /*----------------------*/
    /* T32A                 */
    /*----------------------*/
    {
        t32a_t *p_t32a = &instance.t32a;

        /*--- Construct  ---*/
        /* Register Allocation */
        switch (bsp_get_timer_ch(BSP_TIMER_1MS))
        {
        case 0:
            p_t32a->p_instance = TSB_T32A0;
            break;
        case 1:
            p_t32a->p_instance = TSB_T32A1;
            break;
        case 2:
            p_t32a->p_instance = TSB_T32A2;
            break;
        case 3:
            p_t32a->p_instance = TSB_T32A3;
            break;
        case 4:
            p_t32a->p_instance = TSB_T32A4;
            break;
        case 5:
            p_t32a->p_instance = TSB_T32A5;
            break;
        default:
            p_t32a->p_instance = MAIN_NULL;
            break;
        }
        /*--- Initialize ---*/
        p_t32a->init_mode.mode.halt = T32A_DBG_HALT_STOP;
        p_t32a->init_mode.mode.mode = T32A_MODE_16;
        if (t32a_mode_init(p_t32a) != TXZ_SUCCESS)
        {
            result = TXZ_ERROR;
        }
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Driver Finalize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result driver_finalize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* T32A                 */
    /*----------------------*/
    {
        t32a_t *p_t32a = &instance.t32a;

        /*--- Finalize ---*/
        /* no processing */
        /*--- Destruct ---*/
        /* Register Release */
        p_t32a->p_instance = MAIN_NULL;
    }
    /*----------------------*/
    /* GPIO                 */
    /*----------------------*/
    /* Driver finalize will process within BSP.     */

    return (result);
}


/*--------------------------------------------------*/
/** 
  * @brief  Application Initialize.
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result application_initialize(void)
{
   TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* Timer                */
    /*----------------------*/
    /* 1ms timer */
    {
        timer_t *p_timer = &instance.timer;

        p_timer->init.id       = (uint32_t)&instance.timer;
        p_timer->init.p_t32a   = &instance.t32a;
        p_timer->init.type     = bsp_get_timer_type(BSP_TIMER_1MS);
        p_timer->init.irq      = bsp_get_timer_nvic(BSP_TIMER_1MS);
        p_timer->init.interval = 1000;
        p_timer->init.handler  = timer_interval_handler;
        timer_initialize(p_timer);
    }
    /*----------------------*/
    /* LED                  */
    /*----------------------*/
    {
        uint32_t i;
        led_t *p_led = MAIN_NULL;

        for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
        {
            p_led = &instance.led[i];

            p_led->init.id                  = (uint32_t)p_led;
            p_led->init.p_gpio              = bsp_get_gpio_instance_address();
            p_led->init.port.group          = bsp_get_gpio_group_led((BSPLed)(i));
            p_led->init.port.num            = bsp_get_gpio_num_led((BSPLed)(i));
            p_led->init.blink.func          = TXZ_DISABLE;
            p_led->init.blink.interval.on   = 0;
            p_led->init.blink.interval.off  = 0;
            p_led->init.state           = LED_STATE_OFF;
            led_initialize(p_led);
        }
    }
    
    /*----------------------*/
    /* PSW                  */
    /*----------------------*/
    {
        uint32_t i;
        sw_t *p_sw = MAIN_NULL;

        for (i=0; i<(uint32_t)BSP_PSW_MAX; i++)
        {
            p_sw = &instance.sw[i];

            p_sw->init.id                   = (uint32_t)p_sw;
            p_sw->init.p_gpio               = bsp_get_gpio_instance_address();
            p_sw->init.port.group           = bsp_get_gpio_group_psw((BSPPsw)(i));
            p_sw->init.port.num             = bsp_get_gpio_num_psw((BSPPsw)(i));
            p_sw->init.polling.func         = TXZ_ENABLE;
            p_sw->init.polling.interval     = CFG_SW_POLLING_TIME;
            p_sw->init.chattering.func      = TXZ_DISABLE;
            p_sw->init.chattering.count     = 0;
            p_sw->init.handler              = sw_state_change_handler;
            sw_initialize(p_sw);
        }
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Application Finalize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result application_finalize(void)
{
    TXZ_Result result = TXZ_SUCCESS;
    uint32_t i;

    /*----------------------*/
    /* PSW                  */
    /*----------------------*/
    for (i=0; i<(uint32_t)BSP_PSW_MAX; i++)
    {
        sw_finalize(&instance.sw[i]);
    }
    /*----------------------*/
    /* LED                  */
    /*----------------------*/
    for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
    {
        led_finalize(&instance.led[i]);
    }
    /*----------------------*/
    /* 1ms Timer Stop       */
    /*----------------------*/
    timer_stop(&instance.timer);
    /*----------------------*/
    /* Timer                */
    /*----------------------*/
    /* 1ms timer */
    timer_finalize(&instance.timer);
#if TX_MODE  == DMA_MODE
    /*--- Finalize ---*/
    if (dma_deinit(&instance.dma) != TXZ_SUCCESS)
    {
        result = TXZ_ERROR;
    }
    /*--- Destruct (Register Release) ---*/
    /* Register Allocation */
    instance.dma.p_instance = MAIN_NULL;
#endif

    return (result);
}


/*--------------------------------------------------*/
/** 
  * @brief  Interval Time Handler.
  * @param  id :User ID
  * @return -
  * @retval -
  * @note   for 1ms Timer.
  * @note   Call by Timer.
  */
/*--------------------------------------------------*/
static void timer_interval_handler(uint32_t id)
{
    if (id == (uint32_t)&instance.timer)
    {
        uint32_t i;

        /*----------------------*/
        /* Tick                 */
        /*----------------------*/
        /* Increment Tick. Tick is used to driver's Timeout. */
        hal_inc_tick();
        /*----------------------*/
        /* SW                   */
        /*----------------------*/
        for (i=0; i<(uint32_t)BSP_PSW_MAX; i++)
        {
            sw_1ms_timer_handler(&instance.sw[i]);
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  SW State Change Handler.
  * @param  id    :User ID
  * @param  state :Push SW Port State
  * @return -
  * @retval -
  * @note   Notify that, "State is changed." \n
  *         Call by SW Task \n
  *         If SW is pushed, change the processing mode(@ref Processing).
  */
/*--------------------------------------------------*/
static void sw_state_change_handler(uint32_t id, gpio_pinstate_t state)
{
    /* Check SW Push(= GPIO_PIN_RESET) */
    if (state == GPIO_PIN_RESET)
    {
        uint32_t i;

        for (i=0; i < (uint32_t)BSP_PSW_MAX; i++)
        {
            if (id == (uint32_t)&instance.sw[i])
            {
                switch ((BSPPsw)i)
                {
                case BSP_PSW_1:
#if TX_MODE  == FIFO_MODE
                    proc = PROC_FIFO_START;
#else
                    proc = PROC_DMAC_START;
#endif
                    led_turn_off(&instance.led[2]);
                    break;
                default:
                    /* no processing */
                    break;
                }
            }
        }
    }
}
/*--------------------------------------------------*/
/**
  * @brief     Initializing of TSPI Driver
  * @param     -
  * @retval    -
  */
/*--------------------------------------------------*/
static TXZ_Result tspi_initialize(void)
{
   TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* TSPI             */
    /*----------------------*/
    /* Tx TSPI channel. */
#if TX_MODE  == FIFO_MODE
    {
        instance.tspi_tx_obj.init.id  = USER_ID_TSPI_TX;
        switch (bsp_get_tspi_tx_ch(BSP_TSPI_0))
        {
        case 0:
            instance.tspi_tx_obj.p_instance  = TSB_TSPI0;
            break;
#if !defined(TMPM4KHA)
        case 1:
            instance.tspi_tx_obj.p_instance  = TSB_TSPI1;
            break;
#endif
        default:
            instance.tspi_tx_obj.p_instance  = MAIN_NULL;
            break;
        }

        /* Set Initial parameter of TSPIxCR1 */
        instance.tspi_tx_obj.init.cnt1.inf = TSPI_INF_DISABLE;
        instance.tspi_tx_obj.init.cnt1.trgen = TSPI_TRGEN_DISABLE;
        instance.tspi_tx_obj.init.cnt1.tspims = TSPI_SPI_MODE;
        instance.tspi_tx_obj.init.cnt1.mstr = TSPI_SLAVE_OPERATION;
        instance.tspi_tx_obj.init.cnt1.tmmd = TSPI_TX_ONLY;
        instance.tspi_tx_obj.init.cnt1.cssel = TSPI_TSPIxCS0_ENABLE;
        instance.tspi_tx_obj.init.cnt1.fc = ((uint32_t)DATA_LENGTH & TSPIxCR1_FC_MASK);
        /* Set Initial parameter of TSPIxCR2 */
        instance.tspi_tx_obj.init.cnt2.tidle = TSPI_TIDLE_HI;
        instance.tspi_tx_obj.init.cnt2.txdemp = TSPI_TXDEMP_HI;
        instance.tspi_tx_obj.init.cnt2.rxdly = TSPI_RXDLY_FSYS_FSCK_4;
        instance.tspi_tx_obj.init.cnt2.til = (TX_FILL_LEVEL << 12U);
        instance.tspi_tx_obj.init.cnt2.ril = TSPI_RX_FILL_LEVEL_1;
        instance.tspi_tx_obj.init.cnt2.inttxwe = TSPI_TX_INT_DISABLE;
        instance.tspi_tx_obj.init.cnt2.intrxwe = TSPI_RX_INT_DISABLE;
        instance.tspi_tx_obj.init.cnt2.inttxfe = TSPI_TX_FIFO_INT_ENABLE;
        instance.tspi_tx_obj.init.cnt2.intrxfe = TSPI_RX_FIFO_INT_DISABLE;
        instance.tspi_tx_obj.init.cnt2.interr = TSPI_ERR_INT_ENABLE;
        instance.tspi_tx_obj.init.cnt2.dmate = TSPI_TX_DMA_INT_DISABLE;
        instance.tspi_tx_obj.init.cnt2.dmare = TSPI_RX_DMA_INT_DISABLE;
        /* Set Initial parameter of TSPIxBR */
        instance.tspi_tx_obj.init.brd.brck = TSPI_BR_CLOCK_1;
        instance.tspi_tx_obj.init.brd.brs = TSPI_BR_DIVIDER_2;
        /* Set Initial parameter of TSPIxFMTR0 */
        instance.tspi_tx_obj.init.fmr0.dir = TSPI_DATA_DIRECTION_MSB;
        instance.tspi_tx_obj.init.fmr0.fl = TSPI_DATA_LENGTH_8;
        instance.tspi_tx_obj.init.fmr0.fint = TSPI_INTERVAL_TIME_0;
        instance.tspi_tx_obj.init.fmr0.cs3pol = TSPI_TSPIxCS3_NEGATIVE;
        instance.tspi_tx_obj.init.fmr0.cs2pol = TSPI_TSPIxCS2_NEGATIVE;
        instance.tspi_tx_obj.init.fmr0.cs1pol = TSPI_TSPIxCS1_NEGATIVE;
        instance.tspi_tx_obj.init.fmr0.cs0pol = TSPI_TSPIxCS0_NEGATIVE;
        instance.tspi_tx_obj.init.fmr0.ckpha = TSPI_SERIAL_CK_2ND_EDGE;
        instance.tspi_tx_obj.init.fmr0.ckpol = TSPI_SERIAL_CK_IDLE_HI;
        instance.tspi_tx_obj.init.fmr0.csint = TSPI_MIN_IDLE_TIME_12;
        instance.tspi_tx_obj.init.fmr0.cssckdl = TSPI_SERIAL_CK_DELAY_4;
        instance.tspi_tx_obj.init.fmr0.sckcsdl = TSPI_NEGATE_8;
        /* Set Initial parameter of TSPIxFMTR1 */
        instance.tspi_tx_obj.init.fmr1.ehold = TSPI_EHOLD_2_FSYS;
        instance.tspi_tx_obj.init.fmr1.vpe = TSPI_PARITY_DISABLE;
        instance.tspi_tx_obj.init.fmr1.vpm = TSPI_PARITY_BIT_ODD;
        /* Set Initial parameter of TSPISECTCR0 */
        instance.tspi_tx_obj.init.sectcr0.sect = TSPI_SECTCR0_SECT_FRAME_MODE;
        /* Set Initial parameter of TSPISECTCR1 */
        instance.tspi_tx_obj.init.sectcr1.sectl0 = TSPI_SECTCR1_SECTL0_1;
        instance.tspi_tx_obj.init.sectcr1.sectl1 = TSPI_SECTCR1_SECTL1_1;
        instance.tspi_tx_obj.init.sectcr1.sectl2 = TSPI_SECTCR1_SECTL2_0;
        instance.tspi_tx_obj.init.sectcr1.sectl3 = TSPI_SECTCR1_SECTL3_0;
        instance.tspi_tx_obj.transmit.handler = transmit_handler;
        if ( instance.tspi_tx_obj.p_instance != MAIN_NULL)
        {
            if (tspi_init(&instance.tspi_tx_obj) != TXZ_SUCCESS)
            {
                result = TXZ_ERROR;
            }
        }
        else
        {
            result = TXZ_ERROR;
        }
    }
#else
    {
        instance.tspi_dma.super.init.id  = USER_ID_TSPI_TX;
        switch (bsp_get_tspi_tx_ch(BSP_TSPI_0))
        {
        case 0:
            instance.tspi_dma.super.p_instance  = TSB_TSPI0;
            break;
#if !defined(TMPM4KHA)
        case 1:
            instance.tspi_dma.super.p_instance  = TSB_TSPI1;
            break;
#endif
        default:
            instance.tspi_dma.super.p_instance  = MAIN_NULL;
            break;
        }

        /* Set Initial parameter of TSPIxCR1 */
        instance.tspi_dma.super.init.cnt1.inf = TSPI_INF_DISABLE;
        instance.tspi_dma.super.init.cnt1.trgen = TSPI_TRGEN_DISABLE;
        instance.tspi_dma.super.init.cnt1.tspims = TSPI_SPI_MODE;
        instance.tspi_dma.super.init.cnt1.mstr = TSPI_SLAVE_OPERATION;
        instance.tspi_dma.super.init.cnt1.tmmd = TSPI_TX_ONLY;
        instance.tspi_dma.super.init.cnt1.cssel = TSPI_TSPIxCS0_ENABLE;
        instance.tspi_dma.super.init.cnt1.fc = TSPI_TRANS_RANGE_CONTINUE;
        /* Set Initial parameter of TSPIxCR2 */
        instance.tspi_dma.super.init.cnt2.tidle = TSPI_TIDLE_HI;
        instance.tspi_dma.super.init.cnt2.txdemp = TSPI_TXDEMP_HI;
        instance.tspi_dma.super.init.cnt2.rxdly = TSPI_RXDLY_FSYS_FSCK_4;
        instance.tspi_dma.super.init.cnt2.til = (TX_FILL_LEVEL << 12U);
        instance.tspi_dma.super.init.cnt2.ril = TSPI_RX_FILL_LEVEL_1;
        instance.tspi_dma.super.init.cnt2.inttxwe = TSPI_TX_INT_DISABLE;
        instance.tspi_dma.super.init.cnt2.intrxwe = TSPI_RX_INT_DISABLE;
        instance.tspi_dma.super.init.cnt2.inttxfe = TSPI_TX_FIFO_INT_ENABLE;
        instance.tspi_dma.super.init.cnt2.intrxfe = TSPI_RX_FIFO_INT_DISABLE;
        instance.tspi_dma.super.init.cnt2.interr = TSPI_ERR_INT_ENABLE;
        instance.tspi_dma.super.init.cnt2.dmate = TSPI_TX_DMA_INT_DISABLE;
        instance.tspi_dma.super.init.cnt2.dmare = TSPI_RX_DMA_INT_DISABLE;
        /* Set Initial parameter of TSPIxBR */
        instance.tspi_dma.super.init.brd.brck = TSPI_BR_CLOCK_1;
        instance.tspi_dma.super.init.brd.brs = TSPI_BR_DIVIDER_2;
        /* Set Initial parameter of TSPIxFMTR0 */
        instance.tspi_dma.super.init.fmr0.dir = TSPI_DATA_DIRECTION_MSB;
        instance.tspi_dma.super.init.fmr0.fl = TSPI_DATA_LENGTH_8;
        instance.tspi_dma.super.init.fmr0.fint = TSPI_INTERVAL_TIME_0;
        instance.tspi_dma.super.init.fmr0.cs3pol = TSPI_TSPIxCS3_NEGATIVE;
        instance.tspi_dma.super.init.fmr0.cs2pol = TSPI_TSPIxCS2_NEGATIVE;
        instance.tspi_dma.super.init.fmr0.cs1pol = TSPI_TSPIxCS1_NEGATIVE;
        instance.tspi_dma.super.init.fmr0.cs0pol = TSPI_TSPIxCS0_NEGATIVE;
        instance.tspi_dma.super.init.fmr0.ckpha = TSPI_SERIAL_CK_2ND_EDGE;
        instance.tspi_dma.super.init.fmr0.ckpol = TSPI_SERIAL_CK_IDLE_HI;
        instance.tspi_dma.super.init.fmr0.csint = TSPI_MIN_IDLE_TIME_12;
        instance.tspi_dma.super.init.fmr0.cssckdl = TSPI_SERIAL_CK_DELAY_4;
        instance.tspi_dma.super.init.fmr0.sckcsdl = TSPI_NEGATE_8;
        /* Set Initial parameter of TSPIxFMTR1 */
        instance.tspi_dma.super.init.fmr1.ehold = TSPI_EHOLD_2_FSYS;
        instance.tspi_dma.super.init.fmr1.vpe = TSPI_PARITY_DISABLE;
        instance.tspi_dma.super.init.fmr1.vpm = TSPI_PARITY_BIT_ODD;
        /* Set Initial parameter of TSPISECTCR0 */
        instance.tspi_dma.super.init.sectcr0.sect = TSPI_SECTCR0_SECT_FRAME_MODE;
        /* Set Initial parameter of TSPISECTCR1 */
        instance.tspi_dma.super.init.sectcr1.sectl0 = TSPI_SECTCR1_SECTL0_1;
        instance.tspi_dma.super.init.sectcr1.sectl1 = TSPI_SECTCR1_SECTL1_1;
        instance.tspi_dma.super.init.sectcr1.sectl2 = TSPI_SECTCR1_SECTL2_0;
        instance.tspi_dma.super.init.sectcr1.sectl3 = TSPI_SECTCR1_SECTL3_0;

        instance.dma.p_instance = TSB_DMAA;
        instance.tspi_dma.init.p_obj = &instance.dma;
        /*--- Initialize ---*/
        instance.dma.init.baseAdd = (uint32_t)&primary[0];
        if (dma_init(&instance.dma) != TXZ_SUCCESS)
        {
            result = TXZ_ERROR;
        }

        instance.tspi_dma.init.tx.type = TSPI_DMA_TYPE_MEM_TO_PERI;
        instance.tspi_dma.init.tx.ch     = bsp_get_tspi_tx_dma_ch(BSP_TSPI_0);
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.dstInc    = CFG_DMA_ch_dstinc_1byte ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.dstSize   = CFG_DMA_ch_dstsize_1byte ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.srcInc    = CFG_DMA_ch_srcinc_none ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.srcSize   = CFG_DMA_ch_srcsize_1byte ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.arbitNum  = CFG_DMA_ch_rpow_001 ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.burst     = CFG_DMA_ch_next_useburst ;
    
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.dstInc    = CFG_DMA_ch_dstinc_none ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.dstSize   = CFG_DMA_ch_dstsize_1byte ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.srcInc    = CFG_DMA_ch_srcinc_1byte ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.srcSize   = CFG_DMA_ch_srcsize_1byte ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.arbitNum  = CFG_DMA_ch_rpow_001 ;
        instance.tspi_dma.init.p_obj->ch[instance.tspi_dma.init.tx.ch].cfg.burst     = CFG_DMA_ch_next_useburst ;
        instance.tspi_dma.super.transmit.handler = transmit_handler;
        if (tspi_dma_init(&instance.tspi_dma) != TXZ_SUCCESS)
        {
            result = TXZ_ERROR;
        }
    }
#endif

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI CRC TXdata
  * @param  -
  * @return -
  * @retval -
  * @note   
  */
/*--------------------------------------------------*/
static void set_crc_tx_data(void)
{
    crc_crctyp_t param;
    uint8_t     data_size  = sizeof(MCU_NAME) - 1;
    uint32_t val[2]  = {0,0};
    uint32_t i;
    uint8_t *ptr;
    uint32_t reg, work;

    memset( (void *)send.tx_buf , 0 , DATA_LENGTH );

    strncpy( (char *)&send.tx_buf[0] , (char *)MCU_NAME, data_size );
    #if CHK_CODE == CHK_CODE_CRC16
    data_size = DATA_LENGTH - 2U;
#else
    data_size = DATA_LENGTH - 4U;
#endif

    /*----------------------*/
    /* CRC                  */
    /*----------------------*/
    /* CRCTYP Register SET. */
    
    param.dbit = REG_CRC_DBIT_32bit;
#if CHK_CODE == CHK_CODE_CRC16
    param.cfmt = REG_CRC_CFMT_CRC16;
#else
    param.cfmt = REG_CRC_CFMT_CRC32;
#endif
    REG_CRCTYP_set(TSB_CRC, param);
#if CHK_CODE == CHK_CODE_CRC16
    REG_CRCCLC_set(TSB_CRC, REG_CRCCLC_DEFAULT_VAL_16);
#else
    REG_CRCCLC_set(TSB_CRC, REG_CRCCLC_DEFAULT_VAL_32);
#endif

    ptr = (uint8_t *)send.tx_buf;
    work = 0x00;
    for( i=0; i < data_size; ++i )
    {
        work = ((work << 8U) | ((uint32_t)*ptr));
        ptr++;
        if( (i % 4) == 3 )
        {
            REG_CRCDIN_set(TSB_CRC, work);
             work = 0x00;
        }
    }
    if( (data_size % 4 ) == 0 )
    {
        /* no process */
    }
    else if( (data_size % 4 ) == 1 )
    {
        reg = (REG_CRCTYP_get(TSB_CRC) & REG_CRC_CFMT_CRC32);
        param.dbit = REG_CRC_DBIT_8bit;
        param.cfmt = reg;
        REG_CRCTYP_set(TSB_CRC, param);
        REG_CRCDIN_set(TSB_CRC, work);
    }
    else if( (data_size % 4 ) == 2 )
    {
        reg = (REG_CRCTYP_get(TSB_CRC) & REG_CRC_CFMT_CRC32);
        param.dbit = REG_CRC_DBIT_16bit;
        param.cfmt = reg;
        REG_CRCTYP_set(TSB_CRC, param);
        REG_CRCDIN_set(TSB_CRC, work);
    }
    else if( (data_size % 4 ) == 3 )
    {
        uint32_t work2 = work >> 8U;
        reg = (REG_CRCTYP_get(TSB_CRC) & REG_CRC_CFMT_CRC32);
        param.dbit = REG_CRC_DBIT_16bit;
        param.cfmt = reg;
        REG_CRCTYP_set(TSB_CRC, param);
        REG_CRCDIN_set(TSB_CRC, work2);
        work2 = work & 0xFFU;
        reg = (REG_CRCTYP_get(TSB_CRC) & REG_CRC_CFMT_CRC32);
        param.dbit = REG_CRC_DBIT_8bit;
        param.cfmt = reg;
        REG_CRCTYP_set(TSB_CRC, param);
        REG_CRCDIN_set(TSB_CRC, work2);
    }

    val[0] = REG_CRCCLC_get(TSB_CRC);
    val[1] = REG_CRCCLC_get(TSB_CRC);

#if CHK_CODE == CHK_CODE_CRC16
    send.tx_buf[data_size] = (uint8_t)(val[1] >> 8);
    send.tx_buf[data_size+1] = (uint8_t)(val[1]  & 0x000000FF);
#else
    send.tx_buf[data_size] = (uint8_t)(val[1] >> 24);
    send.tx_buf[data_size+1] = (uint8_t)(val[1] >> 16);
    send.tx_buf[data_size+2] = (uint8_t)(val[1] >> 8);
    send.tx_buf[data_size+3] = (uint8_t)(val[1]  & 0x000000FF);
#endif
}


/**
 *  @}
 */ /* End of group TSPI_SlaveTrans_Private_functions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup TSPI_SlaveTrans_Exported_functions TSPI_SlaveTrans Exported Functions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    int ret;

    /*----------------------*/
    /* BSP initialize       */
    /*----------------------*/
    bsp_initialize();
    /*----------------------*/
    /* Initialize           */
    /*----------------------*/
    /*--- variable    ---*/
    variable_initialize();
    /*--- driver      ---*/
    if (driver_initialize() != TXZ_SUCCESS)
    {
        proc = PROC_ERROR;
    }
    /*--- application ---*/
    if (application_initialize() != TXZ_SUCCESS)
    {
        proc = PROC_ERROR;
    }
    /*--- tspi ---*/
    if (tspi_initialize() != TXZ_SUCCESS)
    {
        proc = PROC_ERROR;
    }
    set_crc_tx_data();
    led_turn_off(&instance.led[1]);
    led_turn_off(&instance.led[2]);
    /*----------------------*/
    /* 1ms Timer Start      */
    /*----------------------*/
    timer_start(&instance.timer);

    /*----------------------*/
    /* Main Processing      */
    /*----------------------*/
    while(proc != PROC_ERROR)
    {
        switch( proc )
        {
#if TX_MODE  == FIFO_MODE
            case PROC_FIFO_IDLE:
            {
                uint32_t i;
                /*----------------------*/
                /* SW                   */
                /*----------------------*/
                for (i=0; i<(uint32_t)BSP_PSW_MAX; i++)
                {
                    sw_task(&instance.sw[i]);
                }
            }
            break;

            case PROC_FIFO_START:
            {
                NVIC_EnableIRQ(bsp_get_tspi_tx_nvic(BSP_TSPI_0));
                NVIC_EnableIRQ(bsp_get_tspi_tx_err_nvic(BSP_TSPI_0));
                /* Send Data Set */
                t_info.tx8.p_data = (uint8_t *)send.tx_buf;
                t_info.tx8.num = DATA_LENGTH;
                /* Transfer Start */
                ret = tspi_transfer(&instance.tspi_tx_obj, &t_info);
                send.state = SEND_RUN;
                proc = PROC_FIFO_TRANS;
                if(ret == TXZ_ERROR)
                {
                    proc = PROC_FIFO_ERROR;
                }
            }
            break;

            case PROC_FIFO_TRANS:
                if(send.state == SEND_SUCCESS){
                    uint32_t status;
                    tspi_get_status(&instance.tspi_tx_obj, &status);
                    if(((status & TSPI_TX_REACH_FILL_LEVEL_MASK) >> 16) == 0)
                    {
                        send.state = SEND_IDLE;
                        proc = PROC_FIFO_FINISHED;
                    }
                }
                else if(send.state == SEND_FAILURE){
                    send.state = SEND_IDLE;
                    proc = PROC_FIFO_ERROR;
                }
                else{
                    /* do nothing */
                }
            break;

            case PROC_FIFO_FINISHED:
            {
                uint32_t status;
                tspi_get_status(&instance.tspi_tx_obj, &status);

                if( (status & TSPI_TX_DONE_FLAG) == TSPI_TX_DONE_FLAG )
                {
                    if( (status & TSPI_TX_FLAG_MASK) == TSPI_TX_FLAG_STOP )
                    {
                        if( (status & TSPI_TX_FIFO_EMP) == TSPI_TX_FIFO_EMP )
                        {
                            if (tspi_stop(&instance.tspi_tx_obj) != TXZ_SUCCESS)
                            {
                                /* no processing */
                            }
                            if(ledflag == 1){
                                led_turn_off(&instance.led[1]);
                                ledflag = 0;
                            }
                            else{
                                led_turn_on(&instance.led[1]);
                                ledflag = 1;
                            }
                            proc = PROC_FIFO_IDLE;
                        }
                    }
                }
            }
            break;

            case PROC_FIFO_ERROR:
                if (tspi_stop(&instance.tspi_tx_obj) != TXZ_SUCCESS)
                {
                    /* no processing */
                }
                NVIC_DisableIRQ(bsp_get_tspi_tx_nvic(BSP_TSPI_0));
                NVIC_DisableIRQ(bsp_get_tspi_tx_err_nvic(BSP_TSPI_0));

                proc = PROC_FIFO_IDLE;
                led_turn_on(&instance.led[2]);
            break;
#else
            case PROC_DMAC_IDLE:
            {
                uint32_t i;
                /*----------------------*/
                /* SW                   */
                /*----------------------*/
                for (i=0; i<(uint32_t)BSP_PSW_MAX; i++)
                {
                    sw_task(&instance.sw[i]);
                }
            }
            break;

            case PROC_DMAC_START: 
            {
                /*------------------------------*/
                /*  Initialize Variable         */
                /*------------------------------*/
                send.state     = TSPI_DMA_SEND_IDLE;

                NVIC_EnableIRQ( INTDMAATC_IRQn );
                NVIC_EnableIRQ( INTDMAAERR_IRQn );
                instance.tspi_dma.super.transmit.info.tx8.p_data = (uint8_t *)send.tx_buf;
                instance.tspi_dma.super.transmit.info.tx8.num = DATA_LENGTH;
                ret = tspi_dma_transmitIt(&instance.tspi_dma, &instance.tspi_dma.super.transmit.info);
                send.state =  TSPI_DMA_SEND_RUN;
                proc = PROC_DMAC_TRANS;
            }
            break;

            case PROC_DMAC_TRANS:
            {
                uint32_t status;

                /*------------------------------*/
                /*  Wait to transmit            */
                /*------------------------------*/
                while( send.state == TSPI_DMA_SEND_RUN )
                {
                }
                /*------------------------------*/
                /*  Check Error                 */
                /*------------------------------*/
                if( send.state  == TSPI_DMA_SEND_FAILURE )
                {
                    ret = TXZ_ERROR;
                }

                tspi_get_status(&instance.tspi_dma.super, &status);
                while( (status & TSPI_TX_FLAG_MASK) == TSPI_TX_FLAG_ACTIVE )
                {
                    tspi_get_status(&instance.tspi_dma.super, &status);
                }
                /* Clear status. */
                send.state = TSPI_DMA_SEND_IDLE;

                if(ret == TXZ_SUCCESS)
                {
                    proc = PROC_DMAC_FINISHED;
                }
                else
                {
                    proc = PROC_DMAC_ERROR;
                }
            }
            break;

            case PROC_DMAC_FINISHED:
            {
                uint32_t status;
                tspi_get_status(&instance.tspi_dma.super, &status);

                if( (status & TSPI_TX_DONE_FLAG) == TSPI_TX_DONE_FLAG )
                {
                    if( (status & TSPI_TX_FLAG_MASK) == TSPI_TX_FLAG_STOP )
                    {
                        if( (status & TSPI_TX_FIFO_EMP) == TSPI_TX_FIFO_EMP )
                        {
                            if (tspi_stop(&instance.tspi_dma.super) != TXZ_SUCCESS)
                            {
                                /* no processing */
                            }
                            NVIC_DisableIRQ( INTDMAATC_IRQn );
                            NVIC_DisableIRQ( INTDMAAERR_IRQn );
                            if(ledflag == 1){
                                led_turn_off(&instance.led[1]);
                                ledflag = 0;
                            }
                            else{
                                led_turn_on(&instance.led[1]);
                                ledflag = 1;
                            }
                            proc = PROC_DMAC_IDLE;
                        }
                    }
                }
            }
            break;

            case PROC_DMAC_ERROR:
            {
                if (tspi_stop(&instance.tspi_dma.super) != TXZ_SUCCESS)
                {
                    /* no processing */
                }
                NVIC_DisableIRQ( INTDMAATC_IRQn );
                NVIC_DisableIRQ( INTDMAAERR_IRQn );
                proc = PROC_DMAC_IDLE;
                led_turn_on(&instance.led[2]);
            }
            break;
#endif
            default:
                break;
        }
    }
    /*>>> System Error. Please Debug. */
    /*----------------------*/
    /* Finalize             */
    /*----------------------*/
    /*--- application ---*/
    if (application_finalize() != TXZ_SUCCESS)
    {
        /* no processing */
    }
    /*--- driver      ---*/
    if (driver_finalize() != TXZ_SUCCESS)
    {
        /* no processing */
    }
    /*----------------------*/
    /* BSP finalize         */
    /*----------------------*/
    bsp_finalize();
#ifdef __DEBUG__
    assert_failed(MAIN_NULL, 0);
#endif

    return (0);
}

/*--------------------------------------------------*/
/** 
  * @brief  Timer.
  * @param  timer :Timer.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_timer(BSPTimer timer)
{
    switch (timer)
    {
    case BSP_TIMER_1MS:
        timer_irq_handler(&instance.timer);
        break;
    default:
        /* no processing */
        break;
    }
}

#if TX_MODE  == FIFO_MODE
/*--------------------------------------------------*/
/** 
  * @brief  TSPI flash transmit IRQ.
  * @param  tspi :TSPI.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_tspi_tx(BSPTspi tspi)
{
    switch(tspi){
        case BSP_TSPI_0:
            tspi_irq_handler_transmit(&instance.tspi_tx_obj);
            break;
        case BSP_TSPI_1:
            tspi_irq_handler_transmit(&instance.tspi_tx_obj);
            break;
        default:
            proc = PROC_FIFO_ERROR;
            break;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI flash error IRQ.
  * @param  tspi :TSPI.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_tspi_err(BSPTspi tspi)
{
    switch(tspi){
        case BSP_TSPI_0:
            tspi_error_irq_handler(&instance.tspi_tx_obj);
            break;
        case BSP_TSPI_1:
            tspi_error_irq_handler(&instance.tspi_tx_obj);
            break;
        default:
            proc = PROC_FIFO_ERROR;
            break;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  Transmit handler.
  * @param  result  :Result.
  * @return -
  * @retval -
  * @note   Called by uart driver.
  */
/*--------------------------------------------------*/
static void transmit_handler(uint32_t id, TXZ_Result result)
{
    if( send.state != SEND_IDLE )
    {
        /*------------------------------*/
        /*  Result Check                */
        /*------------------------------*/
        if( result == TXZ_SUCCESS )
        {
            send.state = SEND_SUCCESS;
        }
        else
        {
            send.state = SEND_FAILURE;
        }
    }
}

#else
/*--------------------------------------------------*/
/** 
  * @brief  DMA transfer done IRQ.
  * @param  ch :DMA Channel
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_dmac_done(uint32_t ch)
{
    /* Call the DMA driver's handler. */
    dma_irq_handler(instance.tspi_dma.init.p_obj, ch);
}

/*--------------------------------------------------*/
/** 
  * @brief  DMA transfer error IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_dmac_err(void)
{
    /* Call the DMA driver's handler. */
    dma_error_irq_handler(instance.tspi_dma.init.p_obj);
}

/*--------------------------------------------------*/
/** 
  * @brief  Transmit handler.
  * @param  result  :Result.
  * @return -
  * @retval -
  * @note   Called by uart driver.
  */
/*--------------------------------------------------*/
static void transmit_handler(uint32_t id, TXZ_Result result)
{
    if( send.state != TSPI_DMA_SEND_IDLE )
    {
        /*------------------------------*/
        /*  Result Check                */
        /*------------------------------*/
        if( result == TXZ_SUCCESS )
        {
            send.state = TSPI_DMA_SEND_SUCCESS;
        }
        else
        {
            send.state = TSPI_DMA_SEND_FAILURE;
        }
    }
}
#endif

#ifdef __DEBUG__
/*--------------------------------------------------*/
/** 
  * @brief  Failure Assert.
  * @note   for debug
  */
/*--------------------------------------------------*/
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

/**
 *  @}
 */ /* End of group TSPI_SlaveTrans_Exported_functions */

/**
 *  @} 
 */ /* End of group TSPI_SlaveTrans */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
