/** 
 *******************************************************************************
 * @file    main.c
 * @brief   UART_RECEIVE Sample Application.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include <stdio.h>
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_uart_io.h"
#include "bsp_uart_io_dma.h"

/**
 *  @addtogroup Example
 *  @{
 */

/** 
 *  @defgroup UART_RECEIVE UART_RECEIVE Sample Appli
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_macro UART_RECEIVE Private Macro
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group UART_RECEIVE_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_define UART_RECEIVE Private Define
 *  @{
 */

/*----------------------*/
/*  DMA Setting         */
/*----------------------*/
/* Work Area = ((The total number of the used channel) * (4 * DWORD) * 2)  */
#define CFG_DMA_WORK_SIZE     ((uint32_t)(DMA_CH_NUM * 4 * sizeof(uint32_t) * 2))     /*!< DMA work area. */

/** 
 *  @}
 */ /* End of group UART_RECEIVE_Private_define */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_define UART_RECEIVE Private Define
 *  @{
 */

#define MAIN_NULL               ((void *)0) /*!< Null Pointer */
#define USER_ID_UART            ((uint32_t)1)   /*!< User ID :USB UART (Any value) */

#define CFG_DMA_ch_dstinc_1byte               0x00000000 ; /*!< dstinc 1 byte */
#define CFG_DMA_ch_dstinc_2byte               0x00000001 ; /*!< dstinc 2 byte */
#define CFG_DMA_ch_dstinc_4byte               0x00000010 ; /*!< dstinc 4 byte */
#define CFG_DMA_ch_dstinc_none                0x00000011 ; /*!< dstinc none */
#define CFG_DMA_ch_dstsize_1byte              0x00000000 ; /*!< dstsize 1 byte */
#define CFG_DMA_ch_dstsize_2byte              0x00000001 ; /*!< dstsize 2 byte */
#define CFG_DMA_ch_dstsize_4byte              0x00000010 ; /*!< dstsize 4 byte */
#define CFG_DMA_ch_srcinc_1byte               0x00000000 ; /*!< srcinc 1 byte */
#define CFG_DMA_ch_srcinc_2byte               0x00000001 ; /*!< srcinc 2 byte */
#define CFG_DMA_ch_srcinc_4byte               0x00000010 ; /*!< srcinc 4 byte */
#define CFG_DMA_ch_srcinc_none                0x00000011 ; /*!< srcinc none */
#define CFG_DMA_ch_srcsize_1byte              0x00000000 ; /*!< srcsize 1 byte */
#define CFG_DMA_ch_srcsize_2byte              0x00000001 ; /*!< srcsize 2 byte */
#define CFG_DMA_ch_srcsize_4byte              0x00000010 ; /*!< srcsize 4 byte */
#define CFG_DMA_ch_rpow_001                   0x00000000 ; /*!< R power 1 */
#define CFG_DMA_ch_rpow_002                   0x00000001 ; /*!< R power 2 */
#define CFG_DMA_ch_rpow_004                   0x00000010 ; /*!< R power 4 */
#define CFG_DMA_ch_rpow_008                   0x00000011 ; /*!< R power 8 */
#define CFG_DMA_ch_rpow_016                   0x00000100 ; /*!< R power 16 */
#define CFG_DMA_ch_rpow_032                   0x00000101 ; /*!< R power 32 */
#define CFG_DMA_ch_rpow_064                   0x00000110 ; /*!< R power 64 */
#define CFG_DMA_ch_rpow_128                   0x00000111 ; /*!< R power 128 */
#define CFG_DMA_ch_rpow_256                   0x00001000 ; /*!< R power 256 */
#define CFG_DMA_ch_rpow_512                   0x00001001 ; /*!< R power 512 */
#define CFG_DMA_ch_rpow_none                  0x00001111 ; /*!< R power none */
#define CFG_DMA_ch_next_usesingle             0x00000000 ; /*!< next use single */
#define CFG_DMA_ch_next_useburst              0x00000001 ; /*!< next use burst  */

#define MCU_NAME        "TMPM4KNFYA\n"
/** 
 *  @}
 */ /* End of group UART_RECEIVE_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_define UART_RECEIVE Private Define
 *  @{
 */
/*----------------------------------*/
/** 
 * @brief  Processing mode.
*/
/*----------------------------------*/
typedef enum
{
    PROC_START,             /*!< Start.                       */
    PROC_INPUT,             /*!< Input message.               */
    PROC_INPUT_COMPARE,     /*!< Input message compare.       */
    PROC_OUTPUT_ERR,        /*!< Output input error message.  */
    PROC_ERROR              /*!< Error.                       */
} Processing;
/** 
 *  @}
 */ /* End of group UART_RECEIVE_Private_define */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_typedef UART_RECEIVE Private Typedef
 *  @{
 */
/*----------------------------------*/
/** 
 * @brief  Private Member.
*/
/*----------------------------------*/
typedef struct
{
    uart_io_private_rx_t    rx;                 /*!< Send information.           */
} info_t;
/*----------------------------------*/
/** 
 * @brief Instance Information.
*/
/*----------------------------------*/
typedef struct
{
    dma_t           dma;                        /*!< Driver      :DMA.               */
    led_t           led[(uint32_t)BSP_LED_MAX]; /*!< Application :LED                */
    uart_io_dma_t   uart_dma;                   /*!< Application :USB UART.          */
    uart_io_t       uart;                       /*!< Application :USB UART. */
    info_t          info;
} instance_t;

/*----------------------------------*/
/** 
 * @brief  Input data information.
*/
/*----------------------------------*/
typedef struct
{
    char    data[(UART_IO_RECEIVE_MAX+2+3)];  /*!< Input data(+ 3(for receive error detection) + LF(\n) + for NULL 1byte). */
    uint8_t rp;                             /*!< Read pointer.                 */
} input_t;
/**
 *  @}
 */ /* End of group UART_RECEIVE_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_variables UART_RECEIVE Private Variables
 *  @{
 */
static instance_t instance;  /*!< Instance.               */
static Processing proc;      /*!< Processing mode.        */
static input_t    input;     /*!< Input data information. */
static uint8_t mcu_name[] = MCU_NAME;
static uint8_t data[sizeof( MCU_NAME ) - 1U];
#ifdef DMA
#if defined ( __CC_ARM   )      /* RealView Compiler */
    static __align(0x400) uint8_t primary[CFG_DMA_WORK_SIZE]; /*!< DMA work area. */
#elif defined ( __ICCARM__ )    /*IAR Compiler */
    #pragma location="dma_work"
    #pragma data_alignment=1024
    static uint8_t primary[CFG_DMA_WORK_SIZE]; /*!< DMA work area. */
#elif defined ( __SES_ARM )     /* Segger Compiler */
    static uint8_t __attribute__((__aligned__(0x400)))primary[CFG_DMA_WORK_SIZE];
#endif
#endif
/**
 *  @}
 */ /* End of group UART_RECEIVE_Private_variables */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Private_fuctions UART_RECEIVE Private Fuctions
 *  @{
 */
static void variable_initialize(void);
#ifdef DMA
static TXZ_Result driver_dma_initialize(void);
static TXZ_Result driver_dma_finalize(void);
#endif
static TXZ_Result driver_initialize(void);
static TXZ_Result driver_finalize(void);
static TXZ_Result application_initialize(void);
static TXZ_Result application_finalize(void);
static void clear_input_data(void);
static TXZ_Result uart_initialize(void);
/*--------------------------------------------------*/
/** 
  * @brief  Variable Initialize
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void variable_initialize(void)
{
    instance.uart.init.p_reg    = MAIN_NULL;
    {
        uint32_t i;

        for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
        {
            instance.led[i].init.p_gpio = MAIN_NULL;
        }
    }
#ifdef DMA
    uint32_t i;

    /* Instance. */
    instance.uart_dma.init.p_reg = MAIN_NULL;
    instance.dma.p_instance     = MAIN_NULL;
    /* DMA work area. */
    for (i=0; i<CFG_DMA_WORK_SIZE; i++)
    {
        primary[i] = 0;
    }
#endif
    /* Processing mode. */
    proc = PROC_START;
    {
        uint8_t i;

        for (i = 0; i < (sizeof( MCU_NAME ) - 1U); i++)
        {
            data[i] = mcu_name[i];
        }
    }
    /* Input data information. */
    clear_input_data();
}

#ifdef DMA
/*--------------------------------------------------*/
/** 
  * @brief  DMA Driver Initialize.
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result driver_dma_initialize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*--- Construct (Register Allocation) ---*/
    instance.dma.p_instance = TSB_DMAA;

    /*--- Initialize ---*/
    instance.dma.init.baseAdd = (uint32_t)&primary[0];
    if (dma_init(&instance.dma) != TXZ_SUCCESS)
    {
        result = TXZ_ERROR;
    }



    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  DMA Driver Finalize.
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result driver_dma_finalize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*--- Finalize ---*/
    if (dma_deinit(&instance.dma) != TXZ_SUCCESS)
    {
        result = TXZ_ERROR;
    }
    /*--- Destruct (Register Release) ---*/
    /* Register Allocation */
    instance.dma.p_instance = MAIN_NULL;

    return (result);
}
#endif

/*--------------------------------------------------*/
/** 
  * @brief  Driver Initialize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result driver_initialize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* GPIO                 */
    /*----------------------*/
    /* Driver initialize has done within BSP. */
    /*----------------------*/
    /* Uart                 */
    /*----------------------*/
    /* Driver initialize will process within USB UART. */
#ifdef DMA
    /*----------------------*/
    /* DMA                  */
    /*----------------------*/
    if (driver_dma_initialize() != TXZ_SUCCESS)
    {
        result = TXZ_ERROR;
    }
#endif

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Driver Finalize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result driver_finalize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* Uart                 */
    /*----------------------*/
    /* Driver finalize has done within USB UART.    */
    /*----------------------*/
    /* GPIO                 */
    /*----------------------*/
    /* Driver finalize will process within BSP.     */
#ifdef DMA
    /*----------------------*/
    /* DMA                  */
    /*----------------------*/
    if (driver_dma_finalize() != TXZ_SUCCESS)
    {
        result = TXZ_ERROR;
    }
#endif
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Application Initialize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result application_initialize(void)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*----------------------*/
    /* LED                  */
    /*----------------------*/
    {
        uint32_t i;
        led_t *p_led = MAIN_NULL;

        for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
        {
            p_led = &instance.led[i];

            p_led->init.id          = (uint32_t)p_led;
            p_led->init.p_gpio      = bsp_get_gpio_instance_address();
            p_led->init.port.group  = bsp_get_gpio_group_led((BSPLed)(i));
            p_led->init.port.num    = bsp_get_gpio_num_led((BSPLed)(i));
            p_led->init.state               = LED_STATE_OFF;
            p_led->init.blink.func          = TXZ_DISABLE;
            p_led->init.blink.interval.on   = 0;
            p_led->init.blink.interval.off  = 0;
            led_initialize(p_led);
        }
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Application Finalize
  * @param  -
  * @return Result.
  * @retval TXZ_SUCCESS :Success
  * @retval TXZ_ERROR   :Failure
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result application_finalize(void)
{
    TXZ_Result result = TXZ_SUCCESS;
    uint32_t i;

#ifdef NODMAC
    /*----------------------*/
    /* Usb Uart             */
    /*----------------------*/
    if (instance.uart.init.p_reg != MAIN_NULL)
    {
        uart_io_finalize();
    }
#endif
#ifdef DMA
    /*----------------------*/
    /* USB UART             */
    /*----------------------*/
    if (instance.uart_dma.init.p_reg != MAIN_NULL)
    {
        uart_io_dma_finalize(&instance.uart_dma);
        NVIC_DisableIRQ(INTDMAATC_IRQn);
        NVIC_DisableIRQ(INTDMAAERR_IRQn);
    }
#endif
    /*----------------------*/
    /* LED                  */
    /*----------------------*/
    for (i=0; i<(uint32_t)BSP_LED_MAX; i++)
    {
        led_finalize(&instance.led[i]);
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Clear input data.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void clear_input_data(void)
{
    uint8_t i;

    for (i=0; i<(UART_IO_RECEIVE_MAX+2+3); i++)
    {
        input.data[i] = 0;
    }
    input.rp = 0;
}

/*--------------------------------------------------*/
/** 
  * @brief  UART1 Initialize
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static TXZ_Result uart_initialize(void)
{
    TXZ_Result result = TXZ_SUCCESS;
    
#ifdef NODMAC
    /*----------------------*/
    /* Uart                 */
    /*----------------------*/
    /* Tx use same UART channel. */
    {
        uart_io_t *param = &instance.uart;
        param->init.id         = USER_ID_UART;

        switch (bsp_get_usb_uart_tx_ch(BSP_USB_UART_0))
        {
        case 0:
            param->init.p_reg  = TSB_UART0;
            break;
        case 1:
            param->init.p_reg  = TSB_UART1;
            break;
        case 2:
            param->init.p_reg  = TSB_UART2;
            break;
        default:
            param->init.p_reg  = MAIN_NULL;
            break;
        }
        param->init.boudrate   = bsp_get_usb_uart_tx_baudrate(BSP_USB_UART_0);
        param->init.irq.tx     = bsp_get_usb_uart_tx_nvic(BSP_USB_UART_0);
        param->init.irq.rx     = bsp_get_usb_uart_rx_nvic(BSP_USB_UART_0);
        param->init.irq.err    = bsp_get_usb_uart_err_nvic(BSP_USB_UART_0);
        if (param->init.p_reg != MAIN_NULL)
        {
            result  = uart_io_initialize(&param->init);
        }
        else
        {
            result = TXZ_ERROR;
        }

        return (result);
    }
#endif
#ifdef DMA
    /*----------------------*/
    /* Uart DMA             */
    /*----------------------*/
    /* Tx are same channel */
    {
        uart_io_dma_t *param = &instance.uart_dma;
        param->init.id         = USER_ID_UART;
        switch (bsp_get_usb_uart_tx_ch(BSP_USB_UART_0))
        {
        case 0:
            param->init.p_reg  = TSB_UART0;
            break;
        case 1:
            param->init.p_reg  = TSB_UART1;
            break;
        case 2:
            param->init.p_reg  = TSB_UART2;
            break;
        default:
            param->init.p_reg  = MAIN_NULL;
            break;
        }
        param->init.boudrate   = bsp_get_usb_uart_tx_baudrate(BSP_USB_UART_0);
        param->init.dma.p_dma  = &instance.dma;
        param->init.dma.tx     = bsp_get_usb_uart_tx_dma_ch(BSP_USB_UART_0);
        param->init.dma.rx     = bsp_get_usb_uart_rx_dma_ch(BSP_USB_UART_0);

        param->init.dma.p_dma->ch[param->init.dma.rx].cfg.dstInc    = CFG_DMA_ch_dstinc_1byte;
        param->init.dma.p_dma->ch[param->init.dma.rx].cfg.dstSize   = CFG_DMA_ch_dstsize_1byte;
        param->init.dma.p_dma->ch[param->init.dma.rx].cfg.srcInc    = CFG_DMA_ch_srcinc_none;
        param->init.dma.p_dma->ch[param->init.dma.rx].cfg.srcSize   = CFG_DMA_ch_srcsize_1byte;
        param->init.dma.p_dma->ch[param->init.dma.rx].cfg.arbitNum  = CFG_DMA_ch_rpow_001;
        param->init.dma.p_dma->ch[param->init.dma.rx].cfg.burst     = CFG_DMA_ch_next_useburst;
    
        param->init.dma.p_dma->ch[param->init.dma.tx].cfg.dstInc    = CFG_DMA_ch_dstinc_none;
        param->init.dma.p_dma->ch[param->init.dma.tx].cfg.dstSize   = CFG_DMA_ch_dstsize_1byte;
        param->init.dma.p_dma->ch[param->init.dma.tx].cfg.srcInc    = CFG_DMA_ch_srcinc_1byte;
        param->init.dma.p_dma->ch[param->init.dma.tx].cfg.srcSize   = CFG_DMA_ch_srcsize_1byte;
        param->init.dma.p_dma->ch[param->init.dma.tx].cfg.arbitNum  = CFG_DMA_ch_rpow_001;
        param->init.dma.p_dma->ch[param->init.dma.tx].cfg.burst     = CFG_DMA_ch_next_useburst;

        if (param->init.p_reg != MAIN_NULL)
        {
            param  = uart_io_dma_initialize(&param->init);
        }
        else
        {
            result = TXZ_ERROR;
        }
        return (result);
    }
#endif
}
/**
 *  @}
 */ /* End of group UART_RECEIVE_Private_fuctions */


/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup UART_RECEIVE_Exported_functions UART_RECEIVE Exported Functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*----------------------*/
    /* BSP initialize       */
    /*----------------------*/
    bsp_initialize();
    /*----------------------*/
    /* Initialize           */
    /*----------------------*/
    /*--- variable    ---*/
    variable_initialize();
    /*--- driver      ---*/
    if (driver_initialize() != TXZ_SUCCESS)
    {
        proc = PROC_ERROR;
    }
    /*--- application ---*/
    if (application_initialize() != TXZ_SUCCESS)
    {
        proc = PROC_ERROR;
    }
    /*----------------------*/
    /* Main Processing      */
    /*----------------------*/
    while(proc != PROC_ERROR)
    {
        switch(proc)
        {
        /*--- Start ---*/
        case PROC_START:
            {
                /* Clear input data.     */
                clear_input_data();
                /*--- uart ---*/
                if (uart_initialize() != TXZ_SUCCESS)
                {
                    proc = PROC_ERROR;
                }
                else{
                    proc = PROC_INPUT;
                }
#ifdef DMA
                NVIC_EnableIRQ(INTDMAATC_IRQn);
                NVIC_EnableIRQ(INTDMAAERR_IRQn);
#endif
                
            }
            break;
        /*--- Wait to Input ---*/
        case PROC_INPUT:
            {
                int data;

                data = getchar();
                if ((data != -1) && (input.rp < (UART_IO_RECEIVE_MAX+1)))
                {
                    input.data[input.rp] = (char)data;
                    input.rp++;
                    switch ((char)data)
                    {
                    /*--- LF: line feed ---*/
                    case '\n':
                        proc = PROC_INPUT_COMPARE;
                        break;
                    /*--- default ---*/
                    default:
                        /* no process */
                        break;
                    }
                }
                else
                {
                    proc = PROC_OUTPUT_ERR;
                }
            }
            break;
        /*--- Input data compare ---*/
        case PROC_INPUT_COMPARE:
            {
                uint32_t tmp = 0U;
                TXZ_Result result = TXZ_SUCCESS;
                led_t *p_led0 = &instance.led[0];
                led_t *p_led2 = &instance.led[2];

                for (tmp = 0U; tmp < input.rp; tmp++) {
                    if (data[tmp] != input.data[tmp]) {
                        result = TXZ_ERROR;
                        break;
                    } else { 
                    }
                }
                if (result == TXZ_SUCCESS)
                {
                    led_turn_on(p_led0);
                }
                else
                {
                    led_turn_off(p_led0);
                }
                led_turn_off(p_led2);
                proc = PROC_START;
            }
            break;
        /*--- Output "Error Message" ---*/
        case PROC_OUTPUT_ERR:
            {
                led_t *p_led0 = &instance.led[0];
                led_t *p_led2 = &instance.led[2];
                led_turn_off(p_led0);
                led_turn_on(p_led2);
                proc = PROC_START;
            }
            break;
        /*--- Error ---*/
        case PROC_ERROR:
            /* no processing */
            break;
        /*--- Default ---*/
        default:
            proc = PROC_ERROR;
            break;
        }
    }
    /*>>> System Error. Please Debug. */
    /*----------------------*/
    /* Finalize             */
    /*----------------------*/
    /*--- application ---*/
    if (application_finalize() != TXZ_SUCCESS)
    {
        /* no processing */
    }
    /*--- driver      ---*/
    if (driver_finalize() != TXZ_SUCCESS)
    {
        /* no processing */
    }
    /*----------------------*/
    /* BSP finalize         */
    /*----------------------*/
    bsp_finalize();
#ifdef __DEBUG__
    assert_failed(MAIN_NULL, 0);
#endif

    return (0);
}

#ifdef NODMAC
/*--------------------------------------------------*/
/** 
  * @brief  USB UART reception IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_usb_uart_rx(BSPUsbUart uart)
{
    switch (uart)
    {
    /*--- usb uart 0 ---*/
    case BSP_USB_UART_0:
        uart_io_rx_irq_handler();
        break;
    /*--- default    ---*/
    default:
        /* no processing */
        break;
    }

}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART transmit IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_usb_uart_tx(BSPUsbUart uart)
{
    switch (uart)
    {
        /*--- usb uart 0 ---*/
    case BSP_USB_UART_0:
        uart_io_tx_irq_handler();
        break;
    /*--- default    ---*/
    default:
        /* no processing */
        break;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  USB UART error IRQ.
  * @param  uart :USB UART.
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_usb_uart_err(BSPUsbUart uart)
{
    switch (uart)
    {
        /*--- usb uart 0 ---*/
    case BSP_USB_UART_0:
        uart_io_err_irq_handler();
        break;
    /*--- default    ---*/
    default:
        /* no processing */
        break;
    }
}
#endif

#ifdef DMA
/*--------------------------------------------------*/
/** 
  * @brief  DMA transfer done IRQ.
  * @param  ch :DMA Channel
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_dmac_done(uint32_t ch)
{
    /* Call the DMA driver's handler. */
    dma_irq_handler(&instance.dma, ch);
}

/*--------------------------------------------------*/
/** 
  * @brief  DMA transfer error IRQ.
  * @param  -
  * @return -
  * @retval -
  * @note   This function is called BSP.
  */
/*--------------------------------------------------*/
void irq_dmac_err(void)
{
    /* Call the DMA driver's handler. */
    dma_error_irq_handler(&instance.dma);
}
#endif

#ifdef __DEBUG__
/*--------------------------------------------------*/
/** 
  * @brief  Failure Assert.
  * @note   for debug
  */
/*--------------------------------------------------*/
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
/**
 *  @}
 */ /* End of group UART_RECEIVE_Exported_functions */

/**
 *  @}
 */ /* End of group UART_RECEIVE */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
