/** 
 *******************************************************************************
 * @file    adc_m4m1.h
 * @brief   This file provides all the functions prototypes for ADC driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __ADC_M4M1_H
#define __ADC_M4M1_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  @addtogroup Periph_Driver
 *  @{
 */

/** 
 *  @defgroup ADC ADC
 *  @brief    ADC Driver.
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
    @addtogroup ADC_Exported_define ADC Exported Define
    @{
 */
/** @enum adc_sampling_period_t
    @brief Outside AIN sampling period.
 */
typedef enum
{
    ADC_SAMPLING_PERIOD1_XN   = 0x000,       /*!< SCLK Period (1/SCLK)xN   */
    ADC_SAMPLING_PERIOD1_X2N  = 0x100,       /*!< SCLK Period (1/SCLK)x2N  */
    ADC_SAMPLING_PERIOD1_X4N  = 0x300,       /*!< SCLK Period (1/SCLK)x4N  */
}adc_sampling_period1_t;

/** @enum adc_sampling_period_t
    @brief Outside AIN sampling period.
 */
typedef enum
{
    ADC_SAMPLING_PERIOD0_XN   = 0x00,       /*!< SCLK Period (1/SCLK)xN   */
    ADC_SAMPLING_PERIOD0_X2N  = 0x08,       /*!< SCLK Period (1/SCLK)x2N  */
    ADC_SAMPLING_PERIOD0_X4N  = 0x18,       /*!< SCLK Period (1/SCLK)x4N  */
}adc_sampling_period0_t;

/*! @enum adc_sclk_t
    @brief Select AD prescaler output (SCLK).
 */
typedef enum
{
    ADC_SCLK_4 =  (0x00000000U),                /*!< ADCLK/4   */
    ADC_SCLK_8 =  (0x00000001U),                /*!< ADCLK/8   */
}adc_sclk_t;

/*! @enum adc_mod1_avdd5_5v_t
    @brief Select AVDD Voltage Band (MOD1).
 */
typedef enum
{
    ADC_MOD1_AVDD5_5V_SCLK_40 =  (0x00306122U),         /*!< SCLK period*4  */
    ADC_MOD1_AVDD5_5V_SCLK_30 =  (0x00308012U),         /*!< SCLK period*5  */
    ADC_MOD1_AVDD5_5V_SCLK_20 =  (0x00104011U),         /*!< SCLK period*6  */
}adc_mod1_avdd5_5v_t;

/*! @enum adc_mod2_t
    @brief Select ADC Product Setting Value (MOD2).
 */
typedef enum
{
    ADC_MOD2_TMPM4Mx = (0x00000000)
}adc_mod2_t;

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "adc_i.h"
#include "adc_ch_i.h"

/*------------------------------------------------------------------------------*/
/*  Table Definition                                                            */
/*------------------------------------------------------------------------------*/
#define VALID_SAMPLING_PERIOD1_TABLE_SIZE  (3U)
static const adc_sampling_period1_t valid_sampling_period1_setting_table[VALID_SAMPLING_PERIOD1_TABLE_SIZE] = {
    ADC_SAMPLING_PERIOD1_XN,
    ADC_SAMPLING_PERIOD1_X2N,
    ADC_SAMPLING_PERIOD1_X4N
};

#define VALID_SAMPLING_PERIOD0_TABLE_SIZE  (3U)
static const adc_sampling_period0_t valid_sampling_period0_setting_table[VALID_SAMPLING_PERIOD0_TABLE_SIZE] = {
    ADC_SAMPLING_PERIOD0_XN,
    ADC_SAMPLING_PERIOD0_X2N,
    ADC_SAMPLING_PERIOD0_X4N
};

#define VALID_SCLK_TABLE_SIZE  (2U)
static const adc_sclk_t valid_sclk_setting_table[VALID_SCLK_TABLE_SIZE] = {
    ADC_SCLK_4,
    ADC_SCLK_8
};

#define VALID_MOD1_TABLE_SIZE  (3U)
static const uint32_t valid_mod1_setting_table[VALID_MOD1_TABLE_SIZE] = {
    ADC_MOD1_AVDD5_5V_SCLK_40,
    ADC_MOD1_AVDD5_5V_SCLK_30,
    ADC_MOD1_AVDD5_5V_SCLK_20
};

#define VALID_MOD2_TABLE_SIZE  (1U)
static const uint32_t valid_mod2_setting_table[VALID_MOD2_TABLE_SIZE] = {
    ADC_MOD2_TMPM4Mx
};


/**
 *  @}
 */ /* End of group ADC */
/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __ADC_M4M1_H */


