/** 
 *******************************************************************************
 * @file    except_m4m1.h
 * @brief   This file provides all the functions prototypes for EXCEPT driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __EXCEPT_M4M1_H
#define __EXCEPT_M4M1_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
/**
 *  @addtogroup Periph_Driver
 *  @{
 */

/** 
 *  @defgroup EXCEPT EXCEPT
 *  @brief    EXCEPT Driver.
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup EXCEPT_Exported_define EXCEPT Exported Define
 *  @{
 */

#define IA_IMC_MAX                   (-1)
#define IB_IMC_MAX                   (69)
#define IMN_FLAG_MAX                 (165)

#define IA_NIC_START                 (0x0)
#define IA_IMC_START                 (0x20)
#define IB_NIC_START                 (0x10)
#define IB_IMC_START                 (0x60)

#define IA_NIC_INTN                  AVAILABLE
#define IB_NIC_INTN                  UNAVAILABLE
#define IA_IMC_INTN_TABLE_MAX        (1U)
#define IB_IMC_INTN_TABLE_MAX        (3U)
#if defined(TMPM4MNA)
static const uint32_t ia_imc_intn_table[IA_IMC_INTN_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_imc_intn_table[IB_IMC_INTN_TABLE_MAX] =
    {0x00000000, 0xFFFFFFFE, 0x00000021};
#elif defined(TMPM4MMA)
static const uint32_t ia_imc_intn_table[IA_IMC_INTN_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_imc_intn_table[IB_IMC_INTN_TABLE_MAX] =
    {0x00000000, 0x1DFFDF5E, 0x00000020};
#elif defined(TMPM4MLA)
static const uint32_t ia_imc_intn_table[IA_IMC_INTN_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_imc_intn_table[IB_IMC_INTN_TABLE_MAX] =
    {0x00000000, 0x00FFDF5E, 0x00000020};
#else
    #error "target device is non-select."
#endif

#define IA_NIC_INTP                  UNAVAILABLE
#define IB_NIC_INTP                  AVAILABLE
#define IA_IMC_INTP_TABLE_MAX        (1U)
#define IB_IMC_INTP_TABLE_MAX        (3U)
#if defined(TMPM4MNA)
static const uint32_t ia_imc_intp_table[IA_IMC_INTP_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_imc_intp_table[IB_IMC_INTP_TABLE_MAX] =
    {0xFFFFFFFF, 0xFFFFFFFF, 0x00000021};
#elif defined(TMPM4MMA)
static const uint32_t ia_imc_intp_table[IA_IMC_INTP_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_imc_intp_table[IB_IMC_INTP_TABLE_MAX] =
    {0xFFFFFFFF, 0x1DFFDF5F, 0x00000020};
#elif defined(TMPM4MLA)
static const uint32_t ia_imc_intp_table[IA_IMC_INTP_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_imc_intp_table[IB_IMC_INTP_TABLE_MAX] =
    {0xFFFFFFFF, 0x00FFDF5F, 0x00000020};
#else
    #error "target device is non-select."
#endif

#define IA_NIC_MODE                  UNAVAILABLE
#define IB_NIC_MODE                  UNAVAILABLE
#define IA_MODE_TABLE_MAX            (1U)
#define IB_MODE_TABLE_MAX            (3U)
#if defined(TMPM4MNA)
static const uint32_t ia_mode_table[IA_MODE_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_mode_table[IB_MODE_TABLE_MAX] =
    {0x00000000, 0xFFFFFFFE, 0x00000021};
#elif defined(TMPM4MMA)
static const uint32_t ia_mode_table[IA_MODE_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_mode_table[IB_MODE_TABLE_MAX] =
    {0x00000000, 0x1DFFDF5E, 0x00000020};
#elif defined(TMPM4MLA)
static const uint32_t ia_mode_table[IA_MODE_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_mode_table[IB_MODE_TABLE_MAX] =
    {0x00000000, 0x00FFDF5E, 0x00000020};
#else
    #error "target device is non-select."
#endif

#define IA_NIC_INTEN                 UNAVAILABLE
#define IB_NIC_INTEN                 UNAVAILABLE
#define IA_INTEN_TABLE_MAX            (1U)
#define IB_INTEN_TABLE_MAX            (3U)
#if defined(TMPM4MNA)
static const uint32_t ia_inten_table[IA_INTEN_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_inten_table[IB_INTEN_TABLE_MAX] =
    {0x00000000, 0xFFFFFFFE, 0x00000021};
#elif defined(TMPM4MMA)
static const uint32_t ia_inten_table[IA_INTEN_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_inten_table[IB_INTEN_TABLE_MAX] =
    {0x00000000, 0x1DFFDF5E, 0x00000020};
#elif defined(TMPM4MLA)
static const uint32_t ia_inten_table[IA_INTEN_TABLE_MAX] =
    {0x00000000};
static const uint32_t ib_inten_table[IB_INTEN_TABLE_MAX] =
    {0x00000000, 0x00FFDF5E, 0x00000020};
#else
    #error "target device is non-select."
#endif

typedef enum
{
    RLM_PORSTF = 0,
    RLM_PINRSTF = 3,
    RLM_LVDRSTF = 5
}rlm_rstflg0_t;

typedef enum
{
    RLM_SYSRSTF = 0,
    RLM_LOCKRSTF,
    RLM_WDTRSTF,
    RLM_OFDRSTF
}rlm_rstflg1_t;

/**
 *  @}
 */ /* End of group EXCEPT_Exported_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup EXCEPT_Exported_define EXCEPT Exported Define
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group EXCEPT_Exported_define */

/**
 *  @}
 */ /* End of group EXCEPT */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __EXCEPT_M4M1_H */


