/**
 *******************************************************************************
 * @file     flash_10mud32_a.h
 * @brief    This file provides all the functions prototypes for FLASH.
 * @version  V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __FLASH_10MUD32_A_H
#define __FLASH_10MUD32_A_H

#ifdef __cplusplus
extern "C" {
#endif                          /* __cplusplus */

/** @addtogroup Periph_Driver Peripheral Driver
  * @{
  */

/** @addtogroup FLASH
  * @brief FLASH Driver
  * @{
  */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
#define AVAILABLE               (1)                             /*!< FC Protect function equipped */
#define UNAVAILABLE             (0)                             /*!< FC Protect function not equipped */

#define CODE_FLASH_AREA1_EQUIPPED   AVAILABLE
#define FCPSR2_REGISTER_EQUIPPED    UNAVAILABLE                 /* available when code flash has over 32 blocks */
#define FCPMR2_REGISTER_EQUIPPED    UNAVAILABLE                 /* available when code flash has over 32 blocks */

/* register name definition in [MCU_NAME].h */
#define REGISTER_NAME_OF_FCACCR             FCACCR              /* Flash FCACCR */

#define FIXED_80MHz             (80000000UL)    /* 80.00MHz */
#define SYSCORECLOCK_ACCR       FIXED_80MHz


#define FC_DATA_FLASH_ADDRESS_TOP   (0x30000000UL)              /*!< DATA FLASH Address Top */
#define FC_DATA_AREA_SIZE           (0x8000)                    /*!< The number of bytes in a area. */
#define FC_DATA_BLOCK_SIZE          (0x1000)                    /*!< The number of bytes in a block. */
#define FC_DATA_PAGE_SIZE           (0x100)                     /*!< The number of bytes in a page. */

#define FC_NUMBER_OF_DATA_AREAS     (0x1)                       /*!< Maxmum areas */
#define FC_NUMBER_OF_DATA_BLOCKS    (0x8)                       /*!< Maxmum blocks */
#define FC_NUMBER_OF_DATA_PAGES     (0x80)                      /*!< Maxmum pages */

#define FC_DATA_FLASH_WRITE_SIZE    (sizeof(uint32_t)*4)        /*!< CDATA FLASH WRITE SIZE */

#define FC_CODE_FLASH_ADDRESS_TOP   (0x5E000000UL)              /*!< CODE FLASH Address Top */
#define FC_CODE_AREA_SIZE           (0x00080000UL)              /*!< The number of bytes in a area. */
#define FC_CODE_BLOCK_SIZE          (0x8000)                    /*!< The number of bytes in a block. */
#define FC_CODE_PAGE_SIZE           (0x1000)                    /*!< The number of bytes in a page. */
#define FC_CODE_FLASH_AREA1_ADDRESS (FC_CODE_FLASH_ADDRESS_TOP + FC_CODE_AREA_SIZE) /*!< Flash Area1 address */

#define FC_NUMBER_OF_CODE_AREAS     (0x2)                       /*!< Maxmum areas */
#define FC_NUMBER_OF_CODE_BLOCKS    (0x20)                      /*!< Maxmum blocks */
#define FC_NUMBER_OF_CODE_PAGES     (0x100)                     /*!< Maxmum pages */

#define FC_CODE_FLASH_WRITE_SIZE    (sizeof(uint32_t)*4)        /*!< CODE FLASH WRITE SIZE */

#define FC_PROTECT_PM0              (0x00000001UL)              /*!< CODE FLASH PM0 protect */
#define FC_PROTECT_PM1              (0x00000002UL)              /*!< CODE FLASH PM1 protect */
#define FC_PROTECT_PM2              (0x00000004UL)              /*!< CODE FLASH PM2 protect */
#define FC_PROTECT_PM3              (0x00000008UL)              /*!< CODE FLASH PM3 protect */
#define FC_PROTECT_PM4              (0x00000010UL)              /*!< CODE FLASH PM4 protect */
#define FC_PROTECT_PM5              (0x00000020UL)              /*!< CODE FLASH PM5 protect */
#define FC_PROTECT_PM6              (0x00000040UL)              /*!< CODE FLASH PM6 protect */
#define FC_PROTECT_PM7              (0x00000080UL)              /*!< CODE FLASH PM7 protect */
#define FC_PROTECT_MSK1             (0x00000002UL)              /*!< CODE FLASH MSK1 protect */
#define FC_PROTECT_MSK2             (0x00000004UL)              /*!< CODE FLASH MSK2 protect */
#define FC_PROTECT_MSK3             (0x00000008UL)              /*!< CODE FLASH MSK3 protect */
#define FC_PROTECT_MSK4             (0x00000010UL)              /*!< CODE FLASH MSK4 protect */
#define FC_PROTECT_MSK5             (0x00000020UL)              /*!< CODE FLASH MSK5 protect */
#define FC_PROTECT_MSK6             (0x00000040UL)              /*!< CODE FLASH MSK6 protect */
#define FC_PROTECT_MSK7             (0x00000080UL)              /*!< CODE FLASH MSK7 protect */
#define FC_PROTECT_MSK8             (0x00000100UL)              /*!< CODE FLASH MSK8 protect */
#define FC_PROTECT_MSK9             (0x00000200UL)              /*!< CODE FLASH MSK9 protect */
#define FC_PROTECT_MSK10            (0x00000400UL)              /*!< CODE FLASH MSK10 protect */
#define FC_PROTECT_MSK11            (0x00000800UL)              /*!< CODE FLASH MSK11 protect */
#define FC_PROTECT_MSK12            (0x00001000UL)              /*!< CODE FLASH MSK12 protect */
#define FC_PROTECT_MSK13            (0x00002000UL)              /*!< CODE FLASH MSK13 protect */
#define FC_PROTECT_MSK14            (0x00004000UL)              /*!< CODE FLASH MSK14 protect */
#define FC_PROTECT_MSK15            (0x00008000UL)              /*!< CODE FLASH MSK15 protect */
#define FC_PROTECT_MSK16            (0x00010000UL)              /*!< CODE FLASH MSK16 protect */
#define FC_PROTECT_MSK17            (0x00020000UL)              /*!< CODE FLASH MSK17 protect */
#define FC_PROTECT_MSK18            (0x00040000UL)              /*!< CODE FLASH MSK18 protect */
#define FC_PROTECT_MSK19            (0x00080000UL)              /*!< CODE FLASH MSK19 protect */
#define FC_PROTECT_MSK20            (0x00100000UL)              /*!< CODE FLASH MSK20 protect */
#define FC_PROTECT_MSK21            (0x00200000UL)              /*!< CODE FLASH MSK21 protect */
#define FC_PROTECT_MSK22            (0x00400000UL)              /*!< CODE FLASH MSK22 protect */
#define FC_PROTECT_MSK23            (0x00800000UL)              /*!< CODE FLASH MSK23 protect */
#define FC_PROTECT_MSK24            (0x01000000UL)              /*!< CODE FLASH MSK24 protect */
#define FC_PROTECT_MSK25            (0x02000000UL)              /*!< CODE FLASH MSK25 protect */
#define FC_PROTECT_MSK26            (0x04000000UL)              /*!< CODE FLASH MSK26 protect */
#define FC_PROTECT_MSK27            (0x08000000UL)              /*!< CODE FLASH MSK27 protect */
#define FC_PROTECT_MSK28            (0x10000000UL)              /*!< CODE FLASH MSK28 protect */
#define FC_PROTECT_MSK29            (0x20000000UL)              /*!< CODE FLASH MSK29 protect */
#define FC_PROTECT_MSK30            (0x40000000UL)              /*!< CODE FLASH MSK30 protect */
#define FC_PROTECT_MSK31            (0x80000000UL)              /*!< CODE FLASH MSK31 protect */
#define FC_PROTECT_DMSK0            (0x00000001UL)              /*!< DATA FLASH DMSK0 protect */
#define FC_PROTECT_DMSK1            (0x00000002UL)              /*!< DATA FLASH DMSK1 protect */
#define FC_PROTECT_DMSK2            (0x00000004UL)              /*!< DATA FLASH DMSK2 protect */
#define FC_PROTECT_DMSK3            (0x00000008UL)              /*!< DATA FLASH DMSK3 protect */
#define FC_PROTECT_DMSK4            (0x00000010UL)              /*!< DATA FLASH DMSK4 protect */
#define FC_PROTECT_DMSK5            (0x00000020UL)              /*!< DATA FLASH DMSK5 protect */
#define FC_PROTECT_DMSK6            (0x00000040UL)              /*!< DATA FLASH DMSK6 protect */
#define FC_PROTECT_DMSK7            (0x00000080UL)              /*!< DATA FLASH DMSK7 protect */


/** 
 *  @enum   fc_sr0_t
 *  @brief  Enumerated type definition of the FCSR0 register.
 */
typedef enum {
    FC_SR0_RDYBSY           = (0x00000001UL)      /*!< 0:Busy, 1:Ready all flash     */
} fc_sr0_t;

/*----------------------------------*/
/** 
 *  @enum   fc_erase_kind_t
 *  @brief  FC Erase FLASH Kind structure definenition.
*/
/*----------------------------------*/
typedef enum {
    FC_ERASE_KIND_PAGE      = (0x00000040UL),    /*!< Page Erase                     */
    FC_ERASE_KIND_BLOCK     = (0x00000030UL),    /*!< Block Erase                    */
    FC_ERASE_KIND_AREA      = (0x00000020UL)     /*!< Area Erase                     */
} fc_erase_kind_t;

typedef enum {
    FC_CODE_FLASH_PAGE0 = 0,    /*!< (0x5E000000UL), CODE FLASH Page0 */
    FC_CODE_FLASH_PAGE1,        /*!< (0x5E001000UL), CODE FLASH Page1 */
    FC_CODE_FLASH_PAGE2,        /*!< (0x5E002000UL), CODE FLASH Page2 */
    FC_CODE_FLASH_PAGE3,        /*!< (0x5E003000UL), CODE FLASH Page3 */
    FC_CODE_FLASH_PAGE4,        /*!< (0x5E004000UL), CODE FLASH Page4 */
    FC_CODE_FLASH_PAGE5,        /*!< (0x5E005000UL), CODE FLASH Page5 */
    FC_CODE_FLASH_PAGE6,        /*!< (0x5E006000UL), CODE FLASH Page6 */
    FC_CODE_FLASH_PAGE7,        /*!< (0x5E007000UL), CODE FLASH Page7 */
    FC_CODE_FLASH_PAGE8,        /*!< (0x5E008000UL), CODE FLASH Page8 */
    FC_CODE_FLASH_PAGE9,        /*!< (0x5E009000UL), CODE FLASH Page9 */
    FC_CODE_FLASH_PAGE10,       /*!< (0x5E00A000UL), CODE FLASH Page10 */
    FC_CODE_FLASH_PAGE11,       /*!< (0x5E00B000UL), CODE FLASH Page11 */
    FC_CODE_FLASH_PAGE12,       /*!< (0x5E00C000UL), CODE FLASH Page12 */
    FC_CODE_FLASH_PAGE13,       /*!< (0x5E00D000UL), CODE FLASH Page13 */
    FC_CODE_FLASH_PAGE14,       /*!< (0x5E00E000UL), CODE FLASH Page14 */
    FC_CODE_FLASH_PAGE15,       /*!< (0x5E00F000UL), CODE FLASH Page15 */
    FC_CODE_FLASH_PAGE16,       /*!< (0x5E010000UL), CODE FLASH Page16 */
    FC_CODE_FLASH_PAGE17,       /*!< (0x5E011000UL), CODE FLASH Page17 */
    FC_CODE_FLASH_PAGE18,       /*!< (0x5E012000UL), CODE FLASH Page18 */
    FC_CODE_FLASH_PAGE19,       /*!< (0x5E013000UL), CODE FLASH Page19 */
    FC_CODE_FLASH_PAGE20,       /*!< (0x5E014000UL), CODE FLASH Page20 */
    FC_CODE_FLASH_PAGE21,       /*!< (0x5E015000UL), CODE FLASH Page21 */
    FC_CODE_FLASH_PAGE22,       /*!< (0x5E016000UL), CODE FLASH Page22 */
    FC_CODE_FLASH_PAGE23,       /*!< (0x5E017000UL), CODE FLASH Page23 */
    FC_CODE_FLASH_PAGE24,       /*!< (0x5E018000UL), CODE FLASH Page24 */
    FC_CODE_FLASH_PAGE25,       /*!< (0x5E019000UL), CODE FLASH Page25 */
    FC_CODE_FLASH_PAGE26,       /*!< (0x5E01A000UL), CODE FLASH Page26 */
    FC_CODE_FLASH_PAGE27,       /*!< (0x5E01B000UL), CODE FLASH Page27 */
    FC_CODE_FLASH_PAGE28,       /*!< (0x5E01C000UL), CODE FLASH Page28 */
    FC_CODE_FLASH_PAGE29,       /*!< (0x5E01D000UL), CODE FLASH Page29 */
    FC_CODE_FLASH_PAGE30,       /*!< (0x5E01E000UL), CODE FLASH Page30 */
    FC_CODE_FLASH_PAGE31,       /*!< (0x5E01F000UL), CODE FLASH Page31 */
    FC_CODE_FLASH_PAGE32,       /*!< (0x5E020000UL), CODE FLASH Page32 */
    FC_CODE_FLASH_PAGE33,       /*!< (0x5E021000UL), CODE FLASH Page33 */
    FC_CODE_FLASH_PAGE34,       /*!< (0x5E022000UL), CODE FLASH Page34 */
    FC_CODE_FLASH_PAGE35,       /*!< (0x5E023000UL), CODE FLASH Page35 */
    FC_CODE_FLASH_PAGE36,       /*!< (0x5E024000UL), CODE FLASH Page36 */
    FC_CODE_FLASH_PAGE37,       /*!< (0x5E025000UL), CODE FLASH Page37 */
    FC_CODE_FLASH_PAGE38,       /*!< (0x5E026000UL), CODE FLASH Page38 */
    FC_CODE_FLASH_PAGE39,       /*!< (0x5E027000UL), CODE FLASH Page39 */
    FC_CODE_FLASH_PAGE40,       /*!< (0x5E028000UL), CODE FLASH Page40 */
    FC_CODE_FLASH_PAGE41,       /*!< (0x5E029000UL), CODE FLASH Page41 */
    FC_CODE_FLASH_PAGE42,       /*!< (0x5E02A000UL), CODE FLASH Page42 */
    FC_CODE_FLASH_PAGE43,       /*!< (0x5E02B000UL), CODE FLASH Page43 */
    FC_CODE_FLASH_PAGE44,       /*!< (0x5E02C000UL), CODE FLASH Page44 */
    FC_CODE_FLASH_PAGE45,       /*!< (0x5E02D000UL), CODE FLASH Page45 */
    FC_CODE_FLASH_PAGE46,       /*!< (0x5E02E000UL), CODE FLASH Page46 */
    FC_CODE_FLASH_PAGE47,       /*!< (0x5E02F000UL), CODE FLASH Page47 */
    FC_CODE_FLASH_PAGE48,       /*!< (0x5E030000UL), CODE FLASH Page48 */
    FC_CODE_FLASH_PAGE49,       /*!< (0x5E031000UL), CODE FLASH Page49 */
    FC_CODE_FLASH_PAGE50,       /*!< (0x5E032000UL), CODE FLASH Page50 */
    FC_CODE_FLASH_PAGE51,       /*!< (0x5E033000UL), CODE FLASH Page51 */
    FC_CODE_FLASH_PAGE52,       /*!< (0x5E034000UL), CODE FLASH Page52 */
    FC_CODE_FLASH_PAGE53,       /*!< (0x5E035000UL), CODE FLASH Page53 */
    FC_CODE_FLASH_PAGE54,       /*!< (0x5E036000UL), CODE FLASH Page54 */
    FC_CODE_FLASH_PAGE55,       /*!< (0x5E037000UL), CODE FLASH Page55 */
    FC_CODE_FLASH_PAGE56,       /*!< (0x5E038000UL), CODE FLASH Page56 */
    FC_CODE_FLASH_PAGE57,       /*!< (0x5E039000UL), CODE FLASH Page57 */
    FC_CODE_FLASH_PAGE58,       /*!< (0x5E03A000UL), CODE FLASH Page58 */
    FC_CODE_FLASH_PAGE59,       /*!< (0x5E03B000UL), CODE FLASH Page59 */
    FC_CODE_FLASH_PAGE60,       /*!< (0x5E03C000UL), CODE FLASH Page60 */
    FC_CODE_FLASH_PAGE61,       /*!< (0x5E03D000UL), CODE FLASH Page61 */
    FC_CODE_FLASH_PAGE62,       /*!< (0x5E03E000UL), CODE FLASH Page62 */
    FC_CODE_FLASH_PAGE63,       /*!< (0x5E03F000UL), CODE FLASH Page63 */
    FC_CODE_FLASH_PAGE64,       /*!< (0x5E040000UL), CODE FLASH Page64 */
    FC_CODE_FLASH_PAGE65,       /*!< (0x5E041000UL), CODE FLASH Page65 */
    FC_CODE_FLASH_PAGE66,       /*!< (0x5E042000UL), CODE FLASH Page66 */
    FC_CODE_FLASH_PAGE67,       /*!< (0x5E043000UL), CODE FLASH Page67 */
    FC_CODE_FLASH_PAGE68,       /*!< (0x5E044000UL), CODE FLASH Page68 */
    FC_CODE_FLASH_PAGE69,       /*!< (0x5E045000UL), CODE FLASH Page69 */
    FC_CODE_FLASH_PAGE70,       /*!< (0x5E046000UL), CODE FLASH Page70 */
    FC_CODE_FLASH_PAGE71,       /*!< (0x5E047000UL), CODE FLASH Page71 */
    FC_CODE_FLASH_PAGE72,       /*!< (0x5E048000UL), CODE FLASH Page72 */
    FC_CODE_FLASH_PAGE73,       /*!< (0x5E049000UL), CODE FLASH Page73 */
    FC_CODE_FLASH_PAGE74,       /*!< (0x5E04A000UL), CODE FLASH Page74 */
    FC_CODE_FLASH_PAGE75,       /*!< (0x5E04B000UL), CODE FLASH Page75 */
    FC_CODE_FLASH_PAGE76,       /*!< (0x5E04C000UL), CODE FLASH Page76 */
    FC_CODE_FLASH_PAGE77,       /*!< (0x5E04D000UL), CODE FLASH Page77 */
    FC_CODE_FLASH_PAGE78,       /*!< (0x5E04E000UL), CODE FLASH Page78 */
    FC_CODE_FLASH_PAGE79,       /*!< (0x5E04F000UL), CODE FLASH Page79 */
    FC_CODE_FLASH_PAGE80,       /*!< (0x5E050000UL), CODE FLASH Page80 */
    FC_CODE_FLASH_PAGE81,       /*!< (0x5E051000UL), CODE FLASH Page81 */
    FC_CODE_FLASH_PAGE82,       /*!< (0x5E052000UL), CODE FLASH Page82 */
    FC_CODE_FLASH_PAGE83,       /*!< (0x5E053000UL), CODE FLASH Page83 */
    FC_CODE_FLASH_PAGE84,       /*!< (0x5E054000UL), CODE FLASH Page84 */
    FC_CODE_FLASH_PAGE85,       /*!< (0x5E055000UL), CODE FLASH Page85 */
    FC_CODE_FLASH_PAGE86,       /*!< (0x5E056000UL), CODE FLASH Page86 */
    FC_CODE_FLASH_PAGE87,       /*!< (0x5E057000UL), CODE FLASH Page87 */
    FC_CODE_FLASH_PAGE88,       /*!< (0x5E058000UL), CODE FLASH Page88 */
    FC_CODE_FLASH_PAGE89,       /*!< (0x5E059000UL), CODE FLASH Page89 */
    FC_CODE_FLASH_PAGE90,       /*!< (0x5E05A000UL), CODE FLASH Page90 */
    FC_CODE_FLASH_PAGE91,       /*!< (0x5E05B000UL), CODE FLASH Page91 */
    FC_CODE_FLASH_PAGE92,       /*!< (0x5E05C000UL), CODE FLASH Page92 */
    FC_CODE_FLASH_PAGE93,       /*!< (0x5E05D000UL), CODE FLASH Page93 */
    FC_CODE_FLASH_PAGE94,       /*!< (0x5E05E000UL), CODE FLASH Page94 */
    FC_CODE_FLASH_PAGE95,       /*!< (0x5E05F000UL), CODE FLASH Page95 */
    FC_CODE_FLASH_PAGE96,       /*!< (0x5E060000UL), CODE FLASH Page96 */
    FC_CODE_FLASH_PAGE97,       /*!< (0x5E061000UL), CODE FLASH Page97 */
    FC_CODE_FLASH_PAGE98,       /*!< (0x5E062000UL), CODE FLASH Page98 */
    FC_CODE_FLASH_PAGE99,       /*!< (0x5E063000UL), CODE FLASH Page99 */
    FC_CODE_FLASH_PAGE100,      /*!< (0x5E064000UL), CODE FLASH Page100 */
    FC_CODE_FLASH_PAGE101,      /*!< (0x5E065000UL), CODE FLASH Page101 */
    FC_CODE_FLASH_PAGE102,      /*!< (0x5E066000UL), CODE FLASH Page102 */
    FC_CODE_FLASH_PAGE103,      /*!< (0x5E067000UL), CODE FLASH Page103 */
    FC_CODE_FLASH_PAGE104,      /*!< (0x5E068000UL), CODE FLASH Page104 */
    FC_CODE_FLASH_PAGE105,      /*!< (0x5E069000UL), CODE FLASH Page105 */
    FC_CODE_FLASH_PAGE106,      /*!< (0x5E06A000UL), CODE FLASH Page106 */
    FC_CODE_FLASH_PAGE107,      /*!< (0x5E06B000UL), CODE FLASH Page107 */
    FC_CODE_FLASH_PAGE108,      /*!< (0x5E06C000UL), CODE FLASH Page108 */
    FC_CODE_FLASH_PAGE109,      /*!< (0x5E06D000UL), CODE FLASH Page109 */
    FC_CODE_FLASH_PAGE110,      /*!< (0x5E06E000UL), CODE FLASH Page110 */
    FC_CODE_FLASH_PAGE111,      /*!< (0x5E06F000UL), CODE FLASH Page111 */
    FC_CODE_FLASH_PAGE112,      /*!< (0x5E070000UL), CODE FLASH Page112 */
    FC_CODE_FLASH_PAGE113,      /*!< (0x5E071000UL), CODE FLASH Page113 */
    FC_CODE_FLASH_PAGE114,      /*!< (0x5E072000UL), CODE FLASH Page114 */
    FC_CODE_FLASH_PAGE115,      /*!< (0x5E073000UL), CODE FLASH Page115 */
    FC_CODE_FLASH_PAGE116,      /*!< (0x5E074000UL), CODE FLASH Page116 */
    FC_CODE_FLASH_PAGE117,      /*!< (0x5E075000UL), CODE FLASH Page117 */
    FC_CODE_FLASH_PAGE118,      /*!< (0x5E076000UL), CODE FLASH Page118 */
    FC_CODE_FLASH_PAGE119,      /*!< (0x5E077000UL), CODE FLASH Page119 */
    FC_CODE_FLASH_PAGE120,      /*!< (0x5E078000UL), CODE FLASH Page120 */
    FC_CODE_FLASH_PAGE121,      /*!< (0x5E079000UL), CODE FLASH Page121 */
    FC_CODE_FLASH_PAGE122,      /*!< (0x5E07A000UL), CODE FLASH Page122 */
    FC_CODE_FLASH_PAGE123,      /*!< (0x5E07B000UL), CODE FLASH Page123 */
    FC_CODE_FLASH_PAGE124,      /*!< (0x5E07C000UL), CODE FLASH Page124 */
    FC_CODE_FLASH_PAGE125,      /*!< (0x5E07D000UL), CODE FLASH Page125 */
    FC_CODE_FLASH_PAGE126,      /*!< (0x5E07E000UL), CODE FLASH Page126 */
    FC_CODE_FLASH_PAGE127,      /*!< (0x5E07F000UL), CODE FLASH Page127 */
    FC_CODE_FLASH_PAGE128,      /*!< (0x5E080000UL), CODE FLASH Page128 */
    FC_CODE_FLASH_PAGE129,      /*!< (0x5E081000UL), CODE FLASH Page129 */
    FC_CODE_FLASH_PAGE130,      /*!< (0x5E082000UL), CODE FLASH Page130 */
    FC_CODE_FLASH_PAGE131,      /*!< (0x5E083000UL), CODE FLASH Page131 */
    FC_CODE_FLASH_PAGE132,      /*!< (0x5E084000UL), CODE FLASH Page132 */
    FC_CODE_FLASH_PAGE133,      /*!< (0x5E085000UL), CODE FLASH Page133 */
    FC_CODE_FLASH_PAGE134,      /*!< (0x5E086000UL), CODE FLASH Page134 */
    FC_CODE_FLASH_PAGE135,      /*!< (0x5E087000UL), CODE FLASH Page135 */
    FC_CODE_FLASH_PAGE136,      /*!< (0x5E088000UL), CODE FLASH Page136 */
    FC_CODE_FLASH_PAGE137,      /*!< (0x5E089000UL), CODE FLASH Page137 */
    FC_CODE_FLASH_PAGE138,      /*!< (0x5E08A000UL), CODE FLASH Page138 */
    FC_CODE_FLASH_PAGE139,      /*!< (0x5E08B000UL), CODE FLASH Page139 */
    FC_CODE_FLASH_PAGE140,      /*!< (0x5E08C000UL), CODE FLASH Page140 */
    FC_CODE_FLASH_PAGE141,      /*!< (0x5E08D000UL), CODE FLASH Page141 */
    FC_CODE_FLASH_PAGE142,      /*!< (0x5E08E000UL), CODE FLASH Page142 */
    FC_CODE_FLASH_PAGE143,      /*!< (0x5E08F000UL), CODE FLASH Page143 */
    FC_CODE_FLASH_PAGE144,      /*!< (0x5E090000UL), CODE FLASH Page144 */
    FC_CODE_FLASH_PAGE145,      /*!< (0x5E091000UL), CODE FLASH Page145 */
    FC_CODE_FLASH_PAGE146,      /*!< (0x5E092000UL), CODE FLASH Page146 */
    FC_CODE_FLASH_PAGE147,      /*!< (0x5E093000UL), CODE FLASH Page147 */
    FC_CODE_FLASH_PAGE148,      /*!< (0x5E094000UL), CODE FLASH Page148 */
    FC_CODE_FLASH_PAGE149,      /*!< (0x5E095000UL), CODE FLASH Page149 */
    FC_CODE_FLASH_PAGE150,      /*!< (0x5E096000UL), CODE FLASH Page150 */
    FC_CODE_FLASH_PAGE151,      /*!< (0x5E097000UL), CODE FLASH Page151 */
    FC_CODE_FLASH_PAGE152,      /*!< (0x5E098000UL), CODE FLASH Page152 */
    FC_CODE_FLASH_PAGE153,      /*!< (0x5E099000UL), CODE FLASH Page153 */
    FC_CODE_FLASH_PAGE154,      /*!< (0x5E09A000UL), CODE FLASH Page154 */
    FC_CODE_FLASH_PAGE155,      /*!< (0x5E09B000UL), CODE FLASH Page155 */
    FC_CODE_FLASH_PAGE156,      /*!< (0x5E09C000UL), CODE FLASH Page156 */
    FC_CODE_FLASH_PAGE157,      /*!< (0x5E09D000UL), CODE FLASH Page157 */
    FC_CODE_FLASH_PAGE158,      /*!< (0x5E09E000UL), CODE FLASH Page158 */
    FC_CODE_FLASH_PAGE159,      /*!< (0x5E09F000UL), CODE FLASH Page159 */
    FC_CODE_FLASH_PAGE160,      /*!< (0x5E0A0000UL), CODE FLASH Page160 */
    FC_CODE_FLASH_PAGE161,      /*!< (0x5E0A1000UL), CODE FLASH Page161 */
    FC_CODE_FLASH_PAGE162,      /*!< (0x5E0A2000UL), CODE FLASH Page162 */
    FC_CODE_FLASH_PAGE163,      /*!< (0x5E0A3000UL), CODE FLASH Page163 */
    FC_CODE_FLASH_PAGE164,      /*!< (0x5E0A4000UL), CODE FLASH Page164 */
    FC_CODE_FLASH_PAGE165,      /*!< (0x5E0A5000UL), CODE FLASH Page165 */
    FC_CODE_FLASH_PAGE166,      /*!< (0x5E0A6000UL), CODE FLASH Page166 */
    FC_CODE_FLASH_PAGE167,      /*!< (0x5E0A7000UL), CODE FLASH Page167 */
    FC_CODE_FLASH_PAGE168,      /*!< (0x5E0A8000UL), CODE FLASH Page168 */
    FC_CODE_FLASH_PAGE169,      /*!< (0x5E0A9000UL), CODE FLASH Page169 */
    FC_CODE_FLASH_PAGE170,      /*!< (0x5E0AA000UL), CODE FLASH Page170 */
    FC_CODE_FLASH_PAGE171,      /*!< (0x5E0AB000UL), CODE FLASH Page171 */
    FC_CODE_FLASH_PAGE172,      /*!< (0x5E0AC000UL), CODE FLASH Page172 */
    FC_CODE_FLASH_PAGE173,      /*!< (0x5E0AD000UL), CODE FLASH Page173 */
    FC_CODE_FLASH_PAGE174,      /*!< (0x5E0AE000UL), CODE FLASH Page174 */
    FC_CODE_FLASH_PAGE175,      /*!< (0x5E0AF000UL), CODE FLASH Page175 */
    FC_CODE_FLASH_PAGE176,      /*!< (0x5E0B0000UL), CODE FLASH Page176 */
    FC_CODE_FLASH_PAGE177,      /*!< (0x5E0B1000UL), CODE FLASH Page177 */
    FC_CODE_FLASH_PAGE178,      /*!< (0x5E0B2000UL), CODE FLASH Page178 */
    FC_CODE_FLASH_PAGE179,      /*!< (0x5E0B3000UL), CODE FLASH Page179 */
    FC_CODE_FLASH_PAGE180,      /*!< (0x5E0B4000UL), CODE FLASH Page180 */
    FC_CODE_FLASH_PAGE181,      /*!< (0x5E0B5000UL), CODE FLASH Page181 */
    FC_CODE_FLASH_PAGE182,      /*!< (0x5E0B6000UL), CODE FLASH Page182 */
    FC_CODE_FLASH_PAGE183,      /*!< (0x5E0B7000UL), CODE FLASH Page183 */
    FC_CODE_FLASH_PAGE184,      /*!< (0x5E0B8000UL), CODE FLASH Page184 */
    FC_CODE_FLASH_PAGE185,      /*!< (0x5E0B9000UL), CODE FLASH Page185 */
    FC_CODE_FLASH_PAGE186,      /*!< (0x5E0BA000UL), CODE FLASH Page186 */
    FC_CODE_FLASH_PAGE187,      /*!< (0x5E0BB000UL), CODE FLASH Page187 */
    FC_CODE_FLASH_PAGE188,      /*!< (0x5E0BC000UL), CODE FLASH Page188 */
    FC_CODE_FLASH_PAGE189,      /*!< (0x5E0BD000UL), CODE FLASH Page189 */
    FC_CODE_FLASH_PAGE190,      /*!< (0x5E0BE000UL), CODE FLASH Page190 */
    FC_CODE_FLASH_PAGE191,      /*!< (0x5E0BF000UL), CODE FLASH Page191 */
    FC_CODE_FLASH_PAGE192,      /*!< (0x5E0C0000UL), CODE FLASH Page192 */
    FC_CODE_FLASH_PAGE193,      /*!< (0x5E0C1000UL), CODE FLASH Page193 */
    FC_CODE_FLASH_PAGE194,      /*!< (0x5E0C2000UL), CODE FLASH Page194 */
    FC_CODE_FLASH_PAGE195,      /*!< (0x5E0C3000UL), CODE FLASH Page195 */
    FC_CODE_FLASH_PAGE196,      /*!< (0x5E0C4000UL), CODE FLASH Page196 */
    FC_CODE_FLASH_PAGE197,      /*!< (0x5E0C5000UL), CODE FLASH Page197 */
    FC_CODE_FLASH_PAGE198,      /*!< (0x5E0C6000UL), CODE FLASH Page198 */
    FC_CODE_FLASH_PAGE199,      /*!< (0x5E0C7000UL), CODE FLASH Page199 */
    FC_CODE_FLASH_PAGE200,      /*!< (0x5E0C8000UL), CODE FLASH Page200 */
    FC_CODE_FLASH_PAGE201,      /*!< (0x5E0C9000UL), CODE FLASH Page201 */
    FC_CODE_FLASH_PAGE202,      /*!< (0x5E0CA000UL), CODE FLASH Page202 */
    FC_CODE_FLASH_PAGE203,      /*!< (0x5E0CB000UL), CODE FLASH Page203 */
    FC_CODE_FLASH_PAGE204,      /*!< (0x5E0CC000UL), CODE FLASH Page204 */
    FC_CODE_FLASH_PAGE205,      /*!< (0x5E0CD000UL), CODE FLASH Page205 */
    FC_CODE_FLASH_PAGE206,      /*!< (0x5E0CE000UL), CODE FLASH Page206 */
    FC_CODE_FLASH_PAGE207,      /*!< (0x5E0CF000UL), CODE FLASH Page207 */
    FC_CODE_FLASH_PAGE208,      /*!< (0x5E0D0000UL), CODE FLASH Page208 */
    FC_CODE_FLASH_PAGE209,      /*!< (0x5E0D1000UL), CODE FLASH Page209 */
    FC_CODE_FLASH_PAGE210,      /*!< (0x5E0D2000UL), CODE FLASH Page210 */
    FC_CODE_FLASH_PAGE211,      /*!< (0x5E0D3000UL), CODE FLASH Page211 */
    FC_CODE_FLASH_PAGE212,      /*!< (0x5E0D4000UL), CODE FLASH Page212 */
    FC_CODE_FLASH_PAGE213,      /*!< (0x5E0D5000UL), CODE FLASH Page213 */
    FC_CODE_FLASH_PAGE214,      /*!< (0x5E0D6000UL), CODE FLASH Page214 */
    FC_CODE_FLASH_PAGE215,      /*!< (0x5E0D7000UL), CODE FLASH Page215 */
    FC_CODE_FLASH_PAGE216,      /*!< (0x5E0D8000UL), CODE FLASH Page216 */
    FC_CODE_FLASH_PAGE217,      /*!< (0x5E0D9000UL), CODE FLASH Page217 */
    FC_CODE_FLASH_PAGE218,      /*!< (0x5E0DA000UL), CODE FLASH Page218 */
    FC_CODE_FLASH_PAGE219,      /*!< (0x5E0DB000UL), CODE FLASH Page219 */
    FC_CODE_FLASH_PAGE220,      /*!< (0x5E0DC000UL), CODE FLASH Page220 */
    FC_CODE_FLASH_PAGE221,      /*!< (0x5E0DD000UL), CODE FLASH Page221 */
    FC_CODE_FLASH_PAGE222,      /*!< (0x5E0DE000UL), CODE FLASH Page222 */
    FC_CODE_FLASH_PAGE223,      /*!< (0x5E0DF000UL), CODE FLASH Page223 */
    FC_CODE_FLASH_PAGE224,      /*!< (0x5E0E0000UL), CODE FLASH Page224 */
    FC_CODE_FLASH_PAGE225,      /*!< (0x5E0E1000UL), CODE FLASH Page225 */
    FC_CODE_FLASH_PAGE226,      /*!< (0x5E0E2000UL), CODE FLASH Page226 */
    FC_CODE_FLASH_PAGE227,      /*!< (0x5E0E3000UL), CODE FLASH Page227 */
    FC_CODE_FLASH_PAGE228,      /*!< (0x5E0E4000UL), CODE FLASH Page228 */
    FC_CODE_FLASH_PAGE229,      /*!< (0x5E0E5000UL), CODE FLASH Page229 */
    FC_CODE_FLASH_PAGE230,      /*!< (0x5E0E6000UL), CODE FLASH Page230 */
    FC_CODE_FLASH_PAGE231,      /*!< (0x5E0E7000UL), CODE FLASH Page231 */
    FC_CODE_FLASH_PAGE232,      /*!< (0x5E0E8000UL), CODE FLASH Page232 */
    FC_CODE_FLASH_PAGE233,      /*!< (0x5E0E9000UL), CODE FLASH Page233 */
    FC_CODE_FLASH_PAGE234,      /*!< (0x5E0EA000UL), CODE FLASH Page234 */
    FC_CODE_FLASH_PAGE235,      /*!< (0x5E0EB000UL), CODE FLASH Page235 */
    FC_CODE_FLASH_PAGE236,      /*!< (0x5E0EC000UL), CODE FLASH Page236 */
    FC_CODE_FLASH_PAGE237,      /*!< (0x5E0ED000UL), CODE FLASH Page237 */
    FC_CODE_FLASH_PAGE238,      /*!< (0x5E0EE000UL), CODE FLASH Page238 */
    FC_CODE_FLASH_PAGE239,      /*!< (0x5E0EF000UL), CODE FLASH Page239 */
    FC_CODE_FLASH_PAGE240,      /*!< (0x5E0F0000UL), CODE FLASH Page240 */
    FC_CODE_FLASH_PAGE241,      /*!< (0x5E0F1000UL), CODE FLASH Page241 */
    FC_CODE_FLASH_PAGE242,      /*!< (0x5E0F2000UL), CODE FLASH Page242 */
    FC_CODE_FLASH_PAGE243,      /*!< (0x5E0F3000UL), CODE FLASH Page243 */
    FC_CODE_FLASH_PAGE244,      /*!< (0x5E0F4000UL), CODE FLASH Page244 */
    FC_CODE_FLASH_PAGE245,      /*!< (0x5E0F5000UL), CODE FLASH Page245 */
    FC_CODE_FLASH_PAGE246,      /*!< (0x5E0F6000UL), CODE FLASH Page246 */
    FC_CODE_FLASH_PAGE247,      /*!< (0x5E0F7000UL), CODE FLASH Page247 */
    FC_CODE_FLASH_PAGE248,      /*!< (0x5E0F8000UL), CODE FLASH Page248 */
    FC_CODE_FLASH_PAGE249,      /*!< (0x5E0F9000UL), CODE FLASH Page249 */
    FC_CODE_FLASH_PAGE250,      /*!< (0x5E0FA000UL), CODE FLASH Page250 */
    FC_CODE_FLASH_PAGE251,      /*!< (0x5E0FB000UL), CODE FLASH Page251 */
    FC_CODE_FLASH_PAGE252,      /*!< (0x5E0FC000UL), CODE FLASH Page252 */
    FC_CODE_FLASH_PAGE253,      /*!< (0x5E0FD000UL), CODE FLASH Page253 */
    FC_CODE_FLASH_PAGE254,      /*!< (0x5E0FE000UL), CODE FLASH Page254 */
    FC_CODE_FLASH_PAGE255       /*!< (0x5E0FF000UL), CODE FLASH Page255 */
} fc_code_flash_page_number_t;
#define FC_CODE_FLASH_PAGE_MAX (FC_CODE_FLASH_PAGE255) /*!< Maxmum pages */

typedef enum {
    FC_DATA_FLASH_PAGE0  = 0,   /*!< (0x30000000UL), DATA FLASH Page0 */
    FC_DATA_FLASH_PAGE1,        /*!< (0x30000100UL), DATA FLASH Page1 */
    FC_DATA_FLASH_PAGE2,        /*!< (0x30000200UL), DATA FLASH Page2 */
    FC_DATA_FLASH_PAGE3,        /*!< (0x30000300UL), DATA FLASH Page3 */
    FC_DATA_FLASH_PAGE4,        /*!< (0x30000400UL), DATA FLASH Page4 */
    FC_DATA_FLASH_PAGE5,        /*!< (0x30000500UL), DATA FLASH Page5 */
    FC_DATA_FLASH_PAGE6,        /*!< (0x30000600UL), DATA FLASH Page6 */
    FC_DATA_FLASH_PAGE7,        /*!< (0x30000700UL), DATA FLASH Page7 */
    FC_DATA_FLASH_PAGE8,        /*!< (0x30000800UL), DATA FLASH Page8 */
    FC_DATA_FLASH_PAGE9,        /*!< (0x30000900UL), DATA FLASH Page9 */
    FC_DATA_FLASH_PAGE10,       /*!< (0x30000A00UL), DATA FLASH Page10 */
    FC_DATA_FLASH_PAGE11,       /*!< (0x30000B00UL), DATA FLASH Page11 */
    FC_DATA_FLASH_PAGE12,       /*!< (0x30000C00UL), DATA FLASH Page12 */
    FC_DATA_FLASH_PAGE13,       /*!< (0x30000D00UL), DATA FLASH Page13 */
    FC_DATA_FLASH_PAGE14,       /*!< (0x30000E00UL), DATA FLASH Page14 */
    FC_DATA_FLASH_PAGE15,       /*!< (0x30000F00UL), DATA FLASH Page15 */
    FC_DATA_FLASH_PAGE16,       /*!< (0x30001000UL), DATA FLASH Page16 */
    FC_DATA_FLASH_PAGE17,       /*!< (0x30001100UL), DATA FLASH Page17 */
    FC_DATA_FLASH_PAGE18,       /*!< (0x30001200UL), DATA FLASH Page18 */
    FC_DATA_FLASH_PAGE19,       /*!< (0x30001300UL), DATA FLASH Page19 */
    FC_DATA_FLASH_PAGE20,       /*!< (0x30001400UL), DATA FLASH Page20 */
    FC_DATA_FLASH_PAGE21,       /*!< (0x30001500UL), DATA FLASH Page21 */
    FC_DATA_FLASH_PAGE22,       /*!< (0x30001600UL), DATA FLASH Page22 */
    FC_DATA_FLASH_PAGE23,       /*!< (0x30001700UL), DATA FLASH Page23 */
    FC_DATA_FLASH_PAGE24,       /*!< (0x30001800UL), DATA FLASH Page24 */
    FC_DATA_FLASH_PAGE25,       /*!< (0x30001900UL), DATA FLASH Page25 */
    FC_DATA_FLASH_PAGE26,       /*!< (0x30001A00UL), DATA FLASH Page26 */
    FC_DATA_FLASH_PAGE27,       /*!< (0x30001B00UL), DATA FLASH Page27 */
    FC_DATA_FLASH_PAGE28,       /*!< (0x30001C00UL), DATA FLASH Page28 */
    FC_DATA_FLASH_PAGE29,       /*!< (0x30001D00UL), DATA FLASH Page29 */
    FC_DATA_FLASH_PAGE30,       /*!< (0x30001E00UL), DATA FLASH Page30 */
    FC_DATA_FLASH_PAGE31,       /*!< (0x30001F00UL), DATA FLASH Page31 */
    FC_DATA_FLASH_PAGE32,       /*!< (0x30002000UL), DATA FLASH Page32 */
    FC_DATA_FLASH_PAGE33,       /*!< (0x30002100UL), DATA FLASH Page33 */
    FC_DATA_FLASH_PAGE34,       /*!< (0x30002200UL), DATA FLASH Page34 */
    FC_DATA_FLASH_PAGE35,       /*!< (0x30002300UL), DATA FLASH Page35 */
    FC_DATA_FLASH_PAGE36,       /*!< (0x30002400UL), DATA FLASH Page36 */
    FC_DATA_FLASH_PAGE37,       /*!< (0x30002500UL), DATA FLASH Page37 */
    FC_DATA_FLASH_PAGE38,       /*!< (0x30002600UL), DATA FLASH Page38 */
    FC_DATA_FLASH_PAGE39,       /*!< (0x30002700UL), DATA FLASH Page39 */
    FC_DATA_FLASH_PAGE40,       /*!< (0x30002800UL), DATA FLASH Page40 */
    FC_DATA_FLASH_PAGE41,       /*!< (0x30002900UL), DATA FLASH Page41 */
    FC_DATA_FLASH_PAGE42,       /*!< (0x30002A00UL), DATA FLASH Page42 */
    FC_DATA_FLASH_PAGE43,       /*!< (0x30002B00UL), DATA FLASH Page43 */
    FC_DATA_FLASH_PAGE44,       /*!< (0x30002C00UL), DATA FLASH Page44 */
    FC_DATA_FLASH_PAGE45,       /*!< (0x30002D00UL), DATA FLASH Page45 */
    FC_DATA_FLASH_PAGE46,       /*!< (0x30002E00UL), DATA FLASH Page46 */
    FC_DATA_FLASH_PAGE47,       /*!< (0x30002F00UL), DATA FLASH Page47 */
    FC_DATA_FLASH_PAGE48,       /*!< (0x30003000UL), DATA FLASH Page48 */
    FC_DATA_FLASH_PAGE49,       /*!< (0x30003100UL), DATA FLASH Page49 */
    FC_DATA_FLASH_PAGE50,       /*!< (0x30003200UL), DATA FLASH Page50 */
    FC_DATA_FLASH_PAGE51,       /*!< (0x30003300UL), DATA FLASH Page51 */
    FC_DATA_FLASH_PAGE52,       /*!< (0x30003400UL), DATA FLASH Page52 */
    FC_DATA_FLASH_PAGE53,       /*!< (0x30003500UL), DATA FLASH Page53 */
    FC_DATA_FLASH_PAGE54,       /*!< (0x30003600UL), DATA FLASH Page54 */
    FC_DATA_FLASH_PAGE55,       /*!< (0x30003700UL), DATA FLASH Page55 */
    FC_DATA_FLASH_PAGE56,       /*!< (0x30003800UL), DATA FLASH Page56 */
    FC_DATA_FLASH_PAGE57,       /*!< (0x30003900UL), DATA FLASH Page57 */
    FC_DATA_FLASH_PAGE58,       /*!< (0x30003A00UL), DATA FLASH Page58 */
    FC_DATA_FLASH_PAGE59,       /*!< (0x30003B00UL), DATA FLASH Page59 */
    FC_DATA_FLASH_PAGE60,       /*!< (0x30003C00UL), DATA FLASH Page60 */
    FC_DATA_FLASH_PAGE61,       /*!< (0x30003D00UL), DATA FLASH Page61 */
    FC_DATA_FLASH_PAGE62,       /*!< (0x30003E00UL), DATA FLASH Page62 */
    FC_DATA_FLASH_PAGE63,       /*!< (0x30003F00UL), DATA FLASH Page63 */
    FC_DATA_FLASH_PAGE64,       /*!< (0x30004000UL), DATA FLASH Page64 */
    FC_DATA_FLASH_PAGE65,       /*!< (0x30004100UL), DATA FLASH Page65 */
    FC_DATA_FLASH_PAGE66,       /*!< (0x30004200UL), DATA FLASH Page66 */
    FC_DATA_FLASH_PAGE67,       /*!< (0x30004300UL), DATA FLASH Page67 */
    FC_DATA_FLASH_PAGE68,       /*!< (0x30004400UL), DATA FLASH Page68 */
    FC_DATA_FLASH_PAGE69,       /*!< (0x30004500UL), DATA FLASH Page69 */
    FC_DATA_FLASH_PAGE70,       /*!< (0x30004600UL), DATA FLASH Page70 */
    FC_DATA_FLASH_PAGE71,       /*!< (0x30004700UL), DATA FLASH Page71 */
    FC_DATA_FLASH_PAGE72,       /*!< (0x30004800UL), DATA FLASH Page72 */
    FC_DATA_FLASH_PAGE73,       /*!< (0x30004900UL), DATA FLASH Page73 */
    FC_DATA_FLASH_PAGE74,       /*!< (0x30004A00UL), DATA FLASH Page74 */
    FC_DATA_FLASH_PAGE75,       /*!< (0x30004B00UL), DATA FLASH Page75 */
    FC_DATA_FLASH_PAGE76,       /*!< (0x30004C00UL), DATA FLASH Page76 */
    FC_DATA_FLASH_PAGE77,       /*!< (0x30004D00UL), DATA FLASH Page77 */
    FC_DATA_FLASH_PAGE78,       /*!< (0x30004E00UL), DATA FLASH Page78 */
    FC_DATA_FLASH_PAGE79,       /*!< (0x30004F00UL), DATA FLASH Page79 */
    FC_DATA_FLASH_PAGE80,       /*!< (0x30005000UL), DATA FLASH Page80 */
    FC_DATA_FLASH_PAGE81,       /*!< (0x30005100UL), DATA FLASH Page81 */
    FC_DATA_FLASH_PAGE82,       /*!< (0x30005200UL), DATA FLASH Page82 */
    FC_DATA_FLASH_PAGE83,       /*!< (0x30005300UL), DATA FLASH Page83 */
    FC_DATA_FLASH_PAGE84,       /*!< (0x30005400UL), DATA FLASH Page84 */
    FC_DATA_FLASH_PAGE85,       /*!< (0x30005500UL), DATA FLASH Page85 */
    FC_DATA_FLASH_PAGE86,       /*!< (0x30005600UL), DATA FLASH Page86 */
    FC_DATA_FLASH_PAGE87,       /*!< (0x30005700UL), DATA FLASH Page87 */
    FC_DATA_FLASH_PAGE88,       /*!< (0x30005800UL), DATA FLASH Page88 */
    FC_DATA_FLASH_PAGE89,       /*!< (0x30005900UL), DATA FLASH Page89 */
    FC_DATA_FLASH_PAGE90,       /*!< (0x30005A00UL), DATA FLASH Page90 */
    FC_DATA_FLASH_PAGE91,       /*!< (0x30005B00UL), DATA FLASH Page91 */
    FC_DATA_FLASH_PAGE92,       /*!< (0x30005C00UL), DATA FLASH Page92 */
    FC_DATA_FLASH_PAGE93,       /*!< (0x30005D00UL), DATA FLASH Page93 */
    FC_DATA_FLASH_PAGE94,       /*!< (0x30005E00UL), DATA FLASH Page94 */
    FC_DATA_FLASH_PAGE95,       /*!< (0x30005F00UL), DATA FLASH Page95 */
    FC_DATA_FLASH_PAGE96,       /*!< (0x30006000UL), DATA FLASH Page96 */
    FC_DATA_FLASH_PAGE97,       /*!< (0x30006100UL), DATA FLASH Page97 */
    FC_DATA_FLASH_PAGE98,       /*!< (0x30006200UL), DATA FLASH Page98 */
    FC_DATA_FLASH_PAGE99,       /*!< (0x30006300UL), DATA FLASH Page99 */
    FC_DATA_FLASH_PAGE100,      /*!< (0x30006400UL), DATA FLASH Page100 */
    FC_DATA_FLASH_PAGE101,      /*!< (0x30006500UL), DATA FLASH Page101 */
    FC_DATA_FLASH_PAGE102,      /*!< (0x30006600UL), DATA FLASH Page102 */
    FC_DATA_FLASH_PAGE103,      /*!< (0x30006700UL), DATA FLASH Page103 */
    FC_DATA_FLASH_PAGE104,      /*!< (0x30006800UL), DATA FLASH Page104 */
    FC_DATA_FLASH_PAGE105,      /*!< (0x30006900UL), DATA FLASH Page105 */
    FC_DATA_FLASH_PAGE106,      /*!< (0x30006A00UL), DATA FLASH Page106 */
    FC_DATA_FLASH_PAGE107,      /*!< (0x30006B00UL), DATA FLASH Page107 */
    FC_DATA_FLASH_PAGE108,      /*!< (0x30006C00UL), DATA FLASH Page108 */
    FC_DATA_FLASH_PAGE109,      /*!< (0x30006D00UL), DATA FLASH Page109 */
    FC_DATA_FLASH_PAGE110,      /*!< (0x30006E00UL), DATA FLASH Page110 */
    FC_DATA_FLASH_PAGE111,      /*!< (0x30006F00UL), DATA FLASH Page111 */
    FC_DATA_FLASH_PAGE112,      /*!< (0x30007000UL), DATA FLASH Page112 */
    FC_DATA_FLASH_PAGE113,      /*!< (0x30007100UL), DATA FLASH Page113 */
    FC_DATA_FLASH_PAGE114,      /*!< (0x30007200UL), DATA FLASH Page114 */
    FC_DATA_FLASH_PAGE115,      /*!< (0x30007300UL), DATA FLASH Page115 */
    FC_DATA_FLASH_PAGE116,      /*!< (0x30007400UL), DATA FLASH Page116 */
    FC_DATA_FLASH_PAGE117,      /*!< (0x30007500UL), DATA FLASH Page117 */
    FC_DATA_FLASH_PAGE118,      /*!< (0x30007600UL), DATA FLASH Page118 */
    FC_DATA_FLASH_PAGE119,      /*!< (0x30007700UL), DATA FLASH Page119 */
    FC_DATA_FLASH_PAGE120,      /*!< (0x30007800UL), DATA FLASH Page120 */
    FC_DATA_FLASH_PAGE121,      /*!< (0x30007900UL), DATA FLASH Page121 */
    FC_DATA_FLASH_PAGE122,      /*!< (0x30007A00UL), DATA FLASH Page122 */
    FC_DATA_FLASH_PAGE123,      /*!< (0x30007B00UL), DATA FLASH Page123 */
    FC_DATA_FLASH_PAGE124,      /*!< (0x30007C00UL), DATA FLASH Page124 */
    FC_DATA_FLASH_PAGE125,      /*!< (0x30007D00UL), DATA FLASH Page125 */
    FC_DATA_FLASH_PAGE126,      /*!< (0x30007E00UL), DATA FLASH Page126 */
    FC_DATA_FLASH_PAGE127       /*!< (0x30007F00UL), DATA FLASH Page127 */
} fc_data_flash_page_number_t;
#define FC_DATA_FLASH_PAGE_MAX  (FC_DATA_FLASH_PAGE127)  /*!< Maxmum pages */

typedef enum {
    FC_CODE_FLASH_BLOCK0  = 0,   /*!< (0x5E000000UL), CODE FLASH Block0 */
    FC_CODE_FLASH_BLOCK1,        /*!< (0x5E008000UL), CODE FLASH Block1 */
    FC_CODE_FLASH_BLOCK2,        /*!< (0x5E010000UL), CODE FLASH Block2 */
    FC_CODE_FLASH_BLOCK3,        /*!< (0x5E018000UL), CODE FLASH Block3 */
    FC_CODE_FLASH_BLOCK4,        /*!< (0x5E020000UL), CODE FLASH Block4 */
    FC_CODE_FLASH_BLOCK5,        /*!< (0x5E028000UL), CODE FLASH Block5 */
    FC_CODE_FLASH_BLOCK6,        /*!< (0x5E030000UL), CODE FLASH Block6 */
    FC_CODE_FLASH_BLOCK7,        /*!< (0x5E038000UL), CODE FLASH Block7 */
    FC_CODE_FLASH_BLOCK8,        /*!< (0x5E040000UL), CODE FLASH Block8 */
    FC_CODE_FLASH_BLOCK9,        /*!< (0x5E048000UL), CODE FLASH Block9 */
    FC_CODE_FLASH_BLOCK10,       /*!< (0x5E050000UL), CODE FLASH Block10 */
    FC_CODE_FLASH_BLOCK11,       /*!< (0x5E058000UL), CODE FLASH Block11 */
    FC_CODE_FLASH_BLOCK12,       /*!< (0x5E060000UL), CODE FLASH Block12 */
    FC_CODE_FLASH_BLOCK13,       /*!< (0x5E068000UL), CODE FLASH Block13 */
    FC_CODE_FLASH_BLOCK14,       /*!< (0x5E070000UL), CODE FLASH Block14 */
    FC_CODE_FLASH_BLOCK15,       /*!< (0x5E078000UL), CODE FLASH Block15 */
    FC_CODE_FLASH_BLOCK16,       /*!< (0x5E080000UL), CODE FLASH Block16 */
    FC_CODE_FLASH_BLOCK17,       /*!< (0x5E088000UL), CODE FLASH Block17 */
    FC_CODE_FLASH_BLOCK18,       /*!< (0x5E090000UL), CODE FLASH Block18 */
    FC_CODE_FLASH_BLOCK19,       /*!< (0x5E098000UL), CODE FLASH Block19 */
    FC_CODE_FLASH_BLOCK20,       /*!< (0x5E0A0000UL), CODE FLASH Block20 */
    FC_CODE_FLASH_BLOCK21,       /*!< (0x5E0A8000UL), CODE FLASH Block21 */
    FC_CODE_FLASH_BLOCK22,       /*!< (0x5E0B0000UL), CODE FLASH Block22 */
    FC_CODE_FLASH_BLOCK23,       /*!< (0x5E0B8000UL), CODE FLASH Block23 */
    FC_CODE_FLASH_BLOCK24,       /*!< (0x5E0C0000UL), CODE FLASH Block24 */
    FC_CODE_FLASH_BLOCK25,       /*!< (0x5E0C8000UL), CODE FLASH Block25 */
    FC_CODE_FLASH_BLOCK26,       /*!< (0x5E0D0000UL), CODE FLASH Block26 */
    FC_CODE_FLASH_BLOCK27,       /*!< (0x5E0D8000UL), CODE FLASH Block27 */
    FC_CODE_FLASH_BLOCK28,       /*!< (0x5E0E0000UL), CODE FLASH Block28 */
    FC_CODE_FLASH_BLOCK29,       /*!< (0x5E0E8000UL), CODE FLASH Block29 */
    FC_CODE_FLASH_BLOCK30,       /*!< (0x5E0F0000UL), CODE FLASH Block30 */
    FC_CODE_FLASH_BLOCK31        /*!< (0x5E0F8000UL), CODE FLASH Block31 */
} fc_code_flash_block_number_t;
#define FC_CODE_FLASH_BLOCK_MAX (FC_CODE_FLASH_BLOCK31)  /*!< Maxmum blocks */

typedef enum {
    FC_DATA_FLASH_BLOCK0  = 0,   /*!< (0x30000000UL), DATA FLASH Block0 */
    FC_DATA_FLASH_BLOCK1,        /*!< (0x30001000UL), DATA FLASH Block1 */
    FC_DATA_FLASH_BLOCK2,        /*!< (0x30002000UL), DATA FLASH Block2 */
    FC_DATA_FLASH_BLOCK3,        /*!< (0x30003000UL), DATA FLASH Block3 */
    FC_DATA_FLASH_BLOCK4,        /*!< (0x30004000UL), DATA FLASH Block4 */
    FC_DATA_FLASH_BLOCK5,        /*!< (0x30005000UL), DATA FLASH Block5 */
    FC_DATA_FLASH_BLOCK6,        /*!< (0x30006000UL), DATA FLASH Block6 */
    FC_DATA_FLASH_BLOCK7         /*!< (0x30007000UL), DATA FLASH Block7 */
} fc_data_flash_block_number_t;
#define FC_DATA_FLASH_BLOCK_MAX (FC_DATA_FLASH_BLOCK7)  /*!< Maxmum blocks */

typedef enum {
    FC_CODE_FLASH_AREA0 = 0,    /*!< (0x5E000000UL), CODE FLASH AREA0 */
    FC_CODE_FLASH_AREA1         /*!< (0x5E080000UL), CODE FLASH AREA1 */
} fc_code_flash_area_number_t;
#define FC_CODE_FLASH_AREA_MAX (FC_CODE_FLASH_AREA1)  /*!< Maxmum areas */

typedef enum {
    FC_DATA_FLASH_AREA4  = 0     /*!< (0x30000000UL), DATA FLASH AREA4 */
} fc_data_flash_area_number_t;
#define FC_DATA_FLASH_AREA_MAX (FC_DATA_FLASH_AREA4)  /*!< Maxmum areas */


/** @} */
/* End of group FLASH */

/** @} */
/* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif  /* __cplusplus */
#endif  /* __FLASH_10MUD32_A_H */
