/** 
 *******************************************************************************
 * @file    cg.h
 * @brief   This file provides all the functions prototypes for CG driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __CG_H
#define __CG_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
#include "cg_config.h"
/**
 *  @addtogroup Periph_Driver
 *  @{
 */

/** 
 *  @defgroup CG CG
 *  @brief    CG Driver.
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CG_Exported_define CG Exported Define
 *  @{
 */

#define CG_GEAR_FC_1            ((uint32_t)0x00000000)      /*!< CG fc register value */
#define CG_GEAR_FC_2            ((uint32_t)0x00000001)      /*!< CG fc/2 register value */
#define CG_GEAR_FC_4            ((uint32_t)0x00000002)      /*!< CG fc/4 register value */
#define CG_GEAR_FC_8            ((uint32_t)0x00000003)      /*!< CG fc/8 register value */
#define CG_GEAR_FC_16           ((uint32_t)0x00000004)      /*!< CG fc/16 register value */
#define CG_PRCK_FC_1            ((uint32_t)0x00000000)      /*!< CG T0 fc register value */
#define CG_PRCK_FC_2            ((uint32_t)0x00000100)      /*!< CG T0 fc/2 register value */
#define CG_PRCK_FC_4            ((uint32_t)0x00000200)      /*!< CG T0 fc/4 register value */
#define CG_PRCK_FC_8            ((uint32_t)0x00000300)      /*!< CG T0 fc/8 register value */
#define CG_PRCK_FC_16           ((uint32_t)0x00000400)      /*!< CG T0 fc/16 register value */
#define CG_PRCK_FC_32           ((uint32_t)0x00000500)      /*!< CG T0 fc/32 register value */
#define CG_PRCK_FC_64           ((uint32_t)0x00000600)      /*!< CG T0 fc/64 register value */
#define CG_PRCK_FC_128          ((uint32_t)0x00000700)      /*!< CG T0 fc/128 register value */
#define CG_PRCK_FC_256          ((uint32_t)0x00000800)      /*!< CG T0 fc/256 register value */
#define CG_PRCK_FC_512          ((uint32_t)0x00000900)      /*!< CG T0 fc/512 register value */

#define CG_PRCKST_FC_1          ((uint32_t)0x00000000)      /*!< CG T0 fc register value */
#define CG_PRCKST_FC_2          ((uint32_t)0x01000000)      /*!< CG T0 fc/2 register value */
#define CG_PRCKST_FC_4          ((uint32_t)0x02000000)      /*!< CG T0 fc/4 register value */
#define CG_PRCKST_FC_8          ((uint32_t)0x03000000)      /*!< CG T0 fc/8 register value */
#define CG_PRCKST_FC_16         ((uint32_t)0x04000000)      /*!< CG T0 fc/16 register value */
#define CG_PRCKST_FC_32         ((uint32_t)0x05000000)      /*!< CG T0 fc/32 register value */
#define CG_PRCKST_FC_64         ((uint32_t)0x06000000)      /*!< CG T0 fc/64 register value */
#define CG_PRCKST_FC_128        ((uint32_t)0x07000000)      /*!< CG T0 fc/128 register value */
#define CG_PRCKST_FC_256        ((uint32_t)0x08000000)      /*!< CG T0 fc/256 register value */
#define CG_PRCKST_FC_512        ((uint32_t)0x09000000)      /*!< CG T0 fc/512 register value */

#define CG_WARM_UP_SRC_EHOSC    ((uint32_t)0x00000100)      /*!< CG warm up src EHOSC */
#define CG_WARM_UP_SRC_IHOSC1   ((uint32_t)0x00000000)      /*!< CG warm up src IHOSC1 */

#define CG_EHOSCEN_UNUSE        ((uint32_t)0x00000000)      /*!< CG EHOSCEN unuse */
#define CG_EHOSCEN_EHOSC        ((uint32_t)0x00000002)      /*!< CG EHOSCEN EHOSC */
#define CG_EHOSCEN_EHOCLKIN     ((uint32_t)0x00000004)      /*!< CG EHOSCEN EHOCLKIN */

#define CG_OSCSEL_EHOSC         ((uint32_t)0x00000100)      /*!< CG OSCSEL EHOSC */
#define CG_OSCSEL_IHOSC1        ((uint32_t)0x00000000)      /*!< CG OSCSEL IHOSC1 */

#define CG_PLL0SEL_FPLL         ((uint32_t)0x00000002)      /*!< CG PLL0SEL fPLL */
#define CG_PLL0SEL_FOSC         ((uint32_t)0x00000000)      /*!< CG PLL0SEL fosc */

#define CG_PLL0SEL_PLL0ON_SET   (0x00000001)                /*!< CG PLL0OON on */
#define PLL0SEL_MASK            (0xFFFFFF00UL)              /*!< CG PLL mask */

#define CG_PARAM_OK             ((int32_t)1)                /*!< Parameter is valid(specified).         */
#define CG_PARAM_NG             ((int32_t)0)                /*!< Parameter is invalid(not specified).   */

#define CG_STBY_IDLE            ((uint32_t)0x00000000)      /*!< CG STBY IDLE */
#define CG_STBY_STOP1           ((uint32_t)0x00000001)      /*!< CG STBY STOP1 */
#define CG_STBY_STOP2           ((uint32_t)0x00000002)      /*!< CG STBY STOP2 */

#define CG_SCOCR_SCOEN_DISABLE  (0x00000000UL)      /*!< CG SCOCR SCOEC DISABLE */
#define CG_SCOCR_SCOEN_ENABLE   (0x00000001UL)      /*!< CG SCOCR SCOEC ENABLE */

#define CG_SCOCR_SCOSEL_FOSC    (0x00000000UL)      /*!< CG SCOCR SCOSEL FOSC */
#define CG_SCOCR_SCOSEL_FC      (0x00000002UL)      /*!< CG SCOCR SCOSEL FC */
#define CG_SCOCR_SCOSEL_FS      (0x00000004UL)      /*!< CG SCOCR SCOSEL FS */
#define CG_SCOCR_SCOSEL_FSYS    (0x00000006UL)      /*!< CG SCOCR SCOSEL FSYS */

#define CG_SCOCR_SCODIV_NONE    (0x00000000UL)      /*!< CG SCOCR SCODIV NONE */
#define CG_SCOCR_SCODIV_2       (0x00000010UL)      /*!< CG SCOCR SCODIV /2 */
#define CG_SCOCR_SCODIV_4       (0x00000020UL)      /*!< CG SCOCR SCODIV /4 */
#define CG_SCOCR_SCODIV_8       (0x00000030UL)      /*!< CG SCOCR SCODIV /8 */
#define CG_SCOCR_SCODIV_16      (0x00000040UL)      /*!< CG SCOCR SCODIV /16 */

#define CG_MCKSELPST_1          ((uint32_t)0x00000000)      /*!< CG mT0 fc register value */
#define CG_MCKSELPST_2          ((uint32_t)0x40000000)      /*!< CG mT0 fc/2 register value */
#define CG_MCKSELPST_4          ((uint32_t)0x80000000)      /*!< CG mT0 fc/4 register value */

#define CG_MCKSELGST_1          ((uint32_t)0x00000000)      /*!< CG fsysm fc register value */
#define CG_MCKSELGST_2          ((uint32_t)0x00400000)      /*!< CG fsysm fc/2 register value */
#define CG_MCKSELGST_4          ((uint32_t)0x00800000)      /*!< CG fsysm fc/4 register value */

#define CG_MCKSEL_1             ((uint32_t)0x00000000)      /*!< CG fsysm, mT0 fc value */
#define CG_MCKSEL_2             ((uint32_t)0x00000040)      /*!< CG fsysm, mT0 fc/2 value */
#define CG_MCKSEL_4             ((uint32_t)0x00000080)      /*!< CG fsysm, mT0 fc/4 value */

#define CG_MCKSEL_1_DIV         ((uint32_t)0x00000001)      /*!< CG fsysm, mT0 fc division value */
#define CG_MCKSEL_2_DIV         ((uint32_t)0x00000002)      /*!< CG fsysm, mT0 fc/2 division value */
#define CG_MCKSEL_4_DIV         ((uint32_t)0x00000004)      /*!< CG fsysm, mT0 fc/4 division value */

#define CG_EXTEND2_0            ((uint32_t)0x00000000)      /*!< CG extend2 write 0 */
#define CG_EXTEND2_RSV22        ((uint32_t)0x00000004)      /*!< CG extend2 RSV22 write 1 */
#define CG_EXTEND2_RSV21        ((uint32_t)0x00000002)      /*!< CG extend2 RSV21 write 1 */
#define CG_EXTEND2_RSV20        ((uint32_t)0x00000001)      /*!< CG extend2 RSV20 write 1 */

#define RLM_XTEN_MASK           ((uint8_t)0xFE)             /*!< RLMLOSCCR 0bit XTEN MASK */
#define RLM_XTEN_ENABLE         ((uint8_t)0x01)             /*!< RLMLOSCCR 0bit XTEN ENABLE */
#define RLM_XTEN_DISABLE        ((uint8_t)0x00)             /*!< RLMLOSCCR 0bit XTEN DISABLE */

#define RLM_IHOSC2_MASK         ((uint8_t)0xEF)             /*!< RLMLOSCCR 4bit IHOSC2 MASK */
#define RLM_IHOSC2_ENABLE       ((uint8_t)0x10)             /*!< RLMLOSCCR 4bit IHOSC2 ENABLE */
#define RLM_IHOSC2_DISABLE      ((uint8_t)0x00)             /*!< RLMLOSCCR 4bit IHOSC2 DISABLE */
#define RLM_IHOSC2_FLAG         ((uint8_t)0x20)             /*!< RLMLOSCCR 5bit IHOSC2 FLAG */

#define RLM_DRCOSCL_MASK        ((uint8_t)0xFB)             /*!< RLMLOSCCR 2bit DRCOSCL MASK */
#define RLM_DRCOSCL_ELCLKIN     ((uint8_t)0x00)             /*!< RLMLOSCCR 2bit DRCOSCL ELCLKIN */
#define RLM_DRCOSCL_ELOSC       ((uint8_t)0x04)             /*!< RLMLOSCCR 2bit DRCOSCL ELOSC */

#define RLM_PTKEEP_MASK         ((uint8_t)0xFE)             /*!< RLMSHTDNOP 0bit PTKEEP MASK */
#define RLM_PTKEEP_ENABLE       ((uint8_t)0x01)             /*!< RLMSHTDNOP 0bit PTKEEP ENABLE */
#define RLM_PTKEEP_DISABLE      ((uint8_t)0x00)             /*!< RLMSHTDNOP 0bit PTKEEP DISABLE */

#define RLM_PROTECT_ENABLE      ((uint8_t)0xC1)             /*!< RLMPROTECT 0bit PTKEEP ENABLE */
#define RLM_PROTECT_DISABLE     ((uint8_t)0x00)             /*!< RLMPROTECT 0bit PTKEEP DISABLE */
/**
 *  @}
 */ /* End of group CG_Exported_define */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CG_Exported_typedef CG Exported Typedef
 *  @{
 */
/** 
 * @brief  CG member.
*/
/*----------------------------------*/
typedef struct
{
    TSB_CG_TypeDef       *p_instance;     /*!< Registers base address.           */
} cg_t;

/** 
 * @brief  RLM member.
*/
/*----------------------------------*/
typedef struct
{
    TSB_RLM_TypeDef       *p_instance;     /*!< Registers base address.           */
} rlm_t;
/**
 *  @}
 */ /* End of group CG_Exported_typedef */

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CG_Exported_functions CG Exported Functions
 *  @{
 */
void cg_set_gear(cg_t *p_obj, uint32_t gear);
uint32_t cg_get_gear(cg_t *p_obj);
void cg_set_phyt0(cg_t *p_obj, uint32_t prck);
uint32_t cg_get_phyt0(cg_t *p_obj);
void cg_set_warm_up_time(cg_t *p_obj, uint32_t source, uint32_t time);
TXZ_WorkState cg_get_warm_up_state(void);
void cg_start_warmup(void);
void cg_wait_warmup(void);
void cg_set_ehoscen(cg_t *p_obj, uint32_t eoscen);
uint32_t cg_get_ehoscen(cg_t *p_obj);
void cg_set_oscsel(uint32_t source);
uint32_t cg_get_oscsel(void);
void cg_ihosc1_enable(void);
void cg_ihosc1_disable(void);
TXZ_WorkState cg_get_ihosc1_state(void);
void cg_set_PLL(cg_t *p_obj, uint32_t PLLset);
void cg_PLL_enable(void);
void cg_PLL_disable(void);
void cg_set_PLL_clock(uint32_t clock);
uint32_t cg_get_PLL_status(void);
uint32_t cg_get_stby_mode(cg_t *p_obj);
void cg_protect_enable(cg_t *p_obj);
void cg_protect_disable(cg_t *p_obj);
void cg_get_system_core_clock(cg_t *p_obj);
void cg_set_fcen(cg_t *p_obj, uint32_t fcipen, TXZ_FunctionalState state);
void cg_set_all_fcen(cg_t *p_obj, TXZ_FunctionalState state);
void cg_set_spclken(cg_t *p_obj, uint32_t spclken, TXZ_FunctionalState state);
void cg_set_all_spclken(cg_t *p_obj, TXZ_FunctionalState state);

uint32_t cg_get_prckst(cg_t *p_obj);
void cg_set_stby_mode(cg_t *p_obj, uint32_t mode);


/* optional function */

/* medium speed clock */
void cg_set_fsysm(cg_t *p_obj, uint32_t fsysm);
uint32_t cg_get_fsysm(cg_t *p_obj);
uint32_t cg_get_mphyt0(cg_t *p_obj);
uint32_t cg_get_mckselgst(cg_t *p_obj);
uint32_t cg_get_mckselpst(cg_t *p_obj);

/* IHOSC2 */
TXZ_WorkState cg_get_ihosc2_state(void);
void cg_ihosc2_enable(void);
void cg_ihosc2_disable(void);

/* SCOUT */
void cg_scout_enable(void);
void cg_scout_disable(void);
void cg_set_scout_clock(cg_t *p_obj, uint32_t source);
void cg_set_scout_time(cg_t *p_obj, uint32_t time);

/* low speed warm up */
void cg_set_low_warm_up_time(cg_t *p_obj, uint32_t time);
void cg_start_low_warmup(void);
TXZ_WorkState cg_get_low_warm_up_state(void);

/* FSYSMENA register */
void cg_set_fsysmena(cg_t *p_obj, uint32_t ipmena, TXZ_FunctionalState state);
void cg_set_all_fsysmena(cg_t *p_obj, TXZ_FunctionalState state);

/* FSYSMENB register */
void cg_set_fsysmenb(cg_t *p_obj, uint32_t ipmenb, TXZ_FunctionalState state);
void cg_set_all_fsysmenb(cg_t *p_obj, TXZ_FunctionalState state);

/* FSYSMENC register */
void cg_set_fsysmenc(cg_t *p_obj, uint32_t ipmenc, TXZ_FunctionalState state);
void cg_set_all_fsysmenc(cg_t *p_obj, TXZ_FunctionalState state);

/* FSYSENA register */
void cg_set_fsysena(cg_t *p_obj, uint32_t ipena, TXZ_FunctionalState state);
void cg_set_all_fsysena(cg_t *p_obj, TXZ_FunctionalState state);

/* FSYSENB register */
void cg_set_fsysenb(cg_t *p_obj, uint32_t ipenb, TXZ_FunctionalState state);
void cg_set_all_fsysenb(cg_t *p_obj, TXZ_FunctionalState state);

/* EXTEND2 function */
void cg_extend2_func(cg_t *p_obj, uint32_t bit);

/* RLM LOSCCR function */
void rlm_fs_enable(rlm_t *p_obj);
void rlm_fs_disable(rlm_t *p_obj);

/* RLM LOSCCR IHOSC2 function */
void rlm_ihosc2_enable(rlm_t *p_obj);
void rlm_ihosc2_disable(rlm_t *p_obj);
TXZ_WorkState rlm_get_ihosc2_state(rlm_t *p_obj);
void rlm_set_elclkin(rlm_t *p_obj);
void rlm_set_elosc(rlm_t *p_obj);

/* RLM SHTDNOP PROTECT function */
void rlm_port_keep_enable(rlm_t *p_obj);
void rlm_port_keep_disable(rlm_t *p_obj);
void rlm_protect_enable(rlm_t *p_obj);
void rlm_protect_disable(rlm_t *p_obj);

/* FCRACCR function */
void fc_ram_con_reg_set(uint32_t sysclock);
/**
 *  @}
 */ /* End of group CG_Exported_functions */

/**
 *  @}
 */ /* End of group CG */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __CG_M4K2_H */


