/** 
 *******************************************************************************
 * @file    dnf.h
 * @brief   This file is wrapper file for DNF driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __DNF_H
#define __DNF_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"

/*------------------------------------------------------------------------------*/
/*  Definition                                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup DNF_Exported_define DNF Exported Define
 *  @{
 */

typedef enum
{
    NFCKS_CLOCK_STOP = 0,
    NFCKS_CLOCK_FC_2,
    NFCKS_CLOCK_FC_4,
    NFCKS_CLOCK_FC_8,
    NFCKS_CLOCK_FC_16,
    NFCKS_CLOCK_FC_32,
    NFCKS_CLOCK_FC_64,
    NFCKS_CLOCK_FC_128
} dnf_nfcks_t;

/**
 *  @}
 */ /* End of group DNF_define */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup DNF_Exported_typedef DNF Exported Typedef
 *  @{
 */

/** 
 * @brief  DNF member.
*/

/*----------------------------------*/
typedef struct
{
    TSB_DNF_TypeDef *p_instance;     /*!< Registers base address.   */
} dnf_t;
/**
 *  @}
 */ /* End of group DNF_Exported_typedef */

#include "dnf_config.h"

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup DNF_Exported_functions
 *  @{
 */
/* DNFCKCR */
TXZ_Result select_noise_filter_clock(dnf_t *p_obj, dnf_nfcks_t clock);
TXZ_Result read_DNFxCKCR_register(dnf_t *p_obj, uint32_t *p_value);

/* DNFENCR */
TXZ_Result enable_noise_filter(dnf_t *p_obj, uint32_t bit);
TXZ_Result disable_noise_filter(dnf_t *p_obj, uint32_t bit);
TXZ_Result read_DNFxENCR_register(dnf_t *p_obj, uint32_t *p_value);

/** 
 *  @}
 */ /* End of group DNF_Exported_functions */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __DNF_H */
