/** 
 *******************************************************************************
 * @file    except.h
 * @brief   This file is wrapper file for EXCEPT driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"

/*------------------------------------------------------------------------------*/
/*  Definition                                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup EXCEPT_Exported_define EXCEPT Exported Define
 *  @{
 */
#define INT_MODE_MASK               0x0E                 /* int mode mask */
#define INT_INTN_CLEAR_BIT          0x80                 /* intn mask */
#define INT_INTP_CLEAR_BIT          0x40                 /* intp mask */
#define INT_INTN_FLAG               0x20                 /* intn flag */
#define INT_INTP_FLAG               0x10                 /* intp flag */
#define INT_INTEN_BIT               0x01                 /* intp flag */
#define EXCEPT_PARAM_OK             ((int32_t)1)         /*!< Parameter is valid(specified).         */
#define EXCEPT_PARAM_NG             ((int32_t)0)         /*!< Parameter is invalid(not specified).   */

typedef enum
{
    INTERRUPT_NOT_DETECT = 0,
    INTERRUPT_DETECT
}except_state;

typedef enum
{
    INT_REGISTER_A = 0,    /*!< 0: IA       */
    INT_REGISTER_B         /*!< 1: IB       */
}except_register_t;

typedef enum
{
    INT_NIC = 0,           /*!< 0: NIC      */
    INT_IMC                /*!< 1: IMC      */
}except_int_t;

typedef enum
{
    MODE_LOW_LEVEL = 0,    /*!< 0: int mode low level    */
    MODE_HIGH_LEVEL,       /*!< 1: int mode high level   */
    MODE_FALLING_EDGE,     /*!< 2: int mode falling edge */
    MODE_RISING_EDGE,      /*!< 3: int mode rising edge  */
    MODE_BOTH_EDGE         /*!< 4: int mode both edge    */
}except_mode_t;

/**
 *  @}
 */ /* End of group EXCEPT_define */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup EXCEPT_Exported_typedef EXCEPT Exported Typedef
 *  @{
 */

/** 
 * @brief  EXCEPT member.
*/
/*----------------------------------*/
typedef struct
{
    TSB_IA_TypeDef       *p_instance1;     /*!< Registers base address.           */
    TSB_IB_TypeDef       *p_instance2;     /*!< Registers base address.           */
    TSB_IMN_TypeDef      *p_instance3;     /*!< Registers base address.           */
} except_t;
/**
 *  @}
 */ /* End of group EXCEPT_Exported_typedef */

#include "except_config.h"

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup EXCEPT_Exported_functions EXCEPT Exported Functions
 *  @{
 */
TXZ_Result except_set_mode(except_t *p_obj, except_register_t target, except_mode_t mode, uint32_t imc, except_int_t nicimc);
TXZ_Result except_clear_intn(except_t *p_obj, except_register_t target, uint32_t imc, except_int_t nicimc);
TXZ_Result except_clear_intp(except_t *p_obj, except_register_t target, uint32_t imc, except_int_t nicimc);
except_state except_get_intn(except_t *p_obj, except_register_t target, uint32_t imc, except_int_t nicimc);
except_state except_get_intp(except_t *p_obj, except_register_t target, uint32_t imc, except_int_t nicimc);
TXZ_Result except_set_inten(except_t *p_obj, except_register_t target, uint32_t imc, except_int_t nicimc, TXZ_FunctionalState status);
except_state rlm_get_flag0(rlm_t *p_obj, rlm_rstflg0_t target);
except_state rlm_get_flag1(rlm_t *p_obj, rlm_rstflg1_t target);
TXZ_Result rlm_clear_flag0(rlm_t *p_obj, rlm_rstflg0_t target);
TXZ_Result rlm_clear_flag1(rlm_t *p_obj, rlm_rstflg1_t target);
except_state imn_get_flag(except_t *p_obj, uint32_t target);


/**
 *  @}
 */ /* End of group EXCEPT_Exported_functions */

#ifdef __cplusplus
}
#endif /* __cplusplus */


