/** 
 *******************************************************************************
 * @file    port.h
 * @brief   This file is wrapper file for PORT driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
#ifndef __PORT_H
#define __PORT_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"

/** 
 *  @enum gpio_pinstate_t
 *  @brief    Pin State Reset/Set Enumerated Type Definition.
 */
typedef enum
{
  GPIO_PIN_RESET = 0,  /*!< 0: Clear       */
  GPIO_PIN_SET,        /*!< 1: Set         */
}gpio_pinstate_t;

/**
 *  @enum gpio_pininout_t
 *  @brief    Pin Input/Output Enumerated Type Definition.
 */
typedef enum
{
  GPIO_PIN_NOTINOUT = 0,   /*!< 0: Not Input/Output */
  GPIO_PIN_INPUT,          /*!< 1: Input       */
  GPIO_PIN_OUTPUT,         /*!< 2: Output       */
  GPIO_PIN_INOUT,          /*!< 3: Input/Output */
}gpio_pininout_t;
 
/** 
 *  @enum gpio_gr_t
 *  @brief    Port Group Enumerated Type Definition.
 */
typedef enum
{
  GPIO_PORT_A = 0x0, /*!< 0: PA       */
  GPIO_PORT_B,       /*!< 1: PB       */
  GPIO_PORT_C,       /*!< 2: PC       */
  GPIO_PORT_D,       /*!< 3: PD       */
  GPIO_PORT_E,       /*!< 4: PE       */
  GPIO_PORT_F,       /*!< 5: PF       */
  GPIO_PORT_G,       /*!< 6: PG       */
  GPIO_PORT_H,       /*!< 7: PH       */
  GPIO_PORT_J,       /*!< 8: PJ       */
  GPIO_PORT_K,       /*!< 9: PK       */
  GPIO_PORT_L,       /*!< 10: PL       */
  GPIO_PORT_M,       /*!< 11: PM       */
  GPIO_PORT_N,       /*!< 12: PN       */
  GPIO_PORT_P,       /*!< 13: PP       */
  GPIO_PORT_R,       /*!< 14: PR       */
  GPIO_PORT_T,       /*!< 15: PT       */
  GPIO_PORT_U,       /*!< 16: PU       */
  GPIO_PORT_V,       /*!< 17: PV       */
  GPIO_PORT_W,       /*!< 18: PW       */
  GPIO_PORT_Y,       /*!< 19: PY       */
  GPIO_GROUP_Max     /*!< Max Number   */
}gpio_gr_t;

/** 
 *  @enum gpio_num_t
 *  @brief    Port Number Enumerated Type Definition.
 */
typedef enum
{
  GPIO_PORT_0 = 0x0, /*!< 0: Port0       */
  GPIO_PORT_1,       /*!< 1: Port1       */
  GPIO_PORT_2,       /*!< 2: Port2       */
  GPIO_PORT_3,       /*!< 3: Port3       */
  GPIO_PORT_4,       /*!< 4: Port4       */
  GPIO_PORT_5,       /*!< 5: Port5       */
  GPIO_PORT_6,       /*!< 6: Port6       */
  GPIO_PORT_7,       /*!< 7: Port7       */
  GPIO_PORT_Max      /*!< Max Number     */
}gpio_num_t;

/** 
 *  @enum gpio_fr_t
 *  @brief    Port Function Number Enumerated Type Definition.
 */
typedef enum
{
  GPIO_FR_1 = 1,   /*!< 1: PxFR1       */
  GPIO_FR_2,       /*!< 2: PxFR2       */
  GPIO_FR_3,       /*!< 3: PxFR3       */
  GPIO_FR_4,       /*!< 4: PxFR4       */
  GPIO_FR_5,       /*!< 5: PxFR5       */
  GPIO_FR_6,       /*!< 6: PxFR6       */
  GPIO_FR_7,       /*!< 7: PxFR7       */
  GPIO_FR_8,       /*!< 8: PxFR8       */
  GPIO_FR_NA,      /*!< 9: N/A         */
  GPIO_FR_Max = 8, /*!< Max Number     */
}gpio_fr_t;

/** 
 *  @enum gpio_mode_t
 *  @brief    Port Mode Enumerated Type Definition.
 */
typedef enum
{
  GPIO_Mode_DATA = 0x0,   /*!< 0x0: PxDATA      */
  GPIO_Mode_CR   = 0x4,   /*!< 0x4: PxCR        */
  GPIO_Mode_FR1  = 0x8,   /*!< 0x8: PxFR1       */
  GPIO_Mode_FR2  = 0xC,   /*!< 0xC: PxFR2       */
  GPIO_Mode_FR3  = 0x10,  /*!< 0x10: PxFR3      */
  GPIO_Mode_FR4  = 0x14,  /*!< 0x14: PxFR4      */
  GPIO_Mode_FR5  = 0x18,  /*!< 0x18: PxFR5      */
  GPIO_Mode_FR6  = 0x1C,  /*!< 0x1C: PxFR6      */
  GPIO_Mode_FR7  = 0x20,  /*!< 0x20: PxFR7      */
  GPIO_Mode_FR8  = 0x24,  /*!< 0x24: PxFR8      */
  GPIO_Mode_OD   = 0x28,  /*!< 0x28: PxOD       */
  GPIO_Mode_PUP  = 0x2C,  /*!< 0x2C: PxPUP      */
  GPIO_Mode_PDN  = 0x30,  /*!< 0x30: PxPDN      */
  GPIO_Mode_RSV0 = 0x34,  /*!< 0x34: RESERVED0  */
  GPIO_Mode_IE   = 0x38,  /*!< 0x38: PxIE       */
  GPIO_Mode_RSV1 = 0x3C,  /*!< 0x3C: RESERVED1  */
  GPIO_Mode_Max  = 16
}gpio_mode_t;

#include "port_config.h"

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup PORT_Exported_functions PORT Exported Functions
 *  @{
 */
TXZ_Result gpio_init(gpio_gr_t group);
TXZ_Result gpio_deinit(gpio_gr_t group);
TXZ_Result gpio_write_mode(gpio_t *p_obj, gpio_gr_t group, gpio_mode_t mode, uint32_t val);
TXZ_Result gpio_read_mode(gpio_gr_t group, gpio_mode_t mode, uint32_t *val);
TXZ_Result gpio_func(gpio_t *p_obj, gpio_gr_t group, gpio_num_t num, uint32_t func, gpio_pininout_t inout);
TXZ_Result gpio_SetPullUp(gpio_t *p_obj, gpio_gr_t group, gpio_num_t num, gpio_pinstate_t val);
TXZ_Result gpio_SetPullDown(gpio_t *p_obj, gpio_gr_t group, gpio_num_t num, gpio_pinstate_t val);
TXZ_Result gpio_SetOpenDrain(gpio_t *p_obj, gpio_gr_t group, gpio_num_t num, gpio_pinstate_t val);
TXZ_Result gpio_write_bit(gpio_t *p_obj, gpio_gr_t group, gpio_num_t num, gpio_mode_t mode, gpio_pinstate_t val);
TXZ_Result gpio_read_bit(gpio_t *p_obj, gpio_gr_t group, gpio_num_t num, gpio_mode_t mode, gpio_pinstate_t *pinstate);

/**
 *  @}
 */ /* End of group PORT_Exported_functions */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __PORT_H */


