/** 
 *******************************************************************************
 * @file    siwdt.h
 * @brief   This file is wrapper file for SIWDT driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __SIWDT_H
#define __SIWDT_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
#include "siwdt_config.h"

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup SIWDT
 *  @brief      SIWDT Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group SIWDT_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_functions
 *  @{
 */

void wdt_disable(TSB_SIWD_TypeDef *p_reg);
void wdt_enable(TSB_SIWD_TypeDef *p_reg);
void wdt_clear(TSB_SIWD_TypeDef *p_reg);
uint32_t wdt_get_flag(TSB_SIWD_TypeDef *p_reg);
void wdt_wdcls_set(TSB_SIWD_TypeDef *p_reg, uint32_t wdcls);
void wdt_wdtp_set(TSB_SIWD_TypeDef *p_reg, uint32_t wdtp);
void wdt_wdcwd_set(TSB_SIWD_TypeDef *p_reg, uint32_t wdcwd);
void wdt_intf_clear(TSB_SIWD_TypeDef *p_reg);
uint32_t wdt_get_intf(TSB_SIWD_TypeDef *p_reg);
void wdt_rescr_set(TSB_SIWD_TypeDef *p_reg, uint32_t rescr);
#if (OSCCR_REGISTER_EQUIPPED == AVAILABLE)
void wdt_protect_disable(TSB_SIWD_TypeDef *p_reg);
void wdt_protect_enable(TSB_SIWD_TypeDef *p_reg);
#endif
uint32_t wdt_get_protect(TSB_SIWD_TypeDef *p_reg);
void wdt_protect_set(TSB_SIWD_TypeDef *p_reg, uint32_t protect);

/** 
 *  @}
 */ /* End of group SIWDT_Private_functions */

/**
 *  @}
 */ /* End of group SIWDT */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __EI2C_H */
