/**
 *******************************************************************************
 * @file    a_enc32_a.c
 * @brief   This file provides API functions for ENC driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "a_enc32_a.h"

#if defined(__A_ENC32_A_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup ENC
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Private_define ENC Private Define
 *  @{
 */
#define ENTNCR_SFTCAP_CAPTURE        ((uint32_t)0x00000800)      /* EMTNCR SFTCAP capture start */
#define ENTNCR_ENCLR_CLEAR           ((uint32_t)0x00000400)      /* EMTNCR ENCLR counter clear */
#define ENINPCR_PDSTP                ((uint32_t)0x00000080)      /* ENINPCR PDSTP stop */
#define ENINPCR_PDSTT                ((uint32_t)0x00000040)      /* ENINPCR PDSTT start */

#define EN_SET0                      ((uint32_t)0x00000000)      /* register set 0 */
#define EN_SET1                      ((uint32_t)0x00000001)      /* register set 1 */
/** 
 *  @}
 */ /* End of group ENC_Private_define */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Private_macro ENC Private Macro
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group ENC_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Private_Enumeration ENC Private Enumeration
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group ENC_Private_Enumeration */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Private_typedef ENC Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group ENC_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Private_variable ENC Private Variable Definition
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group ENC_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Private_fuctions ENC Private Fuctions
 *  @{
 */

#ifdef __DEBUG__
    __STATIC_INLINE int32_t check_param_cmpsel(uint32_t param);
    __STATIC_INLINE int32_t check_param_udmd(uint32_t param);
    __STATIC_INLINE int32_t check_param_tovmd(uint32_t param);
    __STATIC_INLINE int32_t check_param_mcmpmd(uint32_t param);
    __STATIC_INLINE int32_t check_param_decmd(uint32_t param);
    __STATIC_INLINE int32_t check_param_sdten(uint32_t param);
    __STATIC_INLINE int32_t check_param_mode(uint32_t param);
    __STATIC_INLINE int32_t check_param_p3en(uint32_t param);
    __STATIC_INLINE int32_t check_param_trgcapmd(uint32_t param);
    __STATIC_INLINE int32_t check_param_zesel(uint32_t param);
    __STATIC_INLINE int32_t check_param_zen(uint32_t param);
    __STATIC_INLINE int32_t check_param_enrun(uint32_t param);
    __STATIC_INLINE int32_t check_param_zeact(uint32_t param);
    __STATIC_INLINE int32_t check_param_endev(uint32_t param);
    __STATIC_INLINE int32_t check_param_nct(uint32_t param);
    __STATIC_INLINE int32_t check_param_syncnczen(uint32_t param);
    __STATIC_INLINE int32_t check_param_syncsplmd(uint32_t param);
    __STATIC_INLINE int32_t check_param_syncsplen(uint32_t param);
    __STATIC_INLINE int32_t check_param_splcks(uint32_t param);
    __STATIC_INLINE int32_t check_param_mcmpie(uint32_t param);
    __STATIC_INLINE int32_t check_param_rldie(uint32_t param);
    __STATIC_INLINE int32_t check_param_cmpie(uint32_t param);
    __STATIC_INLINE int32_t check_param_errie(uint32_t param);
    __STATIC_INLINE int32_t check_param_capie(uint32_t param);
    __STATIC_INLINE int32_t check_param_tplsie(uint32_t param);
#endif /* #ifdef __DEBUG__ */

#ifdef __DEBUG__
/*--------------------------------------------------*/
/** 
  * @brief  Check the CMPSEL's parameter.
  * @param  param    :CMPSEL's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_CMPSEL"ENTNCR_CMPSEL__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_cmpsel(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_CMPSEL_INTMATCH:
    case ENTNCR_CMPSEL_RELOADMATCH:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the UDMD's parameter.
  * @param  param    :UDMD's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_UDMD"ENTNCR_UDMD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_udmd(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_UDMD_UP:
    case ENTNCR_UDMD_DOWN:
    case ENTNCR_UDMD_UPDOWN:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TOVMD's parameter.
  * @param  param    :TOVMD's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_TOVMD"ENTNCR_TOVMD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tovmd(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_TOVMD_CONTINUE:
    case ENTNCR_TOVMD_STOP:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MCMPMD's parameter.
  * @param  param    :MCMPMD's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_MCMPMD"ENTNCR_MCMPMD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_mcmpmd(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_MCMPMD_MATCH:
    case ENTNCR_MCMPMD_NOMATCH:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the DECMD's parameter.
  * @param  param    :DECMD's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_DECMD"ENTNCR_DECMD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_decmd(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_DECMD_NOW:
    case ENTNCR_DECMD_CW:
    case ENTNCR_DECMD_CCW:
    case ENTNCR_DECMD_LAST:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SDTEN's parameter.
  * @param  param    :SDTEN's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_SDTEN"ENTNCR_SDTEN__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_sdten(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_SDTEN_DISABLE:
    case ENTNCR_SDTEN_ENABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MODE's parameter.
  * @param  param    :MODE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_MODE"ENTNCR_MODE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_mode(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_MODE_ENCODE:
    case ENTNCR_MODE_EVENT:
    case ENTNCR_MODE_SENSOR_TIMER:
    case ENTNCR_MODE_TIMER:
    case ENTNCR_MODE_SENSOR:
    case ENTNCR_MODE_COUNTER:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the P3EN's parameter.
  * @param  param    :P3EN's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_P3EN"ENTNCR_P3EN__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_p3en(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_P3EN_2:
    case ENTNCR_P3EN_3:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TRGCAPMD's parameter.
  * @param  param    :TRGCAPMD's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_TRGCAPMD"ENTNCR_TRGCAPMD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_trgcapmd(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_TRGCAPMD_CLEAR:
    case ENTNCR_TRGCAPMD_CAPTURE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ZESEL's parameter.
  * @param  param    :ZESEL's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_ZESEL"ENTNCR_ZESEL__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_zesel(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_ZESEL_RISING:
    case ENTNCR_ZESEL_FALLING:
    case ENTNCR_ZESEL_BOTH:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ZEN's parameter.
  * @param  param    :ZEN's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_ZEN"ENTNCR_ZEN__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_zen(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_ZEN_DISABLE:
    case ENTNCR_ZEN_ENABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ENRUN's parameter.
  * @param  param    :ENRUN's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_ENRUN"ENTNCR_ENRUN__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_enrun(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_ENRUN_DISABLE:
    case ENTNCR_ENRUN_ENABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ZEACT's parameter.
  * @param  param    :ZEACT's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_ZEACT"ENTNCR_ZEACT__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_zeact(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_ZEACT_HIGH:
    case ENTNCR_ZEACT_LOW:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ENDEV's parameter.
  * @param  param    :ENDEV's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENTNCR_ENDEV"ENTNCR_ENDEV__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_endev(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENTNCR_ENDEV_1:
    case ENTNCR_ENDEV_2:
    case ENTNCR_ENDEV_4:
    case ENTNCR_ENDEV_8:
    case ENTNCR_ENDEV_16:
    case ENTNCR_ENDEV_32:
    case ENTNCR_ENDEV_64:
    case ENTNCR_ENDEV_128:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ENC_NCTMax's parameter.
  * @param  param    :ENC_NCTMax's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENC_NCTMax"ENINPCR_NCT_MAX".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_nct(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    if (param <= ENINPCR_NCT_MAX)
    {
        result = ENC_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SYNCNCZEN's parameter.
  * @param  param    :SYNCNCZEN's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINPCR_SYNCNCZEN"ENINPCR_SYNCNCZEN__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_syncnczen(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINPCR_SYNCNCZEN_STOP:
    case ENINPCR_SYNCNCZEN_CLEAR:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SYNCSPLMD's parameter.
  * @param  param    :SYNCSPLMD's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINPCR_SYNCSPLMD"ENINPCR_SYNCSPLMD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_syncsplmd(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINPCR_SYNCSPLMD_ON:
    case ENINPCR_SYNCSPLMD_OFF:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SYNCSPLEN's parameter.
  * @param  param    :SYNCSPLEN's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINPCR_SYNCSPLEN"ENINPCR_SYNCSPLEN__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_syncsplen(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINPCR_SYNCSPLEN_CONTINUE:
    case ENINPCR_SYNCSPLEN_PWM:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SPLCKS's parameter.
  * @param  param    :SPLCKS's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENCLKCR_SPLCKS"ENCLKCR_SPLCKS__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_splcks(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENCLKCR_SPLCKS_0:
    case ENCLKCR_SPLCKS_2:
    case ENCLKCR_SPLCKS_4:
    case ENCLKCR_SPLCKS_8:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MCMPIE's parameter.
  * @param  param    :MCMPIE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINTCR_MCMPIE"ENINTCR_MCMPIE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_mcmpie(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINTCR_MCMPIE_ENABLE:
    case ENINTCR_MCMPIE_DISABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RLDIE's parameter.
  * @param  param    :RLDIE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINTCR_RLDIE"ENINTCR_RLDIE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rldie(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINTCR_RLDIE_ENABLE:
    case ENINTCR_RLDIE_DISABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the CMPIE's parameter.
  * @param  param    :CMPIE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINTCR_CMPIE"ENINTCR_CMPIE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_cmpie(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINTCR_CMPIE_ENABLE:
    case ENINTCR_CMPIE_DISABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ERRIE's parameter.
  * @param  param    :ERRIE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINTCR_ERRIE"ENINTCR_ERRIE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_errie(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINTCR_ERRIE_ENABLE:
    case ENINTCR_ERRIE_DISABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the CAPIE's parameter.
  * @param  param    :CAPIE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINTCR_CAPIE"ENINTCR_CAPIE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_capie(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINTCR_CAPIE_ENABLE:
    case ENINTCR_CAPIE_DISABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TPLSIE's parameter.
  * @param  param    :TPLSIE's parameter
  * @retval ENC_PARAM_OK :Valid
  * @retval ENC_PARAM_NG :Invalid
  * @note   Macro definition is @ref ENINTCR_TPLSIE"ENINTCR_TPLSIE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tplsie(uint32_t param)
{
    int32_t result = ENC_PARAM_NG;

    switch (param) 
    {
    case ENINTCR_TPLSIE_ENABLE:
    case ENINTCR_TPLSIE_DISABLE:
        result = ENC_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }
    return (result);
}
#endif /* #ifdef __DEBUG__ */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup ENC_Exported_functions
 *  @{
 */ 

/*--------------------------------------------------*/
/**
  * @brief     ENTNCR Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_control(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_cmpsel(p_obj->con.cmpsel));
    assert_param(check_param_udmd(p_obj->con.udmd));
    assert_param(check_param_tovmd(p_obj->con.tovmd));
    assert_param(check_param_mcmpmd(p_obj->con.mcmpmd));
    assert_param(check_param_decmd(p_obj->con.decmd));
    assert_param(check_param_sdten(p_obj->con.sdten));
    assert_param(check_param_mode(p_obj->con.mode));
    assert_param(check_param_p3en(p_obj->con.p3en));
    assert_param(check_param_trgcapmd(p_obj->con.trgcapmd));
    assert_param(check_param_zesel(p_obj->con.zesel));
    assert_param(check_param_zen(p_obj->con.zen));
    assert_param(check_param_enrun(p_obj->con.enrun));
    assert_param(check_param_zeact(p_obj->con.zeact));
    assert_param(check_param_endev(p_obj->con.endev));
#endif
    if ( (p_obj->con.mode == ENTNCR_MODE_TIMER) ||
         (p_obj->con.mode == ENTNCR_MODE_COUNTER) ) {
        p_obj->con.decmd = EN_SET0;
    }
    if ( (p_obj->con.mode == ENTNCR_MODE_ENCODE) ||
         (p_obj->con.mode == ENTNCR_MODE_TIMER) ) {
        p_obj->con.p3en = EN_SET0;
    }
    if ( (p_obj->con.mode != ENTNCR_MODE_TIMER) &&
         (p_obj->con.mode != ENTNCR_MODE_COUNTER) ) {
        p_obj->con.zesel = EN_SET0;
    }
    if ( (p_obj->con.mode == ENTNCR_MODE_EVENT) ||
         (p_obj->con.mode == ENTNCR_MODE_SENSOR_TIMER) ||
         (p_obj->con.mode == ENTNCR_MODE_SENSOR) ) {
        p_obj->con.zen = EN_SET0;
    }
    p_obj->p_instance->TNCR = (p_obj->con.cmpsel | p_obj->con.udmd | 
                               p_obj->con.tovmd | p_obj->con.mcmpmd | 
                               p_obj->con.decmd | p_obj->con.sdten | 
                               p_obj->con.mode | p_obj->con.p3en | 
                               p_obj->con.trgcapmd | p_obj->con.zesel | 
                               p_obj->con.zen | p_obj->con.enrun | 
                               p_obj->con.zeact   | p_obj->con.endev);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENC soft capture start
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_softcapture_start(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->TNCR |= ENTNCR_SFTCAP_CAPTURE;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENC counter clear
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_counter_clear(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->TNCR |= ENTNCR_ENCLR_CLEAR;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENC enable
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_enable(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->TNCR |= ENTNCR_ENRUN_ENABLE;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENC disable
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_disable(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->TNCR &= ~ENTNCR_ENRUN_ENABLE;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENRELOAD Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_reload(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->RELOAD = p_obj->reload;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENINT Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_int(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->INT = p_obj->intcmp;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result enc_get_count(enc_t *p_obj, uint32_t *p_count)
  * @brief  Get counter.
  * @details  Counter bits.
  * | Bit   | Bit Symbol | Function                         |
  * | :---  | :---       | :---                             |
  * | 31-0  | CNT        | Counter                          |
  * 
  * @param[in] p_obj    :ENC object.
  * @param[out] p_count :counter. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result enc_get_count(enc_t *p_obj, uint32_t *p_count)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_count));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_count = p_obj->p_instance->CNT;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENMCMP Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_mcmp(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->MCMP = p_obj->mcmp;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENRATE Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_rate(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->RATE = p_obj->rate;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result enc_get_status(enc_t *p_obj, uint32_t *p_status)
  * @brief  Get status.
  * @details  Status bits.
  * | Bit   | Bit Symbol | Function                         |
  * | :---  | :---       | :---                             |
  * | 31-15 | -          | -                                |
  * | 14    | REVERR     | ENSTS REVERR                     |
  * | 13    | UD         | ENSTS UD                         |
  * | 12    | ZDET       | ENSTS ZDET                       |
  * | 11-3  | -          | -                                |
  * | 2     | SKPDT      | ENSTS SKPDT                      |
  * | 1     | PDERR      | ENSTS PDERR                      |
  * | 0     | INERR      | ENSTS INERR                      |
  * 
  * @param[in] p_obj    :ENC object.
  * @param[out] p_status:status. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result enc_get_status(enc_t *p_obj, uint32_t *p_status)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_status));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_status = p_obj->p_instance->STS;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENINPCR Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_input(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_nct(p_obj->inpcr.nct));
    assert_param(check_param_syncnczen(p_obj->inpcr.syncnczen));
    assert_param(check_param_syncsplmd(p_obj->inpcr.syncsplmd));
    assert_param(check_param_syncsplen(p_obj->inpcr.syncsplen));
#endif
    p_obj->p_instance->INPCR = ((p_obj->inpcr.nct << 8U) | p_obj->inpcr.syncnczen | 
                               p_obj->inpcr.syncsplmd | p_obj->inpcr.syncsplen);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENC edge detect start
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_edgedetect_start(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->INPCR |= ENINPCR_PDSTT;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENC edge detect stop
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_edgedetect_stop(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->INPCR |= ENINPCR_PDSTP;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENSMPDLY Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_sampdly(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->SMPDLY = p_obj->smpdly;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result enc_get_inpmon(enc_t *p_obj, uint32_t *p_inpmon)
  * @brief  Get input monitor.
  * @details  Status bits.
  * | Bit   | Bit Symbol | Function                         |
  * | :---  | :---       | :---                             |
  * | 31-6  | -          | -                                |
  * | 6     | DETMONZ    | ENINPMON DETMONZ                 |
  * | 5     | DETMONB    | ENINPMON DETMONB                 |
  * | 4     | DETMONA    | ENINPMON DETMONA                 |
  * | 3     | -          | -                                |
  * | 2     | SPLMONZ    | ENINPMON SPLMONZ                 |
  * | 1     | SPLMONB    | ENINPMON SPLMONB                 |
  * | 0     | SPLMONA    | ENINPMON SPLMONA                 |
  * 
  * @param[in] p_obj    :ENC object.
  * @param[out] p_inpmon:input monitor. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result enc_get_inpmon(enc_t *p_obj, uint32_t *p_inpmon)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_inpmon));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_inpmon = p_obj->p_instance->INPMON;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENCLKCR Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_clk(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_splcks(p_obj->clk));
#endif
    p_obj->p_instance->CLKCR = p_obj->clk;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     ENTINTCR Value Setting
  * @param     p_obj :ENC object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result enc_set_intcontrol(enc_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_mcmpie(p_obj->intcr.mcmpie));
    assert_param(check_param_rldie(p_obj->intcr.rldie));
    assert_param(check_param_cmpie(p_obj->intcr.cmpie));
    assert_param(check_param_errie(p_obj->intcr.errie));
    assert_param(check_param_capie(p_obj->intcr.capie));
    assert_param(check_param_tplsie(p_obj->intcr.tplsie));
#endif
    p_obj->p_instance->INTCR = (p_obj->intcr.mcmpie | p_obj->intcr.rldie | 
                                p_obj->intcr.cmpie  | p_obj->intcr.errie |
                                p_obj->intcr.capie  | p_obj->intcr.tplsie);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result enc_get_intf(enc_t *p_obj, uint32_t *p_intf)
  * @brief  Get INT flag Status.
  * @details  Status bits.
  * | Bit   | Bit Symbol | Function                            |
  * | :---  | :---       | :---                                |
  * | 31-6  | -          | -                                   |
  * | 5     | MCMPF      | ENINTF MCMPF detect                 |
  * | 4     | RLDCPF     | ENINTF RLDCPF detect                |
  * | 3     | INTCPF     | ENINTF INTCPF detect                |
  * | 2     | ERRF       | ENINTF ERRF detect                  |
  * | 1     | CAPF       | ENINTF CAPF detect                  |
  * | 0     | TPLSF      | ENINTF TPLSF detect                 |
  * 
  * @param[in] p_obj    :ENC object.
  * @param[out] p_intf  :INT flag Status. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result enc_get_intf(enc_t *p_obj, uint32_t *p_intf)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_intf));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_intf = p_obj->p_instance->INTF;

    return (result);
}
/**
 *  @}
 */ /* End of group ENC_Exported_functions */

/**
 *  @} 
 */ /* End of group ENC */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__A_ENC32_A_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

