/** 
 *******************************************************************************
 * @file    a_enc32_a.h
 * @brief   This file provides all the functions prototypes for ENC driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __A_ENC32_A_H
#define __A_ENC32_A_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup ENC ENC
 *  @brief      ENC Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup ENC_Exported_define ENC Exported Define
 *  @{
 */

/** 
 *  @defgroup ENC_NullPointer  Null Pointer
 *  @brief    Null Pointer.
 *  @{
 */
#define ENC_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group ENC_NullPointer */

/** 
 *  @defgroup ENC_ParameterResult  Parameter Check Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define ENC_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define ENC_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group ENC_ParameterResult */

/** 
 *  @defgroup ENC_NCTMax  Max Num of noise cansel time
 *  @brief    Max Num of noise cansel time.
 *  @{
 */
#define ENINPCR_NCT_MAX               ((uint32_t)127)            /*!< Max noise cancel time. */
/**
 *  @}
 */ /* End of group ENC_NCTMax */

/** 
 *  @defgroup ENTNCR_CMPSEL  ENC Control Register
 *  @brief    ENC Control Register CMPSEL Macro Definition.
 *  @{
 */
#define ENTNCR_CMPSEL_INTMATCH         ((uint32_t)0x00000000)    /*!< ENTNCR CMPSEL int match */
#define ENTNCR_CMPSEL_RELOADMATCH      ((uint32_t)0x10000000)    /*!< ENTNCR CMPSEL reload match */
/**
 *  @}
 */ /* End of group ENTNCR_CMPSEL */

/** 
 *  @defgroup ENTNCR_UDMD  ENC Control Register
 *  @brief    ENC Control Register UDMD Macro Definition.
 *  @{
 */
#define ENTNCR_UDMD_UP                 ((uint32_t)0x00000000)    /*!< ENTNCR UDMD up */
#define ENTNCR_UDMD_DOWN               ((uint32_t)0x04000000)    /*!< ENTNCR UDMD down */
#define ENTNCR_UDMD_UPDOWN             ((uint32_t)0x08000000)    /*!< ENTNCR UDMD updown */
/**
 *  @}
 */ /* End of group ENTNCR_UDMD */

/** 
 *  @defgroup ENTNCR_TOVMD  ENC Control Register
 *  @brief    ENC Control Register TOVMD Macro Definition.
 *  @{
 */
#define ENTNCR_TOVMD_CONTINUE           ((uint32_t)0x00000000)    /*!< ENTNCR TOVMD continue */
#define ENTNCR_TOVMD_STOP               ((uint32_t)0x02000000)    /*!< ENTNCR TOVMD stop */
/**
 *  @}
 */ /* End of group ENTNCR_TOVMD */

/** 
 *  @defgroup ENTNCR_MCMPMD  ENC Control Register
 *  @brief    ENC Control Register MCMPMD Macro Definition.
 *  @{
 */
#define ENTNCR_MCMPMD_MATCH             ((uint32_t)0x00000000)    /*!< ENTNCR MCMPMD match */
#define ENTNCR_MCMPMD_NOMATCH           ((uint32_t)0x01000000)    /*!< ENTNCR MCMPMD no match */
/**
 *  @}
 */ /* End of group ENTNCR_MCMPMD */

/** 
 *  @defgroup ENTNCR_DECMD  ENC Control Register
 *  @brief    ENC Control Register DECMD Macro Definition.
 *  @{
 */
#define ENTNCR_DECMD_NOW                ((uint32_t)0x00000000)    /*!< ENTNCR DECMD now */
#define ENTNCR_DECMD_CW                 ((uint32_t)0x00400000)    /*!< ENTNCR DECMD cw */
#define ENTNCR_DECMD_CCW                ((uint32_t)0x00800000)    /*!< ENTNCR DECMD ccw */
#define ENTNCR_DECMD_LAST               ((uint32_t)0x00C00000)    /*!< ENTNCR DECMD last */
/**
 *  @}
 */ /* End of group ENTNCR_DECMD */

/** 
 *  @defgroup ENTNCR_SDTEN  ENC Control Register
 *  @brief    ENC Control Register SDTEN Macro Definition.
 *  @{
 */
#define ENTNCR_SDTEN_DISABLE             ((uint32_t)0x00000000)    /*!< ENTNCR SDTEN disable */
#define ENTNCR_SDTEN_ENABLE              ((uint32_t)0x00200000)    /*!< ENTNCR SDTEN enable */
/**
 *  @}
 */ /* End of group ENTNCR_SDTEN */

/** 
 *  @defgroup ENTNCR_MODE  ENC Control Register
 *  @brief    ENC Control Register MODE Macro Definition.
 *  @{
 */
#define ENTNCR_MODE_ENCODE               ((uint32_t)0x00000000)    /*!< ENTNCR MODE encode */
#define ENTNCR_MODE_EVENT                ((uint32_t)0x00020000)    /*!< ENTNCR MODE event */
#define ENTNCR_MODE_SENSOR_TIMER         ((uint32_t)0x00040000)    /*!< ENTNCR MODE sensor timer */
#define ENTNCR_MODE_TIMER                ((uint32_t)0x00060000)    /*!< ENTNCR MODE timer */
#define ENTNCR_MODE_SENSOR               ((uint32_t)0x000C0000)    /*!< ENTNCR MODE sensor */
#define ENTNCR_MODE_COUNTER              ((uint32_t)0x000E0000)    /*!< ENTNCR MODE counter */
/**
 *  @}
 */ /* End of group ENTNCR_MODE */

/** 
 *  @defgroup ENTNCR_P3EN  ENC Control Register
 *  @brief    ENC Control Register P3EN Macro Definition.
 *  @{
 */
#define ENTNCR_P3EN_2                    ((uint32_t)0x00000000)    /*!< ENTNCR P3EN 2 */
#define ENTNCR_P3EN_3                    ((uint32_t)0x00010000)    /*!< ENTNCR P3EN 3 */
/**
 *  @}
 */ /* End of group ENTNCR_P3EN */

/** 
 *  @defgroup ENTNCR_TRGCAPMD  ENC Control Register
 *  @brief    ENC Control Register TRGCAPMD Macro Definition.
 *  @{
 */
#define ENTNCR_TRGCAPMD_CLEAR             ((uint32_t)0x00000000)    /*!< ENTNCR TRGCAPMD clear */
#define ENTNCR_TRGCAPMD_CAPTURE           ((uint32_t)0x00001000)    /*!< ENTNCR TRGCAPMD capture */
/**
 *  @}
 */ /* End of group ENTNCR_TRGCAPMD */

/** 
 *  @defgroup ENTNCR_ZESEL  ENC Control Register
 *  @brief    ENC Control Register ZESEL Macro Definition.
 *  @{
 */
#define ENTNCR_ZESEL_RISING               ((uint32_t)0x00000100)    /*!< ENTNCR ZESEL rising */
#define ENTNCR_ZESEL_FALLING              ((uint32_t)0x00000200)    /*!< ENTNCR ZESEL falling */
#define ENTNCR_ZESEL_BOTH                 ((uint32_t)0x00000300)    /*!< ENTNCR ZESEL both */
/**
 *  @}
 */ /* End of group ENTNCR_ZESEL */

/** 
 *  @defgroup ENTNCR_ZEN  ENC Control Register
 *  @brief    ENC Control Register ZEN Macro Definition.
 *  @{
 */
#define ENTNCR_ZEN_DISABLE                ((uint32_t)0x00000000)    /*!< ENTNCR ZEN disable */
#define ENTNCR_ZEN_ENABLE                 ((uint32_t)0x00000080)    /*!< ENTNCR ZEN enable */
/**
 *  @}
 */ /* End of group ENTNCR_ZEN */

/** 
 *  @defgroup ENTNCR_ENRUN  ENC Control Register
 *  @brief    ENC Control Register ENRUN Macro Definition.
 *  @{
 */
#define ENTNCR_ENRUN_DISABLE               ((uint32_t)0x00000000)    /*!< ENTNCR ENRUN disable */
#define ENTNCR_ENRUN_ENABLE                ((uint32_t)0x00000040)    /*!< ENTNCR ENRUN enable */
/**
 *  @}
 */ /* End of group ENTNCR_ENRUN */

/** 
 *  @defgroup ENTNCR_ZEACT  ENC Control Register
 *  @brief    ENC Control Register ZEACT Macro Definition.
 *  @{
 */
#define ENTNCR_ZEACT_HIGH                 ((uint32_t)0x00000000)    /*!< ENTNCR ZEACT high */
#define ENTNCR_ZEACT_LOW                  ((uint32_t)0x00000020)    /*!< ENTNCR ZEACT low */
/**
 *  @}
 */ /* End of group ENTNCR_ZEACT */

/** 
 *  @defgroup ENTNCR_ENDEV  ENC Control Register
 *  @brief    ENC Control Register ENDEV Macro Definition.
 *  @{
 */
#define ENTNCR_ENDEV_1                    ((uint32_t)0x00000000)    /*!< ENTNCR ENDEV div1 */
#define ENTNCR_ENDEV_2                    ((uint32_t)0x00000001)    /*!< ENTNCR ENDEV div2 */
#define ENTNCR_ENDEV_4                    ((uint32_t)0x00000002)    /*!< ENTNCR ENDEV div4 */
#define ENTNCR_ENDEV_8                    ((uint32_t)0x00000003)    /*!< ENTNCR ENDEV div8 */
#define ENTNCR_ENDEV_16                   ((uint32_t)0x00000004)    /*!< ENTNCR ENDEV div16 */
#define ENTNCR_ENDEV_32                   ((uint32_t)0x00000005)    /*!< ENTNCR ENDEV div32 */
#define ENTNCR_ENDEV_64                   ((uint32_t)0x00000006)    /*!< ENTNCR ENDEV div64 */
#define ENTNCR_ENDEV_128                  ((uint32_t)0x00000007)    /*!< ENTNCR ENDEV div128 */
/**
 *  @}
 */ /* End of group ENTNCR_ENDEV */

/** 
 *  @defgroup ENSTS  ENC Status Register
 *  @brief    ENC Status Register Macro Definition.
 *  @{
 */
#define ENSTS_REVERR_INVERS               ((uint32_t)0x00004000)    /*!< ENSTS REVERR invers */
#define ENSTS_UD_CCW                      ((uint32_t)0x00000000)    /*!< ENSTS UD CCW */
#define ENSTS_UD_CW                       ((uint32_t)0x00002000)    /*!< ENSTS UD CW */
#define ENSTS_ZDET_NODETECT               ((uint32_t)0x00000000)    /*!< ENSTS ZDET no detect */
#define ENSTS_ZDET_DETECT                 ((uint32_t)0x00001000)    /*!< ENSTS ZDET detect */
#define ENSTS_SKPDT_NODETECT              ((uint32_t)0x00000000)    /*!< ENSTS SKPDT no detect */
#define ENSTS_SKPDT_DETECT                ((uint32_t)0x00000004)    /*!< ENSTS SKPDT detect */
#define ENSTS_PDERR_NODETECT              ((uint32_t)0x00000000)    /*!< ENSTS PDERR no detect */
#define ENSTS_PDERR_DETECT                ((uint32_t)0x00000002)    /*!< ENSTS PDERR detect */
#define ENSTS_INERR_NODETECT              ((uint32_t)0x00000000)    /*!< ENSTS INERR no detect */
#define ENSTS_INERR_DETECT                ((uint32_t)0x00000001)    /*!< ENSTS INERR detect */
/**
 *  @}
 */ /* End of group ENSTS */

/** 
 *  @defgroup ENINPCR_SYNCNCZEN  ENC Input Register
 *  @brief    ENC Input Register SYNCNCZEN Macro Definition.
 *  @{
 */
#define ENINPCR_SYNCNCZEN_STOP            ((uint32_t)0x00000000)    /*!< ENINPCR SYNCSPLMD stop */
#define ENINPCR_SYNCNCZEN_CLEAR           ((uint32_t)0x00000004)    /*!< ENINPCR SYNCSPLMD clear */
/**
 *  @}
 */ /* End of group ENINPCR_SYNCNCZEN */

/** 
 *  @defgroup ENINPCR_SYNCSPLMD  ENC Input Register
 *  @brief    ENC Input Register SYNCSPLMD Macro Definition.
 *  @{
 */
#define ENINPCR_SYNCSPLMD_ON              ((uint32_t)0x00000000)    /*!< ENINPCR SYNCSPLMD on */
#define ENINPCR_SYNCSPLMD_OFF             ((uint32_t)0x00000002)    /*!< ENINPCR SYNCSPLMD off */
/**
 *  @}
 */ /* End of group ENINPCR_SYNCSPLMD */

/** 
 *  @defgroup ENINPCR_SYNCSPLEN  ENC Input Register
 *  @brief    ENC Input Register SYNCSPLEN Macro Definition.
 *  @{
 */
#define ENINPCR_SYNCSPLEN_CONTINUE        ((uint32_t)0x00000000)    /*!< ENINPCR SYNCSPLEN continue */
#define ENINPCR_SYNCSPLEN_PWM             ((uint32_t)0x00000001)    /*!< ENINPCR SYNCSPLEN pwm */
/**
 *  @}
 */ /* End of group ENINPCR_SYNCSPLEN */

/** 
 *  @defgroup ENINPMON  ENC Input Monitor Register
 *  @brief    ENC Input Monitor Register Macro Definition.
 *  @{
 */
#define ENINPMON_DETMONZ_0                ((uint32_t)0x00000000)    /*!< ENINPMON DETMONZ 0 */
#define ENINPMON_DETMONZ_1                ((uint32_t)0x00000040)    /*!< ENINPMON DETMONZ 1 */
#define ENINPMON_DETMONB_0                ((uint32_t)0x00000000)    /*!< ENINPMON DETMONB 0 */
#define ENINPMON_DETMONB_1                ((uint32_t)0x00000020)    /*!< ENINPMON DETMONB 1 */
#define ENINPMON_DETMONA_0                ((uint32_t)0x00000000)    /*!< ENINPMON DETMONA 0 */
#define ENINPMON_DETMONA_1                ((uint32_t)0x00000010)    /*!< ENINPMON DETMONA 1 */
#define ENINPMON_SPLMONZ_0                ((uint32_t)0x00000000)    /*!< ENINPMON SPLMONZ 0 */
#define ENINPMON_SPLMONZ_1                ((uint32_t)0x00000004)    /*!< ENINPMON SPLMONZ 1 */
#define ENINPMON_SPLMONB_0                ((uint32_t)0x00000000)    /*!< ENINPMON SPLMONB 0 */
#define ENINPMON_SPLMONB_1                ((uint32_t)0x00000002)    /*!< ENINPMON SPLMONB 1 */
#define ENINPMON_SPLMONA_0                ((uint32_t)0x00000000)    /*!< ENINPMON SPLMONA 0 */
#define ENINPMON_SPLMONA_1                ((uint32_t)0x00000001)    /*!< ENINPMON SPLMONA 1 */
/**
 *  @}
 */ /* End of group ENINPMON */

/** 
 *  @defgroup ENINTCR_MCMPIE  ENC INT Control Register
 *  @brief    ENC INT Control Register MCMPIE Macro Definition.
 *  @{
 */
#define ENINTCR_MCMPIE_ENABLE              ((uint32_t)0x00000020)    /*!< ENINTCR MCMPIE enable */
#define ENINTCR_MCMPIE_DISABLE             ((uint32_t)0x00000000)    /*!< ENINTCR MCMPIE disable */
/**
 *  @}
 */ /* End of group ENINTCR_MCMPIE */

/** 
 *  @defgroup ENINTCR_RLDIE  ENC INT Control Register
 *  @brief    ENC INT Control Register RLDIE Macro Definition.
 *  @{
 */
#define ENINTCR_RLDIE_ENABLE               ((uint32_t)0x00000010)    /*!< ENINTCR RLDIE enable */
#define ENINTCR_RLDIE_DISABLE              ((uint32_t)0x00000000)    /*!< ENINTCR RLDIE disable */
/**
 *  @}
 */ /* End of group ENINTCR_RLDIE */

/** 
 *  @defgroup ENINTCR_CMPIE  ENC INT Control Register
 *  @brief    ENC INT Control Register CMPIE Macro Definition.
 *  @{
 */
#define ENINTCR_CMPIE_ENABLE               ((uint32_t)0x00000008)    /*!< ENINTCR CMPIE enable */
#define ENINTCR_CMPIE_DISABLE              ((uint32_t)0x00000000)    /*!< ENINTCR CMPIE disable */
/**
 *  @}
 */ /* End of group ENINTCR_CMPIE */

/** 
 *  @defgroup ENINTCR_ERRIE  ENC INT Control Register
 *  @brief    ENC INT Control Register ERRIE Macro Definition.
 *  @{
 */
#define ENINTCR_ERRIE_ENABLE               ((uint32_t)0x00000004)    /*!< ENINTCR ERRIE enable */
#define ENINTCR_ERRIE_DISABLE              ((uint32_t)0x00000000)    /*!< ENINTCR ERRIE disable */
/**
 *  @}
 */ /* End of group ENINTCR_ERRIE */

/** 
 *  @defgroup ENINTCR_CAPIE  ENC INT Control Register
 *  @brief    ENC INT Control Register CAPIE Macro Definition.
 *  @{
 */
#define ENINTCR_CAPIE_ENABLE               ((uint32_t)0x00000002)    /*!< ENINTCR CAPIE enable */
#define ENINTCR_CAPIE_DISABLE              ((uint32_t)0x00000000)    /*!< ENINTCR CAPIE disable */
/**
 *  @}
 */ /* End of group ENINTCR_CAPIE */

/** 
 *  @defgroup ENINTCR_TPLSIE  ENC INT Control Register
 *  @brief    ENC INT Control Register TPLSIE Macro Definition.
 *  @{
 */
#define ENINTCR_TPLSIE_ENABLE              ((uint32_t)0x00000001)    /*!< ENINTCR TPLSIE enable */
#define ENINTCR_TPLSIE_DISABLE             ((uint32_t)0x00000000)    /*!< ENINTCR TPLSIE disable */
/**
 *  @}
 */ /* End of group ENINTCR_TPLSIE */

/** 
 *  @defgroup ENINTF  ENC INT Flag Register
 *  @brief    ENC INT Flag Register Macro Definition.
 *  @{
 */
#define ENINTF_MCMPF_DETECT                ((uint32_t)0x00000020)    /*!< ENINTF MCMPF detect */
#define ENINTF_RLDCPF_DETECT               ((uint32_t)0x00000010)    /*!< ENINTF RLDCPF detect */
#define ENINTF_INTCPF_DETECT               ((uint32_t)0x00000008)    /*!< ENINTF INTCPF detect */
#define ENINTF_ERRF_DETECT                 ((uint32_t)0x00000004)    /*!< ENINTF ERRF detect */
#define ENINTF_CAPF_DETECT                 ((uint32_t)0x00000002)    /*!< ENINTF CAPF detect */
#define ENINTF_TPLSF_DETECT                ((uint32_t)0x00000001)    /*!< ENINTF TPLSF detect */
/**
 *  @}
 */ /* End of group ENINTF */
/**
 *  @}
 */ /* End of group ENC_Exported_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
    @addtogroup ENC_Exported_define ENC Exported Define
    @{
 */

/*! @enum enc_clock_t
 *  @brief ENC Clock Register Setting
 */
typedef enum
{
    ENCLKCR_SPLCKS_0 = (0x00000000), /*!< 0: Sampling frequency fsys     */
    ENCLKCR_SPLCKS_2 = (0x00000001), /*!< 1: Sampling frequency fsys/2   */
    ENCLKCR_SPLCKS_4 = (0x00000002), /*!< 2: Sampling frequency fsys/4   */
    ENCLKCR_SPLCKS_8 = (0x00000003), /*!< 3: Sampling frequency fsys/8   */
}enc_clock_t;


/*!
    @}
 */ /* End of group ENC_Exported_define */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/*! 
    @defgroup ENC_Exported_typedef ENC Exported Typedef
    @{
 */

/*----------------------------------*/
/*! @struct enc_control_setting_t
    @brief  ENC Control Register setting structure definenition
*/
/*----------------------------------*/
typedef struct
{
    uint32_t   cmpsel;              /*!< CMPSEL Setting
                                       : Use @ref ENTNCR_CMPSEL */
    uint32_t   udmd;                /*!< UDMD Setting
                                       : Use @ref ENTNCR_UDMD */
    uint32_t   tovmd;               /*!< TOVMD Setting
                                       : Use @ref ENTNCR_TOVMD */
    uint32_t   mcmpmd;              /*!< MCMPMD Setting
                                       : Use @ref ENTNCR_MCMPMD */
    uint32_t   decmd;               /*!< DECMD Setting
                                       : Use @ref ENTNCR_DECMD */
    uint32_t   sdten;               /*!< SDTEN Setting
                                       : Use @ref ENTNCR_SDTEN */
    uint32_t   mode;                /*!< MODE Setting
                                       : Use @ref ENTNCR_MODE */
    uint32_t   p3en;                /*!< P3EN Setting
                                       : Use @ref ENTNCR_P3EN */
    uint32_t   trgcapmd;            /*!< TRGCAPMD Setting
                                       : Use @ref ENTNCR_TRGCAPMD */
    uint32_t   zesel;               /*!< ZESEL Setting
                                       : Use @ref ENTNCR_ZESEL */
    uint32_t   zen;                 /*!< ZEN Setting
                                       : Use @ref ENTNCR_ZEN */
    uint32_t   enrun;               /*!< ENRUN Setting
                                       : Use @ref ENTNCR_ENRUN */
    uint32_t   zeact;               /*!< ZEACT Setting
                                       : Use @ref ENTNCR_ZEACT */
    uint32_t   endev;               /*!< ENDEV Setting
                                       : Use @ref ENTNCR_ENDEV */
} enc_control_setting_t;

/*----------------------------------*/
/*! @struct enc_input_control_t
    @brief  ENC Input Register Setting
*/
/*----------------------------------*/
typedef struct
{
    uint32_t nct;                  /*!< NCT Setting
                                      : NCT ( NCT =< ENINPCR_NCT_MAX )   @ref ENINPCR_NCT */
    uint32_t syncnczen;            /*!< SYNCNCZEN Setting
                                      : Use @ref ENINPCR_SYNCNCZEN */
    uint32_t syncsplmd;            /*!< SYNCSPLMD Setting
                                      : Use @ref ENINPCR_SYNCSPLMD */
    uint32_t syncsplen;            /*!< SYNCSPLEN Setting
                                      : Use @ref ENINPCR_SYNCSPLEN */
} enc_input_control_t;

/*----------------------------------*/
/*! @struct enc_int_t
    @brief  ENC INT Control Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t mcmpie;            /*!< MCMPIE Setting
                                   : Use @ref ENINTCR_MCMPIE */
    uint32_t rldie;             /*!< RLDIE Setting
                                   : Use @ref ENINTCR_RLDIE */
    uint32_t cmpie;             /*!< CMPIE Setting
                                   : Use @ref ENINTCR_CMPIE */
    uint32_t errie;             /*!< ERRIE Setting
                                   : Use @ref ENINTCR_ERRIE */
    uint32_t capie;             /*!< CAPIE Setting
                                   : Use @ref ENINTCR_CAPIE */
    uint32_t tplsie;            /*!< TPLSIE Setting
                                   : Use @ref ENINTCR_TPLSIE */
} enc_int_t;

/*----------------------------------*/
/*! @struct enc_t
    @brief  ENC handle structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    TSB_EN_TypeDef           *p_instance;     /*!< Registers base address */
    enc_control_setting_t    con;             /*!< ENC Control Register Setting
                                                 : Use @ref enc_control_setting_t */
    uint32_t                 reload;          /*!< ENC Reload Compare Register Setting */
    uint32_t                 intcmp;          /*!< ENC INT Compare Register Setting */
    uint32_t                 mcmp;            /*!< ENC MCMP Compare Register Setting */
    uint16_t                 rate;            /*!< ENC Count Rate Register Setting */
    enc_input_control_t      inpcr;           /*!< ENC Input Register Setting
                                                 : Use @ref enc_input_control_t */
    uint8_t                  smpdly;          /*!< ENC Sample Delay Register Setting */
    enc_clock_t              clk;             /*!< ENC Clock Register Setting
                                                 : Use @ref enc_clock_t */
    enc_int_t                intcr;           /*!< ENC INT Control Register Setting
                                                 : Use @ref enc_int_t */
} enc_t;
/**
 *  @}
 */ /* End of group ENC_Exported_typedef */

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup ENC_Exported_functions ENC Exported Functions
 *  @{
 */
TXZ_Result enc_set_control(enc_t *p_obj);
TXZ_Result enc_softcapture_start(enc_t *p_obj);
TXZ_Result enc_counter_clear(enc_t *p_obj);
TXZ_Result enc_set_enable(enc_t *p_obj);
TXZ_Result enc_set_disable(enc_t *p_obj);
TXZ_Result enc_set_reload(enc_t *p_obj);
TXZ_Result enc_set_int(enc_t *p_obj);
TXZ_Result enc_get_count(enc_t *p_obj, uint32_t *p_count);
TXZ_Result enc_set_mcmp(enc_t *p_obj);
TXZ_Result enc_set_rate(enc_t *p_obj);
TXZ_Result enc_get_status(enc_t *p_obj, uint32_t *p_status);
TXZ_Result enc_set_input(enc_t *p_obj);
TXZ_Result enc_edgedetect_start(enc_t *p_obj);
TXZ_Result enc_edgedetect_stop(enc_t *p_obj);
TXZ_Result enc_set_sampdly(enc_t *p_obj);
TXZ_Result enc_get_inpmon(enc_t *p_obj, uint32_t *p_inpmon);
TXZ_Result enc_set_clk(enc_t *p_obj);
TXZ_Result enc_set_intcontrol(enc_t *p_obj);
TXZ_Result enc_get_intf(enc_t *p_obj, uint32_t *p_intf);
/**
 *  @}
 */ /* End of group ENC_Exported_functions */

/**
 *  @}
 */ /* End of group ENC */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __A_ENC32_A_H */


