/**
 *******************************************************************************
 * @file    can_b.c
 * @brief   This file provides API functions for CAN driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "can_b.h"

#if defined(__CAN_B_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup CAN
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Private_define CAN Private Define
 *  @{
 */


/** 
 *  @}
 */ /* End of group CAN_Private_define */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Private_macro CAN Private Macro
 *  @{
 */
#define CANMD_MD31               ((uint32_t)0x80000000)      /* CANMD MD31 */
#define CANMCR_TSCC_CLAER        ((uint32_t)0x00000002)      /* CANMCR TSCC clear */
#define CANMCR_SRES_RESET        ((uint32_t)0x00000001)      /* CANMCR SRES reset */
/**
 *  @}
 */ /* End of group CAN_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Private_Enumeration CAN Private Enumeration
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group CAN_Private_Enumeration */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Private_typedef CAN Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group CAN_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Private_variable CAN Private Variable Definition
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group CAN_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Private_fuctions CAN Private Fuctions
 *  @{
 */

#ifdef __DEBUG__
    __STATIC_INLINE int32_t check_param_ide(uint32_t param);
    __STATIC_INLINE int32_t check_param_gamelame(uint32_t param);
    __STATIC_INLINE int32_t check_param_rfh(uint32_t param);
    __STATIC_INLINE int32_t check_param_id(uint32_t param);
    __STATIC_INLINE int32_t check_param_tsv(uint32_t param);
    __STATIC_INLINE int32_t check_param_rtr(uint32_t param);
    __STATIC_INLINE int32_t check_param_dlc(uint32_t param);
    __STATIC_INLINE int32_t check_param_datafield(uint32_t param);
    __STATIC_INLINE int32_t check_param_md(uint32_t param);
    __STATIC_INLINE int32_t check_param_trs(uint32_t param);
    __STATIC_INLINE int32_t check_param_trr(uint32_t param);
    __STATIC_INLINE int32_t check_param_ta(uint32_t param);
    __STATIC_INLINE int32_t check_param_aa(uint32_t param);
    __STATIC_INLINE int32_t check_param_rmp(uint32_t param);
    __STATIC_INLINE int32_t check_param_rml(uint32_t param);
    __STATIC_INLINE int32_t check_param_lam(uint32_t param);
    __STATIC_INLINE int32_t check_param_lami(uint32_t param);
    __STATIC_INLINE int32_t check_param_gam(uint32_t param);
    __STATIC_INLINE int32_t check_param_gami(uint32_t param);
    __STATIC_INLINE int32_t check_param_sur(uint32_t param);
    __STATIC_INLINE int32_t check_param_tstlb(uint32_t param);
    __STATIC_INLINE int32_t check_param_tsterr(uint32_t param);
    __STATIC_INLINE int32_t check_param_ccr(uint32_t param);
    __STATIC_INLINE int32_t check_param_smr(uint32_t param);
    __STATIC_INLINE int32_t check_param_wuba(uint32_t param);
    __STATIC_INLINE int32_t check_param_mtos(uint32_t param);
    __STATIC_INLINE int32_t check_param_bcr1(uint32_t param);
    __STATIC_INLINE int32_t check_param_sjw(uint32_t param);
    __STATIC_INLINE int32_t check_param_sam(uint32_t param);
    __STATIC_INLINE int32_t check_param_tseg2(uint32_t param);
    __STATIC_INLINE int32_t check_param_tseg1(uint32_t param);
    __STATIC_INLINE int32_t check_param_rfpf(uint32_t param);
    __STATIC_INLINE int32_t check_param_wuif(uint32_t param);
    __STATIC_INLINE int32_t check_param_rmlif(uint32_t param);
    __STATIC_INLINE int32_t check_param_trmabf(uint32_t param);
    __STATIC_INLINE int32_t check_param_tsoif(uint32_t param);
    __STATIC_INLINE int32_t check_param_boif(uint32_t param);
    __STATIC_INLINE int32_t check_param_epif(uint32_t param);
    __STATIC_INLINE int32_t check_param_wlif(uint32_t param);
    __STATIC_INLINE int32_t check_param_rfpm(uint32_t param);
    __STATIC_INLINE int32_t check_param_wuim(uint32_t param);
    __STATIC_INLINE int32_t check_param_rmlim(uint32_t param);
    __STATIC_INLINE int32_t check_param_trmabf_mask(uint32_t param);
    __STATIC_INLINE int32_t check_param_tsoim(uint32_t param);
    __STATIC_INLINE int32_t check_param_boim(uint32_t param);
    __STATIC_INLINE int32_t check_param_epim(uint32_t param);
    __STATIC_INLINE int32_t check_param_wlim(uint32_t param);
    __STATIC_INLINE int32_t check_param_mbtif(uint32_t param);
    __STATIC_INLINE int32_t check_param_mbrif(uint32_t param);
    __STATIC_INLINE int32_t check_param_cdr(uint32_t param);
    __STATIC_INLINE int32_t check_param_rfp(uint32_t param);
    __STATIC_INLINE int32_t check_param_cec_tec(uint32_t param);
    __STATIC_INLINE int32_t check_param_cec_rec(uint32_t param);
    __STATIC_INLINE int32_t check_param_tsp(uint8_t param);
#endif /* #ifdef __DEBUG__ */

#ifdef __DEBUG__
/*--------------------------------------------------*/
/** 
  * @brief  Check the IDE's parameter.
  * @param  param    :IDE's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBID_IDE"CANMBID_IDE__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_ide(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBID_IDE_STANDARD:
    case CANMBID_IDE_EXPANSION:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the GAMELAME's parameter.
  * @param  param    :GAMELAME's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBID_GAMELAME"CANMBID_GAMELAME__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_gamelame(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBID_GAMELAME_DISABLE:
    case CANMBID_GAMELAME_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RFH's parameter.
  * @param  param    :RFH's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBID_RFH"CANMBID_RFH__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rfh(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBID_RFH_NORES:
    case CANMBID_RFH_RES:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the ID's parameter.
  * @param  param    :ID's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBID"CANMBID__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_id(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANMBID_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSV's parameter.
  * @param  param    :TSV's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBTSVMCF_TSV"CANMBTSVMCF_TSV__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tsv(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANMBTSVMCF_TSV_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RTR's parameter.
  * @param  param    :RTR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBTSVMCF_RTR"CANMBTSVMCF_RTR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rtr(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBTSVMCF_RTR_DATA:
    case CANMBTSVMCF_RTR_REMORT:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the DLC's parameter.
  * @param  param    :DLC's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBTSVMCF_DLC"CANMBTSVMCF_DLC__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_dlc(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBTSVMCF_DLC_0:
    case CANMBTSVMCF_DLC_1:
    case CANMBTSVMCF_DLC_2:
    case CANMBTSVMCF_DLC_3:
    case CANMBTSVMCF_DLC_4:
    case CANMBTSVMCF_DLC_5:
    case CANMBTSVMCF_DLC_6:
    case CANMBTSVMCF_DLC_7:
    case CANMBTSVMCF_DLC_8:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the DATA's parameter.
  * @param  param    :DATA's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMB_DATA"CANMB_DATA__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_datafield(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMB_DATAL:
    case CANMB_DATAH:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MD's parameter.
  * @param  param    :MD's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMD_MD"CANMD_MD__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_md(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANMD_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TRS's parameter.
  * @param  param    :TRS's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANTRS_TRS"CANTRS_TRS__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_trs(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANTRS_TRS_TRS0REQ:
    case CANTRS_TRS_TRS1REQ:
    case CANTRS_TRS_TRS2REQ:
    case CANTRS_TRS_TRS3REQ:
    case CANTRS_TRS_TRS4REQ:
    case CANTRS_TRS_TRS5REQ:
    case CANTRS_TRS_TRS6REQ:
    case CANTRS_TRS_TRS7REQ:
    case CANTRS_TRS_TRS8REQ:
    case CANTRS_TRS_TRS9REQ:
    case CANTRS_TRS_TRS10REQ:
    case CANTRS_TRS_TRS11REQ:
    case CANTRS_TRS_TRS12REQ:
    case CANTRS_TRS_TRS13REQ:
    case CANTRS_TRS_TRS14REQ:
    case CANTRS_TRS_TRS15REQ:
    case CANTRS_TRS_TRS16REQ:
    case CANTRS_TRS_TRS17REQ:
    case CANTRS_TRS_TRS18REQ:
    case CANTRS_TRS_TRS19REQ:
    case CANTRS_TRS_TRS20REQ:
    case CANTRS_TRS_TRS21REQ:
    case CANTRS_TRS_TRS22REQ:
    case CANTRS_TRS_TRS23REQ:
    case CANTRS_TRS_TRS24REQ:
    case CANTRS_TRS_TRS25REQ:
    case CANTRS_TRS_TRS26REQ:
    case CANTRS_TRS_TRS27REQ:
    case CANTRS_TRS_TRS28REQ:
    case CANTRS_TRS_TRS29REQ:
    case CANTRS_TRS_TRS30REQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TRR's parameter.
  * @param  param    :TRR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANTRR_TRR"CANTRR_TRR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_trr(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANTRR_TRR_TRR0REQ:
    case CANTRR_TRR_TRR1REQ:
    case CANTRR_TRR_TRR2REQ:
    case CANTRR_TRR_TRR3REQ:
    case CANTRR_TRR_TRR4REQ:
    case CANTRR_TRR_TRR5REQ:
    case CANTRR_TRR_TRR6REQ:
    case CANTRR_TRR_TRR7REQ:
    case CANTRR_TRR_TRR8REQ:
    case CANTRR_TRR_TRR9REQ:
    case CANTRR_TRR_TRR10REQ:
    case CANTRR_TRR_TRR11REQ:
    case CANTRR_TRR_TRR12REQ:
    case CANTRR_TRR_TRR13REQ:
    case CANTRR_TRR_TRR14REQ:
    case CANTRR_TRR_TRR15REQ:
    case CANTRR_TRR_TRR16REQ:
    case CANTRR_TRR_TRR17REQ:
    case CANTRR_TRR_TRR18REQ:
    case CANTRR_TRR_TRR19REQ:
    case CANTRR_TRR_TRR20REQ:
    case CANTRR_TRR_TRR21REQ:
    case CANTRR_TRR_TRR22REQ:
    case CANTRR_TRR_TRR23REQ:
    case CANTRR_TRR_TRR24REQ:
    case CANTRR_TRR_TRR25REQ:
    case CANTRR_TRR_TRR26REQ:
    case CANTRR_TRR_TRR27REQ:
    case CANTRR_TRR_TRR28REQ:
    case CANTRR_TRR_TRR29REQ:
    case CANTRR_TRR_TRR30REQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TA's parameter.
  * @param  param    :TA's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANTA_TA"CANTA_TA__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_ta(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANTA_TA_TA0CLR:
    case CANTA_TA_TA1CLR:
    case CANTA_TA_TA2CLR:
    case CANTA_TA_TA3CLR:
    case CANTA_TA_TA4CLR:
    case CANTA_TA_TA5CLR:
    case CANTA_TA_TA6CLR:
    case CANTA_TA_TA7CLR:
    case CANTA_TA_TA8CLR:
    case CANTA_TA_TA9CLR:
    case CANTA_TA_TA10CLR:
    case CANTA_TA_TA11CLR:
    case CANTA_TA_TA12CLR:
    case CANTA_TA_TA13CLR:
    case CANTA_TA_TA14CLR:
    case CANTA_TA_TA15CLR:
    case CANTA_TA_TA16CLR:
    case CANTA_TA_TA17CLR:
    case CANTA_TA_TA18CLR:
    case CANTA_TA_TA19CLR:
    case CANTA_TA_TA20CLR:
    case CANTA_TA_TA21CLR:
    case CANTA_TA_TA22CLR:
    case CANTA_TA_TA23CLR:
    case CANTA_TA_TA24CLR:
    case CANTA_TA_TA25CLR:
    case CANTA_TA_TA26CLR:
    case CANTA_TA_TA27CLR:
    case CANTA_TA_TA28CLR:
    case CANTA_TA_TA29CLR:
    case CANTA_TA_TA30CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the AA's parameter.
  * @param  param    :AA's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANAA_AA"CANAA_AA__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_aa(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANAA_AA_AA0CLR:
    case CANAA_AA_AA1CLR:
    case CANAA_AA_AA2CLR:
    case CANAA_AA_AA3CLR:
    case CANAA_AA_AA4CLR:
    case CANAA_AA_AA5CLR:
    case CANAA_AA_AA6CLR:
    case CANAA_AA_AA7CLR:
    case CANAA_AA_AA8CLR:
    case CANAA_AA_AA9CLR:
    case CANAA_AA_AA10CLR:
    case CANAA_AA_AA11CLR:
    case CANAA_AA_AA12CLR:
    case CANAA_AA_AA13CLR:
    case CANAA_AA_AA14CLR:
    case CANAA_AA_AA15CLR:
    case CANAA_AA_AA16CLR:
    case CANAA_AA_AA17CLR:
    case CANAA_AA_AA18CLR:
    case CANAA_AA_AA19CLR:
    case CANAA_AA_AA20CLR:
    case CANAA_AA_AA21CLR:
    case CANAA_AA_AA22CLR:
    case CANAA_AA_AA23CLR:
    case CANAA_AA_AA24CLR:
    case CANAA_AA_AA25CLR:
    case CANAA_AA_AA26CLR:
    case CANAA_AA_AA27CLR:
    case CANAA_AA_AA28CLR:
    case CANAA_AA_AA29CLR:
    case CANAA_AA_AA30CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RMP's parameter.
  * @param  param    :RMP's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANRMP_RMP"CANRMP_RMP__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rmp(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANRMP_RMP_RMP0CLR:
    case CANRMP_RMP_RMP1CLR:
    case CANRMP_RMP_RMP2CLR:
    case CANRMP_RMP_RMP3CLR:
    case CANRMP_RMP_RMP4CLR:
    case CANRMP_RMP_RMP5CLR:
    case CANRMP_RMP_RMP6CLR:
    case CANRMP_RMP_RMP7CLR:
    case CANRMP_RMP_RMP8CLR:
    case CANRMP_RMP_RMP9CLR:
    case CANRMP_RMP_RMP10CLR:
    case CANRMP_RMP_RMP11CLR:
    case CANRMP_RMP_RMP12CLR:
    case CANRMP_RMP_RMP13CLR:
    case CANRMP_RMP_RMP14CLR:
    case CANRMP_RMP_RMP15CLR:
    case CANRMP_RMP_RMP16CLR:
    case CANRMP_RMP_RMP17CLR:
    case CANRMP_RMP_RMP18CLR:
    case CANRMP_RMP_RMP19CLR:
    case CANRMP_RMP_RMP20CLR:
    case CANRMP_RMP_RMP21CLR:
    case CANRMP_RMP_RMP22CLR:
    case CANRMP_RMP_RMP23CLR:
    case CANRMP_RMP_RMP24CLR:
    case CANRMP_RMP_RMP25CLR:
    case CANRMP_RMP_RMP26CLR:
    case CANRMP_RMP_RMP27CLR:
    case CANRMP_RMP_RMP28CLR:
    case CANRMP_RMP_RMP29CLR:
    case CANRMP_RMP_RMP30CLR:
    case CANRMP_RMP_RMP31CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RML's parameter.
  * @param  param    :RML's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANRML_RML"CANRML_RML__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rml(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANRML_RML_RML0CLR:
    case CANRML_RML_RML1CLR:
    case CANRML_RML_RML2CLR:
    case CANRML_RML_RML3CLR:
    case CANRML_RML_RML4CLR:
    case CANRML_RML_RML5CLR:
    case CANRML_RML_RML6CLR:
    case CANRML_RML_RML7CLR:
    case CANRML_RML_RML8CLR:
    case CANRML_RML_RML9CLR:
    case CANRML_RML_RML10CLR:
    case CANRML_RML_RML11CLR:
    case CANRML_RML_RML12CLR:
    case CANRML_RML_RML13CLR:
    case CANRML_RML_RML14CLR:
    case CANRML_RML_RML15CLR:
    case CANRML_RML_RML16CLR:
    case CANRML_RML_RML17CLR:
    case CANRML_RML_RML18CLR:
    case CANRML_RML_RML19CLR:
    case CANRML_RML_RML20CLR:
    case CANRML_RML_RML21CLR:
    case CANRML_RML_RML22CLR:
    case CANRML_RML_RML23CLR:
    case CANRML_RML_RML24CLR:
    case CANRML_RML_RML25CLR:
    case CANRML_RML_RML26CLR:
    case CANRML_RML_RML27CLR:
    case CANRML_RML_RML28CLR:
    case CANRML_RML_RML29CLR:
    case CANRML_RML_RML30CLR:
    case CANRML_RML_RML31CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the LAM_'s parameter.
  * @param  param    :LAM_'s parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANLAM_LAM"CANLAM_LAM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_lam(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANLAM_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the LAMI's parameter.
  * @param  param    :LAMI's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANLAM_LAMI"CANLAM_LAMI__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_lami(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANLAM_LAMI_LAMIMASK:
    case CANLAM_LAMI_LAMINOMASK:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the GAM's parameter.
  * @param  param    :GAM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGAM_GAM"CANGAM_GAM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_gam(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANGAM_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the GAMI's parameter.
  * @param  param    :GAMI's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGAM_GAMI"CANGAM_GAMI__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_gami(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGAM_GAMI_GAMIMASK:
    case CANGAM_GAMI_GAMINOMASK:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SUR's parameter.
  * @param  param    :SUR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_SUR"CANMCR_SUR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_sur(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_SUR_SUSPENDCLR:
    case CANMCR_SUR_SUSPENDREQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSTLB's parameter.
  * @param  param    :TSTLB's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_TSTLB"CANMCR_TSTLB__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tstlb(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_TSTLB_LBCLR:
    case CANMCR_TSTLB_LBREQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSTERR's parameter.
  * @param  param    :TSTERR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_TSTERR"CANMCR_TSTERR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tsterr(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_TSTERR_ERRCLR:
    case CANMCR_TSTERR_ERRREQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the CCR's parameter.
  * @param  param    :CCR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_CCR"CANMCR_CCR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_ccr(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_CCR_CCRCLR:
    case CANMCR_CCR_CCRREQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SMR's parameter.
  * @param  param    :SMR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_SMR"CANMCR_SMR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_smr(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_SMR_SMRCLR:
    case CANMCR_SMR_SMRREQ:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the WUBA's parameter.
  * @param  param    :WUBA's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_WUBA"CANMCR_WUBA__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wuba(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_WUBA_WRITE:
    case CANMCR_WUBA_DETECT:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MTOS's parameter.
  * @param  param    :MTOS's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMCR_MTOS"CANMCR_MTOS__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_mtos(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMCR_MTOS_LITTLE:
    case CANMCR_MTOS_PRIORITY:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the BCR1's parameter.
  * @param  param    :BCR1's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANBCR1"CANBCR1__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_bcr1(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANBCR1_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SJW's parameter.
  * @param  param    :SJW's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANBCR2_SJW"CANBCR2_SJW__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_sjw(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANBCR2_SJW_1:
    case CANBCR2_SJW_2:
    case CANBCR2_SJW_3:
    case CANBCR2_SJW_4:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the SAM's parameter.
  * @param  param    :SAM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANBCR2_SAM"CANBCR2_SAM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_sam(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANBCR2_SAM_SINGLE:
    case CANBCR2_SAM_TRIPLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSEG2's parameter.
  * @param  param    :TSEG2's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANBCR2_TSEG2"CANBCR2_TSEG2__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tseg2(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANBCR2_TSEG2_2:
    case CANBCR2_TSEG2_3:
    case CANBCR2_TSEG2_4:
    case CANBCR2_TSEG2_5:
    case CANBCR2_TSEG2_6:
    case CANBCR2_TSEG2_7:
    case CANBCR2_TSEG2_8:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSEG1's parameter.
  * @param  param    :TSEG1's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANBCR2_TSEG1"CANBCR2_TSEG1__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tseg1(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANBCR2_TSEG1_2:
    case CANBCR2_TSEG1_3:
    case CANBCR2_TSEG1_4:
    case CANBCR2_TSEG1_5:
    case CANBCR2_TSEG1_6:
    case CANBCR2_TSEG1_7:
    case CANBCR2_TSEG1_8:
    case CANBCR2_TSEG1_9:
    case CANBCR2_TSEG1_10:
    case CANBCR2_TSEG1_11:
    case CANBCR2_TSEG1_12:
    case CANBCR2_TSEG1_13:
    case CANBCR2_TSEG1_14:
    case CANBCR2_TSEG1_15:
    case CANBCR2_TSEG1_16:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RFPF's parameter.
  * @param  param    :RFPF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_RFPF"CANGIF_RFPF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rfpf(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_RFPF_NORECEIVE:
    case CANGIF_RFPF_RECEIVE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the WUIF's parameter.
  * @param  param    :WUIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_WUIF"CANGIF_WUIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wuif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_WUIF_SLEEP:
    case CANGIF_WUIF_NOSLEEP:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RMLIF's parameter.
  * @param  param    :RMLIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_RMLIF"CANGIF_RMLIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rmlif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_RMLIF_NOLOST:
    case CANGIF_RMLIF_LOST:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TRMABF's parameter.
  * @param  param    :TRMABF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_TRMABF"CANGIF_TRMABF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_trmabf(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_TRMABF_NOABORT:
    case CANGIF_TRMABF_ABORT:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSOIF's parameter.
  * @param  param    :TSOIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_TSOIF"CANGIF_TSOIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tsoif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_TSOIF_NOOVER:
    case CANGIF_TSOIF_OVER:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the BOIF's parameter.
  * @param  param    :BOIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_BOIF"CANGIF_BOIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_boif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_BOIF_ON:
    case CANGIF_BOIF_OFF:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the EPIF's parameter.
  * @param  param    :EPIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_EPIF"CANGIF_EPIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_epif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_EPIF_ACTIVE:
    case CANGIF_EPIF_PASSIVE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the WLIF's parameter.
  * @param  param    :WLIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIF_WLIF"CANGIF_WLIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wlif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIF_WLIF_NOWARNING:
    case CANGIF_WLIF_WARNING:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RFPM's parameter.
  * @param  param    :RFPM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_RFPM"CANGIM_RFPM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rfpm(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_RFPM_DISABLE:
    case CANGIM_RFPM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the WUIM's parameter.
  * @param  param    :WUIM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_WUIM"CANGIM_WUIM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wuim(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_WUIM_DISABLE:
    case CANGIM_WUIM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RMLIM's parameter.
  * @param  param    :RMLIM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_RMLIM"CANGIM_RMLIM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rmlim(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_RMLIM_DISABLE:
    case CANGIM_RMLIM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TRMABF's parameter.
  * @param  param    :TRMABF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_TRMABF"CANGIM_TRMABF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_trmabf_mask(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_TRMABF_DISABLE:
    case CANGIM_TRMABF_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSOIM's parameter.
  * @param  param    :TSOIM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_TSOIM"CANGIM_TSOIM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tsoim(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_TSOIM_DISABLE:
    case CANGIM_TSOIM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the BOIM's parameter.
  * @param  param    :BOIM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_BOIM"CANGIM_BOIM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_boim(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_BOIM_DISABLE:
    case CANGIM_BOIM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the EPIM's parameter.
  * @param  param    :EPIM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_EPIM"CANGIM_EPIM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_epim(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_EPIM_DISABLE:
    case CANGIM_EPIM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the WLIM's parameter.
  * @param  param    :WLIM's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANGIM_WLIM"CANGIM_WLIM__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wlim(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANGIM_WLIM_DISABLE:
    case CANGIM_WLIM_ENABLE:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MBTIF's parameter.
  * @param  param    :MBTIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBTIF_MBTIF"CANMBTIF_MBTIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_mbtif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBTIF_MBTIF_MBTIF0CLR:
    case CANMBTIF_MBTIF_MBTIF1CLR:
    case CANMBTIF_MBTIF_MBTIF2CLR:
    case CANMBTIF_MBTIF_MBTIF3CLR:
    case CANMBTIF_MBTIF_MBTIF4CLR:
    case CANMBTIF_MBTIF_MBTIF5CLR:
    case CANMBTIF_MBTIF_MBTIF6CLR:
    case CANMBTIF_MBTIF_MBTIF7CLR:
    case CANMBTIF_MBTIF_MBTIF8CLR:
    case CANMBTIF_MBTIF_MBTIF9CLR:
    case CANMBTIF_MBTIF_MBTIF10CLR:
    case CANMBTIF_MBTIF_MBTIF11CLR:
    case CANMBTIF_MBTIF_MBTIF12CLR:
    case CANMBTIF_MBTIF_MBTIF13CLR:
    case CANMBTIF_MBTIF_MBTIF14CLR:
    case CANMBTIF_MBTIF_MBTIF15CLR:
    case CANMBTIF_MBTIF_MBTIF16CLR:
    case CANMBTIF_MBTIF_MBTIF17CLR:
    case CANMBTIF_MBTIF_MBTIF18CLR:
    case CANMBTIF_MBTIF_MBTIF19CLR:
    case CANMBTIF_MBTIF_MBTIF20CLR:
    case CANMBTIF_MBTIF_MBTIF21CLR:
    case CANMBTIF_MBTIF_MBTIF22CLR:
    case CANMBTIF_MBTIF_MBTIF23CLR:
    case CANMBTIF_MBTIF_MBTIF24CLR:
    case CANMBTIF_MBTIF_MBTIF25CLR:
    case CANMBTIF_MBTIF_MBTIF26CLR:
    case CANMBTIF_MBTIF_MBTIF27CLR:
    case CANMBTIF_MBTIF_MBTIF28CLR:
    case CANMBTIF_MBTIF_MBTIF29CLR:
    case CANMBTIF_MBTIF_MBTIF30CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the MBRIF's parameter.
  * @param  param    :MBRIF's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANMBRIF_MBRIF"CANMBRIF_MBRIF__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_mbrif(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANMBRIF_MBRIF_MBRIF0CLR:
    case CANMBRIF_MBRIF_MBRIF1CLR:
    case CANMBRIF_MBRIF_MBRIF2CLR:
    case CANMBRIF_MBRIF_MBRIF3CLR:
    case CANMBRIF_MBRIF_MBRIF4CLR:
    case CANMBRIF_MBRIF_MBRIF5CLR:
    case CANMBRIF_MBRIF_MBRIF6CLR:
    case CANMBRIF_MBRIF_MBRIF7CLR:
    case CANMBRIF_MBRIF_MBRIF8CLR:
    case CANMBRIF_MBRIF_MBRIF9CLR:
    case CANMBRIF_MBRIF_MBRIF10CLR:
    case CANMBRIF_MBRIF_MBRIF11CLR:
    case CANMBRIF_MBRIF_MBRIF12CLR:
    case CANMBRIF_MBRIF_MBRIF13CLR:
    case CANMBRIF_MBRIF_MBRIF14CLR:
    case CANMBRIF_MBRIF_MBRIF15CLR:
    case CANMBRIF_MBRIF_MBRIF16CLR:
    case CANMBRIF_MBRIF_MBRIF17CLR:
    case CANMBRIF_MBRIF_MBRIF18CLR:
    case CANMBRIF_MBRIF_MBRIF19CLR:
    case CANMBRIF_MBRIF_MBRIF20CLR:
    case CANMBRIF_MBRIF_MBRIF21CLR:
    case CANMBRIF_MBRIF_MBRIF22CLR:
    case CANMBRIF_MBRIF_MBRIF23CLR:
    case CANMBRIF_MBRIF_MBRIF24CLR:
    case CANMBRIF_MBRIF_MBRIF25CLR:
    case CANMBRIF_MBRIF_MBRIF26CLR:
    case CANMBRIF_MBRIF_MBRIF27CLR:
    case CANMBRIF_MBRIF_MBRIF28CLR:
    case CANMBRIF_MBRIF_MBRIF29CLR:
    case CANMBRIF_MBRIF_MBRIF30CLR:
    case CANMBRIF_MBRIF_MBRIF31CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the CDR's parameter.
  * @param  param    :CDR's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANCDR_CDR"CANCDR_CDR__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_cdr(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANCDR_CDR_CDR0CLR:
    case CANCDR_CDR_CDR1CLR:
    case CANCDR_CDR_CDR2CLR:
    case CANCDR_CDR_CDR3CLR:
    case CANCDR_CDR_CDR4CLR:
    case CANCDR_CDR_CDR5CLR:
    case CANCDR_CDR_CDR6CLR:
    case CANCDR_CDR_CDR7CLR:
    case CANCDR_CDR_CDR8CLR:
    case CANCDR_CDR_CDR9CLR:
    case CANCDR_CDR_CDR10CLR:
    case CANCDR_CDR_CDR11CLR:
    case CANCDR_CDR_CDR12CLR:
    case CANCDR_CDR_CDR13CLR:
    case CANCDR_CDR_CDR14CLR:
    case CANCDR_CDR_CDR15CLR:
    case CANCDR_CDR_CDR16CLR:
    case CANCDR_CDR_CDR17CLR:
    case CANCDR_CDR_CDR18CLR:
    case CANCDR_CDR_CDR19CLR:
    case CANCDR_CDR_CDR20CLR:
    case CANCDR_CDR_CDR21CLR:
    case CANCDR_CDR_CDR22CLR:
    case CANCDR_CDR_CDR23CLR:
    case CANCDR_CDR_CDR24CLR:
    case CANCDR_CDR_CDR25CLR:
    case CANCDR_CDR_CDR26CLR:
    case CANCDR_CDR_CDR27CLR:
    case CANCDR_CDR_CDR28CLR:
    case CANCDR_CDR_CDR29CLR:
    case CANCDR_CDR_CDR30CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the RFP's parameter.
  * @param  param    :RFP's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANRFP_RFP"CANRFP_RFP__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rfp(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    switch (param) 
    {
    case CANRFP_RFP_RFP0CLR:
    case CANRFP_RFP_RFP1CLR:
    case CANRFP_RFP_RFP2CLR:
    case CANRFP_RFP_RFP3CLR:
    case CANRFP_RFP_RFP4CLR:
    case CANRFP_RFP_RFP5CLR:
    case CANRFP_RFP_RFP6CLR:
    case CANRFP_RFP_RFP7CLR:
    case CANRFP_RFP_RFP8CLR:
    case CANRFP_RFP_RFP9CLR:
    case CANRFP_RFP_RFP10CLR:
    case CANRFP_RFP_RFP11CLR:
    case CANRFP_RFP_RFP12CLR:
    case CANRFP_RFP_RFP13CLR:
    case CANRFP_RFP_RFP14CLR:
    case CANRFP_RFP_RFP15CLR:
    case CANRFP_RFP_RFP16CLR:
    case CANRFP_RFP_RFP17CLR:
    case CANRFP_RFP_RFP18CLR:
    case CANRFP_RFP_RFP19CLR:
    case CANRFP_RFP_RFP20CLR:
    case CANRFP_RFP_RFP21CLR:
    case CANRFP_RFP_RFP22CLR:
    case CANRFP_RFP_RFP23CLR:
    case CANRFP_RFP_RFP24CLR:
    case CANRFP_RFP_RFP25CLR:
    case CANRFP_RFP_RFP26CLR:
    case CANRFP_RFP_RFP27CLR:
    case CANRFP_RFP_RFP28CLR:
    case CANRFP_RFP_RFP29CLR:
    case CANRFP_RFP_RFP30CLR:
    case CANRFP_RFP_RFP31CLR:
        result = CAN_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TEC's parameter.
  * @param  param    :TEC's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANCEC_TEC"CANCEC_TEC__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_cec_tec(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANCEC_TEC_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the REC's parameter.
  * @param  param    :REC's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANCEC_REC"CANCEC_REC__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_cec_rec(uint32_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANCEC_REC_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

/*--------------------------------------------------*/
/** 
  * @brief  Check the TSP's parameter.
  * @param  param    :TSP's parameter
  * @retval CAN_PARAM_OK :Valid
  * @retval CAN_PARAM_NG :Invalid
  * @note   Macro definition is @ref CANTSP"CANTSP__xxxx".
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_tsp(uint8_t param)
{
    int32_t result = CAN_PARAM_NG;

    if (param <= CANTSP_MAX)
    {
        result = CAN_PARAM_OK;
    }
    return (result);
}

#endif /* #ifdef __DEBUG__ */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CAN_Exported_functions
 *  @{
 */ 
/*--------------------------------------------------*/
/**
  * @brief     CANMBID Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_id(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance2));
    assert_param(check_param_ide(p_obj->id.ide));
    assert_param(check_param_gamelame(p_obj->id.gamelame));
    assert_param(check_param_rfh(p_obj->id.rfh));
    assert_param(check_param_id(p_obj->id.id));
#endif
    p_obj->p_instance2->ID = (p_obj->id.ide | p_obj->id.gamelame | 
                              p_obj->id.rfh | p_obj->id.id);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMBTSVMCF Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_tsvmcf(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance2));
    assert_param(check_param_tsv(p_obj->tsvmcf.tsv));
    assert_param(check_param_rtr(p_obj->tsvmcf.rtr));
    assert_param(check_param_dlc(p_obj->tsvmcf.dlc));
#endif
    p_obj->p_instance2->TSVMCF = ((p_obj->tsvmcf.tsv << 16U) | p_obj->tsvmcf.rtr | 
                              p_obj->tsvmcf.dlc);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMBDL/DH Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_transdata(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance2));
    assert_param(check_param_datafield(p_obj->transdata.datafield));
#endif
    if(p_obj->transdata.datafield == CANMB_DATAL)
    {
        p_obj->p_instance2->DL = p_obj->transdata.data;
    }
    else{
        p_obj->p_instance2->DH = p_obj->transdata.data;
    }
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result can_get_receivedata(can_t *p_obj)
  * @brief  Get receive data.
  * @details  receive data.
  * | Bit   | Bit Symbol | Function                              |
  * | :---  | :---       | :---                                  |
  * | 31-24 | D7         | D7                                    |
  * | 23-16 | D6         | D6                                    |
  * | 15-8  | D5         | D5                                    |
  * | 7-0   | D4         | D4                                    |
  * 
  * | 31-24 | D3         | D3                                    |
  * | 23-16 | D2         | D2                                    |
  * | 15-8  | D1         | D4                                    |
  * | 7-0   | D0         | D0                                    |
  * 
  * @param[in] p_obj    :CAN object.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result can_get_receivedata(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance2));
    assert_param(check_param_datafield(p_obj->receivedata.datafield));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    if(p_obj->receivedata.datafield == CANMB_DATAL)
    {
        p_obj->receivedata.data = p_obj->p_instance2->DL;
    }
    else{
        p_obj->receivedata.data = p_obj->p_instance2->DH;
    }
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMC Value Getting
  * @param     p_obj :CAN object.
  * @param[out] p_mc :CAN MC
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_get_mc(can_t *p_obj, uint32_t *p_mc)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_mc));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_mc = p_obj->p_instance->MC;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMC Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_mc(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->MC = p_obj->mc;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMD Value Getting
  * @param     p_obj :CAN object.
  * @param[out] p_md :CAN MD
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_get_md(can_t *p_obj, uint32_t *p_md)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_md));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_md = p_obj->p_instance->MD;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMD Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_md(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_md(p_obj->md));
#endif
    p_obj->p_instance->MD = p_obj->md;
    p_obj->p_instance->MD |= CANMD_MD31;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANTRS Value Getting
  * @param     p_obj :CAN object.
  * @param[out] p_trs:CAN TRS
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_get_trs(can_t *p_obj, uint32_t *p_trs)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_trs));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_trs = p_obj->p_instance->TRS;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANTRS Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_trs(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_trs(p_obj->trs));
#endif
    p_obj->p_instance->TRS = p_obj->trs;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANTRR Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_trr(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_trr(p_obj->trr));
#endif
    p_obj->p_instance->TRR = p_obj->trr;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANTA Value Getting
  * @param     p_obj :CAN object.
  * @param[out] p_ta :CAN TA
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_get_ta(can_t *p_obj, uint32_t *p_ta)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_ta));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_ta = p_obj->p_instance->TA;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANTA Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_ta(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_ta(p_obj->ta));
#endif
    p_obj->p_instance->TA = p_obj->ta;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANAA Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_aa(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_aa(p_obj->aa));
#endif
    p_obj->p_instance->AA = p_obj->aa;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANRMP Value Getting
  * @param     p_obj :CAN object.
  * @param[out] p_rmp :CAN RMP
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_get_rmp(can_t *p_obj, uint32_t *p_rmp)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_rmp));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_rmp = p_obj->p_instance->RMP;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANRMP Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_rmp(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_rmp(p_obj->rmp));
#endif
    p_obj->p_instance->RMP = p_obj->rmp;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANRML Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_rml(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_rml(p_obj->rml));
#endif
    p_obj->p_instance->RML = p_obj->rml;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANLAM Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_lam(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_lam(p_obj->lam.lam));
    assert_param(check_param_lami(p_obj->lam.lami));
#endif
    p_obj->p_instance->LAM = (p_obj->lam.lam | p_obj->lam.lami);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANGAM Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_gam(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_gam(p_obj->gam.gam));
    assert_param(check_param_gami(p_obj->gam.gami));
#endif
    p_obj->p_instance->GAM = (p_obj->gam.gam | p_obj->gam.gami);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMCR Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_mcr(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_sur(p_obj->mcr.sur));
    assert_param(check_param_tstlb(p_obj->mcr.tstlb));
    assert_param(check_param_tsterr(p_obj->mcr.tsterr));
    assert_param(check_param_ccr(p_obj->mcr.ccr));
    assert_param(check_param_smr(p_obj->mcr.smr));
    assert_param(check_param_wuba(p_obj->mcr.wuba));
    assert_param(check_param_mtos(p_obj->mcr.mtos));
#endif
    p_obj->p_instance->MCR = (p_obj->mcr.sur | p_obj->mcr.tstlb | 
                              p_obj->mcr.tsterr | p_obj->mcr.ccr | 
                              p_obj->mcr.smr | p_obj->mcr.wuba  | 
                              p_obj->mcr.mtos);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CAN counter clear
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_counter_clear(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->MCR |= CANMCR_TSCC_CLAER;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CAN software reset
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_software_reset(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->MCR |= CANMCR_SRES_RESET;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result can_get_gsr(can_t *p_obj, uint32_t *p_gsr)
  * @brief  Get GSR.
  * @details  GSR bits.
  * | Bit   | Bit Symbol | Function                             |
  * | :---  | :---       | :---                                 |
  * | 31-17 | -          | -                                    |
  * | 16-12 | MIS        | MIS                                  |
  * | 11    | RM         | RM                                   |
  * | 10    | TM         | TM                                   |
  * | 9     | -          | -                                    |
  * | 8     | SUA        | SUA                                  |
  * | 7     | CCE        | CCE                                  |
  * | 6     | SMA        | SMA                                  |
  * | 5-4   | -          | -                                    |
  * | 3     | TSO        | TSO                                  |
  * | 2     | BO         | BO                                   |
  * | 1     | EP         | EP                                   |
  * | 0     | EW         | EW                                   |
  * 
  * @param[in] p_obj    :CAN object.
  * @param[out] p_gsr   :GSR. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result can_get_gsr(can_t *p_obj, uint32_t *p_gsr)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_gsr));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_gsr = p_obj->p_instance->GSR;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANBCR1 Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_bcr1(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_bcr1(p_obj->bcr1));
#endif
    p_obj->p_instance->BCR1 = p_obj->bcr1;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANBCR2 Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_bcr2(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_sjw(p_obj->bcr2.sjw));
    assert_param(check_param_sam(p_obj->bcr2.sam));
    assert_param(check_param_tseg2(p_obj->bcr2.tseg2));
    assert_param(check_param_tseg1(p_obj->bcr2.tseg1));
#endif
    p_obj->p_instance->BCR2 = (p_obj->bcr2.sjw | p_obj->bcr2.sam | 
                                p_obj->bcr2.tseg2  | p_obj->bcr2.tseg1);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANGIF Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_gif(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_rfpf(p_obj->gif.rfpf));
    assert_param(check_param_wuif(p_obj->gif.wuif));
    assert_param(check_param_rmlif(p_obj->gif.rmlif));
    assert_param(check_param_trmabf(p_obj->gif.trmabf));
    assert_param(check_param_tsoif(p_obj->gif.tsoif));
    assert_param(check_param_boif(p_obj->gif.boif));
    assert_param(check_param_epif(p_obj->gif.epif));
    assert_param(check_param_wlif(p_obj->gif.wlif));
#endif
    p_obj->p_instance->GIF = (p_obj->gif.rfpf | p_obj->gif.wuif | 
                                p_obj->gif.rmlif  | p_obj->gif.trmabf |
                                p_obj->gif.tsoif  | p_obj->gif.boif |
                                p_obj->gif.epif  | p_obj->gif.wlif);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANGIM Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_gim(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_rfpm(p_obj->gim.rfpm));
    assert_param(check_param_wuim(p_obj->gim.wuim));
    assert_param(check_param_rmlim(p_obj->gim.rmlim));
    assert_param(check_param_trmabf_mask(p_obj->gim.trmabf));
    assert_param(check_param_tsoim(p_obj->gim.tsoim));
    assert_param(check_param_boim(p_obj->gim.boim));
    assert_param(check_param_epim(p_obj->gim.epim));
    assert_param(check_param_wlim(p_obj->gim.wlim));
#endif
    p_obj->p_instance->GIM = (p_obj->gim.rfpm | p_obj->gim.wuim | 
                                p_obj->gim.rmlim  | p_obj->gim.trmabf |
                                p_obj->gim.tsoim  | p_obj->gim.boim |
                                p_obj->gim.epim  | p_obj->gim.wlim);
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMBTIF Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_mbtif(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_mbtif(p_obj->mbtif));
#endif
    p_obj->p_instance->MBTIF = p_obj->mbtif;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMBRIF Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_mbrif(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_mbrif(p_obj->mbrif));
#endif
    p_obj->p_instance->MBRIF = p_obj->mbrif;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANMBIM Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_mbim(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
#endif
    p_obj->p_instance->MBIM = p_obj->mbim;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANCDR Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_cdr(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_cdr(p_obj->cdr));
#endif
    p_obj->p_instance->CDR = p_obj->cdr;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANRFP Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_rfp(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_rfp(p_obj->rfp));
#endif
    p_obj->p_instance->RFP = p_obj->rfp;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result can_get_cec(can_t *p_obj, uint32_t *p_cec)
  * @brief  Get CEC.
  * @details  CEC bits.
  * | Bit   | Bit Symbol | Function                              |
  * | :---  | :---       | :---                                  |
  * | 31-16 | -          | -                                     |
  * | 15-8  | TEC        | TEC                                   |
  * | 7-0   | REC        | REC                                   |
  * 
  * @param[in] p_obj    :CAN object.
  * @param[out] p_cec   :CEC. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result can_get_cec(can_t *p_obj, uint32_t *p_cec)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_cec));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_cec = p_obj->p_instance->CEC;

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANCEC Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_cec(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_cec_tec(p_obj->cec.tec));
    assert_param(check_param_cec_rec(p_obj->cec.rec));
#endif
    p_obj->p_instance->CEC = (p_obj->cec.rec | (p_obj->cec.tec << 8U));
    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     CANTSP Value Setting
  * @param     p_obj :CAN object.
  * @retval    TXZ_SUCCESS :Success.
  * @retval    TXZ_ERROR :Failure.
  * @note      When p_obj is NULL, "Failure" is returned.
  * @note      An initial value of default is set at the
               reset status value. If needed, please
               rewrite and use an initial value.
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
TXZ_Result can_set_tsp(can_t *p_obj)
{
    TXZ_Result result = TXZ_SUCCESS;
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_tsp(p_obj->tsp));
#endif
    p_obj->p_instance->TSP = p_obj->tsp;
    return (result);
}

/*--------------------------------------------------*/
/**
  * @fn     TXZ_Result can_get_tsc(can_t *p_obj, uint16_t *p_tsc)
  * @brief  Get TSC.
  * @details  TSC bits.
  * | Bit   | Bit Symbol | Function                              |
  * | :---  | :---       | :---                                  |
  * | 31-16 | -          | -                                     |
  * | 15-0  | TSC        | TSC                                   |
  * 
  * @param[in] p_obj    :CAN object.
  * @param[out] p_tsc   :TSC. Destination address.
  * @retval TXZ_SUCCESS :Success.
  * @retval TXZ_ERROR   :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result can_get_tsc(can_t *p_obj, uint16_t *p_tsc)
{
    TXZ_Result result = TXZ_SUCCESS;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(IS_POINTER_NOT_NULL(p_tsc));
#endif
    /*------------------------------*/
    /*  Read Register               */
    /*------------------------------*/
    *p_tsc = p_obj->p_instance->TSC;

    return (result);
}
/**
 *  @}
 */ /* End of group CAN_Exported_functions */

/**
 *  @} 
 */ /* End of group CAN */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__CAN_B_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

