/** 
 *******************************************************************************
 * @file    can_b.h
 * @brief   This file provides all the functions prototypes for CAN driver.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __CAN_B_H
#define __CAN_B_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup CAN CAN
 *  @brief      CAN Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CAN_Exported_define CAN Exported Define
 *  @{
 */

/** 
 *  @defgroup CAN_NullPointer  Null Pointer
 *  @brief    Null Pointer.
 *  @{
 */
#define CAN_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group CAN_NullPointer */

/** 
 *  @defgroup CAN_ParameterResult  Parameter Check Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define CAN_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define CAN_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group CAN_ParameterResult */

/** 
 *  @defgroup CAN_LAMMax  Max Num of LAM
 *  @brief    Max Num of LAM.
 *  @{
 */
#define CANLAM_MAX             ((uint32_t)0x1FFFFFFF)      /*!< Max LAM. */
/**
 *  @}
 */ /* End of group CAN_LAMMax */

/** 
 *  @defgroup CAN_GAMMax  Max Num of GAM
 *  @brief    Max Num of GAM.
 *  @{
 */
#define CANGAM_MAX             ((uint32_t)0x1FFFFFFF)      /*!< Max GAM. */
/**
 *  @}
 */ /* End of group CAN_GAMMax */

/** 
 *  @defgroup CAN_MDMax  Max Num of MD
 *  @brief    Max Num of MD.
 *  @{
 */
#define CANMD_MAX             ((uint32_t)0x7FFFFFFF)      /*!< Max MD. */
/**
 *  @}
 */ /* End of group CAN_MDMax */

/** 
 *  @defgroup CAN_MBIDMax  Max Num of ID
 *  @brief    Max Num of ID.
 *  @{
 */
#define CANMBID_MAX             ((uint32_t)0x1FFFFFFF)      /*!< Max ID. */
/**
 *  @}
 */ /* End of group CAN_MBIDMax */

/** 
 *  @defgroup CAN_MBTSVMCF_TSVMax  Max Num of TSV
 *  @brief    Max Num of TSV.
 *  @{
 */
#define CANMBTSVMCF_TSV_MAX      ((uint32_t)0x0000FFFF)     /*!< Max TSV. */
/**
 *  @}
 */ /* End of group CAN_MBTSVMCF_TSVMax */

/** 
 *  @defgroup CAN_BCR1Max  Max Num of BCR1
 *  @brief    Max Num of BCR1.
 *  @{
 */
#define CANBCR1_MAX              ((uint16_t)1023)           /*!< Max BCR1. */
/**
 *  @}
 */ /* End of group CAN_BCR1Max */

/** 
 *  @defgroup CAN_TSPMax  Max Num of TSP
 *  @brief    Max Num of TSP.
 *  @{
 */
#define CANTSP_MAX                ((uint8_t)0xF)            /*!< Max TSP. */
/**
 *  @}
 */ /* End of group CAN_TSPMax */

/** 
 *  @defgroup CAN_CEC_TECMax  Max Num of CEC_TEC
 *  @brief    Max Num of CEC_TEC.
 *  @{
 */
#define CANCEC_TEC_MAX             ((uint8_t)0xFF)            /*!< Max TEC. */
/**
 *  @}
 */ /* End of group CAN_CEC_TECMax */

/** 
 *  @defgroup CAN_CEC_RECMax  Max Num of CEC_REC
 *  @brief    Max Num of CEC_REC.
 *  @{
 */
#define CANCEC_REC_MAX             ((uint8_t)0xFF)            /*!< Max REC. */
/**
 *  @}
 */ /* End of group CAN_CEC_RECMax */

/** 
 *  @defgroup CAN_TSCMax  Max Num of TSC
 *  @brief    Max Num of TSC.
 *  @{
 */
#define CANTSC_MAX                 ((uint16_t)0xFFFF)        /*!< Max TSC. */
/**
 *  @}
 */ /* End of group CAN_TSCMax */

/** 
 *  @defgroup CANMBID_IDE  CAN MBID Register
 *  @brief    CAN MBID Register Macro Definition.
 *  @{
 */
#define CANMBID_IDE_STANDARD       ((uint32_t)0x00000000)    /*!< CANMBID IDE standard */
#define CANMBID_IDE_EXPANSION      ((uint32_t)0x80000000)    /*!< CANMBID IDE expansion */
/**
 *  @}
 */ /* End of group CANMBID_IDE */

/** 
 *  @defgroup CANMBID_GAMELAME  CAN MBID Register
 *  @brief    CAN MBID Register Macro Definition.
 *  @{
 */
#define CANMBID_GAMELAME_DISABLE   ((uint32_t)0x00000000)    /*!< CANMBID GAMELAME disable */
#define CANMBID_GAMELAME_ENABLE    ((uint32_t)0x40000000)    /*!< CANMBID GAMELAME enable */
/**
 *  @}
 */ /* End of group CANMBID_GAMELAME */

/** 
 *  @defgroup CANMBID_RFH  CAN MBID Register
 *  @brief    CAN CMBID Register Macro Definition.
 *  @{
 */
#define CANMBID_RFH_NORES          ((uint32_t)0x00000000)    /*!< CANMBID RFH no res */
#define CANMBID_RFH_RES            ((uint32_t)0x20000000)    /*!< CANMBID RFH res */
/**
 *  @}
 */ /* End of group CANMBID_RFH */

/** 
 *  @defgroup CANMBTSVMCF_RTR  CAN MBTSVMCF Register
 *  @brief    CAN MBTSVMCF Register Macro Definition.
 *  @{
 */
#define CANMBTSVMCF_RTR_DATA       ((uint32_t)0x00000000)    /*!< CANMBTSVMCF RTR data */
#define CANMBTSVMCF_RTR_REMORT     ((uint32_t)0x00000010)    /*!< CANMBTSVMCF RTR remort */
/**
 *  @}
 */ /* End of group CANMBTSVMCF_RTR */

/** 
 *  @defgroup CANMBTSVMCF_DLC  CAN MBTSVMCF Register
 *  @brief    CAN MBTSVMCF Register Macro Definition.
 *  @{
 */
#define CANMBTSVMCF_DLC_0          ((uint32_t)0x00000000)    /*!< CANMBTSVMCF DLC 0byte */
#define CANMBTSVMCF_DLC_1          ((uint32_t)0x00000001)    /*!< CANMBTSVMCF DLC 1byte */
#define CANMBTSVMCF_DLC_2          ((uint32_t)0x00000002)    /*!< CANMBTSVMCF DLC 2byte */
#define CANMBTSVMCF_DLC_3          ((uint32_t)0x00000003)    /*!< CANMBTSVMCF DLC 3byte */
#define CANMBTSVMCF_DLC_4          ((uint32_t)0x00000004)    /*!< CANMBTSVMCF DLC 4byte */
#define CANMBTSVMCF_DLC_5          ((uint32_t)0x00000005)    /*!< CANMBTSVMCF DLC 5byte */
#define CANMBTSVMCF_DLC_6          ((uint32_t)0x00000006)    /*!< CANMBTSVMCF DLC 6byte */
#define CANMBTSVMCF_DLC_7          ((uint32_t)0x00000007)    /*!< CANMBTSVMCF DLC 7byte */
#define CANMBTSVMCF_DLC_8          ((uint32_t)0x00000008)    /*!< CANMBTSVMCF DLC 8byte */
/**
 *  @}
 */ /* End of group CANMBTSVMCF_DLC */

/** 
 *  @defgroup CANMC_MC  CAN MC Register
 *  @brief    CAN MC Register Macro Definition.
 *  @{
 */
#define CANMC_MC_MC0_ENABLE        ((uint32_t)0x00000001)    /*!< CANMC MC0 enable */
#define CANMC_MC_MC1_ENABLE        ((uint32_t)0x00000002)    /*!< CANMC MC1 enable */
#define CANMC_MC_MC2_ENABLE        ((uint32_t)0x00000004)    /*!< CANMC MC2 enable */
#define CANMC_MC_MC3_ENABLE        ((uint32_t)0x00000008)    /*!< CANMC MC3 enable */
#define CANMC_MC_MC4_ENABLE        ((uint32_t)0x00000010)    /*!< CANMC MC4 enable */
#define CANMC_MC_MC5_ENABLE        ((uint32_t)0x00000020)    /*!< CANMC MC5 enable */
#define CANMC_MC_MC6_ENABLE        ((uint32_t)0x00000040)    /*!< CANMC MC6 enable */
#define CANMC_MC_MC7_ENABLE        ((uint32_t)0x00000080)    /*!< CANMC MC7 enable */
#define CANMC_MC_MC8_ENABLE        ((uint32_t)0x00000100)    /*!< CANMC MC8 enable */
#define CANMC_MC_MC9_ENABLE        ((uint32_t)0x00000200)    /*!< CANMC MC9 enable */
#define CANMC_MC_MC10_ENABLE       ((uint32_t)0x00000400)    /*!< CANMC MC10 enable */
#define CANMC_MC_MC11_ENABLE       ((uint32_t)0x00000800)    /*!< CANMC MC11 enable */
#define CANMC_MC_MC12_ENABLE       ((uint32_t)0x00001000)    /*!< CANMC MC12 enable */
#define CANMC_MC_MC13_ENABLE       ((uint32_t)0x00002000)    /*!< CANMC MC13 enable */
#define CANMC_MC_MC14_ENABLE       ((uint32_t)0x00004000)    /*!< CANMC MC14 enable */
#define CANMC_MC_MC15_ENABLE       ((uint32_t)0x00008000)    /*!< CANMC MC15 enable */
#define CANMC_MC_MC16_ENABLE       ((uint32_t)0x00010000)    /*!< CANMC MC16 enable */
#define CANMC_MC_MC17_ENABLE       ((uint32_t)0x00020000)    /*!< CANMC MC17 enable */
#define CANMC_MC_MC18_ENABLE       ((uint32_t)0x00040000)    /*!< CANMC MC18 enable */
#define CANMC_MC_MC19_ENABLE       ((uint32_t)0x00080000)    /*!< CANMC MC19 enable */
#define CANMC_MC_MC20_ENABLE       ((uint32_t)0x00100000)    /*!< CANMC MC20 enable */
#define CANMC_MC_MC21_ENABLE       ((uint32_t)0x00200000)    /*!< CANMC MC21 enable */
#define CANMC_MC_MC22_ENABLE       ((uint32_t)0x00400000)    /*!< CANMC MC22 enable */
#define CANMC_MC_MC23_ENABLE       ((uint32_t)0x00800000)    /*!< CANMC MC23 enable */
#define CANMC_MC_MC24_ENABLE       ((uint32_t)0x01000000)    /*!< CANMC MC24 enable */
#define CANMC_MC_MC25_ENABLE       ((uint32_t)0x02000000)    /*!< CANMC MC25 enable */
#define CANMC_MC_MC26_ENABLE       ((uint32_t)0x04000000)    /*!< CANMC MC26 enable */
#define CANMC_MC_MC27_ENABLE       ((uint32_t)0x08000000)    /*!< CANMC MC27 enable */
#define CANMC_MC_MC28_ENABLE       ((uint32_t)0x10000000)    /*!< CANMC MC28 enable */
#define CANMC_MC_MC29_ENABLE       ((uint32_t)0x20000000)    /*!< CANMC MC29 enable */
#define CANMC_MC_MC30_ENABLE       ((uint32_t)0x40000000)    /*!< CANMC MC30 enable */
#define CANMC_MC_MC31_ENABLE       ((uint32_t)0x80000000)    /*!< CANMC MC31 enable */

#define CANMC_MC_MC0_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC0 disable */
#define CANMC_MC_MC1_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC1 disable */
#define CANMC_MC_MC2_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC2 disable */
#define CANMC_MC_MC3_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC3 disable */
#define CANMC_MC_MC4_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC4 disable */
#define CANMC_MC_MC5_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC5 disable */
#define CANMC_MC_MC6_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC6 disable */
#define CANMC_MC_MC7_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC7 disable */
#define CANMC_MC_MC8_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC8 disable */
#define CANMC_MC_MC9_DISABLE       ((uint32_t)0x00000000)    /*!< CANMC MC9 disable */
#define CANMC_MC_MC10_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC10 disable */
#define CANMC_MC_MC11_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC11 disable */
#define CANMC_MC_MC12_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC12 disable */
#define CANMC_MC_MC13_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC13 disable */
#define CANMC_MC_MC14_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC14 disable */
#define CANMC_MC_MC15_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC15 disable */
#define CANMC_MC_MC16_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC16 disable */
#define CANMC_MC_MC17_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC17 disable */
#define CANMC_MC_MC18_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC18 disable */
#define CANMC_MC_MC19_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC19 disable */
#define CANMC_MC_MC20_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC20 disable */
#define CANMC_MC_MC21_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC21 disable */
#define CANMC_MC_MC22_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC22 disable */
#define CANMC_MC_MC23_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC23 disable */
#define CANMC_MC_MC24_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC24 disable */
#define CANMC_MC_MC25_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC25 disable */
#define CANMC_MC_MC26_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC26 disable */
#define CANMC_MC_MC27_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC27 disable */
#define CANMC_MC_MC28_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC28 disable */
#define CANMC_MC_MC29_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC29 disable */
#define CANMC_MC_MC30_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC30 disable */
#define CANMC_MC_MC31_DISABLE      ((uint32_t)0x00000000)    /*!< CANMC MC31 disable */
/**
 *  @}
 */ /* End of group CANMC_MC */

/** 
 *  @defgroup CANMD_MD  CAN MD Register
 *  @brief    CAN MD Register Macro Definition.
 *  @{
 */
#define CANMD_MD0_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD0 trans */
#define CANMD_MD1_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD1 trans */
#define CANMD_MD2_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD2 trans */
#define CANMD_MD3_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD3 trans */
#define CANMD_MD4_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD4 trans */
#define CANMD_MD5_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD5 trans */
#define CANMD_MD6_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD6 trans */
#define CANMD_MD7_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD7 trans */
#define CANMD_MD8_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD8 trans */
#define CANMD_MD9_TRANS            ((uint32_t)0x00000000)    /*!< CANMD MD9 trans */
#define CANMD_MD10_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD10 trans */
#define CANMD_MD11_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD11 trans */
#define CANMD_MD12_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD12 trans */
#define CANMD_MD13_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD13 trans */
#define CANMD_MD14_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD14 trans */
#define CANMD_MD15_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD15 trans */
#define CANMD_MD16_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD16 trans */
#define CANMD_MD17_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD17 trans */
#define CANMD_MD18_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD18 trans */
#define CANMD_MD19_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD19 trans */
#define CANMD_MD20_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD20 trans */
#define CANMD_MD21_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD21 trans */
#define CANMD_MD22_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD22 trans */
#define CANMD_MD23_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD23 trans */
#define CANMD_MD24_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD24 trans */
#define CANMD_MD25_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD25 trans */
#define CANMD_MD26_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD26 trans */
#define CANMD_MD27_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD27 trans */
#define CANMD_MD28_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD28 trans */
#define CANMD_MD29_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD29 trans */
#define CANMD_MD30_TRANS           ((uint32_t)0x00000000)    /*!< CANMD MD30 trans */

#define CANMD_MD0_RECEIVE          ((uint32_t)0x00000001)    /*!< CANMD MD0 receive */
#define CANMD_MD1_RECEIVE          ((uint32_t)0x00000002)    /*!< CANMD MD1 receive */
#define CANMD_MD2_RECEIVE          ((uint32_t)0x00000004)    /*!< CANMD MD2 receive */
#define CANMD_MD3_RECEIVE          ((uint32_t)0x00000008)    /*!< CANMD MD3 receive */
#define CANMD_MD4_RECEIVE          ((uint32_t)0x00000010)    /*!< CANMD MD4 receive */
#define CANMD_MD5_RECEIVE          ((uint32_t)0x00000020)    /*!< CANMD MD5 receive */
#define CANMD_MD6_RECEIVE          ((uint32_t)0x00000040)    /*!< CANMD MD6 receive */
#define CANMD_MD7_RECEIVE          ((uint32_t)0x00000080)    /*!< CANMD MD7 receive */
#define CANMD_MD8_RECEIVE          ((uint32_t)0x00000100)    /*!< CANMD MD8 receive */
#define CANMD_MD9_RECEIVE          ((uint32_t)0x00000200)    /*!< CANMD MD9 receive */
#define CANMD_MD10_RECEIVE         ((uint32_t)0x00000400)    /*!< CANMD MD10 receive */
#define CANMD_MD11_RECEIVE         ((uint32_t)0x00000800)    /*!< CANMD MD11 receive */
#define CANMD_MD12_RECEIVE         ((uint32_t)0x00001000)    /*!< CANMD MD12 receive */
#define CANMD_MD13_RECEIVE         ((uint32_t)0x00002000)    /*!< CANMD MD13 receive */
#define CANMD_MD14_RECEIVE         ((uint32_t)0x00004000)    /*!< CANMD MD14 receive */
#define CANMD_MD15_RECEIVE         ((uint32_t)0x00008000)    /*!< CANMD MD15 receive */
#define CANMD_MD16_RECEIVE         ((uint32_t)0x00010000)    /*!< CANMD MD16 receive */
#define CANMD_MD17_RECEIVE         ((uint32_t)0x00020000)    /*!< CANMD MD17 receive */
#define CANMD_MD18_RECEIVE         ((uint32_t)0x00040000)    /*!< CANMD MD18 receive */
#define CANMD_MD19_RECEIVE         ((uint32_t)0x00080000)    /*!< CANMD MD19 receive */
#define CANMD_MD20_RECEIVE         ((uint32_t)0x00100000)    /*!< CANMD MD20 receive */
#define CANMD_MD21_RECEIVE         ((uint32_t)0x00200000)    /*!< CANMD MD21 receive */
#define CANMD_MD22_RECEIVE         ((uint32_t)0x00400000)    /*!< CANMD MD22 receive */
#define CANMD_MD23_RECEIVE         ((uint32_t)0x00800000)    /*!< CANMD MD23 receive */
#define CANMD_MD24_RECEIVE         ((uint32_t)0x01000000)    /*!< CANMD MD24 receive */
#define CANMD_MD25_RECEIVE         ((uint32_t)0x02000000)    /*!< CANMD MD25 receive */
#define CANMD_MD26_RECEIVE         ((uint32_t)0x04000000)    /*!< CANMD MD26 receive */
#define CANMD_MD27_RECEIVE         ((uint32_t)0x08000000)    /*!< CANMD MD27 receive */
#define CANMD_MD28_RECEIVE         ((uint32_t)0x10000000)    /*!< CANMD MD28 receive */
#define CANMD_MD29_RECEIVE         ((uint32_t)0x20000000)    /*!< CANMD MD29 receive */
#define CANMD_MD30_RECEIVE         ((uint32_t)0x40000000)    /*!< CANMD MD30 receive */
/**
 *  @}
 */ /* End of group CANMD_MD */

/** 
 *  @defgroup CANTRS_TRS  CAN TRS Register
 *  @brief    CAN TRS Register Macro Definition.
 *  @{
 */
#define CANTRS_TRS_TRS0REQ         ((uint32_t)0x00000001)    /*!< CANTRS TRS0 req */
#define CANTRS_TRS_TRS1REQ         ((uint32_t)0x00000002)    /*!< CANTRS TRS1 req */
#define CANTRS_TRS_TRS2REQ         ((uint32_t)0x00000004)    /*!< CANTRS TRS2 req */
#define CANTRS_TRS_TRS3REQ         ((uint32_t)0x00000008)    /*!< CANTRS TRS3 req */
#define CANTRS_TRS_TRS4REQ         ((uint32_t)0x00000010)    /*!< CANTRS TRS4 req */
#define CANTRS_TRS_TRS5REQ         ((uint32_t)0x00000020)    /*!< CANTRS TRS5 req */
#define CANTRS_TRS_TRS6REQ         ((uint32_t)0x00000040)    /*!< CANTRS TRS6 req */
#define CANTRS_TRS_TRS7REQ         ((uint32_t)0x00000080)    /*!< CANTRS TRS7 req */
#define CANTRS_TRS_TRS8REQ         ((uint32_t)0x00000100)    /*!< CANTRS TRS8 req */
#define CANTRS_TRS_TRS9REQ         ((uint32_t)0x00000200)    /*!< CANTRS TRS9 req */
#define CANTRS_TRS_TRS10REQ        ((uint32_t)0x00000400)    /*!< CANTRS TRS10 req */
#define CANTRS_TRS_TRS11REQ        ((uint32_t)0x00000800)    /*!< CANTRS TRS11 req */
#define CANTRS_TRS_TRS12REQ        ((uint32_t)0x00001000)    /*!< CANTRS TRS12 req */
#define CANTRS_TRS_TRS13REQ        ((uint32_t)0x00002000)    /*!< CANTRS TRS13 req */
#define CANTRS_TRS_TRS14REQ        ((uint32_t)0x00004000)    /*!< CANTRS TRS14 req */
#define CANTRS_TRS_TRS15REQ        ((uint32_t)0x00008000)    /*!< CANTRS TRS15 req */
#define CANTRS_TRS_TRS16REQ        ((uint32_t)0x00010000)    /*!< CANTRS TRS16 req */
#define CANTRS_TRS_TRS17REQ        ((uint32_t)0x00020000)    /*!< CANTRS TRS17 req */
#define CANTRS_TRS_TRS18REQ        ((uint32_t)0x00040000)    /*!< CANTRS TRS18 req */
#define CANTRS_TRS_TRS19REQ        ((uint32_t)0x00080000)    /*!< CANTRS TRS19 req */
#define CANTRS_TRS_TRS20REQ        ((uint32_t)0x00100000)    /*!< CANTRS TRS20 req */
#define CANTRS_TRS_TRS21REQ        ((uint32_t)0x00200000)    /*!< CANTRS TRS21 req */
#define CANTRS_TRS_TRS22REQ        ((uint32_t)0x00400000)    /*!< CANTRS TRS22 req */
#define CANTRS_TRS_TRS23REQ        ((uint32_t)0x00800000)    /*!< CANTRS TRS23 req */
#define CANTRS_TRS_TRS24REQ        ((uint32_t)0x01000000)    /*!< CANTRS TRS24 req */
#define CANTRS_TRS_TRS25REQ        ((uint32_t)0x02000000)    /*!< CANTRS TRS25 req */
#define CANTRS_TRS_TRS26REQ        ((uint32_t)0x04000000)    /*!< CANTRS TRS26 req */
#define CANTRS_TRS_TRS27REQ        ((uint32_t)0x08000000)    /*!< CANTRS TRS27 req */
#define CANTRS_TRS_TRS28REQ        ((uint32_t)0x10000000)    /*!< CANTRS TRS28 req */
#define CANTRS_TRS_TRS29REQ        ((uint32_t)0x20000000)    /*!< CANTRS TRS29 req */
#define CANTRS_TRS_TRS30REQ        ((uint32_t)0x40000000)    /*!< CANTRS TRS30 req */
/**
 *  @}
 */ /* End of group CANTRS_TRS */

/** 
 *  @defgroup CANTRR_TRR  CAN TRR Register
 *  @brief    CAN TRR Register Macro Definition.
 *  @{
 */
#define CANTRR_TRR_TRR0REQ         ((uint32_t)0x00000001)    /*!< CANTRR TRR0 req */
#define CANTRR_TRR_TRR1REQ         ((uint32_t)0x00000002)    /*!< CANTRR TRR1 req */
#define CANTRR_TRR_TRR2REQ         ((uint32_t)0x00000004)    /*!< CANTRR TRR2 req */
#define CANTRR_TRR_TRR3REQ         ((uint32_t)0x00000008)    /*!< CANTRR TRR3 req */
#define CANTRR_TRR_TRR4REQ         ((uint32_t)0x00000010)    /*!< CANTRR TRR4 req */
#define CANTRR_TRR_TRR5REQ         ((uint32_t)0x00000020)    /*!< CANTRR TRR5 req */
#define CANTRR_TRR_TRR6REQ         ((uint32_t)0x00000040)    /*!< CANTRR TRR6 req */
#define CANTRR_TRR_TRR7REQ         ((uint32_t)0x00000080)    /*!< CANTRR TRR7 req */
#define CANTRR_TRR_TRR8REQ         ((uint32_t)0x00000100)    /*!< CANTRR TRR8 req */
#define CANTRR_TRR_TRR9REQ         ((uint32_t)0x00000200)    /*!< CANTRR TRR9 req */
#define CANTRR_TRR_TRR10REQ        ((uint32_t)0x00000400)    /*!< CANTRR TRR10 req */
#define CANTRR_TRR_TRR11REQ        ((uint32_t)0x00000800)    /*!< CANTRR TRR11 req */
#define CANTRR_TRR_TRR12REQ        ((uint32_t)0x00001000)    /*!< CANTRR TRR12 req */
#define CANTRR_TRR_TRR13REQ        ((uint32_t)0x00002000)    /*!< CANTRR TRR13 req */
#define CANTRR_TRR_TRR14REQ        ((uint32_t)0x00004000)    /*!< CANTRR TRR14 req */
#define CANTRR_TRR_TRR15REQ        ((uint32_t)0x00008000)    /*!< CANTRR TRR15 req */
#define CANTRR_TRR_TRR16REQ        ((uint32_t)0x00010000)    /*!< CANTRR TRR16 req */
#define CANTRR_TRR_TRR17REQ        ((uint32_t)0x00020000)    /*!< CANTRR TRR17 req */
#define CANTRR_TRR_TRR18REQ        ((uint32_t)0x00040000)    /*!< CANTRR TRR18 req */
#define CANTRR_TRR_TRR19REQ        ((uint32_t)0x00080000)    /*!< CANTRR TRR19 req */
#define CANTRR_TRR_TRR20REQ        ((uint32_t)0x00100000)    /*!< CANTRR TRR20 req */
#define CANTRR_TRR_TRR21REQ        ((uint32_t)0x00200000)    /*!< CANTRR TRR21 req */
#define CANTRR_TRR_TRR22REQ        ((uint32_t)0x00400000)    /*!< CANTRR TRR22 req */
#define CANTRR_TRR_TRR23REQ        ((uint32_t)0x00800000)    /*!< CANTRR TRR23 req */
#define CANTRR_TRR_TRR24REQ        ((uint32_t)0x01000000)    /*!< CANTRR TRR24 req */
#define CANTRR_TRR_TRR25REQ        ((uint32_t)0x02000000)    /*!< CANTRR TRR25 req */
#define CANTRR_TRR_TRR26REQ        ((uint32_t)0x04000000)    /*!< CANTRR TRR26 req */
#define CANTRR_TRR_TRR27REQ        ((uint32_t)0x08000000)    /*!< CANTRR TRR27 req */
#define CANTRR_TRR_TRR28REQ        ((uint32_t)0x10000000)    /*!< CANTRR TRR28 req */
#define CANTRR_TRR_TRR29REQ        ((uint32_t)0x20000000)    /*!< CANTRR TRR29 req */
#define CANTRR_TRR_TRR30REQ        ((uint32_t)0x40000000)    /*!< CANTRR TRR30 req */
/**
 *  @}
 */ /* End of group CANTRR_TRR */

/** 
 *  @defgroup CANTA_TA  CAN TA Register
 *  @brief    CAN TA Register Macro Definition.
 *  @{
 */
#define CANTA_TA_TA0CLR            ((uint32_t)0x00000001)    /*!< CANTA TA0 clear */
#define CANTA_TA_TA1CLR            ((uint32_t)0x00000002)    /*!< CANTA TA1 clear */
#define CANTA_TA_TA2CLR            ((uint32_t)0x00000004)    /*!< CANTA TA2 clear */
#define CANTA_TA_TA3CLR            ((uint32_t)0x00000008)    /*!< CANTA TA3 clear */
#define CANTA_TA_TA4CLR            ((uint32_t)0x00000010)    /*!< CANTA TA4 clear */
#define CANTA_TA_TA5CLR            ((uint32_t)0x00000020)    /*!< CANTA TA5 clear */
#define CANTA_TA_TA6CLR            ((uint32_t)0x00000040)    /*!< CANTA TA6 clear */
#define CANTA_TA_TA7CLR            ((uint32_t)0x00000080)    /*!< CANTA TA7 clear */
#define CANTA_TA_TA8CLR            ((uint32_t)0x00000100)    /*!< CANTA TA8 clear */
#define CANTA_TA_TA9CLR            ((uint32_t)0x00000200)    /*!< CANTA TA9 clear */
#define CANTA_TA_TA10CLR           ((uint32_t)0x00000400)    /*!< CANTA TA10 clear */
#define CANTA_TA_TA11CLR           ((uint32_t)0x00000800)    /*!< CANTA TA11 clear */
#define CANTA_TA_TA12CLR           ((uint32_t)0x00001000)    /*!< CANTA TA12 clear */
#define CANTA_TA_TA13CLR           ((uint32_t)0x00002000)    /*!< CANTA TA13 clear */
#define CANTA_TA_TA14CLR           ((uint32_t)0x00004000)    /*!< CANTA TA14 clear */
#define CANTA_TA_TA15CLR           ((uint32_t)0x00008000)    /*!< CANTA TA15 clear */
#define CANTA_TA_TA16CLR           ((uint32_t)0x00010000)    /*!< CANTA TA16 clear */
#define CANTA_TA_TA17CLR           ((uint32_t)0x00020000)    /*!< CANTA TA17 clear */
#define CANTA_TA_TA18CLR           ((uint32_t)0x00040000)    /*!< CANTA TA18 clear */
#define CANTA_TA_TA19CLR           ((uint32_t)0x00080000)    /*!< CANTA TA19 clear */
#define CANTA_TA_TA20CLR           ((uint32_t)0x00100000)    /*!< CANTA TA20 clear */
#define CANTA_TA_TA21CLR           ((uint32_t)0x00200000)    /*!< CANTA TA21 clear */
#define CANTA_TA_TA22CLR           ((uint32_t)0x00400000)    /*!< CANTA TA22 clear */
#define CANTA_TA_TA23CLR           ((uint32_t)0x00800000)    /*!< CANTA TA23 clear */
#define CANTA_TA_TA24CLR           ((uint32_t)0x01000000)    /*!< CANTA TA24 clear */
#define CANTA_TA_TA25CLR           ((uint32_t)0x02000000)    /*!< CANTA TA25 clear */
#define CANTA_TA_TA26CLR           ((uint32_t)0x04000000)    /*!< CANTA TA26 clear */
#define CANTA_TA_TA27CLR           ((uint32_t)0x08000000)    /*!< CANTA TA27 clear */
#define CANTA_TA_TA28CLR           ((uint32_t)0x10000000)    /*!< CANTA TA28 clear */
#define CANTA_TA_TA29CLR           ((uint32_t)0x20000000)    /*!< CANTA TA29 clear */
#define CANTA_TA_TA30CLR           ((uint32_t)0x40000000)    /*!< CANTA TA30 clear */
/**
 *  @}
 */ /* End of group CANTA_TA */

/** 
 *  @defgroup CANAA_AA  CAN AA Register
 *  @brief    CAN AA Register Macro Definition.
 *  @{
 */
#define CANAA_AA_AA0CLR            ((uint32_t)0x00000001)    /*!< CANAA AA0 clear */
#define CANAA_AA_AA1CLR            ((uint32_t)0x00000002)    /*!< CANAA AA1 clear */
#define CANAA_AA_AA2CLR            ((uint32_t)0x00000004)    /*!< CANAA AA2 clear */
#define CANAA_AA_AA3CLR            ((uint32_t)0x00000008)    /*!< CANAA AA3 clear */
#define CANAA_AA_AA4CLR            ((uint32_t)0x00000010)    /*!< CANAA AA4 clear */
#define CANAA_AA_AA5CLR            ((uint32_t)0x00000020)    /*!< CANAA AA5 clear */
#define CANAA_AA_AA6CLR            ((uint32_t)0x00000040)    /*!< CANAA AA6 clear */
#define CANAA_AA_AA7CLR            ((uint32_t)0x00000080)    /*!< CANAA AA7 clear */
#define CANAA_AA_AA8CLR            ((uint32_t)0x00000100)    /*!< CANAA AA8 clear */
#define CANAA_AA_AA9CLR            ((uint32_t)0x00000200)    /*!< CANAA AA9 clear */
#define CANAA_AA_AA10CLR           ((uint32_t)0x00000400)    /*!< CANAA AA10 clear */
#define CANAA_AA_AA11CLR           ((uint32_t)0x00000800)    /*!< CANAA AA11 clear */
#define CANAA_AA_AA12CLR           ((uint32_t)0x00001000)    /*!< CANAA AA12 clear */
#define CANAA_AA_AA13CLR           ((uint32_t)0x00002000)    /*!< CANAA AA13 clear */
#define CANAA_AA_AA14CLR           ((uint32_t)0x00004000)    /*!< CANAA AA14 clear */
#define CANAA_AA_AA15CLR           ((uint32_t)0x00008000)    /*!< CANAA AA15 clear */
#define CANAA_AA_AA16CLR           ((uint32_t)0x00010000)    /*!< CANAA AA16 clear */
#define CANAA_AA_AA17CLR           ((uint32_t)0x00020000)    /*!< CANAA AA17 clear */
#define CANAA_AA_AA18CLR           ((uint32_t)0x00040000)    /*!< CANAA AA18 clear */
#define CANAA_AA_AA19CLR           ((uint32_t)0x00080000)    /*!< CANAA AA19 clear */
#define CANAA_AA_AA20CLR           ((uint32_t)0x00100000)    /*!< CANAA AA20 clear */
#define CANAA_AA_AA21CLR           ((uint32_t)0x00200000)    /*!< CANAA AA21 clear */
#define CANAA_AA_AA22CLR           ((uint32_t)0x00400000)    /*!< CANAA AA22 clear */
#define CANAA_AA_AA23CLR           ((uint32_t)0x00800000)    /*!< CANAA AA23 clear */
#define CANAA_AA_AA24CLR           ((uint32_t)0x01000000)    /*!< CANAA AA24 clear */
#define CANAA_AA_AA25CLR           ((uint32_t)0x02000000)    /*!< CANAA AA25 clear */
#define CANAA_AA_AA26CLR           ((uint32_t)0x04000000)    /*!< CANAA AA26 clear */
#define CANAA_AA_AA27CLR           ((uint32_t)0x08000000)    /*!< CANAA AA27 clear */
#define CANAA_AA_AA28CLR           ((uint32_t)0x10000000)    /*!< CANAA AA28 clear */
#define CANAA_AA_AA29CLR           ((uint32_t)0x20000000)    /*!< CANAA AA29 clear */
#define CANAA_AA_AA30CLR           ((uint32_t)0x40000000)    /*!< CANAA AA30 clear */
/**
 *  @}
 */ /* End of group CANAA_AA */

/** 
 *  @defgroup CANRMP_RMP  CAN RMP Register
 *  @brief    CAN RMP Register Macro Definition.
 *  @{
 */
#define CANRMP_RMP_RMP0CLR         ((uint32_t)0x00000001)    /*!< CANRMP RMP0 clear */
#define CANRMP_RMP_RMP1CLR         ((uint32_t)0x00000002)    /*!< CANRMP RMP1 clear */
#define CANRMP_RMP_RMP2CLR         ((uint32_t)0x00000004)    /*!< CANRMP RMP2 clear */
#define CANRMP_RMP_RMP3CLR         ((uint32_t)0x00000008)    /*!< CANRMP RMP3 clear */
#define CANRMP_RMP_RMP4CLR         ((uint32_t)0x00000010)    /*!< CANRMP RMP4 clear */
#define CANRMP_RMP_RMP5CLR         ((uint32_t)0x00000020)    /*!< CANRMP RMP5 clear */
#define CANRMP_RMP_RMP6CLR         ((uint32_t)0x00000040)    /*!< CANRMP RMP6 clear */
#define CANRMP_RMP_RMP7CLR         ((uint32_t)0x00000080)    /*!< CANRMP RMP7 clear */
#define CANRMP_RMP_RMP8CLR         ((uint32_t)0x00000100)    /*!< CANRMP RMP8 clear */
#define CANRMP_RMP_RMP9CLR         ((uint32_t)0x00000200)    /*!< CANRMP RMP9 clear */
#define CANRMP_RMP_RMP10CLR        ((uint32_t)0x00000400)    /*!< CANRMP RMP10 clear */
#define CANRMP_RMP_RMP11CLR        ((uint32_t)0x00000800)    /*!< CANRMP RMP11 clear */
#define CANRMP_RMP_RMP12CLR        ((uint32_t)0x00001000)    /*!< CANRMP RMP12 clear */
#define CANRMP_RMP_RMP13CLR        ((uint32_t)0x00002000)    /*!< CANRMP RMP13 clear */
#define CANRMP_RMP_RMP14CLR        ((uint32_t)0x00004000)    /*!< CANRMP RMP14 clear */
#define CANRMP_RMP_RMP15CLR        ((uint32_t)0x00008000)    /*!< CANRMP RMP15 clear */
#define CANRMP_RMP_RMP16CLR        ((uint32_t)0x00010000)    /*!< CANRMP RMP16 clear */
#define CANRMP_RMP_RMP17CLR        ((uint32_t)0x00020000)    /*!< CANRMP RMP17 clear */
#define CANRMP_RMP_RMP18CLR        ((uint32_t)0x00040000)    /*!< CANRMP RMP18 clear */
#define CANRMP_RMP_RMP19CLR        ((uint32_t)0x00080000)    /*!< CANRMP RMP19 clear */
#define CANRMP_RMP_RMP20CLR        ((uint32_t)0x00100000)    /*!< CANRMP RMP20 clear */
#define CANRMP_RMP_RMP21CLR        ((uint32_t)0x00200000)    /*!< CANRMP RMP21 clear */
#define CANRMP_RMP_RMP22CLR        ((uint32_t)0x00400000)    /*!< CANRMP RMP22 clear */
#define CANRMP_RMP_RMP23CLR        ((uint32_t)0x00800000)    /*!< CANRMP RMP23 clear */
#define CANRMP_RMP_RMP24CLR        ((uint32_t)0x01000000)    /*!< CANRMP RMP24 clear */
#define CANRMP_RMP_RMP25CLR        ((uint32_t)0x02000000)    /*!< CANRMP RMP25 clear */
#define CANRMP_RMP_RMP26CLR        ((uint32_t)0x04000000)    /*!< CANRMP RMP26 clear */
#define CANRMP_RMP_RMP27CLR        ((uint32_t)0x08000000)    /*!< CANRMP RMP27 clear */
#define CANRMP_RMP_RMP28CLR        ((uint32_t)0x10000000)    /*!< CANRMP RMP28 clear */
#define CANRMP_RMP_RMP29CLR        ((uint32_t)0x20000000)    /*!< CANRMP RMP29 clear */
#define CANRMP_RMP_RMP30CLR        ((uint32_t)0x40000000)    /*!< CANRMP RMP30 clear */
#define CANRMP_RMP_RMP31CLR        ((uint32_t)0x80000000)    /*!< CANRMP RMP31 clear */
/**
 *  @}
 */ /* End of group CANRMP_RMP */

/** 
 *  @defgroup CANRML_RML  CAN RML Register
 *  @brief    CAN RML Register Macro Definition.
 *  @{
 */
#define CANRML_RML_RML0CLR         ((uint32_t)0x00000001)    /*!< CANRML RML0 clear */
#define CANRML_RML_RML1CLR         ((uint32_t)0x00000002)    /*!< CANRML RML1 clear */
#define CANRML_RML_RML2CLR         ((uint32_t)0x00000004)    /*!< CANRML RML2 clear */
#define CANRML_RML_RML3CLR         ((uint32_t)0x00000008)    /*!< CANRML RML3 clear */
#define CANRML_RML_RML4CLR         ((uint32_t)0x00000010)    /*!< CANRML RML4 clear */
#define CANRML_RML_RML5CLR         ((uint32_t)0x00000020)    /*!< CANRML RML5 clear */
#define CANRML_RML_RML6CLR         ((uint32_t)0x00000040)    /*!< CANRML RML6 clear */
#define CANRML_RML_RML7CLR         ((uint32_t)0x00000080)    /*!< CANRML RML7 clear */
#define CANRML_RML_RML8CLR         ((uint32_t)0x00000100)    /*!< CANRML RML8 clear */
#define CANRML_RML_RML9CLR         ((uint32_t)0x00000200)    /*!< CANRML RML9 clear */
#define CANRML_RML_RML10CLR        ((uint32_t)0x00000400)    /*!< CANRML RML10 clear */
#define CANRML_RML_RML11CLR        ((uint32_t)0x00000800)    /*!< CANRML RML11 clear */
#define CANRML_RML_RML12CLR        ((uint32_t)0x00001000)    /*!< CANRML RML12 clear */
#define CANRML_RML_RML13CLR        ((uint32_t)0x00002000)    /*!< CANRML RML13 clear */
#define CANRML_RML_RML14CLR        ((uint32_t)0x00004000)    /*!< CANRML RML14 clear */
#define CANRML_RML_RML15CLR        ((uint32_t)0x00008000)    /*!< CANRML RML15 clear */
#define CANRML_RML_RML16CLR        ((uint32_t)0x00010000)    /*!< CANRML RML16 clear */
#define CANRML_RML_RML17CLR        ((uint32_t)0x00020000)    /*!< CANRML RML17 clear */
#define CANRML_RML_RML18CLR        ((uint32_t)0x00040000)    /*!< CANRML RML18 clear */
#define CANRML_RML_RML19CLR        ((uint32_t)0x00080000)    /*!< CANRML RML19 clear */
#define CANRML_RML_RML20CLR        ((uint32_t)0x00100000)    /*!< CANRML RML20 clear */
#define CANRML_RML_RML21CLR        ((uint32_t)0x00200000)    /*!< CANRML RML21 clear */
#define CANRML_RML_RML22CLR        ((uint32_t)0x00400000)    /*!< CANRML RML22 clear */
#define CANRML_RML_RML23CLR        ((uint32_t)0x00800000)    /*!< CANRML RML23 clear */
#define CANRML_RML_RML24CLR        ((uint32_t)0x01000000)    /*!< CANRML RML24 clear */
#define CANRML_RML_RML25CLR        ((uint32_t)0x02000000)    /*!< CANRML RML25 clear */
#define CANRML_RML_RML26CLR        ((uint32_t)0x04000000)    /*!< CANRML RML26 clear */
#define CANRML_RML_RML27CLR        ((uint32_t)0x08000000)    /*!< CANRML RML27 clear */
#define CANRML_RML_RML28CLR        ((uint32_t)0x10000000)    /*!< CANRML RML28 clear */
#define CANRML_RML_RML29CLR        ((uint32_t)0x20000000)    /*!< CANRML RML29 clear */
#define CANRML_RML_RML30CLR        ((uint32_t)0x40000000)    /*!< CANRML RML30 clear */
#define CANRML_RML_RML31CLR        ((uint32_t)0x80000000)    /*!< CANRML RML31 clear */
/**
 *  @}
 */ /* End of group CANRML_RML */

/** 
 *  @defgroup CANLAM_LAMI  CAN LAM Register
 *  @brief    CAN LAM Register Macro Definition.
 *  @{
 */
#define CANLAM_LAMI_LAMIMASK        ((uint32_t)0x80000000)    /*!< CANLAM LAMI mask */
#define CANLAM_LAMI_LAMINOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAMI no mask */
/**
 *  @}
 */ /* End of group CANLAM_LAMI */

/** 
 *  @defgroup CANLAM_LAM  CAN LAM Register
 *  @brief    CAN LAM Register Macro Definition.
 *  @{
 */
#define CANLAM_LAM_LAM0MASK         ((uint32_t)0x00000001)    /*!< CANLAM LAM LAM0 mask */
#define CANLAM_LAM_LAM1MASK         ((uint32_t)0x00000002)    /*!< CANLAM LAM LAM1 mask */
#define CANLAM_LAM_LAM2MASK         ((uint32_t)0x00000004)    /*!< CANLAM LAM LAM2 mask */
#define CANLAM_LAM_LAM3MASK         ((uint32_t)0x00000008)    /*!< CANLAM LAM LAM3 mask */
#define CANLAM_LAM_LAM4MASK         ((uint32_t)0x00000010)    /*!< CANLAM LAM LAM4 mask */
#define CANLAM_LAM_LAM5MASK         ((uint32_t)0x00000020)    /*!< CANLAM LAM LAM5 mask */
#define CANLAM_LAM_LAM6MASK         ((uint32_t)0x00000040)    /*!< CANLAM LAM LAM6 mask */
#define CANLAM_LAM_LAM7MASK         ((uint32_t)0x00000080)    /*!< CANLAM LAM LAM7 mask */
#define CANLAM_LAM_LAM8MASK         ((uint32_t)0x00000100)    /*!< CANLAM LAM LAM8 mask */
#define CANLAM_LAM_LAM9MASK         ((uint32_t)0x00000200)    /*!< CANLAM LAM LAM9 mask */
#define CANLAM_LAM_LAM10MASK        ((uint32_t)0x00000400)    /*!< CANLAM LAM LAM10 mask */
#define CANLAM_LAM_LAM11MASK        ((uint32_t)0x00000800)    /*!< CANLAM LAM LAM11 mask */
#define CANLAM_LAM_LAM12MASK        ((uint32_t)0x00001000)    /*!< CANLAM LAM LAM12 mask */
#define CANLAM_LAM_LAM13MASK        ((uint32_t)0x00002000)    /*!< CANLAM LAM LAM13 mask */
#define CANLAM_LAM_LAM14MASK        ((uint32_t)0x00004000)    /*!< CANLAM LAM LAM14 mask */
#define CANLAM_LAM_LAM15MASK        ((uint32_t)0x00008000)    /*!< CANLAM LAM LAM15 mask */
#define CANLAM_LAM_LAM16MASK        ((uint32_t)0x00010000)    /*!< CANLAM LAM LAM16 mask */
#define CANLAM_LAM_LAM17MASK        ((uint32_t)0x00020000)    /*!< CANLAM LAM LAM17 mask */
#define CANLAM_LAM_LAM18MASK        ((uint32_t)0x00040000)    /*!< CANLAM LAM LAM18 mask */
#define CANLAM_LAM_LAM19MASK        ((uint32_t)0x00080000)    /*!< CANLAM LAM LAM19 mask */
#define CANLAM_LAM_LAM20MASK        ((uint32_t)0x00100000)    /*!< CANLAM LAM LAM20 mask */
#define CANLAM_LAM_LAM21MASK        ((uint32_t)0x00200000)    /*!< CANLAM LAM LAM21 mask */
#define CANLAM_LAM_LAM22MASK        ((uint32_t)0x00400000)    /*!< CANLAM LAM LAM22 mask */
#define CANLAM_LAM_LAM23MASK        ((uint32_t)0x00800000)    /*!< CANLAM LAM LAM23 mask */
#define CANLAM_LAM_LAM24MASK        ((uint32_t)0x01000000)    /*!< CANLAM LAM LAM24 mask */
#define CANLAM_LAM_LAM25MASK        ((uint32_t)0x02000000)    /*!< CANLAM LAM LAM25 mask */
#define CANLAM_LAM_LAM26MASK        ((uint32_t)0x04000000)    /*!< CANLAM LAM LAM26 mask */
#define CANLAM_LAM_LAM27MASK        ((uint32_t)0x08000000)    /*!< CANLAM LAM LAM27 mask */
#define CANLAM_LAM_LAM28MASK        ((uint32_t)0x10000000)    /*!< CANLAM LAM LAM28 mask */

#define CANLAM_LAM_LAM0NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM0 no mask */
#define CANLAM_LAM_LAM1NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM1 no mask */
#define CANLAM_LAM_LAM2NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM2 no mask */
#define CANLAM_LAM_LAM3NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM3 no mask */
#define CANLAM_LAM_LAM4NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM4 no mask */
#define CANLAM_LAM_LAM5NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM5 no mask */
#define CANLAM_LAM_LAM6NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM6 no mask */
#define CANLAM_LAM_LAM7NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM7 no mask */
#define CANLAM_LAM_LAM8NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM8 no mask */
#define CANLAM_LAM_LAM9NOMASK       ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM9 no mask */
#define CANLAM_LAM_LAM10NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM10 no mask */
#define CANLAM_LAM_LAM11NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM11 no mask */
#define CANLAM_LAM_LAM12NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM12 no mask */
#define CANLAM_LAM_LAM13NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM13 no mask */
#define CANLAM_LAM_LAM14NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM14 no mask */
#define CANLAM_LAM_LAM15NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM15 no mask */
#define CANLAM_LAM_LAM16NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM16 no mask */
#define CANLAM_LAM_LAM17NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM17 no mask */
#define CANLAM_LAM_LAM18NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM18 no mask */
#define CANLAM_LAM_LAM19NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM19 no mask */
#define CANLAM_LAM_LAM20NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM20 no mask */
#define CANLAM_LAM_LAM21NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM21 no mask */
#define CANLAM_LAM_LAM22NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM22 no mask */
#define CANLAM_LAM_LAM23NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM23 no mask */
#define CANLAM_LAM_LAM24NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM24 no mask */
#define CANLAM_LAM_LAM25NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM25 no mask */
#define CANLAM_LAM_LAM26NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM26 no mask */
#define CANLAM_LAM_LAM27NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM27 no mask */
#define CANLAM_LAM_LAM28NOMASK      ((uint32_t)0x00000000)    /*!< CANLAM LAM LAM28 no mask */
/**
 *  @}
 */ /* End of group CANLAM_LAM */

/** 
 *  @defgroup CANGAM_GAMI  CAN GAM Register
 *  @brief    CAN GAM Register Macro Definition.
 *  @{
 */
#define CANGAM_GAMI_GAMIMASK        ((uint32_t)0x80000000)    /*!< CANGAM GAMI mask */
#define CANGAM_GAMI_GAMINOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAMI no mask */
/**
 *  @}
 */ /* End of group CANGAM_GAMI */

/** 
 *  @defgroup CANGAM_GAM  CAN GAM Register
 *  @brief    CAN GAM Register Macro Definition.
 *  @{
 */
#define CANGAM_GAM_GAM0MASK         ((uint32_t)0x00000001)    /*!< CANGAM GAM GAM0 mask */
#define CANGAM_GAM_GAM1MASK         ((uint32_t)0x00000002)    /*!< CANGAM GAM GAM1 mask */
#define CANGAM_GAM_GAM2MASK         ((uint32_t)0x00000004)    /*!< CANGAM GAM GAM2 mask */
#define CANGAM_GAM_GAM3MASK         ((uint32_t)0x00000008)    /*!< CANGAM GAM GAM3 mask */
#define CANGAM_GAM_GAM4MASK         ((uint32_t)0x00000010)    /*!< CANGAM GAM GAM4 mask */
#define CANGAM_GAM_GAM5MASK         ((uint32_t)0x00000020)    /*!< CANGAM GAM GAM5 mask */
#define CANGAM_GAM_GAM6MASK         ((uint32_t)0x00000040)    /*!< CANGAM GAM GAM6 mask */
#define CANGAM_GAM_GAM7MASK         ((uint32_t)0x00000080)    /*!< CANGAM GAM GAM7 mask */
#define CANGAM_GAM_GAM8MASK         ((uint32_t)0x00000100)    /*!< CANGAM GAM GAM8 mask */
#define CANGAM_GAM_GAM9MASK         ((uint32_t)0x00000200)    /*!< CANGAM GAM GAM9 mask */
#define CANGAM_GAM_GAM10MASK        ((uint32_t)0x00000400)    /*!< CANGAM GAM GAM10 mask */
#define CANGAM_GAM_GAM11MASK        ((uint32_t)0x00000800)    /*!< CANGAM GAM GAM11 mask */
#define CANGAM_GAM_GAM12MASK        ((uint32_t)0x00001000)    /*!< CANGAM GAM GAM12 mask */
#define CANGAM_GAM_GAM13MASK        ((uint32_t)0x00002000)    /*!< CANGAM GAM GAM13 mask */
#define CANGAM_GAM_GAM14MASK        ((uint32_t)0x00004000)    /*!< CANGAM GAM GAM14 mask */
#define CANGAM_GAM_GAM15MASK        ((uint32_t)0x00008000)    /*!< CANGAM GAM GAM15 mask */
#define CANGAM_GAM_GAM16MASK        ((uint32_t)0x00010000)    /*!< CANGAM GAM GAM16 mask */
#define CANGAM_GAM_GAM17MASK        ((uint32_t)0x00020000)    /*!< CANGAM GAM GAM17 mask */
#define CANGAM_GAM_GAM18MASK        ((uint32_t)0x00040000)    /*!< CANGAM GAM GAM18 mask */
#define CANGAM_GAM_GAM19MASK        ((uint32_t)0x00080000)    /*!< CANGAM GAM GAM19 mask */
#define CANGAM_GAM_GAM20MASK        ((uint32_t)0x00100000)    /*!< CANGAM GAM GAM20 mask */
#define CANGAM_GAM_GAM21MASK        ((uint32_t)0x00200000)    /*!< CANGAM GAM GAM21 mask */
#define CANGAM_GAM_GAM22MASK        ((uint32_t)0x00400000)    /*!< CANGAM GAM GAM22 mask */
#define CANGAM_GAM_GAM23MASK        ((uint32_t)0x00800000)    /*!< CANGAM GAM GAM23 mask */
#define CANGAM_GAM_GAM24MASK        ((uint32_t)0x01000000)    /*!< CANGAM GAM GAM24 mask */
#define CANGAM_GAM_GAM25MASK        ((uint32_t)0x02000000)    /*!< CANGAM GAM GAM25 mask */
#define CANGAM_GAM_GAM26MASK        ((uint32_t)0x04000000)    /*!< CANGAM GAM GAM26 mask */
#define CANGAM_GAM_GAM27MASK        ((uint32_t)0x08000000)    /*!< CANGAM GAM GAM27 mask */
#define CANGAM_GAM_GAM28MASK        ((uint32_t)0x10000000)    /*!< CANGAM GAM GAM28 mask */

#define CANGAM_GAM_GAM0NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM0 no mask */
#define CANGAM_GAM_GAM1NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM1 no mask */
#define CANGAM_GAM_GAM2NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM2 no mask */
#define CANGAM_GAM_GAM3NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM3 no mask */
#define CANGAM_GAM_GAM4NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM4 no mask */
#define CANGAM_GAM_GAM5NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM5 no mask */
#define CANGAM_GAM_GAM6NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM6 no mask */
#define CANGAM_GAM_GAM7NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM7 no mask */
#define CANGAM_GAM_GAM8NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM8 no mask */
#define CANGAM_GAM_GAM9NOMASK       ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM9 no mask */
#define CANGAM_GAM_GAM10NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM10 no mask */
#define CANGAM_GAM_GAM11NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM11 no mask */
#define CANGAM_GAM_GAM12NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM12 no mask */
#define CANGAM_GAM_GAM13NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM13 no mask */
#define CANGAM_GAM_GAM14NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM14 no mask */
#define CANGAM_GAM_GAM15NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM15 no mask */
#define CANGAM_GAM_GAM16NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM16 no mask */
#define CANGAM_GAM_GAM17NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM17 no mask */
#define CANGAM_GAM_GAM18NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM18 no mask */
#define CANGAM_GAM_GAM19NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM19 no mask */
#define CANGAM_GAM_GAM20NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM20 no mask */
#define CANGAM_GAM_GAM21NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM21 no mask */
#define CANGAM_GAM_GAM22NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM22 no mask */
#define CANGAM_GAM_GAM23NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM23 no mask */
#define CANGAM_GAM_GAM24NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM24 no mask */
#define CANGAM_GAM_GAM25NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM25 no mask */
#define CANGAM_GAM_GAM26NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM26 no mask */
#define CANGAM_GAM_GAM27NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM27 no mask */
#define CANGAM_GAM_GAM28NOMASK      ((uint32_t)0x00000000)    /*!< CANGAM GAM GAM28 no mask */
/**
 *  @}
 */ /* End of group CANGAM_GAM */

/** 
 *  @defgroup CANMCR_SUR  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_SUR_SUSPENDCLR       ((uint32_t)0x00000000)    /*!< CANMCR SUR suspend clear */
#define CANMCR_SUR_SUSPENDREQ       ((uint32_t)0x00000800)    /*!< CANMCR SUR suspend req */
/**
 *  @}
 */ /* End of group CANMCR_SUR */

/** 
 *  @defgroup CANMCR_TSTLB  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_TSTLB_LBCLR          ((uint32_t)0x00000000)    /*!< CANMCR TSTLB LB clear */
#define CANMCR_TSTLB_LBREQ          ((uint32_t)0x00000200)    /*!< CANMCR TSTLB LB req */
/**
 *  @}
 */ /* End of group CANMCR_TSTLB */

/** 
 *  @defgroup CANMCR_TSTERR  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_TSTERR_ERRCLR        ((uint32_t)0x00000000)    /*!< CANMCR TSTERR error clear */
#define CANMCR_TSTERR_ERRREQ        ((uint32_t)0x00000100)    /*!< CANMCR TSTERR error req */
/**
 *  @}
 */ /* End of group CANMCR_TSTERR */

/** 
 *  @defgroup CANMCR_CCR  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_CCR_CCRCLR           ((uint32_t)0x00000000)    /*!< CANMCR CCR CCR clear */
#define CANMCR_CCR_CCRREQ           ((uint32_t)0x00000080)    /*!< CANMCR CCR CCR req */
/**
 *  @}
 */ /* End of group CANMCR_CCR */

/** 
 *  @defgroup CANMCR_SMR  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_SMR_SMRCLR           ((uint32_t)0x00000000)    /*!< CANMCR SMR SMR clear */
#define CANMCR_SMR_SMRREQ           ((uint32_t)0x00000040)    /*!< CANMCR SMR SMR req */
/**
 *  @}
 */ /* End of group CANMCR_SMR */

/** 
 *  @defgroup CANMCR_WUBA  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_WUBA_WRITE           ((uint32_t)0x00000000)    /*!< CANMCR WUBA write */
#define CANMCR_WUBA_DETECT          ((uint32_t)0x00000010)    /*!< CANMCR WUBA detect */
/**
 *  @}
 */ /* End of group CANMCR_WUBA */

/** 
 *  @defgroup CANMCR_MTOS  CAN MCR Register
 *  @brief    CAN MCR Register Macro Definition.
 *  @{
 */
#define CANMCR_MTOS_LITTLE          ((uint32_t)0x00000000)    /*!< CANMCR MTOS little */
#define CANMCR_MTOS_PRIORITY        ((uint32_t)0x00000008)    /*!< CANMCR MTOS priority */
/**
 *  @}
 */ /* End of group CANMCR_MTOS */

/** 
 *  @defgroup CANBCR2_SJW  CAN BCR2 Register
 *  @brief    CAN BCR2 Register Macro Definition.
 *  @{
 */
#define CANBCR2_SJW_1                ((uint32_t)0x00000000)    /*!< CANBCR2 SJW 1*Tq */
#define CANBCR2_SJW_2                ((uint32_t)0x00000100)    /*!< CANBCR2 SJW 2*Tq */
#define CANBCR2_SJW_3                ((uint32_t)0x00000200)    /*!< CANBCR2 SJW 3*Tq */
#define CANBCR2_SJW_4                ((uint32_t)0x00000300)    /*!< CANBCR2 SJW 4*Tq */
/**
 *  @}
 */ /* End of group CANBCR2_SJW */

/** 
 *  @defgroup CANBCR2_SAM  CAN BCR2 Register
 *  @brief    CAN BCR2 Register Macro Definition.
 *  @{
 */
#define CANBCR2_SAM_SINGLE            ((uint32_t)0x00000000)    /*!< CANBCR2 SAM single */
#define CANBCR2_SAM_TRIPLE            ((uint32_t)0x00000080)    /*!< CANBCR2 SAM triple */
/**
 *  @}
 */ /* End of group CANBCR2_SAM */

/** 
 *  @defgroup CANBCR2_TSEG2  CAN BCR2 Register
 *  @brief    CAN BCR2 Register Macro Definition.
 *  @{
 */
#define CANBCR2_TSEG2_2               ((uint32_t)0x00000010)    /*!< CANBCR2 TSEG2 2*Tq */
#define CANBCR2_TSEG2_3               ((uint32_t)0x00000020)    /*!< CANBCR2 TSEG2 3*Tq */
#define CANBCR2_TSEG2_4               ((uint32_t)0x00000030)    /*!< CANBCR2 TSEG2 4*Tq */
#define CANBCR2_TSEG2_5               ((uint32_t)0x00000040)    /*!< CANBCR2 TSEG2 5*Tq */
#define CANBCR2_TSEG2_6               ((uint32_t)0x00000050)    /*!< CANBCR2 TSEG2 6*Tq */
#define CANBCR2_TSEG2_7               ((uint32_t)0x00000060)    /*!< CANBCR2 TSEG2 7*Tq */
#define CANBCR2_TSEG2_8               ((uint32_t)0x00000070)    /*!< CANBCR2 TSEG2 8*Tq */
/**
 *  @}
 */ /* End of group CANBCR2_TSEG2 */

/** 
 *  @defgroup CANBCR2_TSEG1  CAN BCR2 Register
 *  @brief    CAN BCR2 Register Macro Definition.
 *  @{
 */
#define CANBCR2_TSEG1_2                ((uint32_t)0x00000001)    /*!< CANBCR2 TSEG1 2*Tq */
#define CANBCR2_TSEG1_3                ((uint32_t)0x00000002)    /*!< CANBCR2 TSEG1 3*Tq */
#define CANBCR2_TSEG1_4                ((uint32_t)0x00000003)    /*!< CANBCR2 TSEG1 4*Tq */
#define CANBCR2_TSEG1_5                ((uint32_t)0x00000004)    /*!< CANBCR2 TSEG1 5*Tq */
#define CANBCR2_TSEG1_6                ((uint32_t)0x00000005)    /*!< CANBCR2 TSEG1 6*Tq */
#define CANBCR2_TSEG1_7                ((uint32_t)0x00000006)    /*!< CANBCR2 TSEG1 7*Tq */
#define CANBCR2_TSEG1_8                ((uint32_t)0x00000007)    /*!< CANBCR2 TSEG1 8*Tq */
#define CANBCR2_TSEG1_9                ((uint32_t)0x00000008)    /*!< CANBCR2 TSEG1 9*Tq */
#define CANBCR2_TSEG1_10               ((uint32_t)0x00000009)    /*!< CANBCR2 TSEG1 10*Tq */
#define CANBCR2_TSEG1_11               ((uint32_t)0x0000000A)    /*!< CANBCR2 TSEG1 11*Tq */
#define CANBCR2_TSEG1_12               ((uint32_t)0x0000000B)    /*!< CANBCR2 TSEG1 12*Tq */
#define CANBCR2_TSEG1_13               ((uint32_t)0x0000000C)    /*!< CANBCR2 TSEG1 13*Tq */
#define CANBCR2_TSEG1_14               ((uint32_t)0x0000000D)    /*!< CANBCR2 TSEG1 14*Tq */
#define CANBCR2_TSEG1_15               ((uint32_t)0x0000000E)    /*!< CANBCR2 TSEG1 15*Tq */
#define CANBCR2_TSEG1_16               ((uint32_t)0x0000000F)    /*!< CANBCR2 TSEG1 16*Tq */
/**
 *  @}
 */ /* End of group CANBCR2_TSEG1 */

/** 
 *  @defgroup CANGIF_RFPF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_RFPF_NORECEIVE           ((uint32_t)0x00000000)    /*!< CANGIF RFPF no receive */
#define CANGIF_RFPF_RECEIVE             ((uint32_t)0x00000080)    /*!< CANGIF RFPF receive */
/**
 *  @}
 */ /* End of group CANGIF_RFPF */

/** 
 *  @defgroup CANGIF_WUIF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_WUIF_SLEEP               ((uint32_t)0x00000000)    /*!< CANGIF WUIF sleep */
#define CANGIF_WUIF_NOSLEEP             ((uint32_t)0x00000040)    /*!< CANGIF WUIF no sleep */
/**
 *  @}
 */ /* End of group CANGIF_WUIF */

/** 
 *  @defgroup CANGIF_RMLIF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_RMLIF_NOLOST             ((uint32_t)0x00000000)    /*!< CANGIF RMLIF no lost */
#define CANGIF_RMLIF_LOST               ((uint32_t)0x00000020)    /*!< CANGIF RMLIF lost */
/**
 *  @}
 */ /* End of group CANGIF_RMLIF */

/** 
 *  @defgroup CANGIF_TRMABF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_TRMABF_NOABORT           ((uint32_t)0x00000000)    /*!< CANGIF TRMABF no abort */
#define CANGIF_TRMABF_ABORT             ((uint32_t)0x00000010)    /*!< CANGIF TRMABF abort */
/**
 *  @}
 */ /* End of group CANGIF_TRMABF */

/** 
 *  @defgroup CANGIF_TSOIF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_TSOIF_NOOVER             ((uint32_t)0x00000000)    /*!< CANGIF TSOIF no over */
#define CANGIF_TSOIF_OVER               ((uint32_t)0x00000008)    /*!< CANGIF TSOIF over */
/**
 *  @}
 */ /* End of group CANGIF_TSOIF */

/** 
 *  @defgroup CANGIF_BOIF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_BOIF_ON                  ((uint32_t)0x00000000)    /*!< CANGIF BOIF on */
#define CANGIF_BOIF_OFF                 ((uint32_t)0x00000004)    /*!< CANGIF BOIF off */
/**
 *  @}
 */ /* End of group CANGIF_BOIF */

/** 
 *  @defgroup CANGIF_EPIF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_EPIF_ACTIVE               ((uint32_t)0x00000000)    /*!< CANGIF EPIF active */
#define CANGIF_EPIF_PASSIVE              ((uint32_t)0x00000002)    /*!< CANGIF EPIF passive */
/**
 *  @}
 */ /* End of group CANGIF_EPIF */

/** 
 *  @defgroup CANGIF_WLIF  CAN GIF Register
 *  @brief    CAN GIF Register Macro Definition.
 *  @{
 */
#define CANGIF_WLIF_NOWARNING            ((uint32_t)0x00000000)    /*!< CANGIF WLIF no warning */
#define CANGIF_WLIF_WARNING              ((uint32_t)0x00000001)    /*!< CANGIF WLIF warning */
/**
 *  @}
 */ /* End of group CANGIF_WLIF */

/** 
 *  @defgroup CANGIM_RFPM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_RFPM_DISABLE              ((uint32_t)0x00000000)    /*!< CANGIM RFPM disable */
#define CANGIM_RFPM_ENABLE               ((uint32_t)0x00000080)    /*!< CANGIM RFPM enable */
/**
 *  @}
 */ /* End of group CANGIM_RFPM */

/** 
 *  @defgroup CANGIM_WUIM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_WUIM_DISABLE              ((uint32_t)0x00000000)    /*!< CANGIM WUIM disable */
#define CANGIM_WUIM_ENABLE               ((uint32_t)0x00000040)    /*!< CANGIM WUIM enable */
/**
 *  @}
 */ /* End of group CANGIM_WUIM */

/** 
 *  @defgroup CANGIM_RMLIM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_RMLIM_DISABLE             ((uint32_t)0x00000000)    /*!< CANGIM RMLIM disable */
#define CANGIM_RMLIM_ENABLE              ((uint32_t)0x00000020)    /*!< CANGIM RMLIM enable */
/**
 *  @}
 */ /* End of group CANGIM_RMLIM */

/** 
 *  @defgroup CANGIM_TRMABF  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_TRMABF_DISABLE            ((uint32_t)0x00000000)    /*!< CANGIM TRMABF disable */
#define CANGIM_TRMABF_ENABLE             ((uint32_t)0x00000010)    /*!< CANGIM TRMABF enable */
/**
 *  @}
 */ /* End of group CANGIM_TRMABF */

/** 
 *  @defgroup CANGIM_TSOIM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_TSOIM_DISABLE             ((uint32_t)0x00000000)    /*!< CANGIM TSOIM disable */
#define CANGIM_TSOIM_ENABLE              ((uint32_t)0x00000008)    /*!< CANGIM TSOIM enable */
/**
 *  @}
 */ /* End of group CANGIM_TSOIM */

/** 
 *  @defgroup CANGIM_BOIM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_BOIM_DISABLE              ((uint32_t)0x00000000)    /*!< CANGIM BOIM disable */
#define CANGIM_BOIM_ENABLE               ((uint32_t)0x00000004)    /*!< CANGIM BOIM enable */
/**
 *  @}
 */ /* End of group CANGIM_BOIM */

/** 
 *  @defgroup CANGIM_EPIM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_EPIM_DISABLE              ((uint32_t)0x00000000)    /*!< CANGIM EPIM disable */
#define CANGIM_EPIM_ENABLE               ((uint32_t)0x00000002)    /*!< CANGIM EPIM enable */
/**
 *  @}
 */ /* End of group CANGIM_EPIM */

/** 
 *  @defgroup CANGIM_WLIM  CAN GIM Register
 *  @brief    CAN GIM Register Macro Definition.
 *  @{
 */
#define CANGIM_WLIM_DISABLE              ((uint32_t)0x00000000)    /*!< CANGIM WLIM disable */
#define CANGIM_WLIM_ENABLE               ((uint32_t)0x00000001)    /*!< CANGIM WLIM enable */
/**
 *  @}
 */ /* End of group CANGIM_WLIM */

/** 
 *  @defgroup CANMBTIF_MBTIF  CAN MBTIF Register
 *  @brief    CAN MBTIF Register Macro Definition.
 *  @{
 */
#define CANMBTIF_MBTIF_MBTIF0CLR          ((uint32_t)0x00000001)    /*!< CANMBTIF MBTIF0 clear */
#define CANMBTIF_MBTIF_MBTIF1CLR          ((uint32_t)0x00000002)    /*!< CANMBTIF MBTIF1 clear */
#define CANMBTIF_MBTIF_MBTIF2CLR          ((uint32_t)0x00000004)    /*!< CANMBTIF MBTIF2 clear */
#define CANMBTIF_MBTIF_MBTIF3CLR          ((uint32_t)0x00000008)    /*!< CANMBTIF MBTIF3 clear */
#define CANMBTIF_MBTIF_MBTIF4CLR          ((uint32_t)0x00000010)    /*!< CANMBTIF MBTIF4 clear */
#define CANMBTIF_MBTIF_MBTIF5CLR          ((uint32_t)0x00000020)    /*!< CANMBTIF MBTIF5 clear */
#define CANMBTIF_MBTIF_MBTIF6CLR          ((uint32_t)0x00000040)    /*!< CANMBTIF MBTIF6 clear */
#define CANMBTIF_MBTIF_MBTIF7CLR          ((uint32_t)0x00000080)    /*!< CANMBTIF MBTIF7 clear */
#define CANMBTIF_MBTIF_MBTIF8CLR          ((uint32_t)0x00000100)    /*!< CANMBTIF MBTIF8 clear */
#define CANMBTIF_MBTIF_MBTIF9CLR          ((uint32_t)0x00000200)    /*!< CANMBTIF MBTIF9 clear */
#define CANMBTIF_MBTIF_MBTIF10CLR         ((uint32_t)0x00000400)    /*!< CANMBTIF MBTIF10 clear */
#define CANMBTIF_MBTIF_MBTIF11CLR         ((uint32_t)0x00000800)    /*!< CANMBTIF MBTIF11 clear */
#define CANMBTIF_MBTIF_MBTIF12CLR         ((uint32_t)0x00001000)    /*!< CANMBTIF MBTIF12 clear */
#define CANMBTIF_MBTIF_MBTIF13CLR         ((uint32_t)0x00002000)    /*!< CANMBTIF MBTIF13 clear */
#define CANMBTIF_MBTIF_MBTIF14CLR         ((uint32_t)0x00004000)    /*!< CANMBTIF MBTIF14 clear */
#define CANMBTIF_MBTIF_MBTIF15CLR         ((uint32_t)0x00008000)    /*!< CANMBTIF MBTIF15 clear */
#define CANMBTIF_MBTIF_MBTIF16CLR         ((uint32_t)0x00010000)    /*!< CANMBTIF MBTIF16 clear */
#define CANMBTIF_MBTIF_MBTIF17CLR         ((uint32_t)0x00020000)    /*!< CANMBTIF MBTIF17 clear */
#define CANMBTIF_MBTIF_MBTIF18CLR         ((uint32_t)0x00040000)    /*!< CANMBTIF MBTIF18 clear */
#define CANMBTIF_MBTIF_MBTIF19CLR         ((uint32_t)0x00080000)    /*!< CANMBTIF MBTIF19 clear */
#define CANMBTIF_MBTIF_MBTIF20CLR         ((uint32_t)0x00100000)    /*!< CANMBTIF MBTIF20 clear */
#define CANMBTIF_MBTIF_MBTIF21CLR         ((uint32_t)0x00200000)    /*!< CANMBTIF MBTIF21 clear */
#define CANMBTIF_MBTIF_MBTIF22CLR         ((uint32_t)0x00400000)    /*!< CANMBTIF MBTIF22 clear */
#define CANMBTIF_MBTIF_MBTIF23CLR         ((uint32_t)0x00800000)    /*!< CANMBTIF MBTIF23 clear */
#define CANMBTIF_MBTIF_MBTIF24CLR         ((uint32_t)0x01000000)    /*!< CANMBTIF MBTIF24 clear */
#define CANMBTIF_MBTIF_MBTIF25CLR         ((uint32_t)0x02000000)    /*!< CANMBTIF MBTIF25 clear */
#define CANMBTIF_MBTIF_MBTIF26CLR         ((uint32_t)0x04000000)    /*!< CANMBTIF MBTIF26 clear */
#define CANMBTIF_MBTIF_MBTIF27CLR         ((uint32_t)0x08000000)    /*!< CANMBTIF MBTIF27 clear */
#define CANMBTIF_MBTIF_MBTIF28CLR         ((uint32_t)0x10000000)    /*!< CANMBTIF MBTIF28 clear */
#define CANMBTIF_MBTIF_MBTIF29CLR         ((uint32_t)0x20000000)    /*!< CANMBTIF MBTIF29 clear */
#define CANMBTIF_MBTIF_MBTIF30CLR         ((uint32_t)0x40000000)    /*!< CANMBTIF MBTIF30 clear */
/**
 *  @}
 */ /* End of group CANMBTIF_MBTIF */

/** 
 *  @defgroup CANMBRIF_MBRIF  CAN MBRIF Register
 *  @brief    CAN MBRIF Register Macro Definition.
 *  @{
 */
#define CANMBRIF_MBRIF_MBRIF0CLR          ((uint32_t)0x00000001)    /*!< CANMBRIF MBRIF0 clear */
#define CANMBRIF_MBRIF_MBRIF1CLR          ((uint32_t)0x00000002)    /*!< CANMBRIF MBRIF1 clear */
#define CANMBRIF_MBRIF_MBRIF2CLR          ((uint32_t)0x00000004)    /*!< CANMBRIF MBRIF2 clear */
#define CANMBRIF_MBRIF_MBRIF3CLR          ((uint32_t)0x00000008)    /*!< CANMBRIF MBRIF3 clear */
#define CANMBRIF_MBRIF_MBRIF4CLR          ((uint32_t)0x00000010)    /*!< CANMBRIF MBRIF4 clear */
#define CANMBRIF_MBRIF_MBRIF5CLR          ((uint32_t)0x00000020)    /*!< CANMBRIF MBRIF5 clear */
#define CANMBRIF_MBRIF_MBRIF6CLR          ((uint32_t)0x00000040)    /*!< CANMBRIF MBRIF6 clear */
#define CANMBRIF_MBRIF_MBRIF7CLR          ((uint32_t)0x00000080)    /*!< CANMBRIF MBRIF7 clear */
#define CANMBRIF_MBRIF_MBRIF8CLR          ((uint32_t)0x00000100)    /*!< CANMBRIF MBRIF8 clear */
#define CANMBRIF_MBRIF_MBRIF9CLR          ((uint32_t)0x00000200)    /*!< CANMBRIF MBRIF9 clear */
#define CANMBRIF_MBRIF_MBRIF10CLR         ((uint32_t)0x00000400)    /*!< CANMBRIF MBRIF10 clear */
#define CANMBRIF_MBRIF_MBRIF11CLR         ((uint32_t)0x00000800)    /*!< CANMBRIF MBRIF11 clear */
#define CANMBRIF_MBRIF_MBRIF12CLR         ((uint32_t)0x00001000)    /*!< CANMBRIF MBRIF12 clear */
#define CANMBRIF_MBRIF_MBRIF13CLR         ((uint32_t)0x00002000)    /*!< CANMBRIF MBRIF13 clear */
#define CANMBRIF_MBRIF_MBRIF14CLR         ((uint32_t)0x00004000)    /*!< CANMBRIF MBRIF14 clear */
#define CANMBRIF_MBRIF_MBRIF15CLR         ((uint32_t)0x00008000)    /*!< CANMBRIF MBRIF15 clear */
#define CANMBRIF_MBRIF_MBRIF16CLR         ((uint32_t)0x00010000)    /*!< CANMBRIF MBRIF16 clear */
#define CANMBRIF_MBRIF_MBRIF17CLR         ((uint32_t)0x00020000)    /*!< CANMBRIF MBRIF17 clear */
#define CANMBRIF_MBRIF_MBRIF18CLR         ((uint32_t)0x00040000)    /*!< CANMBRIF MBRIF18 clear */
#define CANMBRIF_MBRIF_MBRIF19CLR         ((uint32_t)0x00080000)    /*!< CANMBRIF MBRIF19 clear */
#define CANMBRIF_MBRIF_MBRIF20CLR         ((uint32_t)0x00100000)    /*!< CANMBRIF MBRIF20 clear */
#define CANMBRIF_MBRIF_MBRIF21CLR         ((uint32_t)0x00200000)    /*!< CANMBRIF MBRIF21 clear */
#define CANMBRIF_MBRIF_MBRIF22CLR         ((uint32_t)0x00400000)    /*!< CANMBRIF MBRIF22 clear */
#define CANMBRIF_MBRIF_MBRIF23CLR         ((uint32_t)0x00800000)    /*!< CANMBRIF MBRIF23 clear */
#define CANMBRIF_MBRIF_MBRIF24CLR         ((uint32_t)0x01000000)    /*!< CANMBRIF MBRIF24 clear */
#define CANMBRIF_MBRIF_MBRIF25CLR         ((uint32_t)0x02000000)    /*!< CANMBRIF MBRIF25 clear */
#define CANMBRIF_MBRIF_MBRIF26CLR         ((uint32_t)0x04000000)    /*!< CANMBRIF MBRIF26 clear */
#define CANMBRIF_MBRIF_MBRIF27CLR         ((uint32_t)0x08000000)    /*!< CANMBRIF MBRIF27 clear */
#define CANMBRIF_MBRIF_MBRIF28CLR         ((uint32_t)0x10000000)    /*!< CANMBRIF MBRIF28 clear */
#define CANMBRIF_MBRIF_MBRIF29CLR         ((uint32_t)0x20000000)    /*!< CANMBRIF MBRIF29 clear */
#define CANMBRIF_MBRIF_MBRIF30CLR         ((uint32_t)0x40000000)    /*!< CANMBRIF MBRIF30 clear */
#define CANMBRIF_MBRIF_MBRIF31CLR         ((uint32_t)0x80000000)    /*!< CANMBRIF MBRIF31 clear */
/**
 *  @}
 */ /* End of group CANMBRIF_MBRIF */

/** 
 *  @defgroup CANMBIM_MBIM  CAN MBIM Register
 *  @brief    CAN MBIM Register Macro Definition.
 *  @{
 */
#define CANMBIM_MBIM_MBIM0_ENABLE        ((uint32_t)0x00000001)    /*!< CANMBIM MBIM0 enable */
#define CANMBIM_MBIM_MBIM1_ENABLE        ((uint32_t)0x00000002)    /*!< CANMBIM MBIM1 enable */
#define CANMBIM_MBIM_MBIM2_ENABLE        ((uint32_t)0x00000004)    /*!< CANMBIM MBIM2 enable */
#define CANMBIM_MBIM_MBIM3_ENABLE        ((uint32_t)0x00000008)    /*!< CANMBIM MBIM3 enable */
#define CANMBIM_MBIM_MBIM4_ENABLE        ((uint32_t)0x00000010)    /*!< CANMBIM MBIM4 enable */
#define CANMBIM_MBIM_MBIM5_ENABLE        ((uint32_t)0x00000020)    /*!< CANMBIM MBIM5 enable */
#define CANMBIM_MBIM_MBIM6_ENABLE        ((uint32_t)0x00000040)    /*!< CANMBIM MBIM6 enable */
#define CANMBIM_MBIM_MBIM7_ENABLE        ((uint32_t)0x00000080)    /*!< CANMBIM MBIM7 enable */
#define CANMBIM_MBIM_MBIM8_ENABLE        ((uint32_t)0x00000100)    /*!< CANMBIM MBIM8 enable */
#define CANMBIM_MBIM_MBIM9_ENABLE        ((uint32_t)0x00000200)    /*!< CANMBIM MBIM9 enable */
#define CANMBIM_MBIM_MBIM10_ENABLE       ((uint32_t)0x00000400)    /*!< CANMBIM MBIM10 enable */
#define CANMBIM_MBIM_MBIM11_ENABLE       ((uint32_t)0x00000800)    /*!< CANMBIM MBIM11 enable */
#define CANMBIM_MBIM_MBIM12_ENABLE       ((uint32_t)0x00001000)    /*!< CANMBIM MBIM12 enable */
#define CANMBIM_MBIM_MBIM13_ENABLE       ((uint32_t)0x00002000)    /*!< CANMBIM MBIM13 enable */
#define CANMBIM_MBIM_MBIM14_ENABLE       ((uint32_t)0x00004000)    /*!< CANMBIM MBIM14 enable */
#define CANMBIM_MBIM_MBIM15_ENABLE       ((uint32_t)0x00008000)    /*!< CANMBIM MBIM15 enable */
#define CANMBIM_MBIM_MBIM16_ENABLE       ((uint32_t)0x00010000)    /*!< CANMBIM MBIM16 enable */
#define CANMBIM_MBIM_MBIM17_ENABLE       ((uint32_t)0x00020000)    /*!< CANMBIM MBIM17 enable */
#define CANMBIM_MBIM_MBIM18_ENABLE       ((uint32_t)0x00040000)    /*!< CANMBIM MBIM18 enable */
#define CANMBIM_MBIM_MBIM19_ENABLE       ((uint32_t)0x00080000)    /*!< CANMBIM MBIM19 enable */
#define CANMBIM_MBIM_MBIM20_ENABLE       ((uint32_t)0x00100000)    /*!< CANMBIM MBIM20 enable */
#define CANMBIM_MBIM_MBIM21_ENABLE       ((uint32_t)0x00200000)    /*!< CANMBIM MBIM21 enable */
#define CANMBIM_MBIM_MBIM22_ENABLE       ((uint32_t)0x00400000)    /*!< CANMBIM MBIM22 enable */
#define CANMBIM_MBIM_MBIM23_ENABLE       ((uint32_t)0x00800000)    /*!< CANMBIM MBIM23 enable */
#define CANMBIM_MBIM_MBIM24_ENABLE       ((uint32_t)0x01000000)    /*!< CANMBIM MBIM24 enable */
#define CANMBIM_MBIM_MBIM25_ENABLE       ((uint32_t)0x02000000)    /*!< CANMBIM MBIM25 enable */
#define CANMBIM_MBIM_MBIM26_ENABLE       ((uint32_t)0x04000000)    /*!< CANMBIM MBIM26 enable */
#define CANMBIM_MBIM_MBIM27_ENABLE       ((uint32_t)0x08000000)    /*!< CANMBIM MBIM27 enable */
#define CANMBIM_MBIM_MBIM28_ENABLE       ((uint32_t)0x10000000)    /*!< CANMBIM MBIM28 enable */
#define CANMBIM_MBIM_MBIM29_ENABLE       ((uint32_t)0x20000000)    /*!< CANMBIM MBIM29 enable */
#define CANMBIM_MBIM_MBIM30_ENABLE       ((uint32_t)0x40000000)    /*!< CANMBIM MBIM30 enable */
#define CANMBIM_MBIM_MBIM31_ENABLE       ((uint32_t)0x80000000)    /*!< CANMBIM MBIM31 enable */

#define CANMBIM_MBIM_MBIM0_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM0 disable */
#define CANMBIM_MBIM_MBIM1_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM1 disable */
#define CANMBIM_MBIM_MBIM2_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM2 disable */
#define CANMBIM_MBIM_MBIM3_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM3 disable */
#define CANMBIM_MBIM_MBIM4_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM4 disable */
#define CANMBIM_MBIM_MBIM5_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM5 disable */
#define CANMBIM_MBIM_MBIM6_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM6 disable */
#define CANMBIM_MBIM_MBIM7_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM7 disable */
#define CANMBIM_MBIM_MBIM8_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM8 disable */
#define CANMBIM_MBIM_MBIM9_DISABLE       ((uint32_t)0x00000000)    /*!< CANMBIM MBIM9 disable */
#define CANMBIM_MBIM_MBIM10_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM10 disable */
#define CANMBIM_MBIM_MBIM11_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM11 disable */
#define CANMBIM_MBIM_MBIM12_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM12 disable */
#define CANMBIM_MBIM_MBIM13_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM13 disable */
#define CANMBIM_MBIM_MBIM14_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM14 disable */
#define CANMBIM_MBIM_MBIM15_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM15 disable */
#define CANMBIM_MBIM_MBIM16_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM16 disable */
#define CANMBIM_MBIM_MBIM17_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM17 disable */
#define CANMBIM_MBIM_MBIM18_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM18 disable */
#define CANMBIM_MBIM_MBIM19_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM19 disable */
#define CANMBIM_MBIM_MBIM20_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM20 disable */
#define CANMBIM_MBIM_MBIM21_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM21 disable */
#define CANMBIM_MBIM_MBIM22_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM22 disable */
#define CANMBIM_MBIM_MBIM23_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM23 disable */
#define CANMBIM_MBIM_MBIM24_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM24 disable */
#define CANMBIM_MBIM_MBIM25_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM25 disable */
#define CANMBIM_MBIM_MBIM26_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM26 disable */
#define CANMBIM_MBIM_MBIM27_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM27 disable */
#define CANMBIM_MBIM_MBIM28_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM28 disable */
#define CANMBIM_MBIM_MBIM29_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM29 disable */
#define CANMBIM_MBIM_MBIM30_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM30 disable */
#define CANMBIM_MBIM_MBIM31_DISABLE      ((uint32_t)0x00000000)    /*!< CANMBIM MBIM31 disable */
/**
 *  @}
 */ /* End of group CANMBIM_MBIM */

/** 
 *  @defgroup CANCDR_CDR  CAN CDR Register
 *  @brief    CAN CDR Register Macro Definition.
 *  @{
 */
#define CANCDR_CDR_CDR0CLR                ((uint32_t)0x00000001)    /*!< CANCDR CDR0 clear */
#define CANCDR_CDR_CDR1CLR                ((uint32_t)0x00000002)    /*!< CANCDR CDR1 clear */
#define CANCDR_CDR_CDR2CLR                ((uint32_t)0x00000004)    /*!< CANCDR CDR2 clear */
#define CANCDR_CDR_CDR3CLR                ((uint32_t)0x00000008)    /*!< CANCDR CDR3 clear */
#define CANCDR_CDR_CDR4CLR                ((uint32_t)0x00000010)    /*!< CANCDR CDR4 clear */
#define CANCDR_CDR_CDR5CLR                ((uint32_t)0x00000020)    /*!< CANCDR CDR5 clear */
#define CANCDR_CDR_CDR6CLR                ((uint32_t)0x00000040)    /*!< CANCDR CDR6 clear */
#define CANCDR_CDR_CDR7CLR                ((uint32_t)0x00000080)    /*!< CANCDR CDR7 clear */
#define CANCDR_CDR_CDR8CLR                ((uint32_t)0x00000100)    /*!< CANCDR CDR8 clear */
#define CANCDR_CDR_CDR9CLR                ((uint32_t)0x00000200)    /*!< CANCDR CDR9 clear */
#define CANCDR_CDR_CDR10CLR               ((uint32_t)0x00000400)    /*!< CANCDR CDR10 clear */
#define CANCDR_CDR_CDR11CLR               ((uint32_t)0x00000800)    /*!< CANCDR CDR11 clear */
#define CANCDR_CDR_CDR12CLR               ((uint32_t)0x00001000)    /*!< CANCDR CDR12 clear */
#define CANCDR_CDR_CDR13CLR               ((uint32_t)0x00002000)    /*!< CANCDR CDR13 clear */
#define CANCDR_CDR_CDR14CLR               ((uint32_t)0x00004000)    /*!< CANCDR CDR14 clear */
#define CANCDR_CDR_CDR15CLR               ((uint32_t)0x00008000)    /*!< CANCDR CDR15 clear */
#define CANCDR_CDR_CDR16CLR               ((uint32_t)0x00010000)    /*!< CANCDR CDR16 clear */
#define CANCDR_CDR_CDR17CLR               ((uint32_t)0x00020000)    /*!< CANCDR CDR17 clear */
#define CANCDR_CDR_CDR18CLR               ((uint32_t)0x00040000)    /*!< CANCDR CDR18 clear */
#define CANCDR_CDR_CDR19CLR               ((uint32_t)0x00080000)    /*!< CANCDR CDR19 clear */
#define CANCDR_CDR_CDR20CLR               ((uint32_t)0x00100000)    /*!< CANCDR CDR20 clear */
#define CANCDR_CDR_CDR21CLR               ((uint32_t)0x00200000)    /*!< CANCDR CDR21 clear */
#define CANCDR_CDR_CDR22CLR               ((uint32_t)0x00400000)    /*!< CANCDR CDR22 clear */
#define CANCDR_CDR_CDR23CLR               ((uint32_t)0x00800000)    /*!< CANCDR CDR23 clear */
#define CANCDR_CDR_CDR24CLR               ((uint32_t)0x01000000)    /*!< CANCDR CDR24 clear */
#define CANCDR_CDR_CDR25CLR               ((uint32_t)0x02000000)    /*!< CANCDR CDR25 clear */
#define CANCDR_CDR_CDR26CLR               ((uint32_t)0x04000000)    /*!< CANCDR CDR26 clear */
#define CANCDR_CDR_CDR27CLR               ((uint32_t)0x08000000)    /*!< CANCDR CDR27 clear */
#define CANCDR_CDR_CDR28CLR               ((uint32_t)0x10000000)    /*!< CANCDR CDR28 clear */
#define CANCDR_CDR_CDR29CLR               ((uint32_t)0x20000000)    /*!< CANCDR CDR29 clear */
#define CANCDR_CDR_CDR30CLR               ((uint32_t)0x40000000)    /*!< CANCDR CDR30 clear */
/**
 *  @}
 */ /* End of group CANCDR_CDR */

/** 
 *  @defgroup CANRFP_RFP  CAN RFP Register
 *  @brief    CAN RFP Register Macro Definition.
 *  @{
 */
#define CANRFP_RFP_RFP0CLR                 ((uint32_t)0x00000001)    /*!< CANRFP RFP0 clear */
#define CANRFP_RFP_RFP1CLR                 ((uint32_t)0x00000002)    /*!< CANRFP RFP1 clear */
#define CANRFP_RFP_RFP2CLR                 ((uint32_t)0x00000004)    /*!< CANRFP RFP2 clear */
#define CANRFP_RFP_RFP3CLR                 ((uint32_t)0x00000008)    /*!< CANRFP RFP3 clear */
#define CANRFP_RFP_RFP4CLR                 ((uint32_t)0x00000010)    /*!< CANRFP RFP4 clear */
#define CANRFP_RFP_RFP5CLR                 ((uint32_t)0x00000020)    /*!< CANRFP RFP5 clear */
#define CANRFP_RFP_RFP6CLR                 ((uint32_t)0x00000040)    /*!< CANRFP RFP6 clear */
#define CANRFP_RFP_RFP7CLR                 ((uint32_t)0x00000080)    /*!< CANRFP RFP7 clear */
#define CANRFP_RFP_RFP8CLR                 ((uint32_t)0x00000100)    /*!< CANRFP RFP8 clear */
#define CANRFP_RFP_RFP9CLR                 ((uint32_t)0x00000200)    /*!< CANRFP RFP9 clear */
#define CANRFP_RFP_RFP10CLR                ((uint32_t)0x00000400)    /*!< CANRFP RFP10 clear */
#define CANRFP_RFP_RFP11CLR                ((uint32_t)0x00000800)    /*!< CANRFP RFP11 clear */
#define CANRFP_RFP_RFP12CLR                ((uint32_t)0x00001000)    /*!< CANRFP RFP12 clear */
#define CANRFP_RFP_RFP13CLR                ((uint32_t)0x00002000)    /*!< CANRFP RFP13 clear */
#define CANRFP_RFP_RFP14CLR                ((uint32_t)0x00004000)    /*!< CANRFP RFP14 clear */
#define CANRFP_RFP_RFP15CLR                ((uint32_t)0x00008000)    /*!< CANRFP RFP15 clear */
#define CANRFP_RFP_RFP16CLR                ((uint32_t)0x00010000)    /*!< CANRFP RFP16 clear */
#define CANRFP_RFP_RFP17CLR                ((uint32_t)0x00020000)    /*!< CANRFP RFP17 clear */
#define CANRFP_RFP_RFP18CLR                ((uint32_t)0x00040000)    /*!< CANRFP RFP18 clear */
#define CANRFP_RFP_RFP19CLR                ((uint32_t)0x00080000)    /*!< CANRFP RFP19 clear */
#define CANRFP_RFP_RFP20CLR                ((uint32_t)0x00100000)    /*!< CANRFP RFP20 clear */
#define CANRFP_RFP_RFP21CLR                ((uint32_t)0x00200000)    /*!< CANRFP RFP21 clear */
#define CANRFP_RFP_RFP22CLR                ((uint32_t)0x00400000)    /*!< CANRFP RFP22 clear */
#define CANRFP_RFP_RFP23CLR                ((uint32_t)0x00800000)    /*!< CANRFP RFP23 clear */
#define CANRFP_RFP_RFP24CLR                ((uint32_t)0x01000000)    /*!< CANRFP RFP24 clear */
#define CANRFP_RFP_RFP25CLR                ((uint32_t)0x02000000)    /*!< CANRFP RFP25 clear */
#define CANRFP_RFP_RFP26CLR                ((uint32_t)0x04000000)    /*!< CANRFP RFP26 clear */
#define CANRFP_RFP_RFP27CLR                ((uint32_t)0x08000000)    /*!< CANRFP RFP27 clear */
#define CANRFP_RFP_RFP28CLR                ((uint32_t)0x10000000)    /*!< CANRFP RFP28 clear */
#define CANRFP_RFP_RFP29CLR                ((uint32_t)0x20000000)    /*!< CANRFP RFP29 clear */
#define CANRFP_RFP_RFP30CLR                ((uint32_t)0x40000000)    /*!< CANRFP RFP30 clear */
#define CANRFP_RFP_RFP31CLR                ((uint32_t)0x80000000)    /*!< CANRFP RFP31 clear */
/**
 *  @}
 */ /* End of group CANRFP_RFP */

/**
 *  @}
 */ /* End of group CAN_Exported_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
    @addtogroup CAN_Exported_define CAN Exported Define
    @{
 */

/*! @enum datafield_t
 *  @brief CAN DataField Setting
 */
typedef enum
{
    CANMB_DATAL = (0x00000000),  /*!< 0: Data Field Low     */
    CANMB_DATAH = (0x00000001),  /*!< 1: Data Field High    */
}datafield_t;


/*!
    @}
 */ /* End of group CAN_Exported_define */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/*! 
    @defgroup CAN_Exported_typedef CAN Exported Typedef
    @{
 */

/*----------------------------------*/
/*! @struct can_id_t
    @brief  CAN ID Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t   ide;              /*!< IDE Setting
                                    : Use @ref CANMBID_IDE */
    uint32_t   gamelame;         /*!< GAMELAME Setting
                                    : Use @ref CANMBID_GAMELAME */
    uint32_t   rfh;              /*!< RFH Setting
                                    : Use @ref CANMBID_RFH */
    uint32_t   id;               /*!< ID Setting
                                    : ID ( ID =< CANMBID_MAX )   @ref CANMBID */
} can_id_t;

/*----------------------------------*/
/*! @struct can_tsvmcf_t
    @brief  CAN TSVMCF Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t tsv;                /*!< TSV Setting
                                    : ID ( TSV =< CANMBTSVMCF_TSV_MAX )   @ref CANMBTSVMCF_TSV */
    uint32_t rtr;                /*!< RTR Setting
                                    : Use @ref CANMBTSVMCF_RTR */
    uint32_t dlc;                /*!< DLC Setting
                                    : Use @ref CANMBTSVMCF_DLC */
} can_tsvmcf_t;

/*----------------------------------*/
/*! @struct can_data_t
    @brief  CAN Data Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t    data;            /*!< CAN Data Setting */
    datafield_t datafield;       /*!< CAN DataField Setting
                                    : Use @ref datafield_t */
} can_data_t;

/*----------------------------------*/
/*! @struct can_lam_t
    @brief  CAN LAM Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t lam;                /*!< LAM Setting
                                    : Use @ref CANLAM_LAM */
    uint32_t lami;               /*!< CAN LAMI Setting
                                    : Use @ref CANLAM_LAMI */
} can_lam_t;

/*----------------------------------*/
/*! @struct can_gam_t
    @brief  CAN GAM Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t gam;                /*!< GAM Setting
                                    : Use @ref CANGAM_GAM */
    uint32_t gami;               /*!< CAN GAMI Setting
                                    : Use @ref CANGAM_GAMI */
} can_gam_t;

/*----------------------------------*/
/*! @struct can_mcr_t
    @brief  CAN MCR Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t sur;                /*!< SUR Setting
                                    : Use @ref CANMCR_SUR */
    uint32_t tstlb;              /*!< TSTLB Setting
                                    : Use @ref CANMCR_TSTLB */
    uint32_t tsterr;             /*!< TSTERR Setting
                                    : Use @ref CANMCR_TSTERR */
    uint32_t ccr;                /*!< CCR Setting
                                    : Use @ref CANMCR_CCR */
    uint32_t smr;                /*!< SMR Setting
                                    : Use @ref CANMCR_SMR */
    uint32_t wuba;               /*!< WUBA Setting
                                    : Use @ref CANMCR_WUBA */
    uint32_t mtos;               /*!< MTOS Setting
                                    : Use @ref CANMCR_MTOS */
} can_mcr_t;

/*----------------------------------*/
/*! @struct can_bcr2_t
    @brief  CAN BCR2 Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t sjw;                /*!< SJW Setting
                                    : Use @ref CANBCR2_SJW */
    uint32_t sam;                /*!< SAM Setting
                                    : Use @ref CANBCR2_SAM */
    uint32_t tseg2;              /*!< TSEG2 Setting
                                    : Use @ref CANBCR2_TSEG2 */
    uint32_t tseg1;              /*!< TSEG1 Setting
                                    : Use @ref CANBCR2_TSEG1 */
} can_bcr2_t;

/*----------------------------------*/
/*! @struct can_gif_t
    @brief  CAN GIF Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t rfpf;                /*!< RFPF Setting
                                     : Use @ref CANGIF_RFPF */
    uint32_t wuif;                /*!< WUIF Setting
                                     : Use @ref CANGIF_WUIF */
    uint32_t rmlif;               /*!< RMLIF Setting
                                     : Use @ref CANGIF_RMLIF */
    uint32_t trmabf;              /*!< TRMABF Setting
                                     : Use @ref CANGIF_TRMABF */
    uint32_t tsoif;               /*!< TSOIF Setting
                                     : Use @ref CANGIF_TSOIF */
    uint32_t boif;                /*!< BOIF Setting
                                     : Use @ref CANGIF_BOIF */
    uint32_t epif;                /*!< EPIF Setting
                                     : Use @ref CANGIF_EPIF */
    uint32_t wlif;                /*!< WLIF Setting
                                     : Use @ref CANGIF_WLIF */
} can_gif_t;

/*----------------------------------*/
/*! @struct can_gim_t
    @brief  CAN GIM Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t rfpm;                /*!< RFPM Setting
                                     : Use @ref CANGIM_RFPM */
    uint32_t wuim;                /*!< WUIM Setting
                                     : Use @ref CANGIM_WUIM */
    uint32_t rmlim;               /*!< RMLIM Setting
                                     : Use @ref CANGIM_RMLIM */
    uint32_t trmabf;              /*!< TRMABF Setting
                                     : Use @ref CANGIM_TRMABF */
    uint32_t tsoim;               /*!< TSOIM Setting
                                     : Use @ref CANGIM_TSOIM */
    uint32_t boim;                /*!< BOIM Setting
                                     : Use @ref CANGIM_BOIM */
    uint32_t epim;                /*!< EPIM Setting
                                     : Use @ref CANGIM_EPIM */
    uint32_t wlim;                /*!< WLIM Setting
                                     : Use @ref CANGIM_WLIM */
} can_gim_t;

/*----------------------------------*/
/*! @struct can_cec_t
    @brief  CAN CEC Register setting structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t tec;                /*!< CAN TEC Setting
                                    : TEC ( TEC =< CANCEC_TEC_MAX )   @ref CANCEC_TEC */
    uint32_t rec;                /*!< CAN REC Setting
                                    : REC ( REC =< CANCEC_REC_MAX )   @ref CANCEC_REC */
} can_cec_t;

/*----------------------------------*/
/*! @struct can_t
    @brief  CAN handle structure definenition.
*/
/*----------------------------------*/
typedef struct
{
    TSB_CAN_TypeDef           *p_instance;     /*!< Registers base address. */
    TSB_CANAMB_TypeDef        *p_instance2;    /*!< Registers base address. */
    can_id_t                  id;              /*!< CAN ID Register Setting
                                                  : Use @ref can_id_t */
    can_tsvmcf_t              tsvmcf;          /*!< CAN TSVMCF Register Setting
                                                  : Use @ref can_tsvmcf_t */
    can_data_t                transdata;       /*!< CAN Trans Data Register Setting
                                                  : Use @ref can_data_t */
    can_data_t                receivedata;     /*!< CAN Receive Data Register Setting
                                                  : Use @ref can_data_t */
    uint32_t                  mc;              /*!< CAN MC Register Setting */
    uint32_t                  md;              /*!< CAN MD Register Setting */
    uint32_t                  trs;             /*!< CAN TRS Register Setting */
    uint32_t                  trr;             /*!< CAN TRR Register Setting */
    uint32_t                  ta;              /*!< CAN TA Register Setting */
    uint32_t                  aa;              /*!< CAN AA Register Setting */
    uint32_t                  rmp;             /*!< CAN RMP Register Setting */
    uint32_t                  rml;             /*!< CAN RML Register Setting */
    can_lam_t                 lam;             /*!< CAN LAM Register Setting
                                                  : Use @ref can_lam_t */
    can_gam_t                 gam;             /*!< CAN GAM Register Setting
                                                  : Use @ref can_gam_t */
    can_mcr_t                 mcr;             /*!< CAN MCR Register Setting
                                                  : Use @ref can_mcr_t */
    uint16_t                  bcr1;            /*!< CAN BCR1 Register Setting */
    can_bcr2_t                bcr2;            /*!< CAN BCR2 Register Setting
                                                  : Use @ref can_bcr2_t */
    can_gif_t                 gif;             /*!< CAN GIF Register Setting
                                                  : Use @ref can_gif_t */
    can_gim_t                 gim;             /*!< CAN GIM Register Setting
                                                  : Use @ref can_gim_t */
    uint32_t                  mbtif;           /*!< CAN MBTIF Register Setting */
    uint32_t                  mbrif;           /*!< CAN MBRIF Register Setting */
    uint32_t                  mbim;            /*!< CAN MBIM Register Setting */
    uint32_t                  cdr;             /*!< CAN CDR Register Setting */
    uint32_t                  rfp;             /*!< CAN RFP Register Setting */
    can_cec_t                 cec;             /*!< CAN CEC Register Setting
                                                  : Use @ref can_cec_t */
    uint8_t                   tsp;             /*!< CAN Timer Stanp Register Setting */
} can_t;
/**
 *  @}
 */ /* End of group CAN_Exported_typedef */

/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @defgroup CAN_Exported_functions CAN Exported Functions
 *  @{
 */
TXZ_Result can_set_id(can_t *p_obj);
TXZ_Result can_set_tsvmcf(can_t *p_obj);
TXZ_Result can_set_transdata(can_t *p_obj);
TXZ_Result can_get_receivedata(can_t *p_obj);
TXZ_Result can_get_mc(can_t *p_obj, uint32_t *p_mc);
TXZ_Result can_set_mc(can_t *p_obj);
TXZ_Result can_get_md(can_t *p_obj, uint32_t *p_md);
TXZ_Result can_set_md(can_t *p_obj);
TXZ_Result can_get_trs(can_t *p_obj, uint32_t *p_trs);
TXZ_Result can_set_trs(can_t *p_obj);
TXZ_Result can_set_trr(can_t *p_obj);
TXZ_Result can_get_ta(can_t *p_obj, uint32_t *p_ta);
TXZ_Result can_set_ta(can_t *p_obj);
TXZ_Result can_set_aa(can_t *p_obj);
TXZ_Result can_get_rmp(can_t *p_obj, uint32_t *p_rmp);
TXZ_Result can_set_rmp(can_t *p_obj);
TXZ_Result can_set_rml(can_t *p_obj);
TXZ_Result can_set_lam(can_t *p_obj);
TXZ_Result can_set_gam(can_t *p_obj);
TXZ_Result can_set_mcr(can_t *p_obj);
TXZ_Result can_set_counter_clear(can_t *p_obj);
TXZ_Result can_set_software_reset(can_t *p_obj);
TXZ_Result can_get_gsr(can_t *p_obj, uint32_t *p_gsr);
TXZ_Result can_set_bcr1(can_t *p_obj);
TXZ_Result can_set_bcr2(can_t *p_obj);
TXZ_Result can_set_gif(can_t *p_obj);
TXZ_Result can_set_gim(can_t *p_obj);
TXZ_Result can_set_mbtif(can_t *p_obj);
TXZ_Result can_set_mbrif(can_t *p_obj);
TXZ_Result can_set_mbim(can_t *p_obj);
TXZ_Result can_set_cdr(can_t *p_obj);
TXZ_Result can_set_rfp(can_t *p_obj);
TXZ_Result can_get_cec(can_t *p_obj, uint32_t *p_cec);
TXZ_Result can_set_cec(can_t *p_obj);
TXZ_Result can_set_tsp(can_t *p_obj);
TXZ_Result can_get_tsc(can_t *p_obj, uint16_t *p_tsc);
/**
 *  @}
 */ /* End of group CAN_Exported_functions */

/**
 *  @}
 */ /* End of group CAN */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __CAN_B_H */


