/**
 *******************************************************************************
 * @file    siwdt_a.c
 * @brief   This file provides API functions for SIWDT.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "siwdt.h"

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @defgroup SIWDT SIWDT
 *  @brief    SIWDT Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_macro
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SIWDT_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_define
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SIWDT_Private_define */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_define
 *  @{
 */

/** 
 *  @defgroup Null Null Pointer
 *  @brief    Null Pointer.
 *  @{
 */
#define REG_SIWDT_NULL                  ((void *)0)
/**
 *  @}
 */ /* End of group Null */

/** 
 *  @defgroup WDT_ParameterResult  Parameter Check Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define WDT_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define WDT_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group WDT_ParameterResult */

/** 
 *  @defgroup CheckParamResult Parameter Check Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define REG_SIWDT_PARAM_OK              ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define REG_SIWDT_PARAM_NG              ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of name Parameter CheckParamResult */


#define SIWDxMOD_WDCLS_MASK             ((uint32_t)0xFFFFCFFF)    /*!< WDCLS Mask */

#define SIWDxMOD_WDTP_MASK              ((uint32_t)0xFFFFF8FF)    /*!< WDTP Mask */

#define SIWDxMOD_WDCWD_MASK             ((uint32_t)0xFFFFFFCF)    /*!< WDCMD Mask */

#define SIWDxMOD_INTF_CLEAR             ((uint32_t)0x00000002)    /*!< INTF Clear */
#define SIWDxMOD_INTF_MASK              ((uint32_t)0xFFFFFFFD)    /*!< INTF Mask */

#define SIWDxMOD_RESCR_MASK             ((uint32_t)0xFFFFFFFE)    /*!< RESCR Mask */

#define SIWDxEN_WDTF_MASK               ((uint32_t)0xFFFFFFFD)    /*!< WDTF Mask */

#define SIWDxPRO_PROTECT_MASK           ((uint32_t)0xFFFFFF00)    /*!< PROTECT Mask */

#define SIWDxPRO_GET_PROTECT_MASK       ((uint32_t)0x000000FF)    /*!< Get PROTECT Mask */
/** 
 *  @}
 */ /* End of group SIWDT_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_define
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SIWDT_Private_define */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_typedef
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SIWDT_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_variables
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group SIWDT_Private_variables */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_fuctions
 *  @{
 */
#ifdef __DEBUG__
__STATIC_INLINE int32_t check_param_wdcls(uint32_t param);
__STATIC_INLINE int32_t check_param_wdtp(uint32_t param);
__STATIC_INLINE int32_t check_param_wdcwd(uint32_t param);
__STATIC_INLINE int32_t check_param_rescr(uint32_t param);
__STATIC_INLINE int32_t check_param_protect(uint32_t param);
#endif /* #ifdef __DEBUG__ */

#ifdef __DEBUG__
/*--------------------------------------------------*/
/*!
  * @fn     static int32_t check_param_wdcls(uint32_t param)
  * @brief  Check the WDCLS's parameter.
  * @param[in] param :WDCLS's parameter
  * @retval    WDT_PARAM_OK :Success.
  * @retval    WDT_PARAM_NG :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wdcls(uint32_t param)
{
    int32_t result = WDT_PARAM_NG;

    switch (param) 
    {
    case SIWDxMOD_WDCLS_FSYS:
    case SIWDxMOD_WDCLS_FIHOSC1:
    case SIWDxMOD_WDCLS_FIHOSC2:
        result = WDT_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/*!
  * @fn     static int32_t check_param_wdtp(uint32_t param)
  * @brief  Check the WDTP's parameter.
  * @param[in] param :WDTP's parameter
  * @retval    WDT_PARAM_OK :Success.
  * @retval    WDT_PARAM_NG :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wdtp(uint32_t param)
{
    int32_t result = WDT_PARAM_NG;

    switch (param) 
    {
    case SIWDxMOD_WDTP_2_15:
    case SIWDxMOD_WDTP_2_17:
    case SIWDxMOD_WDTP_2_19:
    case SIWDxMOD_WDTP_2_21:
    case SIWDxMOD_WDTP_2_23:
    case SIWDxMOD_WDTP_2_25:
    case SIWDxMOD_WDTP_2_27:
    case SIWDxMOD_WDTP_2_29:
        result = WDT_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/*!
  * @fn     static int32_t check_param_wdcwd(uint32_t param)
  * @brief  Check the WDCWD's parameter.
  * @param[in] param :WDCWD's parameter
  * @retval    WDT_PARAM_OK :Success.
  * @retval    WDT_PARAM_NG :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_wdcwd(uint32_t param)
{
    int32_t result = WDT_PARAM_NG;

    switch (param) 
    {
    case SIWDxMOD_WDCWD_NONE:
    case SIWDxMOD_WDCWD_2:
    case SIWDxMOD_WDCWD_4:
        result = WDT_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/*!
  * @fn     static int32_t check_param_rescr(uint32_t param)
  * @brief  Check the RESCR's parameter.
  * @param[in] param :RESCR's parameter
  * @retval    WDT_PARAM_OK :Success.
  * @retval    WDT_PARAM_NG :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_rescr(uint32_t param)
{
    int32_t result = WDT_PARAM_NG;

    switch (param) 
    {
    case SIWDxMOD_RESCR_INT:
    case SIWDxMOD_RESCR_RESET:
        result = WDT_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}

/*--------------------------------------------------*/
/*!
  * @fn     static int32_t check_param_protect(uint32_t param)
  * @brief  Check the PROTECT's parameter.
  * @param[in] param :PROTECT's parameter
  * @retval    WDT_PARAM_OK :Success.
  * @retval    WDT_PARAM_NG :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_protect(uint32_t param)
{
    int32_t result = WDT_PARAM_NG;

    switch (param) 
    {
    case SIWDxPRO_PROTECT_NONE:
    case SIWDxPRO_PROTECT_A:
    case SIWDxPRO_PROTECT_B:
        result = WDT_PARAM_OK;
        break;
    default:
        /* no process */
        break;
    }

    return (result);
}
#endif /* #ifdef __DEBUG__ */
/**
 *  @}
 */ /* End of group SIWDT_Private_fuctions */


/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Exported_functions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  WDT Disable
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_disable(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    p_reg->EN = SIWDxEN_WDTE_RW_DISABLE;
    p_reg->CR = SIWDxCR_WDCR_W_DISABLE;
}


/*--------------------------------------------------*/
/** 
  * @brief  WDT Enable
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_enable(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    p_reg->EN = SIWDxEN_WDTE_RW_ENABLE;
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT Clear
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_clear(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    p_reg->CR = SIWDxCR_WDCR_W_CLEAR;
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT get flag
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t wdt_get_flag(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    return(p_reg->EN & SIWDxEN_WDTF_MASK);
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT WDCLS Set
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_wdcls_set(TSB_SIWD_TypeDef *p_reg, uint32_t wdcls)
{
    uint32_t regval = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
    assert_param(check_param_wdcls(wdcls));
#endif /* #ifdef __DEBUG__ */

    regval = p_reg->MOD & SIWDxMOD_WDCLS_MASK;
    regval |= wdcls;
    p_reg->MOD = regval;
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT WDTP Set
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_wdtp_set(TSB_SIWD_TypeDef *p_reg, uint32_t wdtp)
{
    uint32_t regval = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
    assert_param(check_param_wdtp(wdtp));
#endif /* #ifdef __DEBUG__ */

    regval = p_reg->MOD & SIWDxMOD_WDTP_MASK;
    regval |= wdtp;
    p_reg->MOD = regval;
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT WDCWD Set
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_wdcwd_set(TSB_SIWD_TypeDef *p_reg, uint32_t wdcwd)
{
    uint32_t regval = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
    assert_param(check_param_wdcwd(wdcwd));
#endif /* #ifdef __DEBUG__ */

    regval = p_reg->MOD & SIWDxMOD_WDCWD_MASK;
    regval |= wdcwd;
    p_reg->MOD = regval;
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT INTF Clear
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_intf_clear(TSB_SIWD_TypeDef *p_reg)
{
    uint32_t regval = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    regval = p_reg->MOD;
    regval |= SIWDxMOD_INTF_CLEAR;
    p_reg->MOD = regval;
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT get INTF
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t wdt_get_intf(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    return(p_reg->MOD & SIWDxMOD_INTF_MASK);
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT RESCR Set
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_rescr_set(TSB_SIWD_TypeDef *p_reg, uint32_t rescr)
{
    uint32_t regval = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
    assert_param(check_param_rescr(rescr));
#endif /* #ifdef __DEBUG__ */

    regval = p_reg->MOD & SIWDxMOD_RESCR_MASK;
    regval |= rescr;
    p_reg->MOD = regval;
}

#if (OSCCR_REGISTER_EQUIPPED == AVAILABLE)
/*--------------------------------------------------*/
/** 
  * @brief  WDT Protect Disable
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_protect_disable(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    while(wdt_get_flag(p_reg) != SIWDxEN_WDTF_STOP);
    if(wdt_get_protect(p_reg) == SIWDxPRO_PROTECT_NONE)
    {
        p_reg->OSCCR = SIWDxOSCCR_OSCPRO_DISABLE;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT Protect Enable
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_protect_enable(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    while(wdt_get_flag(p_reg) != SIWDxEN_WDTF_STOP);
    if(wdt_get_protect(p_reg) == SIWDxPRO_PROTECT_NONE)
    {
        p_reg->OSCCR = SIWDxOSCCR_OSCPRO_ENABLE;
    }
}
#endif /* #if (OSCCR_REGISTER_EQUIPPED == AVAILABLE) */

/*--------------------------------------------------*/
/** 
  * @brief  WDT get PROTECT
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t wdt_get_protect(TSB_SIWD_TypeDef *p_reg)
{
    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
#endif /* #ifdef __DEBUG__ */

    return(p_reg->PRO & SIWDxPRO_GET_PROTECT_MASK);
}

/*--------------------------------------------------*/
/** 
  * @brief  WDT RESCR Set
  * @param  p_reg   :Register Base Address.
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wdt_protect_set(TSB_SIWD_TypeDef *p_reg, uint32_t protect)
{
    uint32_t regval = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the SIWDT_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_reg));
    assert_param(check_param_protect(protect));
#endif /* #ifdef __DEBUG__ */

    regval = p_reg->PRO & SIWDxPRO_PROTECT_MASK;
    regval |= protect;
    p_reg->PRO = regval;
}

/**
 *  @}
 */ /* End of group SIWDT_Exported_functions */

/**
 *  @}
 */ /* End of group SIWDT */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */


