/**
 *******************************************************************************
 * @file    trgsel.c
 * @brief   This file provides API functions for TRGSEL.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2022
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "trgsel.h"

#if defined(__TRGSEL_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup TRGSEL
 *  @brief      TRGSEL Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TRGSEL_Private_macro
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group TRGSEL_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TRGSEL_Private_define
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group TRGSEL_Private_define */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TRGSEL_Private_define
 *  @{
 */
#define CR_FEATURES         4
#define FEATURE_SIZE        8
#define INSEL_LOCATE        4
#define UPDN_LOCATE         2
#define OUTSEL_LOCATE       1
#define EN_LOCATE           0
#define CR_SIZE_SHIFT       2
#define TRGSEL_MASK         0xFF
/** 
 *  @}
 */ /* End of group TRGSEL_Private_define */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TRGSEL_Private_fuctions
 *  @{
 */
#ifdef __DEBUG__
    __STATIC_INLINE int32_t check_param_trgsel_num(uint32_t param);


/*--------------------------------------------------*/
/*!
  * @fn     static int32_t check_param_trgsel_num(uint32_t param)
  * @brief  Check the TRGSEL INSEL's parameter.
  * @param[in] param :TRGSEL INSEL's parameter
  * @retval    TRGSEL_PARAM_OK :Success.
  * @retval    TRGSEL_PARAM_NG :Failure.
  * @note   -
  */
/*--------------------------------------------------*/
__STATIC_INLINE int32_t check_param_trgsel_num(uint32_t param)
{
    int32_t result = TRGSEL_PARAM_NG;

    if(param < TRGSEL_MAX){
        result = TRGSEL_PARAM_OK;
    }else{
        /*do nothing */
    }

    return (result);
}
#endif /* #ifdef __DEBUG__ */

/**
 *  @}
 */ /* End of group TRGSEL_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TRGSEL_Exported_functions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  Set TRGSEL register
  * @param  p_obj trgsel object
  * @param  num trgsel number
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
TXZ_Result set_trgsel(trgsel_t *p_obj, uint32_t num)
{
    uint32_t reg = 0;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the LVD_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_trgsel_num(num));
#endif /* #ifdef __DEBUG__ */

    uint32_t *address = (uint32_t *)p_obj->p_instance;
    uint8_t modnum = num % CR_FEATURES;

    if(!(trgsel_table[num / VARIABLE_SIZE] & (1 << (num % VARIABLE_SIZE)))){
        return TXZ_ERROR;
    }

    if(!(insel_table[num] & (1 << p_obj->init.insel))){
        return TXZ_ERROR;
    }
    
    num = num % TRGSEL_CH_SIZE;

    address = (uint32_t *)((uint32_t)address | ((num / CR_FEATURES) << CR_SIZE_SHIFT));

    reg = *address & ~(TRGSEL_MASK << (modnum * FEATURE_SIZE));
    reg |= p_obj->init.insel << (modnum * FEATURE_SIZE + INSEL_LOCATE);
    *address = reg;
    reg |= p_obj->init.updn << (modnum * FEATURE_SIZE + UPDN_LOCATE);
    *address = reg;
    reg |= p_obj->init.outsel << (modnum * FEATURE_SIZE + OUTSEL_LOCATE);
    *address = reg;
    reg |= p_obj->init.en << (modnum * FEATURE_SIZE + EN_LOCATE);
    *address |= reg;

    return TXZ_SUCCESS;
}

/*--------------------------------------------------*/
/** 
  * @brief  Get trgsel value
  * @param  p_obj trgsel object
  * @param  num trgsel number
  * @retval trgsel value
  * @note   -
  */
/*--------------------------------------------------*/
trgsel_obj_t get_trgsel(trgsel_t *p_obj, uint32_t num)
{
    trgsel_obj_t retval;

    /*------------------------------*/
    /*  Parameter Check             */
    /*------------------------------*/
#ifdef __DEBUG__
    /* Check the LVD_NULL of address. */
    assert_param(IS_POINTER_NOT_NULL(p_obj));
    assert_param(IS_POINTER_NOT_NULL(p_obj->p_instance));
    assert_param(check_param_trgsel_num(num));
#endif /* #ifdef __DEBUG__ */

    uint32_t *address = (uint32_t *)p_obj->p_instance;
    uint8_t modnum = num % CR_FEATURES;
    num = num % TRGSEL_CH_SIZE;

    address = (uint32_t *)((uint32_t)address | ((num / CR_FEATURES) << CR_SIZE_SHIFT));

    if(*address & (1 << (modnum * FEATURE_SIZE + EN_LOCATE))){
        retval.en = TRGSEL_ENABLE;
    } else {
        retval.en = TRGSEL_DISABLE;
    }
    if(*address & (1 << (modnum * FEATURE_SIZE + OUTSEL_LOCATE))){
        retval.outsel = TRGSEL_OUTSEL_DETECT;
    } else {
        retval.outsel = TRGSEL_OUTSEL_UNDETECT;
    }
    if(*address & (1 << (modnum * FEATURE_SIZE + UPDN_LOCATE))){
        retval.updn = TRGSEL_UPDN_FALLING;
    } else {
        retval.updn = TRGSEL_UPDN_RISING;
    }
    retval.insel = (trgsel_insel_t)(*address >> (modnum * FEATURE_SIZE + INSEL_LOCATE));
    return retval;
}

/**
 *  @}
 */ /* End of group TRGSEL_Exported_functions */

/**
 *  @}
 */ /* End of group TRGSEL */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__TRGSEL_H)  */
#ifdef __cplusplus
}
#endif /* __cplusplus */
